/**
 * 指定のアイテムの装備数を取得する.
 * @param itemId アイテムＩＤ
 * @param rgnId  装備箇所ＩＤ（未指定時はすべて）
 * @returns 装備数
 */
function EquipNumSearch(itemId, rgnId) {
//function EquipNumSearch(itemId, rgnId == EQUIP_REGION_ID_ANY) {

	// 仮引数に未対応のブラウザ対策
	if (rgnId == undefined) {
		rgnId = EQUIP_REGION_ID_ANY;
	}

	var itemNum = 0;

	// 全ての装着部位を走査して、指定のアイテムＩＤの数を数える
	if (rgnId == EQUIP_REGION_ID_ANY) {
		for (var idx = 0; idx < n_A_Equip.length; idx++) {
			if (itemId == n_A_Equip[idx]) {
				itemNum += 1;
			}
		}
	}

	// または、指定の装備部位を走査する
	else {
		if (itemId == n_A_Equip[rgnId]) {
			itemNum += 1;
		}
	}

	return itemNum;
}



/**
 * 指定のカードの装備数を取得する.
 * @param cardId カードＩＤ
 * @param rgnId  装備箇所ＩＤ（未指定時はすべて）
 * @returns 装備数
 */
function CardNumSearch(cardId, rgnId) {
//function CardNumSearch(cardId, rgnId = CARD_REGION_ID_ANY) {

	// 仮引数に未対応のブラウザ対策
	if (rgnId == undefined) {
		rgnId = CARD_REGION_ID_ANY;
	}

	var cardNum = 0;

	// 全ての装着部位を走査して、指定のカードＩＤの数を数える
	if (rgnId == CARD_REGION_ID_ANY) {
		for (var idx = 0; idx < n_A_card.length; idx++) {
			if(cardId == n_A_card[idx]) {
				cardNum += 1;
			}
		}
	}

	// または、指定の装備部位を走査する
	else if (rgnId < 0) {
		switch (rgnId) {
		case CARD_REGION_ID_ARMS_RIGHT_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_RIGHT_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_RIGHT_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_RIGHT_3]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_RIGHT_4]) cardNum += 1;
			break;

		case CARD_REGION_ID_ARMS_LEFT_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_LEFT_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_LEFT_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_LEFT_3]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ARMS_LEFT_4]) cardNum += 1;
			break;

		case CARD_REGION_ID_HEAD_TOP_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_HEAD_TOP]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_HEAD_MID_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_HEAD_MID]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_HEAD_UNDER_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_HEAD_UNDER]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_SHIELD_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_SHIELD]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_BODY_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_BODY]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_BODY_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_BODY_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_BODY_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_SHOULDER_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_SHOULDER]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_SHOES_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_SHOES]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_ACCESSARY_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_ACCESSARY_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_3]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ACCESSARY_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_ACCESSARY_1_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_ACCESSARY_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_3]) cardNum += 1;
			break;

		case CARD_REGION_ID_ACCESSARY_2_ANY:
			if (cardId == n_A_card[CARD_REGION_ID_ACCESSARY_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_1]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_2]) cardNum += 1;
			if (cardId == n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_3]) cardNum += 1;
			break;
		}
	}

	// または、指定の装備部位（１箇所）を走査する
	else {
		if (cardId == n_A_card[rgnId]) {
			cardNum += 1;
		}
	}

	return cardNum;
}





EXBUF_ID_ASUMUPTIO						 =  2050000;
EXBUF_ID_IDUNNNO_RINGO					 =  3030001;
EXBUF_ID_IDUNNNO_RINGO_BUFFER_VITRANK	 =  3030002;
EXBUF_ID_IDUNNNO_RINGO_BUFFER_SKILLLV	 =  3030003;
EXBUF_ID_HUMMING						 =  3040001;
EXBUF_ID_HUMMING_BUFFER_DEXRANK			 =  3040002;
EXBUF_ID_HUMMING_BUFFER_SKILLLV			 =  3040003;
EXBUF_ID_SERVICE_FOR_YOU				 =  3060001;
EXBUF_ID_SERVICE_FOR_YOU_BUFFER_INTRANK	 =  3060002;
EXBUF_ID_SERVICE_FOR_YOU_BUFFER_SKILLLV	 =  3060003;
EXBUF_ID_IKUSADAIKONO_HIBIKI			 =  3090001;
EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI		 =  3190101;
EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_JOBLV		 =  3190102;
EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_SKILLLV	 =  3190103;
EXBUF_ID_ECHONO_UTA						 =  3190201;
EXBUF_ID_ECHONO_UTA_BUFFER_JOBLV		 =  3190202;
EXBUF_ID_ECHONO_UTA_BUFFER_SKILLLV		 =  3190203;
EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY	 =  3190501;
EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_JOBLV			 =  3190502;
EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_SKILLLV		 =  3190503;
EXBUF_ID_FRIGGNO_UTA					 =  3190700;
EXBUF_ID_FRYDAY_NIGHT_FEVER				 =  3390100;
EXBUF_ID_RELAZUNO_TSUYU					 =  3390301;
EXBUF_ID_RELAZUNO_TSUYU_COUNT_OF_MINWAN	 =  3390302;
EXBUF_ID_BEYOND_OF_WARCRAY				 =  3390401;
EXBUF_ID_BEYOND_OF_WARCRAY_COUNT_OF_MINWAN			 =  3390401;
EXBUF_ID_DANCE_WITH_WUG					 =  3390601;
EXBUF_ID_DANCE_WITH_WUG_COUNT_OF_MINWAN	 =  3390602;
EXBUF_ID_GOSPEL_HP_UP					 =  4060000;
EXBUF_ID_GOSPEL_SP_UP					 =  4070000;
EXBUF_ID_GOSPEL_HIT_FLEE_PLUS			 =  4090000;
EXBUF_ID_DELUGE							 =  6000100;
EXBUF_ID_ZYUTSUSHIKI_TENKAI				 =  6100000;
EXBUF_ID_FIGHTING_SPIRIT				 =  6110000;
EXBUF_ID_ODINNO_CHIKARA					 =  6120000;
EXBUF_ID_ODINNO_EPICLESIS				 =  6130000;
EXBUF_ID_HOM_S_PAINKILLER				 =  6210001;
EXBUF_ID_HOM_S_PAINKILLER_HOM_LEVEL		 =  6210002;
EXBUF_ID_CHAGASHI						 =  7000000;
EXBUF_ID_NIZIIRONO_OKASHI				 =  7020000;
EXBUF_ID_URAMINO_HAKO					 =  7090000;
EXBUF_ID_VITATA500						 =  7240000;
EXBUF_ID_BUCHE_DE_NOEL					 =  7250000;
EXBUF_ID_RUNEMIDGARTSSAN_OYATSU			 =  7260000;
EXBUF_ID_SCHWARZWALDSAN_OYATSU			 =  7270000;
EXBUF_ID_GUARANA_CANDY					 =  7350000;
EXBUF_ID_YAKITOMOROKOSHI				 =  7360000;
EXBUF_ID_HPZOKA_POTION					 =  7380000;
EXBUF_ID_SPZOKA_POTION					 =  7390000;
EXBUF_ID_SENTOYAKU						 =  7410000;
EXBUF_ID_EVENT_BUF_ATK_PLUS				 =  7420000;
EXBUF_ID_EVENT_BUF_HIT_PLUS				 =  7440000;
EXBUF_ID_ORLEANS_FULLCOURSE				 =  7490000;
EXBUF_ID_OTP_LOGIN_BONUS				 =  8220400;
EXBUF_ID_QUEPET_RUBYRIT					 =  8510000;
EXBUF_ID_QUEPET_SAFARIT					 =  8520000;
EXBUF_ID_QUEPET_EMERIT					 =  8530000;
EXBUF_ID_QUEPET_TOPARIT					 =  8540000;
EXBUF_ID_CUSTOM_HIT_PLUS				 =  9100000;
EXBUF_ID_CUSTOM_ATK_PLUS				 =  9170000;
EXBUF_ID_CUSTOM_HP_PLUS					 = 10010000;
EXBUF_ID_CUSTOM_HP_UP					 = 10030000;
EXBUF_ID_CUSTOM_SP_PLUS					 = 10040000;
EXBUF_ID_CUSTOM_SP_UP					 = 10060000;
EXBUF_ID_CUSTOM_DEF_PLUS				 = 10070000;
EXBUF_ID_CUSTOM_MDEF_PLUS				 = 10080000;
/**
 * 指定の外支援Ｂｕｆｆの効果値（レベル、補正値等）を取得する.
 * （自身の習得しているスキルは含まない）
 * @param exBufId 外支援ＢｕｆｆＩＤ
 * @returns 効果値（レベル、補正値等）
 */

function ExBuffNumSearch(exBufId) {

	var exBufNum = 0;


	switch (exBufId) {

	// 支援アスムプティオ
	case EXBUF_ID_ASUMUPTIO:
		exBufNum = n_A_PassSkill2[5];
		break;

	}



	switch (exBufId) {

	// 支援イドゥンの林檎
	case EXBUF_ID_IDUNNNO_RINGO:
		exBufNum = n_A_PassSkill3[3];
		break;

	// 支援イドゥンの林檎　支援者ＶＩＴランク
	case EXBUF_ID_IDUNNNO_RINGO_BUFFER_VITRANK:
		if (n_A_PassSkill3[3]) exBufNum = n_A_PassSkill3[23];
		break;

	// 支援イドゥンの林檎　支援者補助スキルレベル
	case EXBUF_ID_IDUNNNO_RINGO_BUFFER_SKILLLV:
		if (n_A_PassSkill3[3]) exBufNum = n_A_PassSkill3[33];
		break;

	// 支援ハミング
	case EXBUF_ID_HUMMING:
		exBufNum = n_A_PassSkill3[4];
		break;

	// 支援ハミング　支援者ＤＥＸランク
	case EXBUF_ID_HUMMING_BUFFER_DEXRANK:
		if (n_A_PassSkill3[3]) exBufNum = n_A_PassSkill3[24];
		break;

	// 支援ハミング　支援者補助スキルレベル
	case EXBUF_ID_HUMMING_BUFFER_SKILLLV:
		if (n_A_PassSkill3[3]) exBufNum = n_A_PassSkill3[34];
		break;

	// 支援サービスフォーユー
	case EXBUF_ID_SERVICE_FOR_YOU:
		exBufNum = n_A_PassSkill3[6];
		break;

	// 支援サービスフォーユー　支援者ＩＮＴランク
	case EXBUF_ID_SERVICE_FOR_YOU_BUFFER_INTRANK:
		if (n_A_PassSkill3[6]) exBufNum = n_A_PassSkill3[26];
		break;

	// 支援サービスフォーユー　支援者補助スキルレベル
	case EXBUF_ID_SERVICE_FOR_YOU_BUFFER_SKILLLV:
		if (n_A_PassSkill3[6]) exBufNum = n_A_PassSkill3[36];
		break;

	// 支援戦太鼓の響き
	case EXBUF_ID_IKUSADAIKONO_HIBIKI:
		exBufNum = n_A_PassSkill3[9];
		break;

	// 支援風車に向かって突撃
	case EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI:
		if (n_A_PassSkill3[19] == 1) exBufNum = n_A_PassSkill3[37];
		break;

	// 支援風車に向かって突撃　支援者ジョブレベル
	case EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_JOBLV:
		if (n_A_PassSkill3[19] == 1) exBufNum = n_A_PassSkill3[46];
		break;

	// 支援風車に向かって突撃　支援者補助スキルレベル
	case EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_SKILLLV:
		if (n_A_PassSkill3[19] == 1) exBufNum = n_A_PassSkill3[38];
		break;

	// 支援エコーの歌
	case EXBUF_ID_ECHONO_UTA:
		if (n_A_PassSkill3[19] == 2) exBufNum = n_A_PassSkill3[37];
		break;

	// 支援エコーの歌　支援者ジョブレベル
	case EXBUF_ID_ECHONO_UTA_BUFFER_JOBLV:
		if (n_A_PassSkill3[19] == 2) exBufNum = n_A_PassSkill3[46];
		break;

	// 支援エコーの歌　支援者補助スキルレベル
	case EXBUF_ID_ECHONO_UTA_BUFFER_SKILLLV:
		if (n_A_PassSkill3[19] == 2) exBufNum = n_A_PassSkill3[38];
		break;

	// 支援恋人たちのためのシンフォニー
	case EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY:
		if (n_A_PassSkill3[19] == 5) exBufNum = n_A_PassSkill3[37];
		break;

	// 支援恋人たちのためのシンフォニー　支援者ジョブレベル
	case EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_JOBLV:
		if (n_A_PassSkill3[19] == 5) exBufNum = n_A_PassSkill3[46];
		break;

	// 支援恋人たちのためのシンフォニー　支援者補助スキルレベル
	case EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_SKILLLV:
		if (n_A_PassSkill3[19] == 5) exBufNum = n_A_PassSkill3[38];
		break;

	// 支援フリッグの歌
	case EXBUF_ID_FRIGGNO_UTA:
		if (n_A_PassSkill3[19] == 7) exBufNum = n_A_PassSkill3[37];
		break;



	// 支援フライデーナイトフィーバー
	case EXBUF_ID_FRYDAY_NIGHT_FEVER:
		if (n_A_PassSkill3[39] == 1) exBufNum = n_A_PassSkill3[40];
		break;

	// 支援レーラズの露
	case EXBUF_ID_RELAZUNO_TSUYU:
		if (n_A_PassSkill3[39] == 3) exBufNum = n_A_PassSkill3[40];
		break;

	// 支援レーラズの露　ミンストレルワンダラーの数
	case EXBUF_ID_RELAZUNO_TSUYU_COUNT_OF_MINWAN:
		if (n_A_PassSkill3[39] == 3) exBufNum = n_A_PassSkill3[41];
		break;

	// 支援ビヨンドオブウォークライ（敵から）
	case EXBUF_ID_BEYOND_OF_WARCRAY:
		if (n_A_PassSkill3[39] == 4) exBufNum = n_A_PassSkill3[40];
		break;

	// 支援ビヨンドオブウォークライ（敵から）　ミンストレルワンダラーの数
	case EXBUF_ID_BEYOND_OF_WARCRAY_COUNT_OF_MINWAN:
		if (n_A_PassSkill3[39] == 4) exBufNum = n_A_PassSkill3[41];
		break;

	// 支援ダンスウィズウォーグ（レンジャー有）
	case EXBUF_ID_DANCE_WITH_WUG:
		if (n_A_PassSkill3[39] == 6) exBufNum = n_A_PassSkill3[40];
		break;

	// 支援ダンスウィズウォーグ（レンジャー有）　ミンストレルワンダラーの数
	case EXBUF_ID_DANCE_WITH_WUG_COUNT_OF_MINWAN:
		if (n_A_PassSkill3[39] == 6) exBufNum = n_A_PassSkill3[41];
		break;

	}



	switch (exBufId) {

	// 支援ゴスペル　ＨＰアップ
	case EXBUF_ID_GOSPEL_HP_UP:
		if (n_A_PassSkill4[6]) exBufNum += 1;
		break;

	// 支援ゴスペル　ＳＰアップ
	case EXBUF_ID_GOSPEL_SP_UP:
		if (n_A_PassSkill4[7]) exBufNum += 1;
		break;

	// 支援ゴスペル　ＨＩＴ、ＦＬＥＥ＋
	case EXBUF_ID_GOSPEL_HIT_FLEE_PLUS:
		if (n_A_PassSkill4[9]) exBufNum += 1;
		break;


	}



	switch (exBufId) {

	// 支援デリュージ
	case EXBUF_ID_DELUGE:
		if (n_A_PassSkill6[0] == 1) exBufNum = n_A_PassSkill6[1];
		break;

	// 支援術式-展開-
	case EXBUF_ID_ZYUTSUSHIKI_TENKAI:
		exBufNum = n_A_PassSkill6[10];
		break;

	// 支援ファイティングスピリット
	case EXBUF_ID_FIGHTING_SPIRIT:
		exBufNum = n_A_PassSkill6[11];
		break;

	// 支援オーディンの力
	case EXBUF_ID_ODINNO_CHIKARA:
		exBufNum = n_A_PassSkill6[12];
		break;

	// 支援エピクレシス
	case EXBUF_ID_ODINNO_EPICLESIS:
		exBufNum = n_A_PassSkill6[13];
		break;

	// 支援ホムＳペインキラー
	case EXBUF_ID_HOM_S_PAINKILLER:
		exBufNum = n_A_PassSkill6[21];
		break;

	// 支援ホムＳペインキラー　ホムンクルスのレベル
	case EXBUF_ID_HOM_S_PAINKILLER_HOM_LEVEL:
		if (n_A_PassSkill6[21] > 0) exBufNum = n_A_PassSkill6[30];
		break;

	}



	switch (exBufId) {
	// 茶菓子
	case EXBUF_ID_CHAGASHI:
		if (n_A_PassSkill7[0]) exBufNum += 1;
		break;


	// 虹色のお菓子
	case EXBUF_ID_NIZIIRONO_OKASHI:
		if (n_A_PassSkill7[2]) exBufNum += 1;
		break;

	// 恨みの箱
	case EXBUF_ID_URAMINO_HAKO:
		if (n_A_PassSkill7[9]) exBufNum += 1;
		break;

	// ビタタ５００
	case EXBUF_ID_VITATA500:
		if (n_A_PassSkill7[24]) exBufNum += 1;
		break;

	// ビュッシュ・ド・ノエル
	case EXBUF_ID_BUCHE_DE_NOEL:
		if (n_A_PassSkill7[25]) exBufNum += 1;
		break;

	// ルーンミッドガッツ産おやつ
	case EXBUF_ID_RUNEMIDGARTSSAN_OYATSU:
		if (n_A_PassSkill7[26]) exBufNum += 1;
		break;

	// シュバルツバルド産おやつ
	case EXBUF_ID_SCHWARZWALDSAN_OYATSU:
		if (n_A_PassSkill7[27]) exBufNum += 1;
		break;

	// ガラナキャンディ
	case EXBUF_ID_GUARANA_CANDY:
		if (n_A_PassSkill7[35]) exBufNum += 1;
		break;

	// 焼きトウモロコシ
	case EXBUF_ID_YAKITOMOROKOSHI:
		if (n_A_PassSkill7[36]) exBufNum += 1;
		break;

	// ＨＰ増加ポーション
	case EXBUF_ID_HPZOKA_POTION:
		exBufNum = n_A_PassSkill7[38];
		break;

	// ＳＰ増加ポーション
	case EXBUF_ID_SPZOKA_POTION:
		exBufNum = n_A_PassSkill7[39];
		break;

	// オルレアンのフルコース
	case EXBUF_ID_ORLEANS_FULLCOURSE:
		if (n_A_PassSkill7[49]) exBufNum += 1;
		break;

	// 戦闘薬
	case EXBUF_ID_SENTOYAKU:
		exBufNum = n_A_PassSkill7[41];
		break;

	// 期間限定イベント支援　ＡＴＫ
	case EXBUF_ID_EVENT_BUF_ATK_PLUS:
		exBufNum = n_A_PassSkill7[42];
		break;

	// 期間限定イベント支援　ＨＩＴ
	case EXBUF_ID_EVENT_BUF_HIT_PLUS:
		exBufNum = n_A_PassSkill7[44];
		break;

	}



	switch (exBufId) {

	// ＯＴＰログインボーナス支援
	case EXBUF_ID_OTP_LOGIN_BONUS:
		exBufNum = n_A_PassSkill8[22];
		break;

	// キューペット　ルビリット
	case EXBUF_ID_QUEPET_RUBYRIT:
		if (n_A_PassSkill8[0] == 51) exBufNum = n_A_PassSkill8[17];
		break;

	// キューペット　サファリット
	case EXBUF_ID_QUEPET_SAFARIT:
		if (n_A_PassSkill8[0] == 52) exBufNum = n_A_PassSkill8[17];
		break;

	// キューペット　エメリット
	case EXBUF_ID_QUEPET_EMERIT:
		if (n_A_PassSkill8[0] == 53) exBufNum = n_A_PassSkill8[17];
		break;

	// キューペット　トパリット
	case EXBUF_ID_QUEPET_TOPARIT:
		if (n_A_PassSkill8[0] == 54) exBufNum = n_A_PassSkill8[17];
		break;

	}



	switch (exBufId) {

	// ＨＩＴ＋
	case EXBUF_ID_CUSTOM_HIT_PLUS:
		if(n_A_PassSkill9[0] == 0) exBufNum = n_A_PassSkill9[10];
		break;

	// ＡＴＫ＋
	case EXBUF_ID_CUSTOM_ATK_PLUS:
		if(n_A_PassSkill9[0] == 0) exBufNum = n_A_PassSkill9[17];
		break;

	// ＭａｘＨＰ＋
	case EXBUF_ID_CUSTOM_HP_PLUS:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[1];
		break;

	// ＭａｘＨＰ％
	case EXBUF_ID_CUSTOM_HP_UP:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[3];
		break;

	// ＭａｘＳＰ＋
	case EXBUF_ID_CUSTOM_SP_PLUS:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[4];
		break;

	// ＭａｘＳＰ％
	case EXBUF_ID_CUSTOM_SP_UP:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[6];
		break;

	// ＤＥＦ＋
	case EXBUF_ID_CUSTOM_DEF_PLUS:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[7];
		break;

	// ＭＤＥＦ＋
	case EXBUF_ID_CUSTOM_MDEF_PLUS:
		if(n_A_PassSkill10[0] == 0) exBufNum = n_A_PassSkill10[8];
		break;

	}



	return exBufNum;
}



/**
 * 指定の時限アイテムの使用数を取得する.
 * @param timeItemId 時限アイテムＩＤ
 * @returns 使用数
 */
function TimeItemNumSearch(timeItemId) {

	var timeItemNum = 0;

	// 全ての設定を走査して、指定の時限アイテムＩＤの数を数える
	for(var idx = 0; idx <= 3; idx++) {
		if(timeItemId == n_A_PassSkill8[8 + idx]) {
			timeItemNum += 1;
		}
	}
	return timeItemNum;
}





//================================================================================================
//================================================================================================
//====
//==== プレイヤー防御属性　ここから
//====
//================================================================================================
//================================================================================================
/**
 * 装備等によるステータスの追加補正値を取得する（防御属性）.
 */
function GetStatusModifyBodyElement() {

	var val = ELM_ID_VANITY;

	//----------------------------------------------------------------
	// 基本処理
	//----------------------------------------------------------------
	// 装備中の単純カード効果を検索
	val = GetEquippedTotalSPCardAndElse(ITEM_SP_BODY_ELEMENT);
	if (val != ELM_ID_VANITY) {
		return val;
	}

	// カード効果がなければ、装備固有の単純効果を検索
	val = GetEquippedTotalSPEquip(ITEM_SP_BODY_ELEMENT);
	if (val != ELM_ID_VANITY) {
		return val;
	}

	//----------------------------------------------------------------
	// 「エクセリオンエンチャント」の、属性チップ
	//----------------------------------------------------------------
	if (CardNumSearch(CARD_ID_E_FIRE)) return ELM_ID_FIRE;
	if (CardNumSearch(CARD_ID_E_WATER)) return ELM_ID_WATER;
	if (CardNumSearch(CARD_ID_E_EARTH)) return ELM_ID_EARTH;
	if (CardNumSearch(CARD_ID_E_WIND)) return ELM_ID_WIND;

	//----------------------------------------------------------------
	// 「古びた楯無の鎧」の、精錬による効果
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_SET_ID_FURUBITA_TATENASHINO_YOROI_REFINE)) {
		if (n_A_BODY_DEF_PLUS == 5) return ELM_ID_EARTH;
		if (n_A_BODY_DEF_PLUS == 6) return ELM_ID_WATER;
		if (n_A_BODY_DEF_PLUS == 7) return ELM_ID_WIND;
		if (n_A_BODY_DEF_PLUS == 8) return ELM_ID_FIRE;
		if (n_A_BODY_DEF_PLUS == 9) return ELM_ID_DARK;
		if (n_A_BODY_DEF_PLUS == 10) return ELM_ID_HOLY;
	}

	//----------------------------------------------------------------
	// 「職業カードセット　クルセイダー」の、装備職業による効果
	//----------------------------------------------------------------
	if (CardNumSearch(CARD_SET_ID_JOBSET_CRUSADER)) {
		if (GetHigherJobSeriesID(n_A_JOB) == JOB_ID_CRUSADER) {
			return ELM_ID_HOLY;
		}
	}

	//----------------------------------------------------------------
	// 「聖体降福」「パイエティ」の、効果
	//----------------------------------------------------------------
	if (n_A_PassSkill6[6]) return ELM_ID_HOLY;

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== ＡＴＫ＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
 * 装備等によるステータスの追加補正値を取得する（ＡＴＫ）.
 */
function GetStatusModifyAtkPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;



	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_ATK_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「ドゥームスレイヤー」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_DOOM_SLAYER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_DOOM_SLAYER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_STR >= 95) val += 340 * itemCountRight;
		if (SU_STR >= 95) val += 340 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ホルグレンの精錬ハンマー」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_HORGRENNO_SEIREN_HUMMER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_HORGRENNO_SEIREN_HUMMER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_STR >= 44) val += 44 * itemCountRight;
		if (SU_STR >= 44) val += 44 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「クラスナヤ」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KRASNAYA, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KRASNAYA, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_STR >= 95) val += 20 * itemCountRight;
		if (SU_STR >= 95) val += 20 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ベチェルアックス」の、素ＬＵＫによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_BECHEL_AXE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_BECHEL_AXE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_LUK >= 90) val += 20 * itemCountRight;
		if (SU_LUK >= 90) val += 20 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「達人の斧」の、製造スキルマスターによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_TATSUZINNO_ONO, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_TATSUZINNO_ONO, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCountRight;
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCountLeft;
	}
	itemCountRight = EquipNumSearch(ITEM_ID_TATSUZINNO_ONO_S2, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_TATSUZINNO_ONO_S2, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCountRight;
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「チャクラム」の、カタール修練マスターによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_CACRAM, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_CACRAM, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SkillSearch(SKILL_ID_KATAR_SHUREN) == 10) val += 10 * itemCountRight;
		if (SkillSearch(SKILL_ID_KATAR_SHUREN) == 10) val += 10 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「蛇蝎大全集」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_DAKATSU_DAIZENSHU, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_DAKATSU_DAIZENSHU, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 3 * n_A_Weapon_ATKplus * itemCountRight;
		val += 3 * n_A_Weapon2_ATKplus * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ギガントランス」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_GIGANT_LANCE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_GIGANT_LANCE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_STR >= 120) val += 300 * itemCountRight;
		if (SU_STR >= 120) val += 300 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「アイアンネイル」の、コンボスキルマスターによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_IRON_NAIL, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_IRON_NAIL, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 20 * SkillSearch(SKILL_ID_ATK_FOR_IRON_NAIL) * itemCountRight;
		val += 20 * SkillSearch(SKILL_ID_ATK_FOR_IRON_NAIL) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「鬼丸」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ONIMARU, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ONIMARU, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		vartmp = 0;

		if (SU_STR >= 120) {
			vartmp += 120;
		}
		else {
			vartmp += SU_STR;
		}
		if (SU_STR >= 95) vartmp += 40;
		if (SU_STR >= 108) vartmp += 80;
		if (SU_STR >= 120) vartmp += 160;

		val += vartmp * itemCountRight;
		val += vartmp * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「メテオストライク」の、精錬による効果
	// 「メテオストライク」の、スキル習得による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_METEOR_STRIKE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_METEOR_STRIKE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		vartmp = 0;

		vartmp += 10 * n_A_Weapon_ATKplus;

		vartmp += 7 * SkillSearch(SKILL_ID_ONO_SHUREN);
		vartmp += 10 * SkillSearch(SKILL_ID_BUKI_KENKYU);
		vartmp += 30 * SkillSearch(SKILL_ID_TEKKEN);

		val += vartmp * itemCountRight;
		val += vartmp * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーハンマー」の、職業による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += 150 * itemCountRight;
			val += 150 * itemCountLeft;
			break;

		// ソードマン系
		case JOB_SERIES_ID_SWORDMAN:
			break;

		// マーチャント系
		case JOB_SERIES_ID_MERCHANT:
			val += 100 * itemCountRight;
			val += 100 * itemCountLeft;
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// プリースト系
			case JOB_SERIES_ID_PRIEST:
				val += 50 * itemCountRight;
				val += 50 * itemCountLeft;
				break;

			// モンク系
			case JOB_SERIES_ID_MONK:
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーナイフ」の、職業による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += 100 * itemCountRight;
			val += 100 * itemCountLeft;
			break;

		// マジシャン系
		case JOB_SERIES_ID_MAGICIAN:
			break;

		// シーフ系
		case JOB_SERIES_ID_THIEF:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// ハンター系
			case JOB_SERIES_ID_HUNTER:
				break;

			// バード系、ダンサー系
			case JOB_SERIES_ID_BARD:
			case JOB_SERIES_ID_DANCER:
				val += 100 * itemCountRight;
				val += 100 * itemCountLeft;
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「邪念のダガー」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_DAGGER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_DAGGER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のセイバー」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_SAVOR, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_SAVOR, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のツーハンドソード」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_TWOHAND_SWORD, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_TWOHAND_SWORD, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のスピア」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_SPEAR, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_SPEAR, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のランス」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_LANCE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_LANCE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のツーハンドアックス」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_TWOHAND_AXE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_TWOHAND_AXE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のメイス」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_MACE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_MACE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のボウ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_BOW, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_BOW, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のカタール」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_KATAR, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_KATAR, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のフィスト」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_FIST, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_FIST, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念の風魔手裏剣」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_FUMASHURIKEN, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_FUMASHURIKEN, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「邪念のハンドガン」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_HANDGUN, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_HANDGUN, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
		val += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
	}

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「盗賊の指輪」の、素ＡＧＩによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TOZOKUNO_YUBIWA)) > 0) {
		if (SU_AGI >= 90) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「大型マジェスティックゴート」の、ジョブレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_OGATA_MAJESTIC_GOAT)) > 0) {
		val += Math.floor(n_A_JobLV / 7 * 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「獅子の仮面」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHISHINO_KAMEN)) > 0) {
		val += 2 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「アーチャーフィギュア」の、装備職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ARCHER_FIGURE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ARCHER) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ルーンサークレット」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_RUNE_CIRCLET)) > 0) {
		if (SU_STR >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「沈黙の執行者」の、素ＡＧＩによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIMONKUNO_SHIKKOSHA)) > 0) {
		if (SU_AGI >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ドライバーバンド」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_DRIVER_BAND)) > 0) {
		if (SU_STR >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「シャドウクラウン」の、素ＡＧＩによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHADOW_CROWN)) > 0) {
		if (SU_AGI >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ブレイジングソウル」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BLAZING_SOUL)) > 0) {
		if (SU_STR >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ミダスのささやき」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MIDASSNO_SASAYAKI)) > 0) {
		if (SU_STR >= 120) val += 5 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルーンブーツ」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_RUNE_BOOTS)) > 0) {
		if (SU_STR >= 90) val += 10 * itemCount;
		if (SU_STR >= 120) val += 10 * itemCount;
	}

	//----------------------------------------------------------------
	// 「百戦錬磨のお守り」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_HYAKUSENRENMANO_OMAMORI)) > 0) {
		if (SU_STR >= 80) val += 5 * itemCount;
		if (SU_STR >= 100) val += 5 * itemCount;
		if (SU_STR >= 120) val += 5 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ナブのフード」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_NABUNO_HOOD)) > 0) {
		val += 2 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「黒羽のスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KUROHANO_SUIT)) > 0) {
		val += 3 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「剣聖の王冠」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KENSENO_OKAN)) > 0) {
		if (n_A_BaseLV >= 50) val += 5 * itemCount;
		if (n_A_BaseLV >= 100) val += 10 * itemCount;
		if (n_A_BaseLV >= 150) val += 15 * itemCount;
	}

	//----------------------------------------------------------------
	// 「力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS)) > 0) {
		val += 7 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS_S1)) > 0) {
		val += 7 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「力の時空ブーツ」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS)) > 0) {
		if (SU_STR >= 120) val += 50 * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS_S1)) > 0) {
		if (SU_STR >= 120) val += 50 * itemCount;
	}

	//----------------------------------------------------------------
	// 「力のグローブ」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_GLOVE)) > 0) {
		val += ROUNDDOWN(SU_STR / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ギャンブラーシール」の、素ＬＵＫによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GAMBLER_SEAL)) > 0) {
		val += 2 * ROUNDDOWN(SU_LUK / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「酸素ボンベ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SANSO_BOMBE)) > 0) {
		val += 5 * ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「古びたミダスのささやき」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FURUBITA_MIDASS)) > 0) {
		val += 7 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ワクワクマント」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_WAKUWAKU_MANT)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 5) val += 2 * ROUNDDOWN(SU_STR / 10) * itemCount;
		if (n_A_SHOULDER_DEF_PLUS >= 7) val += 3 * ROUNDDOWN(SU_STR / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「熾天使の花冠」の、素ＩＮＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHITENSHINO_HANAKANMURI)) > 0) {
		val += 5 * ROUNDDOWN(SU_INT / 8) * itemCount;
		if (SU_INT >= 108) val += 50 * itemCount;
		if (SU_INT >= 120) val += 125 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ガイアシールド」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GAIA_SHIELD)) > 0) {
		if (n_A_LEFT_DEF_PLUS >= 8) {
			if (SU_STR >= 90) {
				val += 50 * itemCount;
			}
		}
	}

	//----------------------------------------------------------------
	// 「グウィバーの皮」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GWIBERNO_KAWA)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 8) {
			val += 5 * ROUNDDOWN((SU_INT + SU_DEX) / 20) * itemCount;
		}
	}


// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「巨大ウィスパーカード」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_KYODAI_WHISPER)) > 0) {
		if (SU_STR >= 80) val += 20 * cardCount;
	}

	//----------------------------------------------------------------
	// 「イフリートカード」の、ジョブレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_EFREET)) > 0) {
		val += Math.floor(n_A_JobLV /10) * cardCount;
	}

	//----------------------------------------------------------------
	// 「リヒトヘルシャーカード」の、＋１０本系列武器による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LICHT_HERRSCHER)) > 0) {
		if ((n_A_WeaponType == ITEM_KIND_BOOK) && (n_A_Weapon_ATKplus >= 10)) {
			val += 20 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ワクワクカード」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WAKUWAKU)) > 0) {
		val += 5 * ROUNDDOWN(SU_STR / 10) * cardCount;
	}

	//----------------------------------------------------------------
	// [LoVA] ルールーカードの、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_RURU)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) val += 6 * ROUNDDOWN(SU_STR / 60) * cardCount;
	}

	//----------------------------------------------------------------
	// [LoVA] 真化ルールーカードの、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_SHINKA_RURU)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7)  val += 6 * ROUNDDOWN(SU_STR / 20) * cardCount;
	}

	//----------------------------------------------------------------
	// 「将軍デヒョンカード」の、剣系統の効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHOGUN_DAEHYON)) > 0) {
		if ((n_A_WeaponType == ITEM_KIND_SWORD) || (n_A_WeaponType == ITEM_KIND_SWORD_2HAND)) {
			val += 100 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エナジー＜致命ノ一撃＞」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_CHIMEINO_ICHIGEKI)) > 0) {
		val += 5 * n_A_SHOULDER_DEF_PLUS * cardCount;
	}

	//----------------------------------------------------------------
	// 「パワフルスケルトンカード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_SKELETON)) > 0) {
		val += 3 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
	}

	//----------------------------------------------------------------
	// 「パワフルSスケルトンカード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_S_SKELETON)) > 0) {
		val += 5 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
	}

	//----------------------------------------------------------------
	// 「レオ」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LEO, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
		// 修羅限定の効果
		if (n_A_JOB == JOB_ID_SHURA) {
			val += 4 * n_A_HEAD_DEF_PLUS * cardCount;
		}
	}


// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　金牛宮」の、精錬による効果
	//----------------------------------------------------------------
	cardCountHeadTop = CardNumSearch(CARD_ID_ENCHANT_KINGYUKYU, CARD_REGION_ID_HEAD_TOP_ANY);
	if (cardCountHeadTop > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 4;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 2;

		val += vartmp * cardCountHeadTop
	}

	//----------------------------------------------------------------
	// 「エンチャント　巨蟹宮」の、精錬による効果
	//----------------------------------------------------------------
	cardCountHeadTop = CardNumSearch(CARD_ID_ENCHANT_KYOKAIKYU, CARD_REGION_ID_HEAD_TOP_ANY);
	if (cardCountHeadTop > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 5;

		val += vartmp * cardCountHeadTop
	}

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－Ａｔｋ」の、精錬と素ＳＴＲによる効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_A_ATK, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_A_ATK, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_A_ATK, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountShoes
	}

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－Ｓｔｒ」の、精錬と素ＳＴＲによる効果
	//----------------------------------------------------------------
	cardCountBody = CardNumSearch(CARD_ID_A_STR, CARD_REGION_ID_BODY_ANY);
	if (cardCountBody > 0) {
		vartmp = 0;

		vartmp += 1;
		if (n_A_BODY_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 4;
		if (n_A_BODY_DEF_PLUS >= 9) vartmp += 8;

		val += vartmp * ROUNDDOWN(SU_STR / 10) * cardCountBody
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「囚人の服　足鎖セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SHUZINNOFUKU_ASHIKUSARI)) > 0) {
		val += n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルーンブーツ　コンチネンタルガードの印章セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_RUNE_BOOTS_CONTINENTAL_GUARDNO_INSHO)) > 0) {
		val += n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「大盗賊の手鎖　囚人の服セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_DAITOZOKUNO_TEKUSARI_SHUZINNO_FUKU)) > 0) {
		val += 2 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「大盗賊の手鎖　足鎖セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_DAITOZOKUNO_TEKUSARI_ASHIKUSARI)) > 0) {
		val += n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ナブのクロース　アーティファクトセット」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_NABUNO_CLOTH_ARTIFACT)) > 0) {
		if (SU_STR >= 120) val += 30 * itemCount;
	}

	//----------------------------------------------------------------
	// 「古びたサンダル　吸収系カードセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FURUBITA_SANDAL_DRAINCARD)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ワクワクマント　ワクワクカードセット」の、素ＳＴＲによる効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_WAKUWAKU_MANT_WAKUWAKU)) > 0) {
		val += -5 * ROUNDDOWN(SU_STR / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「勇者の怒りセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANOIKARI_ORCISH_AXE_ORCISH_SWORD)) > 0) {
		val += 15 * ROUNDDOWN( (n_A_Weapon_ATKplus + n_A_Weapon2_ATKplus) / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「魔羊の咆哮　クレセントサイダーセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_CRESCENT_CIZER)) > 0) {
		val += 15 * n_A_Weapon_ATKplus * itemCount;
	}

	//----------------------------------------------------------------
	// 「魔羊の咆哮　テグリョンセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_TEGRYONG)) > 0) {
		val += 15 * n_A_Weapon_ATKplus * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_TEGRYONG_S2)) > 0) {
		val += 15 * n_A_Weapon_ATKplus * itemCount;
	}

	//----------------------------------------------------------------
	// 「神魔バフォメットの角　ブラッディクロスセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SHINMA_BAPHOMETNO_TSUNO_BLOODY_CROSS)) > 0) {
		val += 15 * n_A_Weapon_ATKplus * itemCount;
	}

	//----------------------------------------------------------------
	// 「アインヘリヤルの鎧　戦死者のマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_EINHERJERNO_YOROI_SEINSHISHANO_MANT)) > 0) {
		val += 3 * n_A_SHOULDER_DEF_PLUS * itemCount
	}

	//----------------------------------------------------------------
	// 「アインヘリヤルの鎧　戦死者のマントセット」の、精錬と素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_EINHERJERNO_YOROI_SEINSHISHANO_MANT)) > 0) {
		vartmp = 0;

		vartmp += 1;
		if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 5;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 7;

		val += vartmp * ROUNDDOWN(SU_STR / 10) * itemCount
	}

	//----------------------------------------------------------------
	// 「勇者の靴　達人の斧セット」の、製造スキルマスターによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_ONO)) > 0) {
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_ONO_S2)) > 0) {
		val += 10 * SkillSearch(SKILL_ID_SKILL_COUNT_CREATE_ARMS_MASTER) * itemCount;
	}


// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ロイヤルガード　インスピレーション」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_INSPIRATION)) > 0) {
		val += 40 * sklLv + 3 * n_A_JobLV;
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　シールドスペル」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SHIELD_SPELL_ATK_PLUS)) > 0) {
		if (n_A_ActiveSkill != SKILL_ID_SHIELD_SPELL_LV_1) {
			if(sklLv == 1) {
				val += ItemObjNew[n_A_Equip[EQUIP_REGION_ID_SHIELD]][ITEM_DATA_INDEX_POWER];
			}
			else{
				val += n_SieldSp[sklLv];
			}
		}
	}

	//----------------------------------------------------------------
	// 「ルーンナイト　ファイティングスピリット」の、効果
	// 「ルーンナイト　ファイティングスピリット（別キャラ支援）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_FIGHTING_SPIRIT)) > 0) {
		val += 7 * sklLv;

		// ルーンヘルム装備時の追加効果
		if(EquipNumSearch(ITEM_ID_RUNE_HELM)) {
			val += 10;
		}
	}
	else if ((bufLv = ExBuffNumSearch(EXBUF_ID_FIGHTING_SPIRIT)) > 0) {
		val += ROUNDDOWN(7 * bufLv / 4);
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　バンディング」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_BANDING)) > 0) {
		val += (10 + 10 * sklLv) * (SkillSearch(SKILL_ID_COUNT_OF_RG_FOR_BANDING) + 1);
	}

	//----------------------------------------------------------------
	// 「修羅　閃光連撃」の、効果
	// 「修羅　閃光連撃直後のＡＴＫ上昇状態」の、効果
	//----------------------------------------------------------------
	if (n_A_ActiveSkill == SKILL_ID_SENKO_RENGEKI) {
		val += 20 + 20 * n_A_ActiveSkillLV;
	}
	else if ((sklLv = SkillSearch(SKILL_ID_ATK_PLUS_AFTER_SENKO_RENGEKI)) > 0) {
		val += 20 + 20 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊（Passive）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE)) > 0) {
		// 火Ｌｖ１～火Ｌｖ３のパッシブモードの場合、ＡＴＫ上昇
		if (SkillSearch(SKILL_ID_SERE_MODE) == 1) {
			if(sklLv == 1) val += 60;
			if(sklLv == 2) val += 120;
			if(sklLv == 3) val += 180;
		}
	}

	//----------------------------------------------------------------
	// 「朧　幻術-残月-」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_GENZYUTSU_ZANGETSU)) > 0) {
		// HP設定が偶数の場合
		if (SkillSearch(SKILL_ID_HPSPCONF_FOR_GENZYUTSU_ZANGETSU) <= 1) {
			val += 20 * sklLv + ROUNDDOWN(n_A_BaseLV / 3);
		}
		// HP設定が奇数の場合
		else {
			val += -30 * sklLv + ROUNDDOWN(n_A_BaseLV / 3);
		}
	}

	//----------------------------------------------------------------
	// 「Ｓホム　パイロクラスティック」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_PYROCLASTIC)) > 0) {
		val += 10 * sklLv + 121 + SkillSearch(SKILL_ID_HOMLV_FOR_PYROCLASTIC);
	}

	//----------------------------------------------------------------
	// 「リベリオン　プラチナムアルター」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_PLATINUM_ALTER)) > 0) {
		// 聖属性の弾丸のみ適用
		if (BulletOBJ[n_A_Arrow][1] == ELM_ID_HOLY) {
			val += sklLv * 10 + SkillSearch(SKILL_ID_PLATINUM_ALTER_COIN_COUNT) * 10;
		}
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援戦太鼓の響き」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_IKUSADAIKONO_HIBIKI)) > 0) {
		val += 25 + 25 * bufLv;
	}

	//----------------------------------------------------------------
	// 「合奏　支援フライデーナイトフィーバー」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_FRYDAY_NIGHT_FEVER)) > 0) {
		val += 100 * bufLv;
	}

	//----------------------------------------------------------------
	// 「合奏　支援ダンスウィズウォーグ（レンジャー有）」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_DANCE_WITH_WUG)) > 0) {
		if ((n_Sanji == 1) && (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ARCHER)) {
			vartmp = Math.min(7, ExBuffNumSearch(EXBUF_ID_DANCE_WITH_WUG_COUNT_OF_MINWAN));
			val += (2 * bufLv) * vartmp;
		}
	}

	//----------------------------------------------------------------
	// 「ミンストレル　支援風車に向かって突撃」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI)) > 0) {
		bufferJobLv = ExBuffNumSearch(EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_JOBLV);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_FUSHANIMUKATTE_TOTSUGEKI_BUFFER_SKILLLV);
		val += (6 * bufLv) + bufferSkillLv + Math.floor(bufferJobLv / 5);
	}

	//----------------------------------------------------------------
	// 「アークビショップ　支援オーディンの力」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ODINNO_CHIKARA)) > 0) {
		if (bufLv == 1) val += 70;
		if (bufLv == 2) val += 100;
	}

	//----------------------------------------------------------------
	// 「影狼・朧　支援術式-展開-」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ZYUTSUSHIKI_TENKAI)) > 0) {
		if (bufLv == n_A_Weapon_zokusei) val += 200;
	}

	//----------------------------------------------------------------
	// 「オルレアンのフルコース」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ORLEANS_FULLCOURSE)) > 0) {
		val += 30 * bufLv;
	}

	//----------------------------------------------------------------
	// 「エクラージュ支援」の、効果
	// 「恨みの箱」の、効果
	// 「虹色のお菓子」の、効果
	// 「ルーンミッドガッツ産おやつ」の、効果
	// ※もっとも効果の大きいひとつのみ有効
	//----------------------------------------------------------------
	vartmp = 0;
	if (vartmp == 0) vartmp += 24 * TimeItemNumSearch(79);
	if (vartmp == 0) vartmp += 20 * ExBuffNumSearch(EXBUF_ID_URAMINO_HAKO);
	if (vartmp == 0) vartmp += 10 * ExBuffNumSearch(EXBUF_ID_NIZIIRONO_OKASHI);
	if (vartmp == 0) vartmp += 5 * ExBuffNumSearch(EXBUF_ID_RUNEMIDGARTSSAN_OYATSU);
	val += vartmp;

	//----------------------------------------------------------------
	// 「期間限定イベント支援」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_EVENT_BUF_ATK_PLUS)) > 0) {
		val += bufLv;
	}

	//----------------------------------------------------------------
	// 「キューペット　ルビリット」の、親密度による効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_QUEPET_RUBYRIT)) > 0) {
		if (bufLv >= 6) val += 10;
	}

	//----------------------------------------------------------------
	// 「柴犬帽(黒)　忠節の首輪セット」の、追加発動による効果
	//----------------------------------------------------------------
	if ((bufLv = TimeItemNumSearch(53)) > 0) {
		val += (30 + 30 * n_A_HEAD_DEF_PLUS) * bufLv;
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＡＴＫ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_ATK_PLUS)) > 0) {
		val += bufLv;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== ＭａｘＨＰ＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＭａｘＨＰ＋）.
*/
function GetStatusModifyMaxHpPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;




	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_MAXHP_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「古代樹の杖」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KODAIZYUNO_TSUE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KODAIZYUNO_TSUE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (n_A_Weapon_ATKplus >= 6) val += -200 * itemCountRight;
		if (n_A_Weapon2_ATKplus >= 6) val += -200 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「クロノス」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_CHRONOS, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_CHRONOS, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 50 * Math.floor(n_A_Weapon_ATKplus / 2) * itemCountRight;
		val += 50 * Math.floor(n_A_Weapon2_ATKplus / 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーハンマー」の、職業による強化
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {

		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += (500 + 200 * n_A_Weapon_ATKplus) * itemCountRight;
			val += (500 + 200 * n_A_Weapon2_ATKplus) * itemCountLeft;
			break;

		// ソードマン系
		case JOB_SERIES_ID_SWORDMAN:
			val += 500 * itemCountRight;
			val += 500 * itemCountLeft;
			break;

		// マーチャント系
		case JOB_SERIES_ID_MERCHANT:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// プリースト系
			case JOB_SERIES_ID_PRIEST:
				break;

			// モンク系
			case JOB_SERIES_ID_MONK:
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーナイフ」の、職業による強化
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += (300 + 200 * n_A_Weapon_ATKplus) * itemCountRight;
			val += (300 + 200 * n_A_Weapon2_ATKplus) * itemCountLeft;
			break;

		// マジシャン系
		case JOB_SERIES_ID_MAGICIAN:
			val += (200 * n_A_Weapon_ATKplus) * itemCountRight;
			val += (200 * n_A_Weapon2_ATKplus) * itemCountLeft;
			break;

		// シーフ系
		case JOB_SERIES_ID_THIEF:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// ハンター系
			case JOB_SERIES_ID_HUNTER:
				val += 200 * itemCountRight;
				val += 200 * itemCountLeft;
				break;

			// バード系、ダンサー系
			case JOB_SERIES_ID_BARD:
			case JOB_SERIES_ID_DANCER:
				break;
			}
		}
	}

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「ディアボロスブーツ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_DIABOLOS_BOOTS)) > 0) {
		val += 10 * n_A_BaseLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーシューズ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VALKIRIE_SHOES)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_ACOLYTE:
		case JOB_SERIES_ID_ARCHER:
		case JOB_SERIES_ID_MAGICIAN:
			val += 5 * n_A_BaseLV * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「エーギルシューズ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_AEGIR_SHOES)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_ACOLYTE:
		case JOB_SERIES_ID_ARCHER:
		case JOB_SERIES_ID_MAGICIAN:
			val += 5 * n_A_BaseLV * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「アカデミーバッジ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ACADEMY_BADGE)) > 0) {
		if (n_A_BaseLV <= 79) val += 400 * itemCount;
	}

	//----------------------------------------------------------------
	// 「ブリュンヒルデ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BRUNHILD)) > 0) {
		val += 20 * n_A_BaseLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「ノービスフィギュア」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_NOVICE_FIGURE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_NOVICE) {
			val += 30 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「カメレオンアーマー」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHAMELEON_ARMER)) > 0) {
		val += 7 * n_A_BaseLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「グロリアス量産型スーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_RYOSANGATA_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 200 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「グロリアス普及型スーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_FUKYUGATA_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 300 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「派手なファントムマスク」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_HADENA_PHANTOM_MASK)) > 0) {
		val += 100 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「通学バッグ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TSUGAKU_BAG)) > 0) {
		if (n_A_BaseLV <= 79) {
			val += 200 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギャラクシーサークレット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GALAXY_CIRCLET)) > 0) {
		val += 10 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「無病息災のお守り」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MUBYOSOKUSAINO_OMAMORI)) > 0) {
		vartmp = 0;
		if (SU_VIT >= 80) vartmp += 50;
		if (SU_VIT >= 100) vartmp += 150;
		if (SU_VIT >= 120) vartmp += 100;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ゲフェニア水の古書」の、素ＩＮＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GEFENIA_MIZUNO_KOSHO)) > 0) {
		if (SU_INT >= 120) {
			val += 800 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS_S1)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「知力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS_S1)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「俊敏の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS_S1)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「体力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS)) > 0) {
		val += 300 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS_S1)) > 0) {
		val += 300 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「技巧の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS_S1)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「幸運の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS_S1)) > 0) {
		val += 100 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「体力のグローブ」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_GLOVE)) > 0) {
		val += 50 * ROUNDDOWN(SU_VIT / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「[衣装]ビギナー帽」の、ベースレベルによる効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ISHO_BEGINNER_BO)) > 0) {
		if ((n_A_BaseLV >= 99) || (n_B_TAISEI[38] == 1)) {
			val += -1000 * itemCount;
		}
		else {
			val += -100 * ROUNDDOWN(n_A_BaseLV / 10) * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「１０周年記念バッジ」の、ジョブレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_10SHUNEN_KINEN_BADGE)) > 0) {
		val += 10 * n_A_JobLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「くわえたイチゴ」の、レベルによる強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KUWAETA_ICHIGO)) > 0) {
		if (n_A_BaseLV <= 99) {
			val += 200;
		}
		else {
			val += 2000;
		}
	}

	//----------------------------------------------------------------
	// 「皇竜の天翼」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_NOVICE:
		case JOB_SERIES_ID_TAEGKUON:
		case JOB_SERIES_ID_NINJA:
		case JOB_SERIES_ID_GUNSLINGER:
			val += 1000 * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「アポカリプスカード」の、過剰精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_APOCALYPSE)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 9) val += 800 * cardCount;
	}

	//----------------------------------------------------------------
	// 「リムーバカード」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_REMOVER)) > 0) {
		val += -40 * n_A_BODY_DEF_PLUS * cardCount;
	}

	//----------------------------------------------------------------
	// 「バンシーカード」の、職業による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_BANSHEE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MAGICIAN) {
			val += -100 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エキオカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_EKIO)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_SWORDMAN) {
			val += 500 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ジェジェリンカード」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_JEJERIN)) > 0) {
		val += 200 * ROUNDDOWN(SU_VIT / 10) * cardCount;
	}

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－ＭａｘＨＰ」の、精錬による効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_A_MAXHP, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_A_MAXHP, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_A_MAXHP, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 6) vartmp += 300;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 1000;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 6) vartmp += 300;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 1000;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 6) vartmp += 300;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 1000;
		val += vartmp * cardCountShoes
	}

	//----------------------------------------------------------------
	// 「エンチャント　安息のニーヴ(体力)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_ANSOKUNO_NIEVE_TAIRYOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 6) vartmp += 300;
		if (n_A_LEFT_DEF_PLUS >= 8) vartmp += 500;
		val += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「クイールペンリング　スモールブックペンダントセット」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_QUILL_PENRING_SMALL_BOOK_PENDANT)) > 0) {
		val += 3 * n_A_BaseLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「破産者の仮面　お金を失ったも者の心セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HASANSHANO_KAMEN_OKANEWO_USHINATTAMONONO_KOKORO)) > 0) {
		val += 100 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「星タマゴバッジ　アカデミーバッジセット」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HOSHITAMAGO_BADGE_ACADEMY_BADGE)) > 0) {
		if (n_A_BaseLV <= 79) {
			val += 200 * itemCount;
		}
		else {
			val += 600 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「飛行船スーツセット」の、精錬による強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HIKOSEN_SUIT_HIKOSEN_MANT_HIKOSEN_BOOTS)) > 0) {
		var refinedtotal = n_A_BODY_DEF_PLUS + n_A_SHOULDER_DEF_PLUS + n_A_SHOES_DEF_PLUS;

		vartmp = 0;
		if (refinedtotal >= 15)  vartmp += 1000;
		if (refinedtotal >= 20)  vartmp += 1500;
		if (refinedtotal >= 25)  vartmp += 2000;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ペルロックのスーツセット」の、精錬による強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_PELLROCKNO_SUIT_PELLROCKNO_MANT_PELLROCKNO_BOOTS)) > 0) {
		var refinedtotal = n_A_BODY_DEF_PLUS + n_A_SHOULDER_DEF_PLUS + n_A_SHOES_DEF_PLUS;

		vartmp = 0;
		if (refinedtotal >= 15)  vartmp += 1000;
		if (refinedtotal >= 20)  vartmp += 1500;
		if (refinedtotal >= 25)  vartmp += 2000;

		val += vartmp * itemCount;
	}

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「クルセイダー　フェイス」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_FAITH)) > 0) {
		val += 200 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊補助スキル（ソリッドスキン）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 29) {
			val += 2000;
		}
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「合奏　支援レーラズの露」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_RELAZUNO_TSUYU)) > 0) {
		vartmp = ExBuffNumSearch(EXBUF_ID_RELAZUNO_TSUYU_COUNT_OF_MINWAN);
		val += (200 * bufLv) - 600 + (300 * vartmp);

	}

	//----------------------------------------------------------------
	// 「キューペット　サファリット」の、親密度による効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_QUEPET_SAFARIT)) > 0) {
		if (bufLv >= 6) val += 100;
	}

	//----------------------------------------------------------------
	// 「キューペット　エメリット」の、親密度による効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_QUEPET_EMERIT)) > 0) {
		if (bufLv >= 6) val += 50;
	}

	//----------------------------------------------------------------
	// 「ＨＰ増加ポーション」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_HPZOKA_POTION)) > 0) {
		val += (-500 + 1000 * bufLv) + ROUNDDOWN(n_A_BaseLV * 10 / 3);
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＭａｘＨＰ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_HP_PLUS)) > 0) {
		val += bufLv;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}






//================================================================================================
//================================================================================================
//====
//==== ＭａｘＨＰ　％ＵＰ　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＭａｘＨＰ％）.
*/
function GetStatusModifyMaxHpUp() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;




	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_MAXHP_UP);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「メンタルスティック」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_MENTAL_STICK, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_MENTAL_STICK, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += -2 * Math.max(0, (n_A_Weapon_ATKplus - 5)) * itemCountRight;
		val += -2 * Math.max(0, (n_A_Weapon2_ATKplus - 5)) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ラグズナイフ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_LAGUZ_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_LAGUZ_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.max(0, (n_A_Weapon_ATKplus - 6)) * itemCountRight;
		val += 1 * Math.max(0, (n_A_Weapon2_ATKplus - 6)) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「エイワズナイフ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_EIHWAZ_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_EIHWAZ_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.max(0, (n_A_Weapon_ATKplus - 6)) * itemCountRight;
		val += 1 * Math.max(0, (n_A_Weapon2_ATKplus - 6)) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「カノナイフ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KANO_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KANO_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.max(0, (n_A_Weapon_ATKplus - 6)) * itemCountRight;
		val += 1 * Math.max(0, (n_A_Weapon2_ATKplus - 6)) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ハガラズナイフ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_HAGALAZ_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_HAGALAZ_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.max(0, (n_A_Weapon_ATKplus - 6)) * itemCountRight;
		val += 1 * Math.max(0, (n_A_Weapon2_ATKplus - 6)) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「オンディーヌの槍」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_ONDINENO_YARI, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_ONDINENO_YARI, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * n_A_Weapon_ATKplus * itemCountRight;
		val += 1 * n_A_Weapon2_ATKplus * itemCountLeft;
	}


// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「バリアントシューズ」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VARIANT_SHOES)) > 0) {
		val += -1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「グロリアススーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「グロリアスシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_SHOES)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「グロリアス量産型シューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_RYOSANGATA_SHOES)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 7 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「グロリアス普及型シューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_FUKYUGATA_SHOES)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「グロリアスマフラー」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_MUFFLER)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 7) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ホワイトフェザー」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_WHITE_FEATHER)) > 0) {
		vartmp = 0;

		vartmp += 10;
		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 3;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 3;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ウルズプレート」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_URUZ_PLATE)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ウルズグリーブ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_URUZ_GREAVE)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 8) {
			val += -2 * (n_A_SHOES_DEF_PLUS - 7) * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「イドゥンの羽耳」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_IDUNNNO_HANEMIMI)) > 0) {
		if (n_A_BaseLV >= 100) {
			val += 1 * itemCount;
		}
		if (n_A_BaseLV >= 150) {
			val += 1 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「賢者の靴」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KENZYANO_KUTSU)) > 0) {
		val += -1 * Math.max(0, n_A_SHOES_DEF_PLUS - 5) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ネクタルスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_NECTAR_SUIT)) > 0) {
		val += 1 * Math.floor(n_A_BODY_DEF_PLUS / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ＢＯＳＳ帽」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BOSS_BO)) > 0) {
		vartmp = 0;

		vartmp += 1 * Math.max(0, n_A_HEAD_DEF_PLUS - 4);
		if (n_A_HEAD_DEF_PLUS >= 10) {
			vartmp += 4;
		}

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「希望の上履き」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIBONO_UWABAKI)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 6) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「スヴェル」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SUVEL)) > 0) {
		val += 1 * Math.floor(n_A_LEFT_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「体力の時空ブーツ」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS)) > 0) {
		if (SU_VIT >= 120) {
			val += 8 * itemCount;
		}
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS_S1)) > 0) {
		if (SU_VIT >= 120) {
			val += 8 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「体力のグローブ」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_GLOVE)) > 0) {
		if (SU_VIT >= 110) {
			val += 1 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「機械人形用増幅装置・改」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIKAININGYOYO_ZOFUKUSOCHI_KAI)) > 0) {
		val += 1 * Math.max(0, n_A_SHOULDER_DEF_PLUS - 5) * itemCount;
	}

	//----------------------------------------------------------------
	// 「機械人形用加速装置・改」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIKAININGYOYO_KASOKUSOCHI_KAI)) > 0) {
		val += -1 * Math.max(0, n_A_BODY_DEF_PLUS - 5) * itemCount;
	}

	//----------------------------------------------------------------
	// 「リアンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LIEN_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「フロワシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FROID_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソルシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SOL_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「シャレールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHALEUR_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルヴァンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LEVAIN_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「プワゾンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_POISON_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「リュミエールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LUMIERE_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソンブルシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SOMBRE_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「エスプリシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ESPRIT_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ラモールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LAMORT_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「アンティマジックスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ANTIMAGIC_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 9) {
			val += 2 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「プロテクトフェザー」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_PROTECT_FEATHER)) > 0) {
		if (SU_VIT >= 120) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「登山靴」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TOZANGUTSU)) > 0) {
		val += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「エクセリオンスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_EXELION_SUIT)) > 0) {
		val += 4 * ROUNDDOWN(n_A_BODY_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「スクトゥム」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SKTOM)) > 0) {
		if (n_A_LEFT_DEF_PLUS >= 10) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「貴族の仮面」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIZOKUNO_KAMEN)) > 0) {
		if (n_A_BaseLV >= 100) {
			val += 1 * itemCount;
		}
		if (n_A_BaseLV >= 150) {
			val += 1 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「レクイエムスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_REQUIEM_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 6) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「レクイエムローブ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_REQUIEM_ROBE)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 6) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「レクイエムマント」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_REQUIEM_MANT)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 6) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「レクイエムブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_REQUIEM_BOOTS)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 6) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「古びた風のささやき」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FURUBITA_KAZENOSASAYAKI)) > 0) {
		val += 1 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「エスランのシャツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ESLANNO_SHIRT)) > 0) {
		vartmp = 0;

		if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 4;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 6;
		if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 8;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「執行者のマント」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHIKKOSHANO_MANT)) > 0) {
		if (n_A_JOB == JOB_ID_GILOTINCROSS) {
			vartmp = 0;

			vartmp += 15;
			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 5;

			val += vartmp * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「エクセリオンレッグ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_EXCELION_LEG)) > 0) {
		vartmp = 0;

		vartmp += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		if (n_A_BaseLV >= 130) vartmp += 4;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ポロロッカシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_POROROCA_SHOES)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 7;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「与一の肩掛け」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_YOICHINO_KATAKAE)) > 0) {
		if (n_A_JOB == JOB_ID_RANGER) {
			vartmp = 0;

			vartmp += 15;
			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 5;

			val += vartmp * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギガントブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GIGANT_BOOTS)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 4;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 4;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「裁きの靴」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SABAKINO_KUTSU)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 7;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「魔呪のメイル」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MAZYUNO_MAIL)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「リンドブルムの皮」の、素ＡＧＩと素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LINDWURMNO_KAWA)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 8) {
			val += 1 * ROUNDDOWN((SU_AGI + SU_VIT) / 20) * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「巨大ウィスパーカード」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_KYODAI_WHISPER)) > 0) {
		if (SU_VIT >= 80) {
			val += 3 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エリオットカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ERIOT)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_SWORDMAN:
		case JOB_SERIES_ID_THIEF:
		case JOB_SERIES_ID_MERCHANT:
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「銃奇兵カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ZYUKIHE)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ゴールドオシドスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GOLD_OSIDOS)) > 0) {
		if (n_A_SHOES_DEF_PLUS <= 4) {
			val += 4 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ランデル＝ロレンス（ＭＶＰ）カード」の、素ＩＮＴによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RANDEL_RORENCE_MVP)) > 0) {
		if (SU_INT >= 110) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「アルフォシオ＝バジルカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ALFOSIO_BASIL)) > 0) {
		if (GetHigherJobSeriesID(n_A_JOB) == JOB_SERIES_ID_BARD) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「トレンティーニカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_TRENTINI)) > 0) {
		if (GetHigherJobSeriesID(n_A_JOB) == JOB_SERIES_ID_DANCER) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ブギスギスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_BUGISGIS)) > 0) {
		val += 1 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2) * cardCount;
	}

	//----------------------------------------------------------------
	// 「変異のシーラカンスカード」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_HENINO_COELACANTH)) > 0) {
		val += -1 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2) * cardCount;
	}

	//----------------------------------------------------------------
	// 「[LoVA] ルールーカード」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_RURU)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 1 * ROUNDDOWN(SU_STR / 60) * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「[LoVA] 真化ルールーカード」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_SHINKA_RURU)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 1 * ROUNDDOWN(SU_STR / 20) * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「プレゼント包装担当者カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_PRESENT_HOSOTANTOSHA)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「不死の軍団カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_FUSHINO_GUNDAN)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「アークビショップマーガレッタ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ARCH_BISHOP_MARGARETTE_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_ARCBISHOP) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「修羅チェン(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHURA_CHENG_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_SHURA) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ソーサラーセリア(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SORCERER_CERIA_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_SORCERER) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ミンストレルアルフォシオ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MINSTREL_ARFOSIO_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_MINSTREL) {
			val += 15 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ワンダラートレンティーニ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WANDERER_TRENTINI_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_WANDERER) {
			val += 15 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ロックステップカード」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ROCKSTEP)) > 0) {
		val += 3 * ROUNDDOWN(SU_VIT / 20) * cardCount;
	}


// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　ＳＰＥＣＩＡＬ－ＬＵＫ」の、精錬による効果
	//----------------------------------------------------------------
	vartmp = CARD_ID_ENCHANT_SPECIAL_LUK;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 9) val += 1 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 9) val += 1 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 9) val += 1 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 9) val += 1 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 9) val += 1 * cardCountShoes;
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「機械人形用増幅装置　エリオットカードセット」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_KIKAININGYOYO_ZOFUKUSOCHI_KAI_ERIOT_CARD)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_SWORDMAN:
		case JOB_SERIES_ID_THIEF:
		case JOB_SERIES_ID_MERCHANT:
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ホワイトフェザー　パイプタバコセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_WHITE_FEATHER_PIPE_TABACCO)) > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 2;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ウルズプレート　アーティファクトセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_URUZ_PLATE_ARTIFACT)) > 0) {
		if ((n_A_BODY_DEF_PLUS >= 7) && (n_A_SHOULDER_DEF_PLUS >= 7) && (n_A_SHOES_DEF_PLUS >= 7)) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「黒羽のスーツ　アーティファクトセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_KUROHANO_SUIT_ARTIFACT)) > 0) {
		if ((n_A_BODY_DEF_PLUS >= 7) && (n_A_SHOULDER_DEF_PLUS >= 7) && (n_A_SHOES_DEF_PLUS >= 7)) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「スプリントグローブ　スプリントシューズセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SPRINT_GLOVE_SPRINT_SHOES)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 2 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「リアンシューズ　リアンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LIEN_SHOES_LIEN_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「フロワシューズ　フロワマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FROID_SHOES_FROID_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソルシューズ　ソルマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SOL_SHOES_SOL_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「シャレールシューズ　シャレールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_CHALEUR_SHOES_CHALEUR_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルヴァンシューズ　ルヴァンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LEVAIN_SHOES_LEVAIN_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「プワゾンシューズ　プワゾンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_POISON_SHOES_POISON_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「リュミエールシューズ　リュミエールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LUMIERE_SHOES_LUMIERE_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソンブルシューズ　ソンブルマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SOMBRE_SHOES_SOMBRE_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「エスプリシューズ　エスプリマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_ESPRIT_SHOES_ESPRIT_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ラモールシューズ　ラモールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LAMORT_SHOES_LAMORT_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「古くピンク色のあれ　サンダルセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FURUKU_PINKIRONO_ARE_SANDAL)) > 0) {
		val += 2 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「楯無の鎧　ＲＳＸ－０８０６カードセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_TATENASHINO_YOROI_RSX_0806)) > 0) {
		val += 5 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「プロテクトフェザー　羽のベレーセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_PROTECT_FEATHER_HANENO_BERET)) > 0) {
		if (n_A_HEAD_DEF_PLUS >= 9) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「浮遊する賢者の石　アミストルキャップセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FUYUSURU_KENZYONO_ISHI_AMISTRL_CAP)) > 0) {
		val += 1 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ハイレベル　銃奇兵カードセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HIGHLEVEL_ZYUKIHE)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「アルティメットモードチェンジャー　ペオースプレートセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_ULTIMATE_MODE_CHANGER_PEORTH_PLATE)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ガーディアンプロセッサ　ガーディアンユニットセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_UNIT)) > 0) {
		vartmp = 0;

		if (n_A_BODY_DEF_PLUS >= 7) vartmp += 10;
		if (n_A_BODY_DEF_PLUS >= 9) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「暴徒のスカーフ　グラスセット」の、素ＡＧＩと素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
		val += 5 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
	}

	//----------------------------------------------------------------
	// 「暴徒のスカーフ　サングラスセット」の、素ＡＧＩと素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
		val += 5 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
	}

	//----------------------------------------------------------------
	// 「業風石　ペオースプレートセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_PLATE)) > 0) {
		vartmp = 0;

		if (n_A_BODY_DEF_PLUS >= 7) vartmp += 15;
		if (n_A_BODY_DEF_PLUS >= 9) vartmp += 15;

		val += vartmp * itemCount;
	}


// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ロイヤルガード　フォースオブバンガード」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_FORCE_OF_BANGUARD)) > 0) {
		val += 3 * sklLv;
	}

	//----------------------------------------------------------------
	// 「修羅　潜龍昇天」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SENRYU_SHOTEN)) > 0) {
		val += 2 + sklLv;
	}

	//----------------------------------------------------------------
	// 「修羅　点穴-反-」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_TENKETSU_HAN)) > 0) {
		val += -4 * sklLv;
	}

	//----------------------------------------------------------------
	// 「修羅　点穴-活-」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_TENKETSU_KATSU)) > 0) {
		val += 2 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊（Passive）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE)) > 0) {
		// 地Ｌｖ１～地Ｌｖ３のパッシブモードの場合、ＡＴＫ上昇
		if (SkillSearch(SKILL_ID_SERE_MODE) == 1) {
			if(sklLv == 10) val += 5;
			if(sklLv == 11) val += 10;
			if(sklLv == 12) val += 15;
		}
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊補助スキル（パワーオブガイア）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 35) {
			val += 20;
		}
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援デリュージ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_DELUGE)) > 0) {
		var valary = [0, 5, 9, 12, 14, 15];
		val += valary[bufLv];
	}

	//----------------------------------------------------------------
	// 「支援ゴスペル　ＨＰアップ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_GOSPEL_HP_UP)) > 0) {
		val += 100;
	}

	//----------------------------------------------------------------
	// 「支援イドゥンの林檎」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_IDUNNNO_RINGO)) > 0) {
		var bufferVitRank = ExBuffNumSearch(EXBUF_ID_IDUNNNO_RINGO_BUFFER_VITRANK);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_IDUNNNO_RINGO_BUFFER_SKILLLV);

		val += 5 + bufLv * 2 + Math.floor(bufferSkillLv / 2) + bufferVitRank;
	}

	//----------------------------------------------------------------
	// 「支援フリッグの歌」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_FRIGGNO_UTA)) > 0) {
		val += 5 * bufLv;
	}

	//----------------------------------------------------------------
	// 「支援ビヨンドオブウォークライ（敵から）」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_BEYOND_OF_WARCRAY)) > 0) {
		var bufferCount = ExBuffNumSearch(EXBUF_ID_BEYOND_OF_WARCRAY_COUNT_OF_MINWAN);
		val += -4 * (bufLv + Math.min(7, bufferCount) - 2);
	}

	//----------------------------------------------------------------
	// 「支援エピクレシス」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ODINNO_EPICLESIS)) > 0) {
		val += 5 * bufLv;
	}

	//----------------------------------------------------------------
	// 「戦闘薬」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_SENTOYAKU)) > 0) {
		if (bufLv == 1) val += -3;
		if (bufLv == 2) val += -5;
	}

	//----------------------------------------------------------------
	// 「ＯＴＰログインボーナス支援　レインボー」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_OTP_LOGIN_BONUS)) > 0) {
		if ((bufLv == 4) && (n_B_TAISEI[38] != 1)) {
			val += 20;
		}
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＭａｘＨＰ％」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_HP_UP)) > 0) {
		val += bufLv;
	}


// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}






//================================================================================================
//================================================================================================
//====
//==== ＭａｘＳＰ　＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＭａｘＳＰ＋）.
*/
function GetStatusModifyMaxSpPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;




	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_MAXSP_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「スタッフオブカーシング」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_STUFF_OF_CURSING, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_STUFF_OF_CURSING, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (n_A_Weapon_ATKplus >= 9) val += 300 * itemCountRight;
		if (n_A_Weapon2_ATKplus >= 9) val += 300 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「古代樹の杖」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KODAIZYUNO_TSUE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KODAIZYUNO_TSUE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (n_A_Weapon_ATKplus >= 6) val += -100 * itemCountRight;
		if (n_A_Weapon2_ATKplus >= 6) val += -100 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーハンマー」の、職業による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += 200 * itemCountRight;
			val += 200 * itemCountLeft;
			break;

		// ソードマン系
		case JOB_SERIES_ID_SWORDMAN:
			val += 100 * itemCountRight;
			val += 100 * itemCountLeft;
			break;

		// マーチャント系
		case JOB_SERIES_ID_MERCHANT:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// プリースト系
			case JOB_SERIES_ID_PRIEST:
				break;

			// モンク系
			case JOB_SERIES_ID_MONK:
				val += 200 * itemCountRight;
				val += 200 * itemCountLeft;
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーナイフ」の、職業による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			val += (300 + 20 * n_A_Weapon_ATKplus) * itemCountRight;
			val += (300 + 20 * n_A_Weapon_ATKplus) * itemCountLeft;
			break;

		// マジシャン系
		case JOB_SERIES_ID_MAGICIAN:
			val += 20 * n_A_Weapon_ATKplus * itemCountRight;
			val += 20 * n_A_Weapon_ATKplus * itemCountLeft;
			break;

		// シーフ系
		case JOB_SERIES_ID_THIEF:
			val += 100 * itemCountRight;
			val += 100 * itemCountLeft;
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// ハンター系
			case JOB_SERIES_ID_HUNTER:
				break;

			// バード系、ダンサー系
			case JOB_SERIES_ID_BARD:
			case JOB_SERIES_ID_DANCER:
				break;
			}
		}
	}

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「ヴァルキリーシューズ」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VALKIRIE_SHOES)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_SWORDMAN:
		case JOB_SERIES_ID_THIEF:
		case JOB_SERIES_ID_MERCHANT:
			val += 2 * n_A_JobLV * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「エーギルシューズ」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_AEGIR_SHOES)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_SWORDMAN:
		case JOB_SERIES_ID_THIEF:
		case JOB_SERIES_ID_MERCHANT:
			val += 2 * n_A_JobLV * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「アカデミーバッジ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ACADEMY_BADGE)) > 0) {
		if (n_A_BaseLV <= 79) {
			val += 200 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ブリュンヒルデ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BRUNHILD)) > 0) {
		val += 5 * n_A_BaseLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「アコライトフィギュア」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ACOLYTE_FIGURE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ACOLYTE) {
			val += 50 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「カメレオンアーマー」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHAMELEON_ARMER)) > 0) {
		val += 1 * Math.floor(n_A_BaseLV / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「スキンオブシャドウ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SKIN_OF_SHADOW)) > 0) {
		val += 1 * (Math.floor(n_A_BaseLV / 3) + (10 * n_A_SHOULDER_DEF_PLUS)) * itemCount;
	}

	//----------------------------------------------------------------
	// 「通学バッグ」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TSUGAKU_BAG)) > 0) {
		if (n_A_BaseLV <= 79) {
			val += 100 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギャラクシーサークレット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GALAXY_CIRCLET)) > 0) {
		val += 10 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIKARANO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「知力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「俊敏の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「体力の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_TAIRYOKUNO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「技巧の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「幸運の時空ブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}
	if ((itemCount = EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS_S1)) > 0) {
		val += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「[衣装]ビギナー帽」の、ベースレベルによる効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ISHO_BEGINNER_BO)) > 0) {
		if ((n_A_BaseLV >= 99) || (n_B_TAISEI[38] == 1)) {
			val += -200 * itemCount;
		}
		else {
			val += -20 * ROUNDDOWN(n_A_BaseLV / 10) * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「皇竜の天翼」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_NOVICE:
		case JOB_SERIES_ID_TAEGKUON:
		case JOB_SERIES_ID_NINJA:
		case JOB_SERIES_ID_GUNSLINGER:
			val += 100 * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「ジェスターカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_JESTER, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
		if (n_A_HEAD_DEF_PLUS >= 9) {
			val += 150 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ブルーオシドスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_BLUE_OSIDOS, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
		if (n_A_HEAD_DEF_PLUS <= 4) {
			val += 40 * cardCount;
		}
	}
	if ((cardCount = CardNumSearch(CARD_ID_BLUE_OSIDOS, CARD_REGION_ID_HEAD_MID_ANY)) > 0) {
		val += 40 * cardCount;
	}

	//----------------------------------------------------------------
	// 「バンシーカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_BANSHEE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MAGICIAN) {
			val += 100 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「アガヴカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_AGAVE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MAGICIAN) {
			val += 100 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エナジー＜守護竜＞」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_SHUGORYU)) > 0) {
		val += 1 * (Math.floor(n_A_BaseLV / 3) + (10 * n_A_SHOULDER_DEF_PLUS)) * cardCount;
	}

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－ＭａｘＳＰ」の、精錬による効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_A_MAXSP, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_A_MAXSP, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_A_MAXSP, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 6) vartmp += 30;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 100;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 6) vartmp += 30;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 100;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 6) vartmp += 30;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 100;
		val += vartmp * cardCountShoes
	}

	//----------------------------------------------------------------
	// 「エンチャント　安息のニーヴ(精神)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_ANSOKUNO_NIEVE_SEISHIN, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 6) vartmp += 20;
		if (n_A_LEFT_DEF_PLUS >= 8) vartmp += 50;
		val += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「クイールペンリング　スモールブックペンダントセット」の、ジョブレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_QUILL_PENRING_SMALL_BOOK_PENDANT)) > 0) {
		val += 1 * n_A_JobLV * itemCount;
	}

	//----------------------------------------------------------------
	// 「星タマゴバッジ　アカデミーバッジセット」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HOSHITAMAGO_BADGE_ACADEMY_BADGE)) > 0) {
		if (n_A_BaseLV <= 79) {
			val += 150 * itemCount;
		}
		else {
			val += 50 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「飛行船スーツセット」の、精錬による強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HIKOSEN_SUIT_HIKOSEN_MANT_HIKOSEN_BOOTS)) > 0) {
		vartmp = 0;

		var refinedtotal = n_A_BODY_DEF_PLUS + n_A_SHOULDER_DEF_PLUS + n_A_SHOES_DEF_PLUS;
		if (refinedtotal >= 15)  vartmp += 30;
		if (refinedtotal >= 20)  vartmp += 100;
		if (refinedtotal >= 25)  vartmp += 200;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ペルロックのスーツセット」の、精錬による強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_PELLROCKNO_SUIT_PELLROCKNO_MANT_PELLROCKNO_BOOTS)) > 0) {
		vartmp = 0;

		var refinedtotal = n_A_BODY_DEF_PLUS + n_A_SHOULDER_DEF_PLUS + n_A_SHOES_DEF_PLUS;
		if (refinedtotal >= 15)  vartmp += 30;
		if (refinedtotal >= 20)  vartmp += 100;
		if (refinedtotal >= 25)  vartmp += 200;

		val += vartmp * itemCount;
	}

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ソウルリンカー　カイナ」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_KAINA)) > 0) {
		val += 30 * sklLv;
	}

	//----------------------------------------------------------------
	// 「レンジャー　トラップ研究」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_TRAP_KENKYU)) > 0) {
		val += 200 + 20 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ミンストレル／ワンダラー　レッスン」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_LESSON)) > 0) {
		val += 30 * sklLv;
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「キューペット　エメリット」の、親密度による効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_QUEPET_EMERIT)) > 0) {
		if (bufLv >= 6) val += 25;
	}

	//----------------------------------------------------------------
	// 「キューペット　トリパット」の、親密度による効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_QUEPET_TOPARIT)) > 0) {
		if (bufLv >= 6) val += 50;
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＭａｘＳＰ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_SP_PLUS)) > 0) {
		val += bufLv;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== ＭａｘＳＰ　％ＵＰ　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＭａｘＳＰ％）.
*/
function GetStatusModifyMaxSpUp() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;



	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_MAXSP_UP);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「グロリアス量産型シューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GLORIOUS_RYOSANGATA_SHOES)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 7 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「魔法のストール」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MAHONO_STOLE)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 6) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ネクタルスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_NECTAR_SUIT)) > 0) {
		val += 1 * Math.floor(n_A_BODY_DEF_PLUS / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ＢＯＳＳ帽」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BOSS_BO)) > 0) {
		vartmp = 0;

		vartmp += -2 * Math.max(0, n_A_HEAD_DEF_PLUS - 4);
		if (n_A_HEAD_DEF_PLUS >= 10) {
			vartmp += -3;
		}

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「希望の上履き」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIBONO_UWABAKI)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 6) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「機械人形用増幅装置・改」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIKAININGYOYO_ZOFUKUSOCHI_KAI)) > 0) {
		val += 1 * Math.max(0, (n_A_SHOULDER_DEF_PLUS - 5)) * itemCount;
	}


	//----------------------------------------------------------------
	// 「リアンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LIEN_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「フロワシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FROID_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソルシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SOL_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「シャレールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHALEUR_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルヴァンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LEVAIN_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「プワゾンシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_POISON_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「リュミエールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LUMIERE_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソンブルシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SOMBRE_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「エスプリシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ESPRIT_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ラモールシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_LAMORT_SHOES)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「登山靴」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TOZANGUTSU)) > 0) {
		val += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「スクトゥム」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SKTOM)) > 0) {
		if (n_A_LEFT_DEF_PLUS >= 10) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「執行者のマント」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHIKKOSHANO_MANT)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 9) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「エクセリオンレッグ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_EXCELION_LEG)) > 0) {
		vartmp = 0;

		vartmp += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		if (n_A_BaseLV >= 130) {
			vartmp += 4;
		}

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「ポロロッカシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_POROROCA_SHOES)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 7;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「与一の肩掛け」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_YOICHINO_KATAKAE)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 9) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギガントブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_GIGANT_BOOTS)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 4;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 4;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「裁きの靴」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SABAKINO_KUTSU)) > 0) {
		vartmp = 0;

		if (n_A_SHOES_DEF_PLUS >= 5) vartmp += 7;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「魔呪のメイル」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MAZYUNO_MAIL)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「バリアントシューズ」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VARIANT_SHOES)) > 0) {
		val += -1 * n_A_SHOES_DEF_PLUS * itemCount;
	}


// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「銃奇兵カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ZYUKIHE)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ゴールドオシドスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GOLD_OSIDOS)) > 0) {
		if (n_A_SHOES_DEF_PLUS <= 4) {
			val += 4 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エリオットカード」の、職業よる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ERIOT)) > 0) {
		vartmp = 0;

		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_ACOLYTE:
		case JOB_SERIES_ID_ARCHER:
		case JOB_SERIES_ID_MAGICIAN:
			vartmp += 5;

			if (EquipNumSearch(ITEM_SET_ID_KIKAININGYOYO_ZOFUKUSOCHI_KAI_ERIOT_CARD) > 0) {
				vartmp += 5;
			}
		}

		val += vartmp * cardCount;
	}

	//----------------------------------------------------------------
	// 「アルフォシオ＝バジルカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ALFOSIO_BASIL)) > 0) {
		if (GetHigherJobSeriesID(n_A_JOB) == JOB_SERIES_ID_BARD) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「トレンティーニ」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_TRENTINI)) > 0) {
		if (GetHigherJobSeriesID(n_A_JOB) == JOB_SERIES_ID_DANCER) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「暴虐のシーラカンスカード」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	cardCountHeadTop = CardNumSearch(CARD_ID_BOGYAKUNO_COELACANTH, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid = CardNumSearch(CARD_ID_BOGYAKUNO_COELACANTH, CARD_REGION_ID_HEAD_MID_ANY);
	if (cardCountHeadTop + cardCountHeadMid > 0) {
		val += -1 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2) * cardCountHeadTop;
		// 中段は精錬できないため、効果を発揮しない
	}


	//----------------------------------------------------------------
	// 「[LoVA] キマカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_KIMA)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 1 * ROUNDDOWN(SU_INT / 30) * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「[LoVA] 真化キマカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LOVA_SHINKA_KIMA)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 7) {
			val += 1 * ROUNDDOWN(SU_INT / 10) * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「プレゼント包装担当者カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_PRESENT_HOSOTANTOSHA)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エナジー＜魔導＞」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_MADO)) > 0) {
		val += 1 * Math.max(0, (n_A_SHOULDER_DEF_PLUS - 4)) * cardCount;
	}

	//----------------------------------------------------------------
	// 「不死の軍団カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_FUSHINO_GUNDAN)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ミンストレルアルフォシオ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MINSTREL_ARFOSIO_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_MINSTREL) {
			val += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ワンダラートレンティーニ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WANDERER_TRENTINI_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_WANDERER) {
			val += 10 * cardCount;
		}
	}

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　ＳＰＥＣＩＡＬ－ＶＩＴ」の、精錬による効果
	//----------------------------------------------------------------
	vartmp = CARD_ID_ENCHANT_SPECIAL_VIT;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 9) val += 1 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 9) val += 1 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 9) val += 1 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 9) val += 1 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 9) val += 1 * cardCountShoes;
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「桜花冠　花びらセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_OKAKAN_HANABIRA)) > 0) {
		val += 1 * Math.max(0, (n_A_HEAD_DEF_PLUS - 6)) * itemCount;
	}

	//----------------------------------------------------------------
	// 「スプリントグローブ　スプリントメイルセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SPRINT_GLOVE_SPRINT_MAIL)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 2 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「リアンシューズ　リアンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LIEN_SHOES_LIEN_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「フロワシューズ　フロワマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FROID_SHOES_FROID_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソルシューズ　ソルマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SOL_SHOES_SOL_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「シャレールシューズ　シャレールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_CHALEUR_SHOES_CHALEUR_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ルヴァンシューズ　ルヴァンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LEVAIN_SHOES_LEVAIN_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「プワゾンシューズ　プワゾンマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_POISON_SHOES_POISON_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「リュミエールシューズ　リュミエールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LUMIERE_SHOES_LUMIERE_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ソンブルシューズ　ソンブルマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_SOMBRE_SHOES_SOMBRE_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「エスプリシューズ　エスプリマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_ESPRIT_SHOES_ESPRIT_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ラモールシューズ　ラモールマントセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_LAMORT_SHOES_LAMORT_MANT)) > 0) {
		val += 1 * n_A_SHOULDER_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「古くピンク色のアレ　サンダルセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FURUKU_PINKIRONO_ARE_SANDAL)) > 0) {
		val += 2 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「浮遊する賢者の石　たれリーフセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_FUYUSURU_KENZYONO_ISHI_TARE_LEAF)) > 0) {
		val += 1 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ハイレベル　銃奇兵カードセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HIGHLEVEL_ZYUKIHE)) > 0) {
		if (n_A_SHOES_DEF_PLUS >= 9) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「紅蓮のストール　呪われたロイヤルナイトカードセット」の、効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_GURENNO_STOLE_NOROWARETA_ROYAL_KNIGHT)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			val += 44 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「堕ちた大神官ヒバムカード　暴走した魔力セット」の、効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_SET_ID_OCHITA_DAISHINKAN_HIBAM_ENCHANT_BOSOSHITA_MARYOKU)) > 0) {
		val += 50 * cardCount;
	}

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ハイプリースト　メディタティオ」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_MEDITATIO)) > 0) {
		val += 1 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ハイウィザード　ソウルドレイン」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SOUL_DRAIN)) > 0) {
		val += 2 * sklLv;
	}

	//----------------------------------------------------------------
	// 「修羅　潜龍昇天」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SENRYU_SHOTEN)) > 0) {
		val += 2 + sklLv;
	}


// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「ダンサー　サービスフォーユー」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_SERVICE_FOR_YOU)) > 0) {
		var bufferIntRank = ExBuffNumSearch(EXBUF_ID_SERVICE_FOR_YOU_BUFFER_INTRANK);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_SERVICE_FOR_YOU_BUFFER_SKILLLV);

		val += 15 + bufLv + Math.floor(bufferSkillLv / 2) + bufferIntRank;
	}

	//----------------------------------------------------------------
	// 「支援ゴスペル　ＳＰアップ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_GOSPEL_SP_UP)) > 0) {
		val += 100 * bufLv;
	}

	//----------------------------------------------------------------
	// 「ビタタ５００」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_VITATA500)) > 0) {
		val += 5 * bufLv;
	}

	//----------------------------------------------------------------
	// 「ＳＰ増加ポーション」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_SPZOKA_POTION)) > 0) {
		val += -10 + 5 * bufLv + ROUNDDOWN(n_A_BaseLV / 10);
	}

	//----------------------------------------------------------------
	// 「戦闘薬」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_SENTOYAKU)) > 0) {
		if (bufLv == 1) val += -3;
		if (bufLv == 2) val += -5;
	}

	//----------------------------------------------------------------
	// 「ＯＴＰログインボーナス支援　レインボー」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_OTP_LOGIN_BONUS)) > 0) {
		if ((bufLv == 4) && (n_B_TAISEI[38] != 1)) {
			val += 20;
		}
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＭａｘＳＰ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_SP_UP)) > 0) {
		val += bufLv;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== 除算ＤＥＦ＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（除算ＤＥＦ＋）.
*/
function GetStatusModifyDefDivPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;



	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_DEF_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「ルナボウ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_RUNA_BOW, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_RUNA_BOW, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		vartmp = 0;
		vartmp += 2;
		if (n_A_Weapon_ATKplus >= 6) vartmp += 3;
		if (n_A_Weapon_ATKplus >= 9) vartmp += 2;
		val += vartmp * itemCountRight;

		vartmp = 0;
		vartmp += 2;
		if (n_A_Weapon2_ATKplus >= 6) vartmp += 3;
		if (n_A_Weapon2_ATKplus >= 9) vartmp += 2;
		val += vartmp * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ゲートキーパーＤＤ」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_GATE_KEEPER_DD, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_GATE_KEEPER_DD, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * n_A_Weapon_ATKplus * itemCountRight;
		val += 1 * n_A_Weapon2_ATKplus * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「カルド」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KARD, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KARD, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.floor(n_A_Weapon_ATKplus / 2) * itemCountRight;
		val += 1 * Math.floor(n_A_Weapon2_ATKplus / 2) * itemCountLeft;
	}


// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「サンタのひげ」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SANTANO_HIGE)) > 0) {
		val += -5 * itemCount;
	}

	//----------------------------------------------------------------
	// 「バリアントシューズ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VARIANT_SHOES)) > 0) {
		val += 1 * Math.floor(n_A_SHOES_DEF_PLUS / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「カメレオンアーマー」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHAMELEON_ARMER)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_SWORDMAN:
		case JOB_SERIES_ID_THIEF:
		case JOB_SERIES_ID_MERCHANT:
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ソードマンフィギュア」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SWORDMAN_FIGURE)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_SWORDMAN) {
			val += 2 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「シュミッツのヘルム」の、素ＩＮＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SCHMITTNO_HELM)) > 0) {
		if (SU_INT >= 120) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「戦死者のマント」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)) > 0) {
		if (SU_VIT >= 130) {
			if (EquipNumSearchFurubitaSet() > 0) {
				val += 600 * itemCount;
			} else {
				val += 300 * itemCount;
			}
		}
	}

	//----------------------------------------------------------------
	// 「古びた守護の冠」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FURUBITA_SHUGONOKANNMURI)) > 0) {
		val += 30 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「金剛石の盾」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KONGOSEKINO_TATE)) > 0) {
		if (n_A_BaseLV >= 150) {
			val += 100 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「金剛石の盾」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KONGOSEKINO_TATE)) > 0) {
		val += 20 * ROUNDDOWN(n_A_LEFT_DEF_PLUS / 3) * itemCount;
	}

	//----------------------------------------------------------------
	// 「バレルヘルム」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BARREL_HELM)) > 0) {
		if (n_A_HEAD_DEF_PLUS >= 7) {
			val += 100 * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「アクラウスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ARCLOUSE)) > 0) {
		if (n_A_LEFT_DEF_PLUS <= 5) {
			val += 2 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ゴートカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GOAT)) > 0) {
		if (n_A_BODY_DEF_PLUS <= 5) {
			val += 2 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ロイヤルガードランデル(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ROYAL_GUARD_RANDEL_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_ROYALGUARD) {
			val += 350 * cardCount;
		}
	}

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－Ｄｅｆ」の、精錬による効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_A_DEF, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_A_DEF, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_A_DEF, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 6) vartmp += 15;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 30;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 6) vartmp += 15;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 30;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 6) vartmp += 15;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 30;
		val += vartmp * cardCountShoes
	}

	//----------------------------------------------------------------
	// 「エンチャント　死のニーヴ(体力)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_SHINO_NIEVE_TAIRYOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 15;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 25;
		val += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「オーディンの祝福　マグニセット」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_ODINNO_SHUKUFUKU_MAGNI_SET)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_SWORDMAN) {
			val += 6 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「オーディンの祝福　フリッグセット」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ODINNO_SHUKUFUKU_FRIGG_SET)) > 0) {
		val += -1 * (n_A_HEAD_DEF_PLUS + n_A_LEFT_DEF_PLUS) * itemCount;
	}

	//----------------------------------------------------------------
	// 「スプリントメイル　シークレットセット」の、効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SPRINT_MAIL)) > 0) {
		var itemCountTmp = 0;
		itemCountTmp += EquipNumSearch(ITEM_ID_LONG_HORN);
		itemCountTmp += EquipNumSearch(ITEM_ID_BATTLE_FOOK);
		itemCountTmp += EquipNumSearch(ITEM_ID_HUNTING_SPEAR);

		if (itemCountTmp > 0) {
			val += 2 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「楯無の鎧　楯無の兜セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_TATENASHINO_YOROI_TATENASHINO_KABUTO)) > 0) {
		vartmp = 0;

		vartmp += 15 * n_A_BODY_DEF_PLUS;
		vartmp += 15 * n_A_HEAD_DEF_PLUS;

		val += vartmp * itemCount;
	}

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「メカニック　メインフレーム改造」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_MAINFRAME_KAIZO)) > 0) {
		val += 20 + 20 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　プレスティージ」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_PRESTAGE)) > 0) {
		var sklLvDefender = SkillSearch(SKILL_ID_SKILL_LV_DEFENDER_FOR_PRESTAGE);
		vartmp = 0;

		vartmp += Math.floor(15 * sklLv * n_A_BaseLV / 100);
		vartmp += Math.floor(sklLvDefender / 5 * n_A_BaseLV / 2);

		val += vartmp;
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　シールドスペル（ＤＥＦ＋）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SHIELD_SPELL_DEF_PLUS)) > 0) {
		if (sklLv == 1) {
			val += Math.floor(10 * n_A_LEFT_DEF_PLUS * n_A_BaseLV / 100);
		}
		else {
			val += Math.floor(10 * (SkillSearch(745) - 1) * n_A_BaseLV / 100);
		}
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　バンディング」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_COUNT_OF_RG_FOR_BANDING)) > 0) {
		var sklLvBanding = SkillSearch(SKILL_ID_BANDING);
		val += (5 + sklLvBanding) * (sklLv + 1);
	}

	//----------------------------------------------------------------
	// 「ルーンナイト　ストーンハードスキン」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_STONE_HARD_SKIN)) > 0) {
		var sklLvRuneMastery = SkillSearch(SKILL_ID_RUNE_MASTERY);
		val += Math.floor(n_A_JobLV * sklLvRuneMastery / 4);
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊スキル　パワーオブガイア」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 35) {
			val += 100;
		}
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援戦太鼓の響き」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_IKUSADAIKONO_HIBIKI)) > 0) {
		val += 10 * bufLv;
	}

	//----------------------------------------------------------------
	// 「支援オーディンの力」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ODINNO_CHIKARA)) > 0) {
		if (bufLv == 1) val -= 20;
		if (bufLv == 2) val -= 40;
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　Ｄｅｆ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_DEF_PLUS)) > 0) {
		val += bufLv;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== 除算Ｄｅｆ　％ＵＰ　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（Ｄｅｆ％）.
*/
function GetStatusModifyDefDivUp() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;


//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ロイヤルガード　フォースオブバンガード」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_FORCE_OF_BANGUARD)) > 0) {
		val += 2 * sklLv;
	}

	//----------------------------------------------------------------
	// 「影狼・朧　土符」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_FU_ELEMENT_OF_FU)) > 0) {
		if (sklLv == ELM_ID_EARTH) {
			val += 10 * SkillSearch(SKILL_ID_FU_COUNT_OF_FU);
		}
	}

	//----------------------------------------------------------------
	// 「レンジャー　カモフラージュ」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_CAMOUFLAGE)) > 0) {
		val += -5 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊補助スキル　ウォーターバリア」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 17) {
			val += 30;
		}
	}

	//----------------------------------------------------------------
	// 「ソーサラー　精霊補助スキル　ソリッドスキン」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 29) {
			val += 100;
		}
	}

	//----------------------------------------------------------------
	// 「ジェネティック　Ｓホム　オーバードブースト」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_OVERED_BOOST)) > 0) {
		val += -50;
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援アスムプティオ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ASUMUPTIO)) > 0) {
		if (n_B_TAISEI[38]) {
			val += 35;
		}
		else {
			val += 100;
		}
	}

	//----------------------------------------------------------------
	// 「支援エコーの歌」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ECHONO_UTA)) > 0) {
		bufferJobLv = ExBuffNumSearch(EXBUF_ID_ECHONO_UTA_BUFFER_JOBLV);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_ECHONO_UTA_BUFFER_SKILLLV);

		val += (6 * bufLv) + (bufferSkillLv) + Math.floor(bufferJobLv / 4);
	}

	//----------------------------------------------------------------
	// 「支援フライデーナイトフィーバー」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_FRYDAY_NIGHT_FEVER)) > 0) {
		val += -1 * (10 + 10 * bufLv);
	}

	//----------------------------------------------------------------
	// キャラクター状態異常　毒
	//----------------------------------------------------------------
	if (n_A_IJYOU[2]) {
		val -= 25;
	}

	//----------------------------------------------------------------
	// キャラクター状態異常　氷結
	//----------------------------------------------------------------
	if (n_A_IJYOU[5]) {
		val -= 10;
	}

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== 除算ＭＤＥＦ＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（除算ＭＤＥＦ＋）.
*/
function GetStatusModifyMdefDivPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;



	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_MDEF_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「ラクリマスティック」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_LACRYMA_STICK, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_LACRYMA_STICK, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * n_A_Weapon_ATKplus * itemCountRight;
		val += 1 * n_A_Weapon2_ATKplus * itemCountLeft;
	}


// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「カメレオンアーマー」の、職業による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHAMELEON_ARMER)) > 0) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {
		case JOB_SERIES_ID_ACOLYTE:
		case JOB_SERIES_ID_ARCHER:
		case JOB_SERIES_ID_MAGICIAN:
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「たれリーフ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TARE_LEAF)) > 0) {
		val += 1 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「真っ赤なドレスハット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MAKKANA_DRESSHAT)) > 0) {
		val += 1 * Math.floor(n_A_HEAD_DEF_PLUS / 2) * itemCount;
	}

	//----------------------------------------------------------------
	// 「ビョンウンゴブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BANGUNGOT_BOOTS)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「バヤニ・ビョンウンゴブーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BAYANI_BANGUNGOT_BOOTS)) > 0) {
		val += 1 * n_A_SHOES_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ナチュラルクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_NATURAL_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「シェファードクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHEPHARD_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ヴァーミンクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VERMIN_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「アグリカルチュラルクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_AGRICULTURAL_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「オルカクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ORCA_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ヴィシャスクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_VICIOUS_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ドラゴンクロース」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_DRAGON_CLOTH)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「アンティマジックスーツ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ANTIMAGIC_SUIT)) > 0) {
		if (n_A_BODY_DEF_PLUS >= 7) {
			val += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「プロテクトフェザー」の、素ＶＩＴによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_PROTECT_FEATHER)) > 0) {
		if (SU_VIT >= 120) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「勇者のマジックコート」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_YUSHANO_MAGIC_COAT)) > 0) {
		if (n_A_BODY_DEF_PLUS % 2 == 0) {
			val += 1 * ROUNDDOWN(n_A_BODY_DEF_PLUS / 2) * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「古びたブレイジングソウル」の、精錬による強化
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FURUBITA_BLAZINGSOUL)) > 0) {
		val += 1 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「死霊魔術師のニット帽」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHIRYOMAZYUTSUSHINO_NITTOBO)) > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 5;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 5;

		w += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「火雷大神靴　月夜花カード　セット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_HONOIKADUCHINOOOKAMI_KUTSU_WORUYAFA)) > 0) {
		if (n_A_BaseLV <= 99) {
			val += 5 * n_A_SHOES_DEF_PLUS * itemCount;
		} else {
			val += 10 * n_A_SHOES_DEF_PLUS * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「ライドワードカード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RIDEWORD)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ACOLYTE) {
			val += 1 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「スティングカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_STING)) > 0) {
		if (n_A_LEFT_DEF_PLUS >= 9) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ジビットカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GIBBET, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
		if (n_A_HEAD_DEF_PLUS <= 5) {
			val += 5 * cardCount;
		}
	}
	if ((cardCount = CardNumSearch(CARD_ID_GIBBET, CARD_REGION_ID_HEAD_MID_ANY)) > 0) {
		val += 5 * cardCount;
	}

	//----------------------------------------------------------------
	// 「アクラウスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ARCLOUSE)) > 0) {
		if (n_A_LEFT_DEF_PLUS <= 5) {
			val += 3 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ゴートカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GOAT)) > 0) {
		if (n_A_BODY_DEF_PLUS <= 5) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「メガリスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MEGALITH)) > 0) {
		if (n_A_SHOES_DEF_PLUS <= 5) {
			val += 7 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「河童カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_KAPPA)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS <= 5) {
			val += 8 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「プルスカード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_FRUS)) > 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MAGICIAN) {
			val += 3 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「エナジー＜魔導＞」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_MADO)) > 0) {
		val += 1 * Math.max(0, (n_A_SHOULDER_DEF_PLUS - 4)) * cardCount;
	}

	//----------------------------------------------------------------
	// 「ウォーロックカトリーヌ(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WARLOCK_CATHERINE_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_WARLOCK) {
			val += 80 * cardCount;
		}
	}


// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－Ｍｄｅｆ」の、精錬による効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_ENCHANT_A_MDEF, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_ENCHANT_A_MDEF, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_ENCHANT_A_MDEF, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 6) vartmp += 4;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 8;
		val += vartmp * cardCountShoes
	}

	//----------------------------------------------------------------
	// 「エンチャント　死のニーヴ(魔防)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_SHINO_NIEVE_MABO, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 6;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 10;
		val += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}


// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「オーディンの祝福　フリッグセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ODINNO_SHUKUFUKU_FRIGG_SET)) > 0) {
		val += 1 * (n_A_HEAD_DEF_PLUS + n_A_LEFT_DEF_PLUS) * itemCount;
	}

	//----------------------------------------------------------------
	// 「プラチナリング　ウェディングセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_PLATINUM_RING_WEDDING_GOODS)) > 0) {
		val += 1 * (n_A_HEAD_DEF_PLUS + n_A_BODY_DEF_PLUS + n_A_SHOES_DEF_PLUS) * itemCount;
	}


// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ソードマン　インデュア」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_ENDURE)) > 0) {
		val += sklLv;
	}

	//----------------------------------------------------------------
	// 「ロードナイト　コンセントレイション」の、効果
	//----------------------------------------------------------------
	else if ((sklLv = SkillSearch(SKILL_ID_CONCENTRATION)) > 0) {
		val += 1;
	}

	//----------------------------------------------------------------
	// 「ルーンナイト　ストーンハードスキン」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_STONE_HARD_SKIN)) > 0) {
		val += Math.floor(n_A_JobLV * SkillSearch(SKILL_ID_RUNE_MASTERY) / 4);
	}


// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援オーディンの力」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ODINNO_CHIKARA)) > 0) {
		if (bufLv == 1) val -= 20;
		if (bufLv == 2) val -= 40;
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　Ｍｄｅｆ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_MDEF_PLUS)) > 0) {
		val += bufLv;
	}


// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}






//================================================================================================
//================================================================================================
//====
//==== 除算Ｍｄｅｆ　％ＵＰ　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（Ｍｄｅｆ％）.
*/
function GetStatusModifyMdefDivUp() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;


//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「アヌビスの帽子」の、効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ANUBISNO_BOSHI)) > 0) {
		val += -50 * itemCount;
	}


// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「ソーサラー　精霊補助スキル　ウォーターバリア」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL)) > 0) {
		if (sklLv == 17) {
			val += 20;
		}
	}

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援アスムプティオ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_ASUMUPTIO)) > 0) {
		if (n_B_TAISEI[38]) {
			val += 35;
		}
		else {
			val += 100;
		}
	}

	//----------------------------------------------------------------
	// 「支援恋人たちのためのシンフォニー」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY)) > 0) {
		bufferJobLv = ExBuffNumSearch(EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_JOBLV);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_KOIBITOTACHINOTAMENO_SYMPHONY_BUFFER_SKILLLV);

		val += (12 * bufLv) + (2 * bufferSkillLv) + Math.floor(bufferJobLv / 2);
	}


// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}





//================================================================================================
//================================================================================================
//====
//==== ＨＩＴ　＋○○　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＨＩＴ＋）.
*/
function GetStatusModifyHitPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;



	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	val += GetRndEnchValue(ITEM_SP_HIT_PLUS);

//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

	//----------------------------------------------------------------
	// 「ジャングルカービン」の、素ＤＥＸによる効果（ペナルティ）
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_JUNGLE_CARBIN, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_JUNGLE_CARBIN, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += -1 * Math.floor(SU_DEX / 3) * itemCountRight;
		val += -1 * Math.floor(SU_DEX / 3) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ギガントアックス」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_GIGANT_AXE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_GIGANT_AXE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (SU_STR >= 95) {
			val += 10 * itemCountRight;
			val += 10 * itemCountLeft;
		}
	}

	//----------------------------------------------------------------
	// 「蛸引包丁」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_TAKOHIKI_HOCHO, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_TAKOHIKI_HOCHO, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * n_A_Weapon_ATKplus * itemCountRight;
		val += 1 * n_A_Weapon2_ATKplus * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「エージェントカタール」の、素ＬＵＫによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_AGENT_KATAR, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_AGENT_KATAR, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.floor(SU_LUK / 2) * itemCountRight;
		val += 1 * Math.floor(SU_LUK / 2) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「メテオストライク」の、スキル習得による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_METEOR_STRIKE, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_METEOR_STRIKE, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 5 * SkillSearch(SKILL_ID_ONO_SHUREN) * itemCountRight;
		val += 5 * SkillSearch(SKILL_ID_ONO_SHUREN) * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「錆びたアーム」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_SABITA_ARM, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_SABITA_ARM, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (n_A_Weapon_ATKplus >= 7) val += 15 * itemCountRight;
		if (n_A_Weapon2_ATKplus >= 7) val += 15 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーハンマー」の、職業による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {

		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			n_A_HIT += 10 * itemCountRight;
			n_A_HIT += 10 * itemCountLeft;
			break;

		// ソードマン系
		case JOB_SERIES_ID_SWORDMAN:
			break;

		// マーチャント系
		case JOB_SERIES_ID_MERCHANT:
			n_A_HIT += 10 * itemCountRight;
			n_A_HIT += 10 * itemCountLeft;
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// プリースト系
			case JOB_SERIES_ID_PRIEST:
				break;

			// モンク系
			case JOB_SERIES_ID_MONK:
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「アヴェンジャーショットガン」の、精錬による効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_AVENGER_SHOTGUN, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_AVENGER_SHOTGUN, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		if (n_A_Weapon_ATKplus >= 9) val += 100 * itemCountRight;
		if (n_A_Weapon2_ATKplus >= 9) val += 100 * itemCountLeft;
	}

	//----------------------------------------------------------------
	// 「荒野の用心棒」の、素ＡＧＩによる効果
	//----------------------------------------------------------------
	itemCountRight = EquipNumSearch(ITEM_ID_KOYANO_YOZINBO, EQUIP_REGION_ID_ARMS_RIGHT);
	itemCountLeft = EquipNumSearch(ITEM_ID_KOYANO_YOZINBO, EQUIP_REGION_ID_ARMS_LEFT);
	if ((itemCountRight > 0) || (itemCountLeft > 0)) {
		val += 1 * Math.floor(SU_AGI / 10) * itemCountRight;
		val += 1 * Math.floor(SU_AGI / 10) * itemCountLeft;
	}

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

	//----------------------------------------------------------------
	// 「盗賊の指輪」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TOZOKUNO_YUBIWA)) > 0) {
		if (SU_STR >= 90) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「ブレイジングソウル」の、素ＳＴＲによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_BLAZING_SOUL)) > 0) {
		if (SU_STR >= 120) {
			val += 3 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「囚人の服」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SHUZINNO_FUKU)) > 0) {
		val += 1 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「ホワイトフェザー」の、精錬による効果（ペナルティ）
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_WHITE_FEATHER)) > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 5) vartmp += -10;
		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += -3;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += -3;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「百戦錬磨のお守り」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_HYAKUSENRENMANO_OMAMORI)) > 0) {
		vartmp = 0;

		if (SU_STR >= 100) vartmp += 2;
		if (SU_STR >= 120) vartmp += 3;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「狩人のマント」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KARYUDONO_MANT)) > 0) {
		val += 1 * Math.max(0, n_A_SHOULDER_DEF_PLUS - 5) * itemCount;
	}

	//----------------------------------------------------------------
	// 「剣聖の王冠」の、スキル習得による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KENSENO_OKAN)) > 0) {
		if (SkillSearch(SKILL_ID_KEN_SHUREN) == 10) {
			val += 10 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「器用さのグローブ」の、素ＤＥＸによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_KIYOSANO_GLOVE)) > 0) {
		val += 1 * ROUNDDOWN(SU_DEX / 10) * itemCount;
	}

	//----------------------------------------------------------------
	// 「[衣装]ビギナー帽」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ISHO_BEGINNER_BO)) > 0) {
		if ((n_A_BaseLV >= 99) || (n_B_TAISEI[38] == 1)) {
			val += -30 * itemCount;
		}
		else {
			val += -3 * ROUNDDOWN(n_A_BaseLV / 10) * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「古びた迷彩ウサギフード」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_FURUBITA_MEISAIUSAGI)) > 0) {
		val += 2 * n_A_HEAD_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「炎竜の鎧」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_ENRYUNO_YOROI)) > 0) {
		vartmp = 0;

		if (n_A_BODY_DEF_PLUS >= 7) vartmp += 10;
		if (n_A_BODY_DEF_PLUS >= 9) vartmp += 10;

		val += vartmp * itemCount;
	}

	//----------------------------------------------------------------
	// 「マタギの剣鉈」の、素ＬＵＫによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_MATAGINO_KENNATA)) > 0) {
		if (SU_LUK >= 100) {
			val += 5 * itemCount;
		}
	}

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

	//----------------------------------------------------------------
	// 「ソードガーディアンカード」の、武器種別による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SWORD_GUARDIAN)) > 0) {
		if ((n_A_WeaponType == ITEM_KIND_SWORD) || (n_A_WeaponType == ITEM_KIND_SWORD_2HAND)) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ボウガーディアンカード」の、武器種別による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_BOW_GUARDIAN)) > 0) {
		if (n_A_WeaponType == ITEM_KIND_BOW) {
			val += 5 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「イフリートカード」の、ジョブレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_EFREET)) > 0) {
		val += 1 * Math.floor(n_A_JobLV /10) * cardCount;
	}

	//----------------------------------------------------------------
	// 「ガーティー＝ウー（ＭＶＰ）カード」の、素ＬＵＫによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GERTIE_UH_MVP)) > 0) {
		if (SU_LUK >= 110) {
			val += 20 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ローラカード」の、武器種別による効果（ペナルティ）
	//----------------------------------------------------------------
	cardCountRight = CardNumSearch(CARD_ID_LOLA, CARD_REGION_ID_ARMS_RIGHT_ANY);
	cardCountLeft = CardNumSearch(CARD_ID_LOLA, CARD_REGION_ID_ARMS_LEFT_ANY);
	if ((cardCountRight > 0) || (cardCountLeft > 0)) {
		if (n_A_WeaponType == ITEM_KIND_CLUB) {
			n_A_HIT += -1 * (10 + 1 * n_A_Weapon_ATKplus) * cardCountRight;
			n_A_HIT += -1 * (10 + 1 * n_A_Weapon2_ATKplus) * cardCountLeft;
		}
	}

	//----------------------------------------------------------------
	// 「レオ」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_LEO, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
		// 修羅限定の効果
		if (n_A_JOB == JOB_ID_SHURA) {
			val += 2 * n_A_HEAD_DEF_PLUS * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「メカニックハワード(MVP)カード」の、職業による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MECHANIC_HAWARD_MVP)) > 0) {
		if (n_A_JOB == JOB_ID_MECHANIC) {
			val += 20 * cardCount;
		}
	}

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

	//----------------------------------------------------------------
	// 「エンチャント　金牛宮」の、精錬による効果
	//----------------------------------------------------------------
	cardCountHeadTop = CardNumSearch(CARD_ID_ENCHANT_KINGYUKYU, CARD_REGION_ID_HEAD_TOP_ANY);
	if (cardCountHeadTop > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 3;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 1;

		val += vartmp * cardCountHeadTop
	}

	//----------------------------------------------------------------
	// 「エンチャント　Ａ－Ｈｉｔ」の、精錬による効果
	//----------------------------------------------------------------
	cardCountBody	  = CardNumSearch(CARD_ID_ENCHANT_A_HIT, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder = CardNumSearch(CARD_ID_ENCHANT_A_HIT, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes	  = CardNumSearch(CARD_ID_ENCHANT_A_HIT, CARD_REGION_ID_SHOES_ANY);
	if (cardCountBody + cardCountShoulder + cardCountShoes > 0) {

		// 体防具へのエンチャント
		vartmp = 0;
		if (n_A_BODY_DEF_PLUS >= 7) vartmp += 10;
		if (n_A_BODY_DEF_PLUS >= 8) vartmp += 10;
		if (n_A_BODY_DEF_PLUS >= 9) vartmp += 10;
		val += vartmp * cardCountBody

		// 肩防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 10;
		if (n_A_SHOULDER_DEF_PLUS >= 8) vartmp += 10;
		if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 10;
		val += vartmp * cardCountShoulder

		// 靴防具へのエンチャント
		vartmp = 0;
		if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;
		if (n_A_SHOES_DEF_PLUS >= 8) vartmp += 10;
		if (n_A_SHOES_DEF_PLUS >= 9) vartmp += 10;
		val += vartmp * cardCountShoes


		// ライオットチップとのセット効果
		if (EquipNumSearch(ITEM_SET_ID_RIOTCHIP_A_HIT)) {
			val += 5 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 3);
		}
	}


// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

	//----------------------------------------------------------------
	// 「ホワイトフェザー　パイプタバコセット」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_SET_ID_WHITE_FEATHER_PIPE_TABACCO)) > 0) {
		vartmp = 0;

		if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 1;
		if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 1;

		val += vartmp * itemCount;
	}

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

	//----------------------------------------------------------------
	// 「アーチャー　ワシの目」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_WASHINO_ME)) > 0) {
		val += 1 * sklLv;
	}

	//----------------------------------------------------------------
	// 「スナイパー　トゥルーサイト」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_TRUE_SIGHT)) > 0) {
		val += 3 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ロードナイト　コンセントレイション」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_CONCENTRATION)) > 0) {
		val += 10 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ガンスリンガー　スネークアイ」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SNAKE_EYE)) > 0) {
		val += 1 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ガンスリンガー　アジャストメント」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_ADJUSTMENT)) > 0) {
		val -= 30;
	}

	//----------------------------------------------------------------
	// 「ガンスリンガー　インクリージングアキュラシー」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_INCREASING_ACCURACY)) > 0) {
		val += 20;
	}

	//----------------------------------------------------------------
	// 「ガンスリンガー　シングルアクション」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_SINGLE_ACTION)) > 0) {
		val += 2 * sklLv;
	}

	//----------------------------------------------------------------
	// 「ロイヤルガード　インスピレーション」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_INSPIRATION)) > 0) {
		val += 5 * sklLv + Math.floor(n_A_JobLV / 2);
	}

	//----------------------------------------------------------------
	// 「メカニック　斧修練（メカニック）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_ONO_SHUREN_MECHANIC)) > 0) {
		vartmp = 0;

		switch (n_A_WeaponType) {
		case ITEM_KIND_AXE:
		case ITEM_KIND_AXE_2HAND:
			vartmp = 3;
			break;

		case ITEM_KIND_CLUB:
			vartmp = 2;
			break;
		}

		val += vartmp * sklLv;
	}

	//----------------------------------------------------------------
	// 「ジェネティック　剣修練（ジェネティック）」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_KEN_SHUREN_GENETIC)) > 0) {
		vartmp = 0;

		switch (n_A_WeaponType) {
		case ITEM_KIND_KNIFE:
		case ITEM_KIND_SWORD:
			vartmp = 3;
			break;
		}

		val += vartmp * sklLv;
	}

	//----------------------------------------------------------------
	// 「リベリオン　ヒートバレル」の、効果
	//----------------------------------------------------------------
	if ((sklLv = SkillSearch(SKILL_ID_HEAT_BARREL)) > 0) {
		val -= (25 + 5 * sklLv);
	}


// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

	//----------------------------------------------------------------
	// 「支援ハミング」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_HUMMING)) > 0) {
		var bufferDexRank = ExBuffNumSearch(EXBUF_ID_HUMMING_BUFFER_DEXRANK);
		bufferSkillLv = ExBuffNumSearch(EXBUF_ID_HUMMING_BUFFER_SKILLLV);

		val += 20 + (2 * bufLv) + (bufferSkillLv) + (bufferDexRank);
	}

	//----------------------------------------------------------------
	// 「支援ゴスペル　ＨＩＴ、ＦＬＥＥ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_GOSPEL_HIT_FLEE_PLUS)) > 0) {
		val += 50 * bufLv;
	}

	//----------------------------------------------------------------
	// 「ビュッシュ・ド・ノエル」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_BUCHE_DE_NOEL)) > 0) {
		val += 3 * bufLv;
	}

	//----------------------------------------------------------------
	// 「茶菓子」の、効果
	// 「シュバルツバルド産おやつ」の、効果
	// 「焼きトウモロコシ」の、効果
	// 「ガラナキャンディ」の、効果
	// ※効果は、もっとも高いもののみ適用
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CHAGASHI)) > 0) {
		val += 30 * bufLv;
	}
	else if ((bufLv = ExBuffNumSearch(EXBUF_ID_SCHWARZWALDSAN_OYATSU)) > 0) {
		val += 10 * bufLv;
	}
	else if ((bufLv = ExBuffNumSearch(EXBUF_ID_YAKITOMOROKOSHI)) > 0) {
		val += 10 * bufLv;
	}
	else if ((bufLv = ExBuffNumSearch(EXBUF_ID_GUARANA_CANDY)) > 0) {
		val += 5 * bufLv;
	}

	//----------------------------------------------------------------
	// 「期間限定イベント支援　ＨＩＴ」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_EVENT_BUF_HIT_PLUS)) > 0) {
		val += bufLv;
	}

	//----------------------------------------------------------------
	// 「ＯＴＰログインボーナス支援」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_OTP_LOGIN_BONUS)) > 0) {
		if ((bufLv == 4) || (bufLv == 3)) {
			val += 10;
		}
	}

	//----------------------------------------------------------------
	// 「性能カスタマイズ　ＨＩＴ＋」の、効果
	//----------------------------------------------------------------
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_CUSTOM_HIT_PLUS)) > 0) {
		val += bufLv;
	}


// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}














//================================================================================================
//================================================================================================
//====
//==== ＭａｘＨＰ　％ＵＰ　ここから
//====
//================================================================================================
//================================================================================================
/**
* 装備等によるステータスの追加補正値を取得する（ＭａｘＨＰ％）.
*/
function GetStatusModifyTEMPPlus() {

	var val = 0;

	var vartmp = 0, varary = [];
	var itemCount = 0;
	var itemCountRight = 0, itemCountLeft = 0;
	var itemCountHeadTop = 0, itemCountHeadMid = 0, itemCountHeadUnder = 0;
	var itemCountShield = 0, itemCountBody = 0, itemCountShoulder = 0, itemCountShoes = 0;
	var itemCountAccessary1 = 0, itemCountAccessary2 = 0;
	var cardCount = 0;
	var cardCountRight = 0, cardCountLeft = 0;
	var cardCountHeadTop = 0, cardCountHeadMid = 0, cardCountHeadUnder = 0;
	var cardCountShield = 0, cardCountBody = 0, cardCountShoulder = 0, cardCountShoes = 0;
	var cardCountAccessary1 = 0, cardCountAccessary2 = 0;
	var sklLv = 0;
	var bufLv = 0;
	var bufferJobLv = 0, bufferSkillLv = 0;


//------------------------------------------------------------------------------------------------
// 武器効果　ここから
// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること

// ★武器は両手に装備される可能性（アサシン、影狼など）を考慮すること
// 武器効果　ここまで
//------------------------------------------------------------------------------------------------
// 防具効果　ここから

// 防具効果　ここまで
//------------------------------------------------------------------------------------------------
// カード効果　ここから

// カード効果　ここまで
//------------------------------------------------------------------------------------------------
// エンチャント効果　ここから
// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること

// ★エンチャントは、複数の装備部位に適用される可能性を考慮すること
// エンチャント効果　ここまで
//------------------------------------------------------------------------------------------------
// 装備セット効果　ここから

// 装備セット効果　ここまで
//------------------------------------------------------------------------------------------------
// 自己スキル効果ここから

// 自己スキル効果　ここまで
//------------------------------------------------------------------------------------------------
// 支援スキル効果　ここから

// 支援スキル効果　ここまで
//------------------------------------------------------------------------------------------------

	return val;
}
