/**
 * ステータスポイントを計算する
 * @param bIgnoreAutoCalc 自動計算回避フラグ
 */
function CalcStatusPoint(bIgnoreAutoCalc) {

	with(document.calcForm) {
		// ベースレベルの自動計算チェックボックスの状態を取得
		if (BLVauto.checked == 0) {
			bIgnoreAutoCalc = true;
		}

		// 職業ＩＤを取得する
		var jobId = eval(A_JOB.value);

		// ベースレベルを取得する
		var blvSelected = eval(A_BaseLV.value);

		// ステータス値を取得する
		var stValSTR = eval(A_STR.value);
		var stValAGI = eval(A_AGI.value);
		var stValVIT = eval(A_VIT.value);
		var stValINT = eval(A_INT.value);
		var stValDEX = eval(A_DEX.value);
		var stValLUK = eval(A_LUK.value);

	}

	// 消費ステータスポイントを計算する
	var stPointUsed = 0;
	stPointUsed += GetStatusTotalCost(stValSTR);
	stPointUsed += GetStatusTotalCost(stValAGI);
	stPointUsed += GetStatusTotalCost(stValVIT);
	stPointUsed += GetStatusTotalCost(stValINT);
	stPointUsed += GetStatusTotalCost(stValDEX);
	stPointUsed += GetStatusTotalCost(stValLUK);

	// 職業の基本情報を設定する
	InitJobInfo();

	// ベースレベル情報の取得
	var blvMin = GetBaseLevelMin(jobId);
	var blvMax = GetBaseLevelMax(jobId);

	// 初期ステータスポイントの決定
	var stPointEarned = 48;
	if (IsReincarnatedJob(jobId) && n_A_PassSkill8[13] == 0) {
		stPointEarned = 100;
	}

	// レベルの自動計算をしない場合
	if (bIgnoreAutoCalc) {
		for (var blv = 1; blv <= blvSelected; blv++) {
			stPointEarned += GetEarningStatusPoint(blv);
		}
	}

	// レベルの自動計算をする場合
	else {

		// 最低レベルまでは強制的に上げる
		for (blv = 1; blv <= blvMin; blv++) {
			stPointEarned += GetEarningStatusPoint(blv);
		}

		// 獲得ステータスポイントが、消費ステータスポイント未満の間
		// かつ、最大レベル以下の間、レベルを上げる
		for (blv; (stPointEarned < stPointUsed) && (blv <= blvMax); blv++) {
			stPointEarned += GetEarningStatusPoint(blv);
		}

		// ベースレベルの値を設定する
		document.calcForm.A_BaseLV.value = blv - 1;
	}

	myInnerHtml("A_STPOINT", stPointEarned - stPointUsed, 0);
}



/**
 * 指定のステータス値に上げるために必要なコストを取得する.
 * @param statusValue ステータス値
 * @return 必要コスト
 */
function GetStatusIncrementCost(statusValue) {
	if(statusValue <= 100) return Math.floor((statusValue - 2) /10) + 2;
	if(statusValue <= 105) return 16;
	if(statusValue <= 110) return 20;
	if(statusValue <= 115) return 24;
	if(statusValue <= 120) return 28;
	if(statusValue <= 125) return 32;
	if(statusValue <= 130) return 36;
}

/**
 * 指定のステータス値に上げるために必要なコストの総和を取得する.
 * @param statusValue ステータス値
 * @return 必要コストの相和
 */
function GetStatusTotalCost(statusValue) {

	var statusPoint = 0;

	// ２から指定の値まで、コストを合算（１は初期値なので不要）
	for(var stVal = 2; stVal <= statusValue; stVal++) {
		statusPoint += GetStatusIncrementCost(stVal);
	}

	return statusPoint;
}

/**
 * 指定のレベルで獲得するステータスポイントを取得する.
 * @param baseLevel ベースレベル
 * @return 獲得ステー足すポイント
 */
function GetEarningStatusPoint(baseLevel) {

	if (baseLevel <= 1) {
		return 0;
	}

	if (baseLevel <= 100) {
		return Math.floor( (baseLevel - 1) / 5) + 3;
	}

	if (baseLevel <= 150) {
		return Math.floor( (baseLevel - 101) / 10) + 23;
	}

	if (baseLevel <= 157) {
		return 28;
	}

	if (baseLevel <= 164) {
		return 29;
	}

	return 30;

}





function SuperNoviceFullWeapon(nSNFW) {
	if(nSNFW == 1){
		SuperNoviceFullWeaponCHECK = 1;
		JobASPD[20][7] = -6;
		JobASPD[61][7] = -6;
	}else{
		SuperNoviceFullWeaponCHECK = 0;
		JobASPD[20][7] = 0;
		JobASPD[61][7] = 0;
	}
	var len = document.calcForm.A_WeaponType.length;
	for(var i=0;i<len;i++) document.calcForm.A_WeaponType.options[0] = null;
	var j = 0;
	for (i=0;
	i<=21;
	i++){
		if(JobASPD[20][i] != 0){
			document.calcForm.A_WeaponType.options[j] = new Option(WeaponName[i],i);
			j++;
		}
	}
	with(document.calcForm){
		if(ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]][ITEM_DATA_INDEX_EQPFLG] != 7 && JobEquipItemSearch(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT])){
			var BK_BUKI = n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT];
			A_WeaponType.value = ItemObjNew[BK_BUKI][ITEM_DATA_INDEX_KIND];
			ClickWeaponType(ItemObjNew[BK_BUKI][ITEM_DATA_INDEX_KIND]);
			WeaponSet2();
			A_weapon1.value = BK_BUKI;
		}else{
			ClickWeaponType(0);
			WeaponSet2();
		}
		if(JobEquipItemSearch(n_A_Equip[EQUIP_REGION_ID_HEAD_TOP])) A_head1.value = n_A_Equip[EQUIP_REGION_ID_HEAD_TOP];
		if(JobEquipItemSearch(n_A_Equip[EQUIP_REGION_ID_HEAD_MID])) A_head2.value = n_A_Equip[EQUIP_REGION_ID_HEAD_MID];
		if(JobEquipItemSearch(n_A_Equip[EQUIP_REGION_ID_HEAD_UNDER])) A_head3.value = n_A_Equip[EQUIP_REGION_ID_HEAD_UNDER];
		A_left.value = n_A_Equip[EQUIP_REGION_ID_SHIELD];
		A_body.value = n_A_Equip[EQUIP_REGION_ID_BODY];
		A_shoulder.value = n_A_Equip[EQUIP_REGION_ID_SHOULDER];
		A_shoes.value = n_A_Equip[EQUIP_REGION_ID_SHOES];
		A_acces1.value = n_A_Equip[EQUIP_REGION_ID_ACCESSARY_1];
		A_acces2.value = n_A_Equip[EQUIP_REGION_ID_ACCESSARY_2];
	}
}



function UpdateEquipItemDataByHtml() {

	// ＨＴＭＬの入力値を元に、変数を更新する
	with(document.calcForm){

		n_A_WeaponType = eval(A_WeaponType.value);
		n_A_WeaponZokusei = eval(A_Weapon_zokusei.value);
		n_A_Arrow = eval(A_Arrow.value);

		// 装備部位配列初期化
		for (var eqpIdx = 0; eqpIdx < EQUIP_REGION_ID_COUNT; eqpIdx++) {
			n_A_Equip[eqpIdx] = 0;
		}

		n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] = eval(A_weapon1.value);
		if (n_Nitou) {
			n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] = eval(A_weapon2.value);
		}

		n_A_Equip[EQUIP_REGION_ID_HEAD_TOP]		 = eval(A_head1.value);
		n_A_Equip[EQUIP_REGION_ID_HEAD_MID]		 = eval(A_head2.value);
		n_A_Equip[EQUIP_REGION_ID_HEAD_UNDER]	 = eval(A_head3.value);
		n_A_Equip[EQUIP_REGION_ID_SHIELD]		 = eval(A_left.value);
		n_A_Equip[EQUIP_REGION_ID_BODY]			 = eval(A_body.value);
		n_A_Equip[EQUIP_REGION_ID_SHOULDER]		 = eval(A_shoulder.value);
		n_A_Equip[EQUIP_REGION_ID_SHOES]		 = eval(A_shoes.value);
		n_A_Equip[EQUIP_REGION_ID_ACCESSARY_1]	 = eval(A_acces1.value);
		n_A_Equip[EQUIP_REGION_ID_ACCESSARY_2]	 = eval(A_acces2.value);
		n_A_Equip[EQUIP_REGION_ID_COSTUME_HEAD_UNDER] = eval(A_isyou3.value);

		// 各種精錬値
		n_A_HEAD_DEF_PLUS = eval(A_HEAD_DEF_PLUS.value);
		n_A_BODY_DEF_PLUS = eval(A_BODY_DEF_PLUS.value);
		n_A_LEFT_DEF_PLUS = eval(A_LEFT_DEF_PLUS.value);
		n_A_SHOULDER_DEF_PLUS = eval(A_SHOULDER_DEF_PLUS.value);
		n_A_SHOES_DEF_PLUS = eval(A_SHOES_DEF_PLUS.value);
	}
}



function UpdateEquipCardDataByHtml() {

	with(document.calcForm){
		// 装着カード配列の初期化
		for (var cardIdx = 0; cardIdx < CARD_REGION_ID_COUNT; cardIdx++) {
			n_A_card[cardIdx] = 0;
		}

		// 右手武器
		n_A_card[CARD_REGION_ID_ARMS_RIGHT_1] = eval(A_weapon1_card1.value);
		n_A_card[CARD_REGION_ID_ARMS_RIGHT_2] = eval(A_weapon1_card2.value);
		n_A_card[CARD_REGION_ID_ARMS_RIGHT_3] = eval(A_weapon1_card3.value);
		n_A_card[CARD_REGION_ID_ARMS_RIGHT_4] = eval(A_weapon1_card4.value);

		// 左手武器
		if(n_Nitou){
			n_A_card[CARD_REGION_ID_ARMS_LEFT_1] = eval(A_weapon2_card1.value);
			n_A_card[CARD_REGION_ID_ARMS_LEFT_2] = eval(A_weapon2_card2.value);
			n_A_card[CARD_REGION_ID_ARMS_LEFT_3] = eval(A_weapon2_card3.value);
			n_A_card[CARD_REGION_ID_ARMS_LEFT_4] = eval(A_weapon2_card4.value);
		}

		// 各装着部位
		n_A_card[CARD_REGION_ID_HEAD_TOP]	 = eval(A_head1_card.value);
		n_A_card[CARD_REGION_ID_HEAD_MID]	 = eval(A_head2_card.value);
		n_A_card[CARD_REGION_ID_SHIELD]		 = eval(A_left_card.value);
		n_A_card[CARD_REGION_ID_BODY]		 = eval(A_body_card.value);
		n_A_card[CARD_REGION_ID_SHOULDER]	 = eval(A_shoulder_card.value);
		n_A_card[CARD_REGION_ID_SHOES]		 = eval(A_shoes_card.value);
		n_A_card[CARD_REGION_ID_ACCESSARY_1] = eval(A_acces1_card.value);
		n_A_card[CARD_REGION_ID_ACCESSARY_2] = eval(A_acces2_card.value);

		var wpnLv = null;

		// 頭上段エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_HEAD_TOP]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_1] = eval(A_head1_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_2] = eval(A_head1_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_TOP_3] = eval(A_head1_card4.value);
		}

		// 頭中段エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_HEAD_MID]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_1] = eval(A_head2_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_2] = eval(A_head2_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_MID_3] = eval(A_head2_card4.value);
		}

		// 頭下段エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_HEAD_UNDER]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_1] = eval(A_head3_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_2] = eval(A_head3_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_HEAD_UNDER_3] = eval(A_head3_card4.value);
		}

		// 盾エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_SHIELD]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_1] = eval(A_left_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_2] = eval(A_left_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHIELD_3] = eval(A_left_card4.value);
		}

		// 体エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_BODY]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] = eval(A_body_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] = eval(A_body_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] = eval(A_body_card4.value);
		}

		// 肩エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_SHOULDER]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] = eval(A_shoulder_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] = eval(A_shoulder_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] = eval(A_shoulder_card4.value);
		}

		// 靴エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_SHOES]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] = eval(A_shoes_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] = eval(A_shoes_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] = eval(A_shoes_card4.value);
		}

		// アクセ１エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ACCESSARY_1]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_1] = eval(A_acces1_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_2] = eval(A_acces1_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_1_3] = eval(A_acces1_card4.value);
		}

		// アクセ２エンチャント
		wpnLv = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ACCESSARY_2]][ITEM_DATA_INDEX_WPNLV];
		if(wpnLv >= 10){
			var w = Math.floor(wpnLv / 10);
			if(n_EnchantType[w][1] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_1] = eval(A_acces2_card2.value);
			if(n_EnchantType[w][2] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_2] = eval(A_acces2_card3.value);
			if(n_EnchantType[w][3] != 0) n_A_card[CARD_REGION_ID_ENCHANT_ACCESSARY_2_3] = eval(A_acces2_card4.value);
		}
	}
}




function StAllCalc(){

	var vartmp = 0;
	var valary = new Array();
	var sklLv = 0;
	var bufLv = 0;


	with(document.calcForm){
		InitJobInfo();
		if(n_A_JOB == 20 || n_A_JOB == 61){
			if(n_Skill1SW){
				if(SuperNoviceFullWeaponCHECK == 0 && eval(A_skill9.value) == 1) SuperNoviceFullWeapon(1);
				else if(SuperNoviceFullWeaponCHECK == 1 && eval(A_skill9.value) == 0) SuperNoviceFullWeapon(0);
			}else{
				if(SuperNoviceFullWeaponCHECK == 0 && SkillSearch(385) == 1) SuperNoviceFullWeapon(1);
				else if(SuperNoviceFullWeaponCHECK == 1 && SkillSearch(385) == 0) SuperNoviceFullWeapon(0);
			}
		}

		//----------------------------------------------------------------
		// 基本パラメタを取得する
		//----------------------------------------------------------------

		n_A_BaseLV = eval(A_BaseLV.value);
		n_A_JobLV = eval(A_JobLV.value);

		n_A_STR = eval(A_STR.value);
		n_A_AGI = eval(A_AGI.value);
		n_A_VIT = eval(A_VIT.value);
		n_A_DEX = eval(A_DEX.value);
		n_A_INT = eval(A_INT.value);
		n_A_LUK = eval(A_LUK.value);

		SU_STR = n_A_STR;
		SU_AGI = n_A_AGI;
		SU_VIT = n_A_VIT;
		SU_DEX = n_A_DEX;
		SU_INT = n_A_INT;
		SU_LUK = n_A_LUK;

		n_A_SpeedPOT = eval(A_SpeedPOT.value);


		//----------------------------------------------------------------
		// 装備を取得する
		//----------------------------------------------------------------

		UpdateEquipItemDataByHtml();


		//----------------------------------------------------------------
		// 攻撃手段を取得する
		//----------------------------------------------------------------

		n_A_ActiveSkill = eval(A_ActiveSkill.value);
		if(n_A_ActiveSkill >= 20000) n_A_ActiveSkill = AutoSpellSkill[n_A_ActiveSkill -20000][2];
		else if(n_A_ActiveSkill >= 10000) n_A_ActiveSkill = InsertSkill[n_A_ActiveSkill -10000][2];
		n_A_ActiveSkillLV = eval(A_ActiveSkillLV.value);




		n_A_WeaponLV = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]][ITEM_DATA_INDEX_WPNLV] % 10;
		n_A_Weapon_ATK = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]][ITEM_DATA_INDEX_POWER];
		n_A_Weapon_ATKplus = eval(A_Weapon_ATKplus.value);
		n_A_WeaponLV_seirenATK = 0;
		n_A_WeaponLV_Minplus = 0;
		n_A_WeaponLV_Maxplus = 0;
		if(n_A_WeaponLV == 1){
			n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 2;
			if(n_A_Weapon_ATKplus >= 8){
				n_A_WeaponLV_Minplus = 1;
				n_A_WeaponLV_Maxplus = 3 * (n_A_Weapon_ATKplus - 7);
			}
		}else if(n_A_WeaponLV == 2){
			n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 3;
			if(n_A_Weapon_ATKplus >= 7){
				n_A_WeaponLV_Minplus = 1;
				n_A_WeaponLV_Maxplus = 5 * (n_A_Weapon_ATKplus - 6);
			}
		}else if(n_A_WeaponLV == 3){
			n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 5;
			if(n_A_Weapon_ATKplus >= 6){
				n_A_WeaponLV_Minplus = 1;
				n_A_WeaponLV_Maxplus = 8 * (n_A_Weapon_ATKplus - 5);
			}
		}else if(n_A_WeaponLV == 4){
			n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 7;
			if(n_A_Weapon_ATKplus >= 5){
				n_A_WeaponLV_Minplus = 1;
				n_A_WeaponLV_Maxplus = 14 * (n_A_Weapon_ATKplus - 4);
			}
		}

		n_A_Weapon2_ATKplus = 0;
		if(n_Nitou){
			n_A_Weapon2LV = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]][ITEM_DATA_INDEX_WPNLV] % 10;
			n_A_Weapon2_ATK = ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]][ITEM_DATA_INDEX_POWER];
			n_A_Weapon2_ATKplus = eval(document.calcForm.A_Weapon2_ATKplus.value);
			n_A_Weapon2LV_seirenATK = 0;
			n_A_Weapon2LV_Minplus = 0;
			n_A_Weapon2LV_Maxplus = 0;
			if(n_A_Weapon2LV == 1){
				n_A_Weapon2LV_seirenATK = n_A_Weapon2_ATKplus * 2;
				if(n_A_Weapon2_ATKplus >= 8){
					n_A_Weapon2LV_Minplus = 1;
					n_A_Weapon2LV_Maxplus = 3 * (n_A_Weapon2_ATKplus - 7);
				}
			}else if(n_A_Weapon2LV == 2){
				n_A_Weapon2LV_seirenATK = n_A_Weapon2_ATKplus * 3;
				if(n_A_Weapon2_ATKplus >= 7){
					n_A_Weapon2LV_Minplus = 1;
					n_A_Weapon2LV_Maxplus = 5 * (n_A_Weapon2_ATKplus - 6);
				}
			}else if(n_A_Weapon2LV == 3){
				n_A_Weapon2LV_seirenATK = n_A_Weapon2_ATKplus * 5;
				if(n_A_Weapon2_ATKplus >= 6){
					n_A_Weapon2LV_Minplus = 1;
					n_A_Weapon2LV_Maxplus = 8 * (n_A_Weapon2_ATKplus - 5);
				}
			}else if(n_A_Weapon2LV == 4){
				n_A_Weapon2LV_seirenATK = n_A_Weapon2_ATKplus * 7;
				if(n_A_Weapon2_ATKplus >= 5){
					n_A_Weapon2LV_Minplus = 1;
					n_A_Weapon2LV_Maxplus = 14 * (n_A_Weapon2_ATKplus - 4);
				}
			}
		}


		//----------------------------------------------------------------
		// 装着カードを取得する
		//----------------------------------------------------------------

		UpdateEquipCardDataByHtml();



		// TODO: 謎処理
		SetEquip();



		if(n_Skill1SW){
			for(var i=0;i <JobSkillPassObjNew[n_A_JOB].length;i++){
				var wOBJ = document.getElementById("A_skill"+i);
				n_A_PassSkill[i] = eval(wOBJ.value);
			}
		}

		SET_ZOKUSEI();
		if(n_Skill2SW){
			n_A_PassSkill2[0] = eval(A2_Skill0.value);
			n_A_PassSkill2[1] = eval(A2_Skill1.value);
			n_A_PassSkill2[2] = eval(A2_Skill2.value);
			n_A_PassSkill2[3] = eval(A2_Skill3.checked);
			n_A_PassSkill2[4] = eval(A2_Skill4.value);
			n_A_PassSkill2[5] = eval(A2_Skill5.checked);
			n_A_PassSkill2[6] = eval(A2_Skill6.value);
			n_A_PassSkill2[7] = eval(A2_Skill7.checked);
			n_A_PassSkill2[8] = eval(A2_Skill8.value);
			n_A_PassSkill2[9] = eval(A2_Skill9.value);
			n_A_PassSkill2[10] = eval(A2_Skill10.value);
			n_A_PassSkill2[11] = eval(A2_Skill11.checked);
			n_A_PassSkill2[12] = eval(A2_Skill12.checked);
			n_A_PassSkill2[13] = eval(A2_Skill13.value);
			n_A_PassSkill2[14] = eval(A2_Skill14.value);
		}
		if(n_Skill3SW){
			n_A_PassSkill3[0] = eval(A3_Skill0_1.value);
			n_A_PassSkill3[1] = eval(A3_Skill1_1.value);
			n_A_PassSkill3[2] = eval(A3_Skill2_1.value);
			n_A_PassSkill3[3] = eval(A3_Skill3_1.value);
			n_A_PassSkill3[4] = eval(A3_Skill4_1.value);
			n_A_PassSkill3[5] = eval(A3_Skill5_1.value);
			n_A_PassSkill3[6] = eval(A3_Skill6_1.value);
			n_A_PassSkill3[7] = eval(A3_Skill7.value);
			n_A_PassSkill3[8] = eval(A3_Skill8.value);
			n_A_PassSkill3[9] = eval(A3_Skill9.value);
			n_A_PassSkill3[10] = eval(A3_Skill10.value);
			n_A_PassSkill3[11] = eval(A3_Skill20.value);
			n_A_PassSkill3[42] = eval(A3_Skill42.value);
			n_A_PassSkill3[12] = eval(A3_Skill11_STR.value);
			n_A_PassSkill3[13] = eval(A3_Skill11_AGI.value);
			n_A_PassSkill3[14] = eval(A3_Skill11_VIT.value);
			n_A_PassSkill3[15] = eval(A3_Skill11_INT.value);
			n_A_PassSkill3[16] = eval(A3_Skill11_DEX.value);
			n_A_PassSkill3[17] = eval(A3_Skill11_LUK.value);
			n_A_PassSkill3[18] = eval(A3_Skill11a.checked);
			n_A_PassSkill3[19] = eval(A3_Skill12_0.value);
			if(n_A_PassSkill3[0]){
				n_A_PassSkill3[20] = eval(A3_Skill0_2.value);
				n_A_PassSkill3[28] = eval(A3_Skill0_4.value);
				n_A_PassSkill3[30] = eval(A3_Skill0_3.value);
			}
			if(n_A_PassSkill3[1]){
				n_A_PassSkill3[21] = eval(A3_Skill1_2.value);
				n_A_PassSkill3[31] = eval(A3_Skill1_3.value);
			}
			if(n_A_PassSkill3[2]){
				n_A_PassSkill3[22] = eval(A3_Skill2_2.value);
				n_A_PassSkill3[29] = eval(A3_Skill2_3.value);
				n_A_PassSkill3[32] = eval(A3_Skill2_4.value);
			}
			if(n_A_PassSkill3[3]){
				n_A_PassSkill3[23] = eval(A3_Skill3_2.value);
				n_A_PassSkill3[33] = eval(A3_Skill3_3.value);
			}
			if(n_A_PassSkill3[4]){
				n_A_PassSkill3[24] = eval(A3_Skill4_2.value);
				n_A_PassSkill3[34] = eval(A3_Skill4_3.value);
			}
			if(n_A_PassSkill3[5]){
				n_A_PassSkill3[25] = eval(A3_Skill5_2.value);
				n_A_PassSkill3[35] = eval(A3_Skill5_3.value);
			}
			if(n_A_PassSkill3[6]){
				n_A_PassSkill3[26] = eval(A3_Skill6_2.value);
				n_A_PassSkill3[36] = eval(A3_Skill6_3.value);
			}
			if(n_A_PassSkill3[19]){
				n_A_PassSkill3[37] = eval(A3_Skill12_1.value);
				if(n_A_PassSkill3[19] != 7){
					n_A_PassSkill3[46] = eval(A3_Skill12_2.value);
					n_A_PassSkill3[38] = eval(A3_Skill12_3.value);
				}
			}
			if(n_A_PassSkill3[39]){
				n_A_PassSkill3[40] = eval(A3_Skill13_1.value);
				n_A_PassSkill3[41] = eval(A3_Skill13_2.value);
			}
		}
		if(n_Skill4SW){
			n_A_PassSkill4[0] = eval(A4_Skill0.checked);
			n_A_PassSkill4[1] = eval(A4_Skill1.value);
			n_A_PassSkill4[2] = eval(A4_Skill2.value);
			n_A_PassSkill4[3] = eval(A4_Skill3.value);
			n_A_PassSkill4[4] = eval(A4_Skill4.value);
			n_A_PassSkill4[5] = eval(A4_Skill5.checked);
			n_A_PassSkill4[6] = eval(A4_Skill6.checked);
			n_A_PassSkill4[7] = eval(A4_Skill7.checked);
			n_A_PassSkill4[8] = eval(A4_Skill8.checked);
			n_A_PassSkill4[9] = eval(A4_Skill9.checked);
			n_A_PassSkill4[10] = eval(A4_Skill10.checked);
			n_A_PassSkill4[11] = eval(A4_Skill11.value);
			n_A_PassSkill4[30] = eval(A4_Skill30.value);
			n_A_PassSkill4[31] = eval(A4_Skill31.value);
			n_A_PassSkill4[32] = eval(A4_Skill32.value);
			n_A_PassSkill4[33] = eval(A4_Skill33.value);
			n_A_PassSkill4[34] = eval(A4_Skill34.value);
			n_A_PassSkill4[35] = eval(A4_Skill35.value);
		}

		// オートスペル設定の取得
		var objSelect = null;
		for (var idx = 0; idx < AUTO_SPELL_SETTING_COUNT; idx++) {
			objSelect = document.getElementById("OBJID_AS_SKILL_ID_" + (OBJID_OFFSET_AS_SKILL_ID + idx));
			if (objSelect) {
				n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_ID + idx] = eval(objSelect.value);
			}

			objSelect = document.getElementById("OBJID_AS_SKILL_LV_" + (OBJID_OFFSET_AS_SKILL_LV + idx));
			if (objSelect) {
				n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_LV + idx] = eval(objSelect.value);
			}

			objSelect = document.getElementById("OBJID_AS_SKILL_PROB_" + (OBJID_OFFSET_AS_SKILL_PROB + idx));
			if (objSelect) {
				n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_PROB + idx] = eval(objSelect.value);
			}
		}

		if(n_Skill6SW){
			n_A_PassSkill6[0] = eval(A6_Skill0.value);
			n_A_PassSkill6[1] = eval(A6_Skill1.value);
			n_A_PassSkill6[2] = eval(A6_Skill2.value);
			n_A_PassSkill6[3] = eval(A6_Skill3.value);
			n_A_PassSkill6[4] = eval(A6_Skill4.value);
			n_A_PassSkill6[5] = eval(A6_Skill5.value);
			n_A_PassSkill6[6] = eval(A6_Skill6.checked);
			n_A_PassSkill6[7] = eval(A6_Skill7.value);
			n_A_PassSkill6[8] = eval(A6_Skill8.value);
			n_A_PassSkill6[9] = eval(A6_Skill9.value);
			n_A_PassSkill6[10] = eval(A6_Skill10.value);
			n_A_PassSkill6[11] = eval(A6_Skill11.value);
			n_A_PassSkill6[12] = eval(A6_Skill12.value);
			n_A_PassSkill6[13] = eval(A6_Skill13.value);
			n_A_PassSkill6[14] = eval(A6_Skill14.value);
			n_A_PassSkill6[15] = eval(A6_Skill15.value);
			n_A_PassSkill6[16] = eval(A6_Skill16.value);
			n_A_PassSkill6[17] = eval(A6_Skill17.value);
			n_A_PassSkill6[18] = eval(A6_Skill18.value);
			n_A_PassSkill6[20] = eval(A6_Skill20.checked);
			n_A_PassSkill6[21] = eval(A6_Skill21.value);
			n_A_PassSkill6[30] = eval(A6_Skill30.value);
		}
		if(n_Skill7SW){
			n_A_PassSkill7[0] = eval(A7_Skill0.checked);
			n_A_PassSkill7[1] = eval(A7_Skill1.checked);
			n_A_PassSkill7[2] = eval(A7_Skill2.checked);
			n_A_PassSkill7[3] = eval(A7_Skill3.value);
			n_A_PassSkill7[4] = eval(A7_Skill4.value);
			n_A_PassSkill7[5] = eval(A7_Skill5.value);
			n_A_PassSkill7[6] = eval(A7_Skill6.value);
			n_A_PassSkill7[7] = eval(A7_Skill7.value);
			n_A_PassSkill7[8] = eval(A7_Skill8.value);
			n_A_PassSkill7[9] = eval(A7_Skill9.checked);
			n_A_PassSkill7[10] = eval(A7_Skill10.checked);
			n_A_PassSkill7[11] = eval(A7_Skill11.checked);
			n_A_PassSkill7[12] = eval(A7_Skill12.checked);
			n_A_PassSkill7[13] = eval(A7_Skill13.checked);
			n_A_PassSkill7[14] = eval(A7_Skill14.checked);
			n_A_PassSkill7[15] = eval(A7_Skill15.checked);
			n_A_PassSkill7[16] = eval(A7_Skill16.checked);
			n_A_PassSkill7[17] = eval(A7_Skill17.checked);
			n_A_PassSkill7[18] = eval(A7_Skill18.checked);
			n_A_PassSkill7[19] = eval(A7_Skill19.checked);
			n_A_PassSkill7[20] = eval(A7_Skill20.checked);
			n_A_PassSkill7[21] = eval(A7_Skill21.checked);
			n_A_PassSkill7[22] = eval(A7_Skill22.checked);
			n_A_PassSkill7[23] = eval(A7_Skill23.checked);
			n_A_PassSkill7[24] = eval(A7_Skill24.checked);
			n_A_PassSkill7[25] = eval(A7_Skill25.checked);
			n_A_PassSkill7[26] = eval(A7_Skill26.checked);
			n_A_PassSkill7[27] = eval(A7_Skill27.checked);
			n_A_PassSkill7[28] = eval(A7_Skill28.checked);
			n_A_PassSkill7[29] = eval(A7_Skill29.checked);
			n_A_PassSkill7[30] = eval(A7_Skill30.checked);
			n_A_PassSkill7[31] = eval(A7_Skill31.checked);
			n_A_PassSkill7[32] = eval(A7_Skill32.checked);
			n_A_PassSkill7[33] = eval(A7_Skill33.checked);
			n_A_PassSkill7[34] = eval(A7_Skill34.checked);
			n_A_PassSkill7[35] = eval(A7_Skill35.checked);
			n_A_PassSkill7[36] = eval(A7_Skill36.checked);
			n_A_PassSkill7[37] = eval(A7_Skill37.checked);
			n_A_PassSkill7[38] = eval(A7_Skill38.value);
			n_A_PassSkill7[39] = eval(A7_Skill39.value);
			n_A_PassSkill7[40] = eval(A7_Skill40.checked);
			n_A_PassSkill7[41] = eval(A7_Skill41.value);
			n_A_PassSkill7[42] = eval(A7_Skill42.value);
			n_A_PassSkill7[43] = eval(A7_Skill43.value);
			n_A_PassSkill7[44] = eval(A7_Skill44.value);
			n_A_PassSkill7[45] = eval(A7_Skill45.value);
			n_A_PassSkill7[46] = eval(A7_Skill46.value);
			n_A_PassSkill7[47] = eval(A7_Skill47.value);
			n_A_PassSkill7[48] = eval(A7_Skill48.checked);
			n_A_PassSkill7[49] = eval(A7_Skill49.checked);
			n_A_PassSkill7[50] = eval(A7_Skill50.value);
			n_A_PassSkill7[51] = eval(A7_Skill51.checked);
		}
		n_A_PassSkill8[14] = 0;
		if(n_Skill8SW){
			n_A_PassSkill8[0] = eval(A8_Skill0.value);
			n_A_PassSkill8[1] = eval(A8_Skill1.value);
			n_A_PassSkill8[2] = eval(A8_Skill2.value);
			n_A_PassSkill8[3] = eval(A8_Skill3.value);
			n_A_PassSkill8[4] = eval(A8_Skill4.checked);
			n_A_PassSkill8[5] = eval(A8_Skill5.value);
			n_A_PassSkill8[6] = eval(A8_Skill6.value);
			n_A_PassSkill8[7] = eval(A8_Skill7.value);
			n_A_PassSkill8[8] = eval(A8_Skill8.value);
			n_A_PassSkill8[9] = eval(A8_Skill9.value);
			n_A_PassSkill8[10] = eval(A8_Skill10.value);
			n_A_PassSkill8[11] = eval(A8_Skill11.value);
			n_A_PassSkill8[12] = eval(A8_Skill12.value);
			n_A_PassSkill8[13] = eval(A8_Skill13.checked);
			n_A_PassSkill8[15] = eval(A8_Skill15.value);
			n_A_PassSkill8[16] = eval(A8_Skill16.checked);
			n_A_PassSkill8[17] = eval(A8_Skill17.value);
			n_A_PassSkill8[19] = eval(A8_Skill19.checked);
			n_A_PassSkill8[21] = eval(A8_Skill21.value);
			n_A_PassSkill8[22] = eval(A8_Skill22.value);
			if(41 <= n_A_JOB && n_A_JOB <= 43){
				if(n_A_PassSkill8[19] == 0) myInnerHtml("ID_A_HUYO_NAME","暖かい風",0);
				else myInnerHtml("ID_A_HUYO_NAME","武器属性付与",0);
			}
			n_A_IJYOU[0] = eval(A_IJYOU0.value);
			n_A_IJYOU[1] = eval(A_IJYOU1.value);
			n_A_IJYOU[2] = eval(A_IJYOU2.checked);
			n_A_IJYOU[3] = eval(A_IJYOU3.checked);
			n_A_IJYOU[4] = eval(A_IJYOU4.value);
			n_A_IJYOU[5] = eval(A_IJYOU5.checked);
		}
		if(n_Skill9SW){
			n_A_PassSkill9[0] = eval(A_COSTOM0.checked);
			n_A_PassSkill9[1] = eval(A_COSTOM1.value);
			n_A_PassSkill9[2] = eval(A_COSTOM2.value);
			n_A_PassSkill9[3] = eval(A_COSTOM3.value);
			n_A_PassSkill9[4] = eval(A_COSTOM4.value);
			n_A_PassSkill9[5] = eval(A_COSTOM5.value);
			n_A_PassSkill9[6] = eval(A_COSTOM6.value);
			n_A_PassSkill9[7] = eval(A_COSTOM7.value);
			n_A_PassSkill9[8] = eval(A_COSTOM8.value);
			n_A_PassSkill9[9] = eval(A_COSTOM9.value);
			n_A_PassSkill9[10] = eval(A_COSTOM10.value);
			n_A_PassSkill9[11] = eval(A_COSTOM11.value);
			n_A_PassSkill9[14] = eval(A_COSTOM14.value);
			n_A_PassSkill9[15] = eval(A_COSTOM15.value);
			n_A_PassSkill9[16] = eval(A_COSTOM16.value);
			n_A_PassSkill9[17] = eval(A_COSTOM17.value);
			n_A_PassSkill9[18] = eval(A_COSTOM18.value);
			n_A_PassSkill9[19] = eval(A_COSTOM19.value);
			n_A_PassSkill9[20] = eval(A_COSTOM20.value);
			n_A_PassSkill9[21] = eval(A_COSTOM21.value);
			n_A_PassSkill9[22] = eval(A_COSTOM22.value);
			n_A_PassSkill9[23] = eval(A_COSTOM23.value);
			n_A_PassSkill9[24] = eval(A_COSTOM24.value);
			n_A_PassSkill9[25] = eval(A_COSTOM25.value);
			n_A_PassSkill9[26] = eval(A_COSTOM26.value);
			n_A_PassSkill9[27] = eval(A_COSTOM27.value);
			n_A_PassSkill9[28] = eval(A_COSTOM28.value);
			n_A_PassSkill9[29] = eval(A_COSTOM29.value);
			n_A_PassSkill9[30] = eval(A_COSTOM30.value);
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[1]) n_A_Weapon_ATK = n_A_PassSkill9[1] * 5;
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[3]){
			n_A_WeaponLV = n_A_PassSkill9[3];
			n_A_WeaponLV_seirenATK = 0;
			n_A_WeaponLV_Minplus = 0;
			n_A_WeaponLV_Maxplus = 0;
			if(n_A_WeaponLV == 1){
				n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 2;
				if(n_A_Weapon_ATKplus >= 8){
					n_A_WeaponLV_Minplus = 1;
					n_A_WeaponLV_Maxplus = 3 * (n_A_Weapon_ATKplus - 7);
				}
			}else if(n_A_WeaponLV == 2){
				n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 3;
				if(n_A_Weapon_ATKplus >= 7){
					n_A_WeaponLV_Minplus = 1;
					n_A_WeaponLV_Maxplus = 5 * (n_A_Weapon_ATKplus - 6);
				}
			}else if(n_A_WeaponLV == 3){
				n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 5;
				if(n_A_Weapon_ATKplus >= 6){
					n_A_WeaponLV_Minplus = 1;
					n_A_WeaponLV_Maxplus = 8 * (n_A_Weapon_ATKplus - 5);
				}
			}else if(n_A_WeaponLV == 4){
				n_A_WeaponLV_seirenATK = n_A_Weapon_ATKplus * 7;
				if(n_A_Weapon_ATKplus >= 5){
					n_A_WeaponLV_Minplus = 1;
					n_A_WeaponLV_Maxplus = 14 * (n_A_Weapon_ATKplus - 4);
				}
			}
		}
		if(n_Skill10SW){
			n_A_PassSkill10[0] = eval(A_COSTOM2_0.checked);
			n_A_PassSkill10[1] = eval(A_COSTOM2_1.value);
			n_A_PassSkill10[3] = eval(A_COSTOM2_3.value);
			n_A_PassSkill10[4] = eval(A_COSTOM2_4.value);
			n_A_PassSkill10[6] = eval(A_COSTOM2_6.value);
			n_A_PassSkill10[7] = eval(A_COSTOM2_7.value);
			n_A_PassSkill10[8] = eval(A_COSTOM2_8.value);
			n_A_PassSkill10[9] = eval(A_COSTOM2_9.value);
			n_A_PassSkill10[10] = eval(A_COSTOM2_10.value);
			n_A_PassSkill10[11] = eval(A_COSTOM2_11.value);
			n_A_PassSkill10[12] = eval(A_COSTOM2_12.value);
			n_A_PassSkill10[13] = eval(A_COSTOM2_13.value);
			n_A_PassSkill10[14] = eval(A_COSTOM2_14.value);
			n_A_PassSkill10[15] = eval(A_COSTOM2_15.value);
		}
		if(n_TaiseiSW){
			n_B_TAISEI[38] = eval(B_TAISEI38.value);
		}
		if(n_B_TAISEI[38] == 1 || n_B_TAISEI[38] == 4 || n_B_TAISEI[38] == 5) n_Ses = 1;
		else n_Ses = 0;
		if(n_SP_MODE == 0){
			for(i=0;i<=22;i++) n_B[i] = MonsterObjNew[B_Enemy.value][i];
		}
		if(n_SP_MODE == 1){
			for(i=0;i<=22;i++) n_B[i] = MonsterObjNew[n_EXP_MONS_NUM][i];
		}
		if(n_B[0] == 787){
			if(n_TaiseiSW) n_B[18] = eval(B_TAISEI7.value) * 10 + 1;
			else n_B[18] = n_B_TAISEI[7] * 10 + 1;
		}
		if(n_KyoukaSW){
			if(Taijin==0 && eval(B_KYOUKA6.value)) n_B[18] = eval(B_KYOUKA6.value);
		}else{
			if(Taijin==0 && n_B_KYOUKA[6]) n_B[18] = n_B_KYOUKA[6];
		}
		if(n_IjyouSW){
			if(Taijin==0 && eval(B_IJYOU23.value)) n_B[18] = eval(B_IJYOU23.value) * 10 + (n_B[18] % 10);
			if(B_IJYOU4.checked) n_B[18] = 11;
			if(B_IJYOU9.checked) n_B[18] = 21;
		}else{
			if(Taijin==0 && n_B_IJYOU[23]) n_B[18] = n_B_IJYOU[23] * 10 + (n_B[18] % 10);
			if(n_B_IJYOU[4]) n_B[18] = 11;
			if(n_B_IJYOU[9]) n_B[18] = 21;
		}

	}





//================================================================================================
// プレイヤー防御属性の導出
//================================================================================================

	n_A_BodyZokusei = GetStatusModifyBodyElement();



//================================================================================================
// 装備特性値の取得
//================================================================================================

	// 特性値を初期化
	// TODO: 配列長　直打ち
	for (idx = 0; idx <= 7; idx++) n_Delay[idx] = 0;

	for (idx = 1; idx <= 400; idx++){
		n_tok[idx] = 0;
		n_tok[idx] += GetEquippedTotalSPEquip(idx);
		n_tok[idx] += GetEquippedTotalSPCardAndElse(idx);
	}



//================================================================================================
// 基本ステータスの算出
//================================================================================================

	StPlusCalc();



//================================================================================================
// ＡＴＫの算出
//================================================================================================

	//----------------------------------------------------------------
	// ステータスＡＴＫの算出
	//----------------------------------------------------------------
	n_A_StatusATK = 0;

	switch (n_A_WeaponType) {

	// ＤＥＸ依存武器
	case ITEM_KIND_BOW:
	case ITEM_KIND_MUSICAL:
	case ITEM_KIND_WHIP:
	case ITEM_KIND_HANDGUN:
	case ITEM_KIND_RIFLE:
	case ITEM_KIND_SHOTGUN:
	case ITEM_KIND_GATLINGGUN:
	case ITEM_KIND_GRENADEGUN:
		n_A_StatusATK = n_A_DEX + n_A_STR / 5 + n_A_LUK / 3;
		break;

	// ＳＴＲ依存武器
	default:
		n_A_StatusATK = n_A_STR + n_A_DEX / 5 + n_A_LUK / 3;
		break;
	}

	n_A_StatusATK = Math.floor(n_A_StatusATK);

	// ＧＸ反動ダメージ用ＡＴＫ
	n_A_StatusATK_GX = n_A_StatusATK;
	n_A_StatusATK_GX += ROUNDDOWN(n_A_StatusATK_GX * zokusei[n_A_BodyZokusei * 10 +1][0] / 100);


	//----------------------------------------------------------------
	// 精錬ＡＴＫの算出
	//----------------------------------------------------------------
	wImp = 0;
	wImp += n_A_WeaponLV_seirenATK;

	// 「ソーサラー　ストライキング」による、効果
	if (sklLv = n_A_PassSkill6[7]) {
		wImp += (8 + 2 * sklLv) * n_A_WeaponLV + 5 * n_A_PassSkill6[8];
	}

	// 「修羅　点穴-反-」による、効果
	var valStr = 0;
	var valDex = 0;
	if (sklLv = SkillSearch(SKILL_ID_TENKETSU_HAN)) {

		// 持ち替え支援の場合、支援欄のステータスを使用
		if(n_A_PassSkill4[11] == 2) {
			valStr = n_A_PassSkill4[30];
			valDex = n_A_PassSkill4[34];
		}

		// 持ち替えなし場合、本人のステータスを使用
		else {
			valStr = n_A_STR;
			valDex = n_A_DEX;
		}

		wImp += Math.floor((Math.floor(valStr / 2) + Math.floor(valDex / 4)) * sklLv / 5);
	}


	//----------------------------------------------------------------
	// 装備ＡＴＫの算出
	//----------------------------------------------------------------

	// アイテム特性
	n_tok[ITEM_SP_ATK_PLUS] += n_tok[244];

	// 装備追加効果、支援効果
	n_tok[ITEM_SP_ATK_PLUS] += GetStatusModifyAtkPlus();


	//----------------------------------------------------------------
	// 左手ＡＴＫの算出
	//----------------------------------------------------------------

	var wLEFT = 0;
	if(n_Nitou) {
		wLEFT = n_A_Weapon2_ATK + n_A_Weapon2LV_seirenATK;
	}


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_ATK", n_A_StatusATK + "+" + (n_A_Weapon_ATK + wImp + wLEFT + n_tok[ITEM_SP_ATK_PLUS]), 0);


	//----------------------------------------------------------------
	// ステータス欄に表示されない効果の適用
	//----------------------------------------------------------------

	// 暖かい風
	if (n_A_PassSkill8[19] == 0) {
		if (GetLowerJobSeriesID(n_A_JOB) == JOB_ID_TAEGWON) {
			n_A_StatusATK = ApplyElementRatio(n_A_StatusATK, n_A_WeaponZokusei);
		}
		else {
			n_A_StatusATK = ApplyElementRatio(n_A_StatusATK, 0);
		}
	}
	else {
		if (GetLowerJobSeriesID(n_A_JOB) != JOB_ID_TAEGWON) {
			n_A_StatusATK = ApplyElementRatio(n_A_StatusATK, n_A_WeaponZokusei);
		}
		else {
			n_A_StatusATK = ApplyElementRatio(n_A_StatusATK, 0);
		}
	}

	// インベナム使用時のＡＴＫ補正
	if (n_A_ActiveSkill == SKILL_ID_ENVENOM) {
		n_tok[ITEM_SP_ATK_PLUS] += 15 * n_A_ActiveSkillLV;
	}

	// ポイズンリアクト（反撃）使用時のＡＴＫ補正
	if ((n_A_ActiveSkill == SKILL_ID_POISON_REACT)) {
		if ((51 <= n_B[18]) && (n_B[18] < 60)) {
			n_tok[ITEM_SP_ATK_PLUS] += 75;
		}
	}




//================================================================================================
// ＭａｘＨＰ算出
//================================================================================================

	//----------------------------------------------------------------
	// ＨＰの基礎値を取得
	//----------------------------------------------------------------
	n_A_MaxHP = GetHPBase(n_A_JOB, n_A_BaseLV, n_A_PassSkill8[13]);

	// テコンランカーの３倍補正
	if ((n_A_JOB == JOB_ID_TAEGWON) && (n_A_BaseLV >= 90)) {
		if (SkillSearch(SKILL_ID_TAEGWON_RANKER)) {
			n_A_MaxHP = n_A_MaxHP * 3;
		}
	}

	// ロイヤルガードの場合は、インスピレーション計算用のバックアップを作成しておく
	var RG_HP_BackUP = 0;
	if (n_A_JOB == JOB_ID_ROYALGUARD) {
		RG_HP_BackUP = n_A_MaxHP;
	}


	//----------------------------------------------------------------
	// ＶＩＴによる補正
	//----------------------------------------------------------------

	// インスピレーションのＶＩＴ補正は、基礎ＨＰ増加量に影響を与えない
	var vitForCalc = n_A_VIT;
	if (SkillSearch(SKILL_ID_INSPIRATION)) {
		vitForCalc -= ROUNDDOWN(n_A_BaseLV / 10 + n_A_JobLV / 5);
	}
	n_A_MaxHP += ROUNDDOWN(n_A_MaxHP * vitForCalc / 100);


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋○○）
	//----------------------------------------------------------------
	var maxHpPlus = 0;

	// アイテム特性
	maxHpPlus += n_tok[ITEM_SP_MAXHP_PLUS];
	maxHpPlus += n_tok[ITEM_SP_MAXHP_PLUS_GVGTE];

	// 装備によるＶＩＴ上昇分は、ＨＰも同量増加させる
	maxHpPlus += GetEquippedTotalSPEquip(ITEM_SP_VIT_PLUS);
	maxHpPlus += GetEquippedTotalSPEquip(ITEM_SP_ALLSTATUS_PLUS);

	// 装備追加効果、支援効果
	maxHpPlus += GetStatusModifyMaxHpPlus();

	// 最終的な効果を適用
	n_A_MaxHP += maxHpPlus;
	if (n_A_MaxHP < 1) n_A_MaxHP = 1;


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋％）
	//----------------------------------------------------------------
	var maxHpPerUp = 0;

	// アイテム特性
	maxHpPerUp += n_tok[ITEM_SP_MAXHP_UP];

	// 装備追加効果、支援効果
	maxHpPerUp += GetStatusModifyMaxHpUp();

	// 最終的な効果を適用
	n_A_MaxHP += n_A_MaxHP * maxHpPerUp / 100;


	//----------------------------------------------------------------
	// ロイヤルガード　インスピレーション使用時の特殊計算
	//----------------------------------------------------------------
	if (SkillSearch(SKILL_ID_INSPIRATION)) {

		// インスピレーションの効果が無い状態で、インスピレーションによる上昇量を算出
		// ここの計算で n_A_MaxHP の値を使うので、一度に計算できない
		vartmp = ROUNDDOWN(SkillSearch(SKILL_ID_INSPIRATION) * (600 + n_A_MaxHP / 20));

		// バックアップしておいたＨＰを元に、インスピレーションの効果込みでＨＰを再計算
		n_A_MaxHP = RG_HP_BackUP;
		n_A_MaxHP += ROUNDDOWN(n_A_MaxHP * n_A_VIT / 100);
		n_A_MaxHP += maxHpPlus + vartmp;		// ここで、インスピレーションのＨＰ上昇を適用
		n_A_MaxHP += ROUNDDOWN(n_A_MaxHP * maxHpPerUp / 100);
	}


	//----------------------------------------------------------------
	// 特殊補正
	//----------------------------------------------------------------

	// バーサーク
	if (SkillSearch(SKILL_ID_BERSERK)) n_A_MaxHP *= 3;


	//----------------------------------------------------------------
	// 小数点以下切り落とし
	//----------------------------------------------------------------
	n_A_MaxHP = Math.floor(n_A_MaxHP);


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_MaxHP", n_A_MaxHP, 0);





//================================================================================================
// ＭａｘＳＰ算出
//================================================================================================

	//----------------------------------------------------------------
	// ＳＰの基礎値を取得
	//----------------------------------------------------------------
	n_A_MaxSP = GetSPBase(n_A_JOB, n_A_BaseLV, n_A_PassSkill8[13]);

	// テコンランカーの３倍補正
	if ((n_A_JOB == JOB_ID_TAEGWON) && (n_A_BaseLV >= 90)) {
		if (SkillSearch(SKILL_ID_TAEGWON_RANKER)) {
			n_A_MaxSP = n_A_MaxSP * 3;
		}
	}


	//----------------------------------------------------------------
	// ＩＮＴによる補正
	//----------------------------------------------------------------
	n_A_MaxSP += ROUNDDOWN(n_A_MaxSP * n_A_INT / 100);


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋○○）
	//----------------------------------------------------------------
	var maxSpPlus = 0;

	// アイテム特性
	maxSpPlus += n_tok[ITEM_SP_MAXSP_PLUS];
	maxSpPlus += n_tok[ITEM_SP_MAXSP_PLUS_GVGTE];

	// 装備によるＩＮＴ上昇分は、ＳＰも同量増加させる
	maxSpPlus += GetEquippedTotalSPEquip(ITEM_SP_INT_PLUS);
	maxSpPlus += GetEquippedTotalSPEquip(ITEM_SP_ALLSTATUS_PLUS);

	// 装備追加効果、支援効果
	maxSpPlus += GetStatusModifyMaxSpPlus();

	// 最終的な効果を適用
	n_A_MaxSP += maxSpPlus;
	if(n_A_MaxSP <0) n_A_MaxSP = 0;


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋％）
	//----------------------------------------------------------------
	var maxSpPerUp = 0;

	// アイテム特性
	maxSpPerUp += n_tok[ITEM_SP_MAXSP_UP];

	// 装備追加効果、支援効果
	maxSpPerUp += GetStatusModifyMaxSpUp();

	// 最終的な効果を適用
	n_A_MaxSP += Math.floor(n_A_MaxSP * maxSpPerUp / 100);


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_MaxSP", n_A_MaxSP, 0);





//================================================================================================
// 除算Ｄｅｆ算出
//================================================================================================

	//----------------------------------------------------------------
	// 基本除算Ｄｅｆ
	//----------------------------------------------------------------
	n_A_DEF = 0;

	// 防具の基本Ｄｅｆ
	for (idx = EQUIP_REGION_ID_HEAD_TOP; idx <= EQUIP_REGION_ID_ACCESSARY_2; idx++) {
		n_A_DEF += ItemObjNew[n_A_Equip[idx]][ITEM_DATA_INDEX_POWER];
	}


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋○○）
	//----------------------------------------------------------------
	var defDivPlus = 0;

	// アイテム特性
	defDivPlus += n_tok[ITEM_SP_DEF_PLUS];

	// 装備追加効果、支援効果
	defDivPlus += GetStatusModifyDefDivPlus();


	//----------------------------------------------------------------
	// 防具の精錬効果
	//----------------------------------------------------------------
	var refineDefTable = [0, 1, 2, 3, 4, 6, 8, 10, 12, 15, 18];
	var defRefined = 0;
	defRefined += refineDefTable[n_A_HEAD_DEF_PLUS];
	defRefined += refineDefTable[n_A_BODY_DEF_PLUS];
	defRefined += refineDefTable[n_A_LEFT_DEF_PLUS];
	defRefined += refineDefTable[n_A_SHOULDER_DEF_PLUS];
	defRefined += refineDefTable[n_A_SHOES_DEF_PLUS];


	//----------------------------------------------------------------
	// 除算Ｄｅｆの算出
	//----------------------------------------------------------------
	n_A_totalDEF = n_A_DEF + defDivPlus + defRefined;


	//----------------------------------------------------------------
	// 特殊効果の適用（各々乗算扱い）
	//----------------------------------------------------------------

	// アイテム特性　キャラの防御力１／ｎ
	if (n_tok[ITEM_SP_DEF_DIVIDE_PENARTY]) {
		n_A_totalDEF = Math.floor(n_A_totalDEF / n_tok[ITEM_SP_DEF_DIVIDE_PENARTY]);
	}

	// ロードナイト　コンセントレイション
	if (sklLv = SkillSearch(SKILL_ID_CONCENTRATION)) {
		n_A_totalDEF = Math.floor(n_A_totalDEF * (1 - 0.05 * sklLv));
	}

	// レンジャー　アンリミット
	if ((n_B_TAISEI[38] == 0 || n_B_TAISEI[38] == 5) && SkillSearch(SKILL_ID_UNLIMIT)) {
		n_A_totalDEF = 1;
	}

	// ロードナイト　バーサーク
	if (SkillSearch(SKILL_ID_BERSERK)) {
		n_A_totalDEF = 0;
	}

	// 囲まれ補正
	if (n_A_PassSkill8[12] >= 3) {
		n_A_totalDEF -= Math.floor(n_A_totalDEF * (n_A_PassSkill8[12] - 2) * 5 / 100);
	}


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋％）
	//----------------------------------------------------------------
	var defDivUp = 0;

	// アイテム特性
	defDivUp += n_tok[ITEM_SP_DEF_UP];

	// 装備追加効果、支援効果
	defDivUp += GetStatusModifyDefDivUp();

	// 最終的な効果を適用
	n_A_totalDEF += ROUNDDOWN(n_A_totalDEF * defDivUp / 100);



//================================================================================================
// 減算Ｄｅｆ算出
//================================================================================================

	//----------------------------------------------------------------
	// 基本減算Ｄｅｆ
	//----------------------------------------------------------------

	// プロボック系による倍率補正
	var rateByProvoke = 100;
	// オートバーサーク
	if (SkillSearch(SKILL_ID_AUTO_BERSERK)) {
		rateByProvoke = 45;
	}
	// 支援プロボック
	else if (n_A_PassSkill6[5]){
		rateByProvoke = 95 - 5 * n_A_PassSkill6[5];
	}
	// 旧アロエベラ（現行未使用）
	else if (n_A_PassSkill2[12]){
		rateByProvoke = 90;
	}

	// 基本値を算出
	var defMinus = 0;
	defMinus = Math.floor(((n_A_VIT / 2) * rateByProvoke / 100) + n_A_BaseLV / 2 + n_A_AGI / 5);


	//----------------------------------------------------------------
	// 特殊効果の適用
	//----------------------------------------------------------------

	// 「ソーサラー　精霊補助スキル　ソリッドスキン」の、効果
	if (SkillSearch(SKILL_ID_SERE_SUPPORT_SKILL) == 29){
		defMinus += defMinus;
	}

	// 「修羅　点穴-活-」の、効果
	if ((sklLv = SkillSearch(SKILL_ID_TENKETSU_KATSU)) > 0) {
		var valVit = 0;

		// 持ち替え支援の場合、支援欄のステータスを使用
		if(n_A_PassSkill4[11] == 3) {
			valVit = n_A_PassSkill4[32];
		}

		// 持ち替えなしの場合、本人のステータスを使用
		else {
			valVit = n_A_VIT;
		}

		defMinus += Math.floor(valVit / 4) * sklLv;
	}

	// 「アコライト　エンジェラス」の、効果
	if (n_A_PassSkill2[4]) {
		defMinus += Math.floor(ROUNDDOWN(n_A_VIT / 2) * (0.05 * n_A_PassSkill2[4]));
	}

	// 「ミスリルマジックマント　時限効果」の、効果（ペナルティ）
	if (TimeItemNumSearch(33)) {
		defMinus -= Math.floor(defMinus * 20 / 100);
	}

	// 「レンジャー　アンリミット」の、効果（ペナルティ）
	if ((n_B_TAISEI[38] == 0 || n_B_TAISEI[38] == 5) && SkillSearch(SKILL_ID_UNLIMIT)){
		defMinus = 1;
	}

	// 「ロードナイト　バーサーク」の、効果（ペナルティ）
	if (SkillSearch(SKILL_ID_BERSERK)){
		defMinus = 0;
	}

	// 囲まれ補正
	if (n_A_PassSkill8[12] >= 3) {
		defMinus -= Math.floor(defMinus * (n_A_PassSkill8[12] - 2) * 5 / 100);
	}

	// 「ジェネティック　Ｓホム　ペインキラー」の、効果
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_HOM_S_PAINKILLER)) > 0) {
		var homLv = ExBuffNumSearch(EXBUF_ID_HOM_S_PAINKILLER_HOM_LEVEL);

		defMinus += ROUNDDOWN(100 * bufLv * (132 + homLv) / 100 * n_A_BaseLV / 150);
	}


	//----------------------------------------------------------------
	// 計算用変数へ設定
	//----------------------------------------------------------------
	n_A_VITDEF = new Array();
	n_A_VITDEF[0] = n_A_VITDEF[1] = n_A_VITDEF[2] = defMinus;


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_totalDEF", n_A_VITDEF[0] + "+" + n_A_totalDEF, 0);





//================================================================================================
// 除算Ｍｄｅｆ算出
//================================================================================================

	//----------------------------------------------------------------
	// 装備、支援等による補正（＋○○）
	//----------------------------------------------------------------
	var mdefDivPlus = 0;

	// アイテム特性
	mdefDivPlus = n_tok[ITEM_SP_MDEF_PLUS];

	// 装備追加効果、支援効果
	mdefDivPlus += GetStatusModifyMdefDivPlus();

	// 最終的な効果を適用
	n_A_MDEF = mdefDivPlus;


	//----------------------------------------------------------------
	// 特殊効果の適用（各々乗算扱い）
	//----------------------------------------------------------------

	// 「修羅　点穴-反-」の、効果（ペナルティ）
	if ((sklLv = SkillSearch(SKILL_ID_TENKETSU_HAN)) > 0) {
		var valInt = 0;

		// 持ち替え支援の場合、支援欄のステータスを使用
		if(n_A_PassSkill4[11] == 2) {
			valInt = n_A_PassSkill4[32];
		}

		// 持ち替えなしの場合、本人のステータスを使用
		else {
			valInt = n_A_VIT;
		}

		if (valInt < 1) valInt = 1;

		// このペナルティによって、Ｍｄｅｆがマイナスになることはない（らしい）
		vartmp = 1 * Math.floor(200 / valInt) * sklLv;
		n_A_MDEF -= Math.min(n_A_MDEF, vartmp);
	}

	// 「レンジャー　アンリミット」の、効果（ペナルティ）
	if ((n_B_TAISEI[38] == 0 || n_B_TAISEI[38] == 5) && SkillSearch(SKILL_ID_UNLIMIT)){
		n_A_MDEF = 1;
	}

	// 「ロードナイト　バーサーク」の、効果（ペナルティ）
	if (SkillSearch(SKILL_ID_BERSERK)){
		n_A_MDEF = 0;
	}


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋％）
	//----------------------------------------------------------------
	var mdefDivUp = 0;

	// アイテム特性
	mdefDivUp += n_tok[ITEM_SP_MDEF_UP];

	// 装備追加効果、支援効果
	mdefDivUp += GetStatusModifyMdefDivUp();

	// 最終的な効果を適用
	n_A_MDEF += Math.floor(n_A_MDEF * mdefDivUp / 100);



//================================================================================================
// 減算Ｍｄｅｆ算出
//================================================================================================

	//----------------------------------------------------------------
	// 基本減算Ｍｄｅｆ
	//----------------------------------------------------------------
	var mdefMinus = 0;
	mdefMinus = Math.floor(n_A_INT + n_A_BaseLV / 4 + n_A_VIT / 5 + n_A_DEX / 5);


	//----------------------------------------------------------------
	// 特殊効果の適用（各々乗算扱い）
	//----------------------------------------------------------------

	// ウルフヘジンの時限効果
	if (TimeItemNumSearch(9)) {
		mdefMinus -= Math.floor(mdefMinus * 20 / 100);
	}

	// 「アヌビス帽」の、効果（ペナルティ）
	if (EquipNumSearch(1281)) {
		mdefMinus = Math.floor(mdefMinus / 2);
	}

	// 「レンジャー　アンリミット」の、効果（ペナルティ）
	if ((n_B_TAISEI[38] == 0 || n_B_TAISEI[38] == 5) && SkillSearch(SKILL_ID_UNLIMIT)){
		mdefMinus = 1;
	}

	// 「ジェネティック　Ｓホム　ペインキラー」の、効果
	if ((bufLv = ExBuffNumSearch(EXBUF_ID_HOM_S_PAINKILLER)) > 0) {
		var homLv = ExBuffNumSearch(EXBUF_ID_HOM_S_PAINKILLER_HOM_LEVEL);

		mdefMinus += ROUNDDOWN(100 * bufLv * (132 + homLv) / 100 * n_A_BaseLV / 150);
	}


	//----------------------------------------------------------------
	// 計算用変数へ設定
	//----------------------------------------------------------------
	n_A_INTMDEF = mdefMinus;


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_MDEF", n_A_INTMDEF + "+" + n_A_MDEF, 0);





//================================================================================================
// ＨＩＴ算出
//================================================================================================

	//----------------------------------------------------------------
	// 基本ＨＩＴ
	//----------------------------------------------------------------

	n_A_HIT = 175 + Math.floor(n_A_BaseLV + n_A_DEX + n_A_LUK / 3);


	//----------------------------------------------------------------
	// 装備、支援等による補正（＋○○）
	//----------------------------------------------------------------
	var hitPlus = 0;

	// アイテム特性
	hitPlus += n_tok[ITEM_SP_HIT_PLUS];

	// 装備追加効果、支援効果
	hitPlus += GetStatusModifyHitPlus();

	// 最終的な効果を適用
	n_A_HIT += hitPlus;


	//----------------------------------------------------------------
	// 表示ＨＴＭＬを組み立て
	//----------------------------------------------------------------
	myInnerHtml("A_HIT",n_A_HIT,0);





	with(document.calcForm){


//================================================================================================================================
//================================================================================================================================
//====
//==== ＦＬＥＥ　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_FLEE_PLUS; idx <= ITEM_SP_FLEE_PLUS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		n_A_FLEE = 100 + n_A_BaseLV + n_A_AGI + Math.floor(n_A_LUK / 5);
		n_A_FLEE += n_tok[9];
		if(GetLowerJobSeriesID(n_A_JOB)==2 && CardNumSearch(295)) n_A_FLEE += 20;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && CardNumSearch(271)) n_A_FLEE += 20;
		if(n_A_SHOULDER_DEF_PLUS <= 4 && CardNumSearch(401)) n_A_FLEE += 10;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && CardNumSearch(403)) n_A_FLEE += 5;
		if(SU_STR >= 90 && EquipNumSearch(442)) n_A_FLEE += 10 * EquipNumSearch(442);
		if(EquipNumSearch(1273)){
			if(n_A_HEAD_DEF_PLUS >= 5) n_A_FLEE += 5;
			if(n_A_HEAD_DEF_PLUS >= 7) n_A_FLEE += 2;
		}
		if(SU_AGI >= 120 && EquipNumSearch(1315)) n_A_FLEE += 3;
		if(SU_INT >= 120 && EquipNumSearch(1319)) n_A_FLEE += 3;
		if(EquipNumSearch(1387)) n_A_FLEE += n_A_BODY_DEF_PLUS;
		if(n_A_PassSkill6[0] == 2 && n_A_PassSkill6[1] >= 1) n_A_FLEE += n_A_PassSkill6[1] *3;
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==483) n_A_FLEE -= (n_A_BaseLV + SU_AGI);
		if(n_A_BaseLV <= 79 && EquipNumSearch(1251)) n_A_FLEE += 5;
		if(SU_AGI >= 80 && EquipNumSearch(1525)){
			var wx = EquipNumSearch(1525);
			n_A_FLEE += 4 * wx;
			if(SU_AGI >= 100) n_A_FLEE += 1 * wx;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 6 && EquipNumSearch(1531)){
			n_A_FLEE += 2;
			if(n_A_SHOULDER_DEF_PLUS >= 8) n_A_FLEE += 3;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 1 && EquipNumSearch(1597)) n_A_FLEE += n_A_SHOULDER_DEF_PLUS * 2;
		if(n_A_BODY_DEF_PLUS >= 1 && EquipNumSearch(1600)) n_A_FLEE += n_A_BODY_DEF_PLUS;
		if(EquipNumSearch(1948)) n_A_FLEE += ROUNDDOWN(SU_AGI / 10) * EquipNumSearch(1948);
		if(n_A_SHOULDER_DEF_PLUS >= 9 && EquipNumSearch(2453)) n_A_FLEE += 5;
		if(SU_VIT >= 110){
			if(CardNumSearch(706)) n_A_FLEE += 20;
			if(CardNumSearch(711)) n_A_FLEE += 20;
		}
		if(EquipNumSearch(2464)) n_A_FLEE += 2 * n_A_SHOULDER_DEF_PLUS;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2566)) n_A_FLEE += 15;
		if(EquipNumSearch(1357)){
			if(EquipNumSearch(266)) n_A_FLEE += 20;
		}

		//----------------------------------------------------------------
		// 「英雄マント」の、精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_EIYU_MANT)){
			n_A_FLEE += 3 * ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3);
			if (n_A_SHOULDER_DEF_PLUS >= 10) {
				n_A_FLEE += 20;
			}
		}

		//----------------------------------------------------------------
		// 「A-FLEE」の、精錬による効果
		//----------------------------------------------------------------
		if(CardNumSearch(CARD_ID_ENCHANT_A_FLEE)){

			// 体装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == CARD_ID_ENCHANT_A_FLEE) {

				if (n_A_BODY_DEF_PLUS >= 7) n_A_FLEE += 10;
				if (n_A_BODY_DEF_PLUS >= 8) n_A_FLEE += 10;
				if (n_A_BODY_DEF_PLUS >= 9) n_A_FLEE += 10;
			}

			// 肩装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == CARD_ID_ENCHANT_A_FLEE) {

				if (n_A_SHOULDER_DEF_PLUS >= 7) n_A_FLEE += 10;
				if (n_A_SHOULDER_DEF_PLUS >= 8) n_A_FLEE += 10;
				if (n_A_SHOULDER_DEF_PLUS >= 9) n_A_FLEE += 10;
			}

			// 靴装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == CARD_ID_ENCHANT_A_FLEE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == CARD_ID_ENCHANT_A_FLEE) {

				if (n_A_SHOES_DEF_PLUS >= 7) n_A_FLEE += 10;
				if (n_A_SHOES_DEF_PLUS >= 8) n_A_FLEE += 10;
				if (n_A_SHOES_DEF_PLUS >= 9) n_A_FLEE += 10;
			}

			// ライオットチップとのセット効果
			if (EquipNumSearch(ITEM_SET_ID_RIOTCHIP_A_FLEE)) {
				n_A_FLEE += 5 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 3);
			}
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_THIEF) {
				n_A_FLEE += 10;
			}
		}

		//----------------------------------------------------------------
		// 「セイヴザキング」の、騎兵修練【未習得】時における、「スピアクイッケン」習得による効果
		//----------------------------------------------------------------
		if (SkillSearch(78) == 0) {
			if (EquipNumSearch(ITEM_ID_SAVE_THE_KING)) {
				n_A_FLEE += 2 * SkillSearch(SKILL_ID_SPEAR_QUICKEN);
			}
		}

		//----------------------------------------------------------------
		// 「ジェネティックエミュール(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_GENETIC_EMUR_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_GENETIC) {
				n_A_FLEE += 20 * cardCount;
			}
		}

		if(GetHigherJobSeriesID(n_A_JOB) == 8 || GetHigherJobSeriesID(n_A_JOB) == 14) n_A_FLEE += 4 * SkillSearch(14);
		else n_A_FLEE += 3 * SkillSearch(14);
		if(SkillSearch(421)) n_A_FLEE += 30;
		if(SkillSearch(433)){
			if(n_A_WeaponType==20 || n_A_WeaponType==0) n_A_FLEE -= 5 * SkillSearch(433);
		}
		Mikiri = new Array(0,1,3,4,6,7,9,10,12,13,15);
		n_A_FLEE += Mikiri[SkillSearch(191)];
		if(n_A_JOB == 24 || n_A_JOB == 49) n_A_FLEE += Math.round(SkillSearch(273) /2);
		if(n_A_PassSkill2[9] && SkillSearch(273)==0) n_A_FLEE += Math.round(n_A_PassSkill2[9] /2);
		if((n_A_WeaponType==4 || n_A_WeaponType==5) && SkillSearch(166)) n_A_FLEE += SkillSearch(166) * 2;
		if(SkillSearch(814) == 20) n_A_FLEE += 10;
		if(SkillSearch(814) == 26) n_A_FLEE += 25;
		if(SkillSearch(383)) n_A_FLEE += 10;
		if(SkillSearch(356)) n_A_FLEE += Math.floor((n_A_BaseLV + n_A_LUK + n_A_DEX) / 10);
		if(SkillSearch(473)) n_A_FLEE += 50 * SkillSearch(473);
		if(n_A_PassSkill4[9]) n_A_FLEE += 50;
		if(n_A_PassSkill3[11]) n_A_FLEE -= (20 + 5 * n_A_PassSkill3[11]);
		if(n_A_PassSkill3[39] == 1) n_A_FLEE -= (40 + 10 * n_A_PassSkill3[40]);
		if(SkillSearch(814) == 17) n_A_FLEE -= 30;
		if(n_A_PassSkill7[1]) n_A_FLEE += 30;
		else if(n_A_PassSkill7[27]) n_A_FLEE += 20;
		else if(n_A_PassSkill7[36]) n_A_FLEE += 10;
		if(3 <= n_A_PassSkill8[22] && n_A_PassSkill8[22] <= 4) n_A_FLEE += 10;
		if(0 <n_A_PassSkill7[45] && n_A_PassSkill7[45] <= 50) n_A_FLEE += n_A_PassSkill7[45];
		if(n_A_PassSkill3[0]) n_A_FLEE += n_A_PassSkill3[0] * 3 + Math.floor(n_A_PassSkill3[30] /2) + n_A_PassSkill3[20];
		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[14] != 0) n_A_FLEE += n_A_PassSkill10[14];
		if(SkillSearch(258)) n_A_FLEE /= 2;
		if(SkillSearch(817)) n_A_FLEE = 300 + 40 * SkillSearch(817);
		if(n_A_PassSkill8[12] >= 3){
			var w = n_A_PassSkill8[12] - 2;
			if(w > 10) w = 10;
			n_A_FLEE -= Math.floor(n_A_FLEE * w * 10 / 100);
		}
		myInnerHtml("A_FLEE",n_A_FLEE,0);





//================================================================================================================================
//================================================================================================================================
//====
//==== 完全回避＋○○　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_LUCKY_PLUS; idx <= ITEM_SP_LUCKY_PLUS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		n_A_LUCKY = 1 + n_A_LUK * 0.1;
		n_A_LUCKY += n_tok[11];
		if(GetLowerJobSeriesID(n_A_JOB)==2) n_A_LUCKY += 5 * CardNumSearch(391);
		if(GetLowerJobSeriesID(n_A_JOB)==1) n_A_LUCKY += 3 * CardNumSearch(354);
		if(n_A_SHOULDER_DEF_PLUS <= 4 && CardNumSearch(401)) n_A_LUCKY += 1;

		if(n_A_Equip[EQUIP_REGION_ID_SHOULDER]==535
			|| EquipNumSearch(1647)
			|| EquipNumSearch(1718)
			|| CardNumSearch(CARD_ID_ENCHANT_ENERGY_IKUSAOTOME)){
			var wHPVS = GetLowerJobSeriesID(n_A_JOB);
			if(wHPVS==3 || wHPVS==4 || wHPVS==5){
				n_A_LUCKY += 5;
				n_A_LUCKY += n_A_SHOULDER_DEF_PLUS * 2;
			}
		}

		if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(678)) n_A_LUCKY += 2;
		if(n_A_LEFT_DEF_PLUS >= 6 && EquipNumSearch(1251)) n_A_LUCKY += 3;
		if(SU_AGI >= 120 && EquipNumSearch(1309)) n_A_LUCKY += 5;
		if(SU_VIT >= 100 && EquipNumSearch(1526)){
			var wx = EquipNumSearch(1526);
			n_A_LUCKY += 1 * wx;
			if(SU_VIT >= 120) n_A_LUCKY += 3 * wx;
		}
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1606)) n_A_LUCKY += 5;
		if(n_A_SHOULDER_DEF_PLUS >= 7 && EquipNumSearch(1607)) n_A_LUCKY += (n_A_SHOULDER_DEF_PLUS - 6);
		if(n_A_SHOULDER_DEF_PLUS >= 7 && EquipNumSearch(1715)) n_A_LUCKY += 2;
		if(n_A_Weapon_ATKplus >= 7 && EquipNumSearch(1765)) n_A_LUCKY += 5;
		if(SU_AGI >= 110 && EquipNumSearch(1948)) n_A_LUCKY += 1 * EquipNumSearch(1948);
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(2121)){
			n_A_LUCKY += 1;
			if(n_A_HEAD_DEF_PLUS >= 9) n_A_LUCKY += 1;
			if(n_A_HEAD_DEF_PLUS >= 10) n_A_LUCKY += 3;
		}
		if(n_A_BaseLV >= 130 && EquipNumSearch(2464)){
			n_A_LUCKY += 2;
			if(EquipNumSearch(2465)) n_A_LUCKY += 6;
		}
		if(CardNumSearch(871)){
			if(n_A_BODY_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 871)n_A_LUCKY += 1;
			}
			if(n_A_BODY_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 871)n_A_LUCKY += 1;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 871)n_A_LUCKY += 1;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 871)n_A_LUCKY += 1;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 871)n_A_LUCKY += 1;
			}
		}
		if(n_A_LEFT_DEF_PLUS >= 3 && EquipNumSearch(2533)) n_A_LUCKY += 2 * ROUNDDOWN(n_A_LEFT_DEF_PLUS / 3);
		if(EquipNumSearch(2542)) n_A_LUCKY += 3 * n_A_SHOULDER_DEF_PLUS;

		//----------------------------------------------------------------
		// 「ヴァルキリーハンマー」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				n_A_LUCKY += 1 * n_A_Weapon_ATKplus;
				break;

			// ソードマン系
			case JOB_SERIES_ID_SWORDMAN:
				break;

			// マーチャント系
			case JOB_SERIES_ID_MERCHANT:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// プリースト系
				case JOB_SERIES_ID_PRIEST:
					break;

				// モンク系
				case JOB_SERIES_ID_MONK:
					n_A_LUCKY += 1 * n_A_Weapon_ATKplus;
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「ロザリオの首飾り　クローチェセット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_ROSARIONO_KUBIKAZARI_CROCE_STUFF)) {
			n_A_LUCKY += 2 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「ロザリオの首飾り　聖職者の看護帽セット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_ROSARIONO_KUBIKAZARI_SEISHOKUSHANO_KANGOBO)) {
			n_A_LUCKY += 1 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャージャマダハル」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_JAMADHAR)) {
			if (n_A_Weapon_ATKplus >= 5) n_A_LUCKY += 5;
			if (n_A_Weapon_ATKplus >= 7) n_A_LUCKY += 5;
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_THIEF) {
				n_A_LUCKY += 3;
			}
		}

		//----------------------------------------------------------------
		// 「エナジー＜致命ノ一撃＞」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_CHIMEINO_ICHIGEKI)) > 0) {
			n_A_LUCKY += 1 * Math.max(0, (n_A_SHOULDER_DEF_PLUS - 4)) * cardCount;
		}

		//----------------------------------------------------------------
		// 「ギロチンクロスエレメス(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_GUILLOTINE_CROSS_ELEMES_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_GILOTINCROSS) {
				n_A_LUCKY += 10 * cardCount;
			}
		}


		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[15] != 0) n_A_LUCKY += n_A_PassSkill10[15];
		if(n_A_PassSkill3[0]) n_A_LUCKY += Math.floor(n_A_PassSkill3[0] / 2) + Math.floor(n_A_PassSkill3[30] / 5) + n_A_PassSkill3[28];
		n_A_LUCKY = Math.round(n_A_LUCKY *10)/10;
		myInnerHtml("A_LUCKY",n_A_LUCKY,0);
		if(n_A_LUCKY <0) n_A_LUCKY = 0;





//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃時、△△形モンスターにクリティカル率＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		// クリティカル率＋○○よりも先に計算すること

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_CRITICAL_UP_RACE_SOLID; idx <= ITEM_SP_CRITICAL_UP_RACE_DRAGON; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		//----------------------------------------------------------------
		// 「勇者の靴　達人の槌　セット」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI)) > 0) {
			n_tok[ITEM_SP_CRITICAL_UP_RACE_UNDEAD] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_CRITICAL_UP_RACE_DEMON] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_CRITICAL_UP_RACE_HUMAN] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
		}
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI_S2)) > 0) {
			n_tok[ITEM_SP_CRITICAL_UP_RACE_UNDEAD] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_CRITICAL_UP_RACE_DEMON] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_CRITICAL_UP_RACE_HUMAN] += 5 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
		}






//================================================================================================================================
//================================================================================================================================
//====
//==== クリティカル率＋○○　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_CRI_PLUS; idx <= ITEM_SP_CRI_PLUS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		n_A_CRI = 1 + n_A_LUK * 0.33;
		w=0;
		w += n_tok[10];
		w += n_tok[110+n_B[19]];
		if(CardNumSearch(402)) w += n_A_SHOULDER_DEF_PLUS;
		if(GetLowerJobSeriesID(n_A_JOB)==2) w += 4 * CardNumSearch(328);
		if(GetLowerJobSeriesID(n_A_JOB)==3){
			if(n_B[19]==1 || n_B[19]==6) w += 9 * CardNumSearch(253);
		}
		if(SU_LUK >= 80 && CardNumSearch(267)) w += 3;
		if(n_A_WeaponType==3 || n_A_WeaponType==2) w += CardNumSearch(464) * 5;
		if(n_A_WeaponType==10) w += CardNumSearch(465) * 5;
		if(CardNumSearch(492)) w += Math.floor(n_A_JobLV /10) * CardNumSearch(492);
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(785)) w += (n_A_HEAD_DEF_PLUS -5);
		if(EquipNumSearch(640)) w += Math.floor(SU_LUK / 5);
		if(EquipNumSearch(689)) w += Math.floor(SU_LUK / 10);
		if(SU_AGI >= 90 && EquipNumSearch(442)) w += 10 * EquipNumSearch(442);
		if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(675)) w += 5;
		if(EquipNumSearch(623)) w += n_A_Weapon_ATKplus;
		if(EquipNumSearch(1122) && GetLowerJobSeriesID(n_A_JOB)==6) w += 5;
		if(n_A_Weapon_ATKplus >= 7 && n_B[19]==7 && EquipNumSearch(1091)) w += 5;
		if(EquipNumSearch(1161) || EquipNumSearch(ITEM_ID_TATSUZINNO_TSUCHI_S2)) {
			w += (2 * SkillSearch(89));
		}
		if(SU_DEX >= 90 && EquipNumSearch(1164)) w += 5;
		if(n_A_HEAD_DEF_PLUS >= 7) if(EquipNumSearch(1267)) w += 5;
		if(SU_STR >= 120 && EquipNumSearch(1313)) w += 3;
		if(SU_AGI >= 120 && EquipNumSearch(1200)) w += 4 * EquipNumSearch(1200);
		if(EquipNumSearch(1412)) w += Math.floor(n_A_SHOES_DEF_PLUS / 2);
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1591)) w += 8;
		if(EquipNumSearch(1661)) w += n_A_Weapon_ATKplus;
		if(n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1812)) w += 3;
		if(EquipNumSearch(1951)) w += ROUNDDOWN(SU_LUK / 10) * EquipNumSearch(1951);
		if(SU_STR >= 110 && CardNumSearch(707)) w += 20;
		if(EquipNumSearch(2242)){
			w += ROUNDDOWN(SU_LUK / 10);
			if(SU_LUK >= 108) w += 5;
			if(SU_LUK >= 120) w += 10;
		}
		if(n_A_LEFT_DEF_PLUS >= 7 && EquipNumSearch(2253)) w += 2;
		if(n_A_WeaponType == 10 && n_A_Arrow == 15) w += 20;


		// ドロセラカード
		if(n_A_WeaponType==10 || 17<=n_A_WeaponType && n_A_WeaponType<=21) {
			// 遠距離物理攻撃限定の効果
			if (n_A_WeaponType == ITEM_KIND_BOW
				|| n_A_WeaponType == ITEM_KIND_HANDGUN
				|| n_A_WeaponType == ITEM_KIND_RIFLE
				|| n_A_WeaponType == ITEM_KIND_SHOTGUN
				|| n_A_WeaponType == ITEM_KIND_GATLINGGUN
				|| n_A_WeaponType == ITEM_KIND_GRENADEGUN) {

				n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += CardNumSearch(462) * 15;
			}
		}

		//----------------------------------------------------------------
		// 「蒼き夜光石」の、ステによる強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AOKI_YAKOSEKI)) {
			if (SU_LUK >= 100) {
				w += 10 * EquipNumSearch(ITEM_ID_AOKI_YAKOSEKI);
			}
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w += 7 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「リス耳フード帽」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RISUMIMI_HOODBO)) {

			// 遠距離物理攻撃限定の効果
			if (n_A_WeaponType == ITEM_KIND_BOW
				|| n_A_WeaponType == ITEM_KIND_HANDGUN
				|| n_A_WeaponType == ITEM_KIND_RIFLE
				|| n_A_WeaponType == ITEM_KIND_SHOTGUN
				|| n_A_WeaponType == ITEM_KIND_GATLINGGUN
				|| n_A_WeaponType == ITEM_KIND_GRENADEGUN) {

				n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += 5;
				if (n_A_HEAD_DEF_PLUS >= 5) n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += 10;
				if (n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += 15;
				if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += 20;
			}
		}

		//----------------------------------------------------------------
		// 「セイヴザキング」の、騎兵修練【未習得】時における、「スピアクイッケン」習得による効果
		//----------------------------------------------------------------
		if (SkillSearch(78) == 0) {
			if (EquipNumSearch(ITEM_ID_SAVE_THE_KING)) {
				w += 3 * SkillSearch(SKILL_ID_SPEAR_QUICKEN);
			}
		}

		//----------------------------------------------------------------
		// 「マタギの剣鉈」の、素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_MATAGINO_KENNATA)) > 0) {
			// 遠距離物理攻撃限定の効果
			if (SU_LUK >= 100) n_tok[ITEM_SP_LONGRANGE_CRI_PLUS] += 10 * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			w += 5 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			w += 5 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「ローラカード」の、強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOLA)) {
			if (n_A_WeaponType == ITEM_KIND_CLUB) {
				w += (10 + 1 * n_A_Weapon_ATKplus) * CardNumSearch(CARD_ID_LOLA);
			}
		}

		//----------------------------------------------------------------
		// 「エナジー＜致命ノ一撃＞」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_CHIMEINO_ICHIGEKI)) > 0) {
			w += 1 * Math.max(0, (n_A_SHOULDER_DEF_PLUS - 4)) * cardCount;
		}

		//----------------------------------------------------------------
		// 「パワフルSスケルトンカード」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_S_SKELETON)) > 0) {
			w += 1 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
		}

		//----------------------------------------------------------------
		// 「レンジャーセシル(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_RANGER_CECIL_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_RANGER) {
				w += 20 * cardCount;
			}
		}


		if(SkillSearch(621)){
			w += 20;
		}else if(SkillSearch(195)){
			w += 7.5 + SkillSearch(195) * 2.5;
		}else if(TimeItemNumSearch(55)){
			w += 15;
		}else if(TimeItemNumSearch(34)) w += 10;
		if(SkillSearch(253)) w += 50;
		if(n_A_JOB == 24 || n_A_JOB == 49) w += SkillSearch(270);
		if((n_A_WeaponType==4 || n_A_WeaponType==5) && SkillSearch(166)) w += SkillSearch(166) * 3;
		if(n_A_PassSkill6[7]) w += n_A_PassSkill6[7];
		if(SkillSearch(599)) w += 20 * SkillSearch(599);
		if(SkillSearch(496)) w += 10 * SkillSearch(496);
		if(n_A_PassSkill3[39] == 4) w += n_A_PassSkill3[40] * n_A_PassSkill3[41];
		if(n_A_PassSkill7[25]) w += 7;
		if(n_A_PassSkill7[28]) w += 7;
		else if(n_A_PassSkill7[36]) w += 7;
		if(0 <n_A_PassSkill7[46] && n_A_PassSkill7[46] <= 50) w += n_A_PassSkill7[46];
		if(n_A_PassSkill3[5]) w += 10 + n_A_PassSkill3[5] + Math.floor(n_A_PassSkill3[35] /2) + n_A_PassSkill3[25];
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[11]) w += n_A_PassSkill9[11];

		n_A_CRI += w;
		// 遠距離物理攻撃限定の効果
		if (n_A_WeaponType == ITEM_KIND_BOW
			|| n_A_WeaponType == ITEM_KIND_HANDGUN
			|| n_A_WeaponType == ITEM_KIND_RIFLE
			|| n_A_WeaponType == ITEM_KIND_SHOTGUN
			|| n_A_WeaponType == ITEM_KIND_GATLINGGUN
			|| n_A_WeaponType == ITEM_KIND_GRENADEGUN) {

			n_A_CRI += n_tok[ITEM_SP_LONGRANGE_CRI_PLUS];
		}

		if(n_A_WeaponType == 11) n_A_CRI += n_A_LUK * 0.3 + w;
		n_A_CRI = Math.floor(n_A_CRI * 10) / 10;
		if(n_A_PassSkill8[16]) n_A_CRI = 0;
		if(n_A_WeaponType == 11) myInnerHtml("A_CRI",n_A_CRI +"(仮)",0);
		else myInnerHtml("A_CRI",n_A_CRI,0);
		if(n_A_CRI <0) n_A_CRI = 0;





//================================================================================================================================
//================================================================================================================================
//====
//==== ＭＡＴＫ＋　ここから
//====
//================================================================================================================================
//================================================================================================================================

		var w = 0;

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		w += GetRndEnchValue(ITEM_SP_MATK_PLUS_TYPE_NOTSTUFF);

		if(SU_STR >= 120 && EquipNumSearch(1308)) w += 5;
		if(SU_INT >= 120 && EquipNumSearch(1310)) w += 10;
		if(SU_DEX >= 120 && EquipNumSearch(1312)) w += 10;
		if(SU_INT >= 120 && EquipNumSearch(1314)) w += 10;
		if(SU_INT >= 120 && EquipNumSearch(1319)) w += 10;
		if(n_A_Weapon_ATKplus >= 6 && EquipNumSearch(1337)) w += 3 * (n_A_Weapon_ATKplus - 5);
		if(EquipNumSearch(1379)) w += 10 * n_A_Weapon_ATKplus;
		if(EquipNumSearch(1385)) w += 2 * n_A_LEFT_DEF_PLUS;
		if(SU_INT >= 80 && EquipNumSearch(1528)){
			var wx = EquipNumSearch(1528);
			w += 5 * wx;
			if(SU_INT >= 100) w += 5 * wx;
			if(SU_INT >= 120) w += 5 * wx;
		}
		if(EquipNumSearch(1628)){
			w += 15 * n_A_Weapon_ATKplus;
			if(n_A_Weapon_ATKplus >= 10) w += 50;
		}
		if(EquipNumSearch(1629)){
			w += 20 * n_A_Weapon_ATKplus;
			if(n_A_Weapon_ATKplus >= 10) w += 50;
		}
		if(EquipNumSearch(1664)) w += 3 * n_A_Weapon_ATKplus;
		if(SU_INT >= 120 && EquipNumSearch(1686)) w += 10;
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1742){
			if(n_A_Weapon_ATKplus >= 5) w += 30;
			if(n_A_Weapon_ATKplus >= 7) w += 40;
			if(n_A_Weapon_ATKplus >= 9) w += 50;
		}
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1742){
			if(n_A_Weapon2_ATKplus >= 5) w += 30;
			if(n_A_Weapon2_ATKplus >= 7) w += 40;
			if(n_A_Weapon2_ATKplus >= 9) w += 50;
		}
		if(EquipNumSearch(1790)) w += 10 * n_A_Weapon_ATKplus;
		w += n_tok[245];

		// 知力の時空ブーツ
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(1918)) {
			w += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}
		if(SU_INT >= 120 && EquipNumSearch(1918)) {
			w += 60;
		}
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS_S1)) {
			w += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}
		if(SU_INT >= 120 && EquipNumSearch(ITEM_ID_CHIRYOKUNO_ZIKU_BOOTS_S1)) {
			w += 60;
		}

		if(EquipNumSearch(1947)) w += ROUNDDOWN(SU_INT / 10) * EquipNumSearch(1947);
		if(2039 <= n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] && n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] <= 2041){
			w += 5 * n_A_Weapon_ATKplus;
			if(n_A_Weapon_ATKplus >= 7) w += 20;
			if(n_A_Weapon_ATKplus >= 10) w += 30;
		}
		if(SU_INT >= 120 && EquipNumSearch(2093)) w += 25;
		if(EquipNumSearch(2194)) w += 10 * n_A_Weapon_ATKplus;
		if(EquipNumSearch(2201)) w += 5 * n_A_HEAD_DEF_PLUS;
		if(EquipNumSearch(2202)) w += 7 * n_A_HEAD_DEF_PLUS;
		if(CardNumSearch(736)) w += 5 * ROUNDDOWN(SU_INT / 10);
		if(n_A_WeaponType==12 && n_A_Weapon_ATKplus >= 10) w += 20 * CardNumSearch(735);
		if(EquipNumSearch(2242)) w += 2 * ROUNDDOWN(SU_LUK / 10);
		if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(2253)) w += 5;
		if(n_A_card[CARD_REGION_ID_HEAD_TOP]==750) w += 5 * n_A_HEAD_DEF_PLUS;
		if(n_A_PassSkill8[0] == 55) if(n_A_PassSkill8[17] == 6) w += 10;
		if(n_A_LEFT_DEF_PLUS >= 7 && EquipNumSearch(2322)){
			w += 20;
			if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(2323)){
				w += 15 * n_A_Weapon_ATKplus;
				if(n_A_Weapon_ATKplus >= 10) w += 50;
			}
		}
		if(EquipNumSearch(2339)) w += 10 * n_A_Weapon_ATKplus;
		if(CardNumSearch(821)){
			if(n_A_HEAD_DEF_PLUS >= 7) w += 10 * CardNumSearch(821);
			if(n_A_HEAD_DEF_PLUS >= 9) w += 10 * CardNumSearch(821);
		}
		if(EquipNumSearch(2413)) w += 7 * n_A_HEAD_DEF_PLUS;

		// アイオーンスタッフ特殊効果
		if(TimeItemNumSearch(84)) {
			w += 24 * LearnedSkillSearch(SKILL_ID_MAHORYOKU_ZOFUKU);
		}

		if(EquipNumSearch(2439)) w += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3) * EquipNumSearch(2439);
		if(CardNumSearch(873)){
			if(n_A_BODY_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 873)w += 4;
			}
			if(n_A_BODY_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 873)w += 8;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 873)w += 4;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 873)w += 8;
			}
			if(n_A_SHOES_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 873)w += 4;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 873)w += 4;
			}
			if(n_A_SHOES_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 873)w += 8;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 873)w += 8;
			}
		}
		if(CardNumSearch(869)){
			if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 869)w += ROUNDDOWN(SU_INT / 10);
			if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 869)w += ROUNDDOWN(SU_INT / 10);
			if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 869)w += ROUNDDOWN(SU_INT / 10);
			if(n_A_BODY_DEF_PLUS >= 7){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 869)w += 2 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 869)w += 2 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 869)w += 2 * ROUNDDOWN(SU_INT / 10);
			}
			if(n_A_BODY_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 869)w += 4 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 869)w += 4 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 869)w += 4 * ROUNDDOWN(SU_INT / 10);
			}
			if(n_A_BODY_DEF_PLUS >= 9){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 869)w += 8 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 869)w += 8 * ROUNDDOWN(SU_INT / 10);
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 869)w += 8 * ROUNDDOWN(SU_INT / 10);
			}
		}
		if(EquipNumSearch(2499)){
			w += 2 * ROUNDDOWN(SU_DEX / 10);
			if(SU_DEX >= 108) w += 60;
			if(SU_DEX >= 120) w += 100;
		}
		if(EquipNumSearch(2528)) w += 15 * n_A_BODY_DEF_PLUS;

		//----------------------------------------------------------------
		// 「ヴァルキリーハンマー」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w += 200;
				break;

			// ソードマン系
			case JOB_SERIES_ID_SWORDMAN:
				break;

			// マーチャント系
			case JOB_SERIES_ID_MERCHANT:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// プリースト系
				case JOB_SERIES_ID_PRIEST:
					w += 100;
					break;

				// モンク系
				case JOB_SERIES_ID_MONK:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「古びたミダスのささやき」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_FURUBITA_MIDASS)) {
			w += 7 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「エメラルドイヤリング」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_EMERALDEARRING)) {
			w += ROUNDDOWN(SkillSearch(631) / 2) * 20 * EquipNumSearch(ITEM_ID_EMERALDEARRING);
		}

		//----------------------------------------------------------------
		// 「魔法石の恩恵」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MAHOSEKINO_ONKE)) {
			w += SU_INT;
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w += 150 * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				w += 15 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				w += 150 * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「カルデュイの法衣　ラフィネセット」の、効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_CARDYUINO_HOI_LAFINE_STUFF)){

			w += 3 * n_A_Weapon_ATKplus;

			if (n_A_BODY_DEF_PLUS >= 7) {
				w += 5 * n_A_Weapon_ATKplus;
			}

			if (n_A_BODY_DEF_PLUS >= 8) {
				w += 7 * n_A_Weapon_ATKplus;
			}
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　ロッドセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_DEX)
			|| EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_INT)) {
			w += 10 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「レインボウ」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RAIN_BO)) {
			w += 10 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 8) {
				if (SU_INT >= 90) {
					w += 30;
				}
			}
		}

		//----------------------------------------------------------------
		// 「神魔バフォメットの角　ブラッディクロスセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_SHINMA_BAPHOMETNO_TSUNO_BLOODY_CROSS)) > 0) {
			w += 15 * n_A_Weapon_ATKplus * itemCount;
		}

		//----------------------------------------------------------------
		// 「サファイアリスト」の、スキル習得による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_SAPPHIRE_LIST)) > 0) {
			var upCount = Math.floor(LearnedSkillSearch(SKILL_ID_SLIMPOTION_PITCHER) / 2);
			w += 20 * upCount * itemCount;
		}

		//----------------------------------------------------------------
		// 「エルダーの御霊」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_ELDERNO_MITAMA)) > 0) {
			vartmp = 0;

			if (n_A_SHOULDER_DEF_PLUS >= 5) vartmp += 5 * ROUNDDOWN(SU_INT / 60);
			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 5 * ROUNDDOWN(SU_INT / 10);

			w += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「エルダーの御霊　毀損された古書カードセット」の、素ＩＮＴによる効果（ペナルティ）
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_ELDERNO_MITAMA_KISONSARETA_KOSHO_CARD)) > 0) {
			w += -5 * ROUNDDOWN(SU_INT / 10) * itemCount;
		}

		//----------------------------------------------------------------
		// 「邪念のロッド」の、精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_ROD, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_ROD, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {
			w += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
			w += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
		}

		//----------------------------------------------------------------
		// 「邪念のスタッフ」の、精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_STUFF, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_STUFF, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {
			w += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
			w += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
		}

		//----------------------------------------------------------------
		// 「邪念のブック」の、精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_BOOK, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_BOOK, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {
			w += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
			w += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
		}

		//----------------------------------------------------------------
		// 「邪念のバイオリン」の、精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_VIOLIN, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_VIOLIN, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {
			w += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
			w += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
		}

		//----------------------------------------------------------------
		// 「邪念のワイヤー」の、精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_ZYANENNO_WIRE, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_ZYANENNO_WIRE, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {
			w += Math.pow(n_A_Weapon_ATKplus, 2) * itemCountRight;
			w += Math.pow(n_A_Weapon2_ATKplus, 2) * itemCountLeft;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			w += 120 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			w += 120 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「火雷大神靴」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HONOIKADUCHINOOOKAMI_KUTSU)) > 0) {
			w += 5 * n_A_SHOES_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「火雷大神靴　月夜花カード　セット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_HONOIKADUCHINOOOKAMI_KUTSU_WORUYAFA)) > 0) {
			if (n_A_BaseLV <= 99) {
				w += 5 * n_A_SHOES_DEF_PLUS * itemCount;
			} else {
				w += 15 * n_A_SHOES_DEF_PLUS * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「[LoVA] キマカード」の、精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOVA_KIMA) > 0) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				w += 6 * ROUNDDOWN(SU_INT / 30);
			}
		}

		//----------------------------------------------------------------
		// 「[LoVA] 真化キマカード」の、精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOVA_SHINKA_KIMA) > 0) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				w += 6 * ROUNDDOWN(SU_INT / 10);
			}
		}

		//----------------------------------------------------------------
		// 「セリーヌ・キミカード　リボンセット」の、精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_SET_ID_CELINE_KIMI_CELINENO_RIBBON)) {
			w += 7 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「将軍デヒョンカード」の、強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_SHOGUN_DAEHYON)) {
			if (n_A_WeaponType == ITEM_KIND_SWORD
				|| n_A_WeaponType == ITEM_KIND_SWORD_2HAND) {
				w += 100;
			}
		}

		if(SkillSearch(778)) w += ROUNDDOWN(n_A_JobLV / 2) * SkillSearch(778);
		if(n_A_PassSkill3[19] == 6) w += (5 * n_A_PassSkill3[37] + n_A_PassSkill3[38] + Math.floor(n_A_PassSkill3[46] / 4));
		if(n_A_PassSkill6[12]){
			if(n_A_PassSkill6[12] == 1) w += 70;
			if(n_A_PassSkill6[12] == 2) w += 100;
		}
		if(SkillSearch(788)){
			if(SkillSearch(793) == 0 || SkillSearch(793) == 2) w += 20 * SkillSearch(788) + ROUNDDOWN(n_A_BaseLV / 3);
			else w -= 30 * SkillSearch(788) + ROUNDDOWN(n_A_BaseLV / 3);
		}
		if(SkillSearch(812) && SkillSearch(813) == 1){
			if(SkillSearch(812) == 4) w += 40;
			if(SkillSearch(812) == 5) w += 80;
			if(SkillSearch(812) == 6) w += 120;
		}
		if(TimeItemNumSearch(59)) w += 5 * Math.floor(n_A_SHOULDER_DEF_PLUS / 3);
		if(TimeItemNumSearch(85)) w += 7 * n_A_BODY_DEF_PLUS;
		if(n_A_PassSkill7[49]) w += 30;
		if(n_A_PassSkill7[51]) w += 25;
		if(TimeItemNumSearch(79)) w += 24;
		else if(n_A_PassSkill7[10]) w += 20;
		else if(n_A_PassSkill7[2]) w += 10;
		else if(n_A_PassSkill7[26]) w += 5;
		if(0 <n_A_PassSkill7[43] && n_A_PassSkill7[43] <= 50) w += n_A_PassSkill7[43];
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[26]) w += n_A_PassSkill9[26];
		n_tok[100] += w;




		var w= Math.floor(n_A_INT / 7);
		n_A_StatusMATK = n_A_INT + Math.floor(w * w / 3 + n_A_DEX / 5 + n_A_LUK / 3);
		var wLEFT = 0;
		if(n_Nitou) wLEFT = n_A_Weapon2LV_seirenATK;
		var wTUE = n_tok[88] + n_A_WeaponLV_seirenATK + wLEFT;
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[2]) wTUE = n_A_PassSkill9[2] * 5 + n_A_WeaponLV_seirenATK + wLEFT;
		if(n_A_WeaponType == 10 || (17 <= n_A_WeaponType && n_A_WeaponType <= 21)) wTUE -= n_A_WeaponLV_seirenATK;
		if(EquipNumSearch(897) && (GetHigherJobSeriesID(n_A_JOB) == 14 || GetLowerJobSeriesID(n_A_JOB) == 44)) wTUE += 90 * EquipNumSearch(897);
		myInnerHtml("A_MATK",n_A_StatusMATK +"+"+ (wTUE + n_tok[100]),0);
		n_A_MATK = [0,0,0];
		if(wTUE >= 1){
			var wPENA = Math.floor(wTUE * 2 / 3) - Math.floor(Math.floor(n_A_INT / 5) * Math.floor(n_A_INT / 5) / n_A_WeaponLV);
			if(wPENA <0) wPENA = 0;
			n_A_MATK[0] = Math.floor((wTUE * 5 + n_A_DEX * (n_A_WeaponLV * 2 + 12)) / 15) - wPENA;
			n_A_MATK[2] = Math.floor(wTUE * (100 + 10 * n_A_WeaponLV) / 100) - wPENA;
			if(n_A_MATK[0] > n_A_MATK[2]) n_A_MATK[0] = n_A_MATK[2];
			if(SkillSearch(522)) n_A_MATK[0] = n_A_MATK[1] = n_A_MATK[2];
			n_A_MATK[0] += n_A_WeaponLV_Minplus;
			n_A_MATK[2] += n_A_WeaponLV_Maxplus;
			if(n_A_WeaponType == 10 || (17 <= n_A_WeaponType && n_A_WeaponType <= 21)){
				n_A_MATK[0] -= n_A_WeaponLV_Minplus;
				n_A_MATK[2] -= n_A_WeaponLV_Maxplus;
			}
			if(n_A_MATK[0] <0) n_A_MATK[0] = 0;
		}
		n_A_MATK[0] += n_A_StatusMATK;
		n_A_MATK[2] += n_A_StatusMATK;
		BK_n_A_MATK = [0,0,0];
		BK_n_A_MATK[0] = n_A_MATK[0];
		BK_n_A_MATK[2] = n_A_MATK[2];
		if(!(533 <= n_A_ActiveSkill && n_A_ActiveSkill <= 536)){
			if(TimeItemNumSearch(84) == 0){
				if(SkillSearch(276)){
					n_A_MATK[0] = Math.floor(n_A_MATK[0] * (1+ 0.05 * SkillSearch(276)));
					n_A_MATK[2] = Math.floor(n_A_MATK[2] * (1+ 0.05 * SkillSearch(276)));
				}else{
					if(TimeItemNumSearch(63)){
						n_A_MATK[0] = Math.floor(n_A_MATK[0] * 1.3);
						n_A_MATK[2] = Math.floor(n_A_MATK[2] * 1.3);
					}
					else if(TimeItemNumSearch(62)){
						n_A_MATK[0] = Math.floor(n_A_MATK[0] * 1.2);
						n_A_MATK[2] = Math.floor(n_A_MATK[2] * 1.2);
					}
					else if(TimeItemNumSearch(60)){
						n_A_MATK[0] = Math.floor(n_A_MATK[0] * 1.1);
						n_A_MATK[2] = Math.floor(n_A_MATK[2] * 1.1);
					}
				}
			}
		}
		n_Heal_MATK[0] = n_A_MATK[0];
		n_Heal_MATK[2] = n_A_MATK[2];
		n_Heal_MATK[1] = Math.floor((n_A_MATK[0] + n_A_MATK[2]) / 2);
		n_A_MATK[0] += n_tok[100];
		n_A_MATK[2] += n_tok[100];
		BK_n_A_MATK[0] += n_tok[100];
		BK_n_A_MATK[2] += n_tok[100];
		n_A_MATK[1] = Math.floor((n_A_MATK[0] + n_A_MATK[2]) / 2);
		BK_n_A_MATK[1] = Math.floor((BK_n_A_MATK[0] + BK_n_A_MATK[2]) / 2);




//================================================================================================================================
//================================================================================================================================
//====
//==== 魔法攻撃で与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		w = 0;
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(642)) w += 3;
		if(EquipNumSearch(646)) w += Math.floor(n_A_Weapon_ATKplus / 2);
		if(EquipNumSearch(737)) w += n_A_Weapon_ATKplus;
		if(EquipNumSearch(1042)) w += n_A_Weapon_ATKplus;
		if(EquipNumSearch(1029) && n_A_HEAD_DEF_PLUS >= 6) w += n_A_HEAD_DEF_PLUS - 5;
		if(n_A_PassSkill6[2]) w += 10;
		if(EquipNumSearch(1083)){
			w += n_A_Weapon_ATKplus;
		}
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1084)) w += 5;
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1095)) w += 5;
		if(SU_INT >= 90 && EquipNumSearch(1403)){
			w += 3;
			if(SU_INT >= 120) w += 2;
		}
		if(GetLowerJobSeriesID(n_A_JOB)==5 && CardNumSearch(454)) w +=3;
		if(n_A_HEAD_DEF_PLUS >= 9 && n_A_card[CARD_REGION_ID_HEAD_TOP]==177) w += 2;
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==484 && SU_INT >= 70) w += 5;
		if(EquipNumSearch(1173)) w += Math.floor(n_A_Weapon_ATKplus / 2);
		if(GetHigherJobSeriesID(n_A_JOB)==14) w += 10 * CardNumSearch(479);
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1361)){
			w += 3;
			if(n_A_HEAD_DEF_PLUS >= 7) w += 3;
		}
		if(EquipNumSearch(1411)) w += Math.floor(n_A_SHOES_DEF_PLUS / 2);
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1451)){
			w += 1;
			if(n_A_HEAD_DEF_PLUS >= 7) w += 2;
		}
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1596)) w += 5;
		if(EquipNumSearch(1695)) if(GetLowerJobSeriesID(n_A_JOB)==3 || GetLowerJobSeriesID(n_A_JOB)==5) w += 8;
		if(SU_INT >= 110 && EquipNumSearch(1947)) w += 1 * EquipNumSearch(1947);
		if(SU_INT >= 99 && EquipNumSearch(1976)){
			w += 2;
			if(SU_INT >= 120) w += 3;
		}

		// アイオーンスタッフ特殊効果
		if(TimeItemNumSearch(84)) {
			w += 8 * LearnedSkillSearch(SKILL_ID_RADIUS);
		}

		if(EquipNumSearch(2442)) w += ROUNDDOWN((n_A_SHOES_DEF_PLUS + n_A_HEAD_DEF_PLUS) / 2);
		if(EquipNumSearch(2462)) w += n_A_HEAD_DEF_PLUS;

		//----------------------------------------------------------------
		// 「戦死者のマント」の、純粋なＩＮＴが１３０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			if (SU_INT >= 130) {
				if (EquipNumSearchFurubitaSet() > 0) {
					w += 10;
				} else {
					w += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「魔法石の恩恵」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MAHOSEKINO_ONKE)) {
			if (n_A_HEAD_DEF_PLUS >= 5) w += 3;
			if (n_A_HEAD_DEF_PLUS >= 7) w += 5;
			if (n_A_HEAD_DEF_PLUS >= 9) w += 7;
			if (CardNumSearch(119) > 0) w += 10;
		}

		//----------------------------------------------------------------
		// 「ポロロッカシューズ」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_POROROCA_SHOES)) {
			if (n_A_SHOES_DEF_PLUS >= 5) w += 3;
			if (n_A_SHOES_DEF_PLUS >= 7) w += 5;
		}

		//----------------------------------------------------------------
		// 「おしゃべりオウム」の、効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_OSHABERI_OUMU)) {
			w += ROUNDDOWN(n_A_BaseLV / 50);
		}

		//----------------------------------------------------------------
		// 「古王の王冠」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KOONO_OKAN)) {
			if (n_A_HEAD_DEF_PLUS >= 6) {
				w += (n_A_HEAD_DEF_PLUS - 5);
			}
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　ロッド＆マントセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_DEX_SURVIVAL_MANT)
			|| EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_INT_SURVIVAL_MANT)) {
			if (n_A_Weapon_ATKplus >= 5) w += 2;
			if (n_A_Weapon_ATKplus >= 7) w += 2;
		}

		//----------------------------------------------------------------
		// 「裁きの靴」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SABAKINO_KUTSU)) {
			if (n_A_SHOES_DEF_PLUS >= 5) w += 3;
			if (n_A_SHOES_DEF_PLUS >= 7) w += 5;
		}

		//----------------------------------------------------------------
		// 「大神官の手袋」の、純粋なＩＮＴが１１０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_DAISHINKANNO_TEBUKURO)){
			if (SU_INT >= 110) {
				w += 5 * EquipNumSearch(ITEM_ID_DAISHINKANNO_TEBUKURO);
			}
		}

		//----------------------------------------------------------------
		// 「ダークハンド」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_DARK_HAND)) > 0) {
			w += 1 * n_A_HEAD_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「魔女の祭祀帽」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_MAZYONO_SAISHIBO)) > 0) {
			w += 1 * n_A_HEAD_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「栄光の証」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_EIKONO_AKASHI)) > 0) {
			if (n_A_BaseLV >= 150) {
				w += 2 * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「魔眼のアムダライスカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_MAGANNO_AMDARAIS)) > 0) {
			w += n_A_BODY_DEF_PLUS * cardCount;
		}

		//----------------------------------------------------------------
		// 「パワフルアムダライスカード」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_AMDARAIS)) > 0) {
			w += 1 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
		}

		//----------------------------------------------------------------
		// 「エンチャント　死のニーヴ(知力)」の、精錬による効果
		//----------------------------------------------------------------
		cardCountShield = CardNumSearch(CARD_ID_ENCHANT_SHINO_NIEVE_CHIRYOKU, CARD_REGION_ID_SHIELD_ANY);
		if (cardCountShield > 0) {

			// 盾防具へのエンチャント
			vartmp = 0;
			if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 1;
			w += vartmp * cardCountShield

			// アクセサリへのエンチャント
			// 精錬できないので処理不要
		}

		//----------------------------------------------------------------
		// 「ウォーロックカトリーヌ(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_WARLOCK_CATHERINE_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_WARLOCK) {
				w += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「シャドウチェイサーガーティ(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_SHADOW_CHASER_GARTY_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_SHADOWCHASER) {
				w += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「ソーサラーセリア(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_SORCERER_CERIA_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_SORCERER) {
				w += 10 * cardCount;
			}
		}



		if(SU_DEX >= 110 && CardNumSearch(709)) w += 7;


		// ＳｐｅｃｉａｌＩｎｔ
		vartmp = CARD_ID_ENCHANT_SPECIAL_INT;
		cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
		cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
		cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
		cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
		cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
		cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
		cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
		cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
		cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
		if (cardCount > 0) {
			if (n_A_HEAD_DEF_PLUS >= 9) w += 1 * cardCountHeadTop;
			if (n_A_LEFT_DEF_PLUS >= 9) w += 1 * cardCountShield;
			if (n_A_BODY_DEF_PLUS >= 9) w += 1 * cardCountBody;
			if (n_A_SHOULDER_DEF_PLUS >= 9) w += 1 * cardCountShoulder;
			if (n_A_SHOES_DEF_PLUS >= 9) w += 1 * cardCountShoes;
		}

		// ＳｐｅｃｉａｌＤｅｘ
		vartmp = CARD_ID_ENCHANT_SPECIAL_DEX;
		cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
		cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
		cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
		cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
		cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
		cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
		cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
		cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
		cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
		if (cardCount > 0) {
			if (n_A_HEAD_DEF_PLUS >= 9) w += 1 * cardCountHeadTop;
			if (n_A_LEFT_DEF_PLUS >= 9) w += 1 * cardCountShield;
			if (n_A_BODY_DEF_PLUS >= 9) w += 1 * cardCountBody;
			if (n_A_SHOULDER_DEF_PLUS >= 9) w += 1 * cardCountShoulder;
			if (n_A_SHOES_DEF_PLUS >= 9) w += 1 * cardCountShoes;
		}

		if(CardNumSearch(830)){
			if(n_A_HEAD_DEF_PLUS >= 7) w += 1 * CardNumSearch(830);
			if(n_A_HEAD_DEF_PLUS >= 9) w += 1 * CardNumSearch(830);
		}
		if(n_A_SHOES_DEF_PLUS >= 7 && CardNumSearch(886)){
			w += 3;
			if(n_A_SHOES_DEF_PLUS >= 9) w += 2;
		}
		if(n_A_card[CARD_REGION_ID_HEAD_TOP] == 893) w += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		if(CardNumSearch(895)) w -= 10;
		if(n_A_PassSkill7[41]){
			if(n_A_PassSkill7[41] == 1) w += 5;
			if(n_A_PassSkill7[41] == 2) w += 10;
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[27]) w += n_A_PassSkill9[27];
		n_tok[89] += w;



		var wAGI = n_A_AGI;
		var wDEX = n_A_DEX;
		if(wAGI <1) wAGI = 1;
		if(wDEX <1) wDEX = 1;
		n_A_ASPD = JobASPD[n_A_JOB][n_A_WeaponType];
		if(n_tok[195]){
			if(EquipNumSearch(88) == 0 && EquipNumSearch(92) == 0) n_A_ASPD = JobASPD[n_A_JOB][22];
		}
		var w = 0;
		if(n_A_ASPD >= 145){
			w = (n_A_ASPD - 144) / 50;
		}
		if(n_A_WeaponType == 10 || n_A_WeaponType == 14 || n_A_WeaponType == 15 || (17 <= n_A_WeaponType && n_A_WeaponType <= 21)) n_A_ASPD += Math.sqrt(wAGI * (10 - 1 / 400) + wDEX * 9 / 49) * (1 - w);
		else n_A_ASPD += Math.sqrt(wAGI * (10 + 10 / 111) + wDEX * 9 / 49) * (1 - w);
		if(n_Nitou){
			var w = JobASPD[n_A_JOB][n_A_WeaponType] + (JobASPD[n_A_JOB][n_A_Weapon2Type] - 194) / 4;
			n_A_ASPD = w + Math.sqrt(wAGI * (10 - 1 / 400) + wDEX * 9 / 49) * 1.05;
		}
		if(n_A_Equip[EQUIP_REGION_ID_SHIELD] != 305) n_A_ASPD -= SHIELD_ASPD[n_A_JOB];
		var w=0;
		if(n_A_SpeedPOT){
			if(n_A_SpeedPOT == 1) w += 10;
			else if(n_A_SpeedPOT == 2) w += 15;
			else if(n_A_SpeedPOT == 3) w += 20;
		}else{
			if(2 <= n_A_PassSkill8[22] && n_A_PassSkill8[22] <= 4){
				w = 10;
				if(n_A_BaseLV >= 40){
					if(n_A_JOB != 3 && n_A_JOB != 37 && GetHigherJobSeriesID(n_A_JOB) != 9 && GetHigherJobSeriesID(n_A_JOB) != 16 && GetHigherJobSeriesID(n_A_JOB) != 17) w = 15;
				}
				if(n_A_BaseLV >= 85){
					if(GetLowerJobSeriesID(n_A_JOB)==1 || GetLowerJobSeriesID(n_A_JOB)==6 || GetLowerJobSeriesID(n_A_JOB)==41 || GetHigherJobSeriesID(n_A_JOB)==14 || GetHigherJobSeriesID(n_A_JOB)==11 || n_A_JOB == 5 || n_A_JOB == 39 || n_A_JOB == 45) w = 20;
				}
			}
			else if(n_A_PassSkill7[35]) w += 10;
		}
		if(0 <n_A_PassSkill7[47] && n_A_PassSkill7[47] <= 50){
			if(w <n_A_PassSkill7[47]) w = n_A_PassSkill7[47];
		}
		var ASPDch = 0;
		var ASPDplusMAX = 0;
		if(n_A_PassSkill3[19] == 4){
			ASPDch = n_A_PassSkill3[37] * 5 + n_A_PassSkill3[38];
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		if(n_A_PassSkill3[39] == 6 || n_A_PassSkill3[39] == 7){
			if(n_A_PassSkill3[41] >= 7) ASPDch = 30;
			else ASPDch = (5 * n_A_PassSkill3[41]) -5;
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		if(n_A_IJYOU[0] == 0 && n_A_IJYOU[1] == 0){
			if(n_A_WeaponType == 3 && SkillSearch(74)){
				ASPDch = 30;
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
			if(n_A_WeaponType == 2 && SkillSearch(386)){
				ASPDch = 30;
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
			if(6 <= n_A_WeaponType && n_A_WeaponType<=8 && SkillSearch(152)){
				ASPDch = 30;
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
			if(SkillSearch(739) == 0){
				if(ASPDch == 0 && SkillSearch(389)){
					ASPDch = 30;
					if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
				}
			}
			if(TimeItemNumSearch(5) || TimeItemNumSearch(28) || TimeItemNumSearch(56)){
				ASPDch = 30;
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
			if((n_A_WeaponType==4 || n_A_WeaponType==5) && SkillSearch(166)){
				ASPDch = 30;
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
		}
		if(SkillSearch(258)){
			ASPDch = 30;
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		if(SkillSearch(420)){
			ASPDch = 20;
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		if(SkillSearch(357) && SkillSearch(361) && n_A_JobLV >= 50){
			ASPDch = Math.floor((n_A_BaseLV + n_A_LUK + n_A_DEX) / 10);
			ASPDch += 1 + SkillSearch(361);
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		else if(SkillSearch(357)){
			ASPDch = Math.floor((n_A_BaseLV + n_A_LUK + n_A_DEX) / 10);
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		else if(SkillSearch(361) && n_A_JobLV >= 50){
			ASPDch = 1 + SkillSearch(361);
			if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
		}
		if(n_A_PassSkill2[6] >= 1){
			if(n_A_IJYOU[0] == 0 && n_A_IJYOU[1] == 0){
				if(SkillSearch(739) == 0){
					if(n_A_PassSkill2[6] == 2){
						if(n_A_WeaponType != 10 && !(17 <= n_A_WeaponType && n_A_WeaponType <= 21)){
							ASPDch = 20;
							if(GetHigherJobSeriesID(n_A_JOB)==12) ASPDch += 10;
							if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
						}
					}
					if(6 <= n_A_WeaponType && n_A_WeaponType <= 8){
						if(n_A_PassSkill2[6] == 1){
							ASPDch = 20;
							if(GetHigherJobSeriesID(n_A_JOB)==12) ASPDch += 10;
							if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
						}
					}
				}
				if(6 <= n_A_WeaponType && n_A_WeaponType <= 8){
					if(n_A_PassSkill2[6] == 3){
						ASPDch = 30;
						if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
					}
				}
			}
		}
		if(n_A_PassSkill3[1]){
			if(n_A_WeaponType != 10 && !(17 <= n_A_WeaponType && n_A_WeaponType <= 21)){
				ASPDch = n_A_PassSkill3[1] + Math.floor(n_A_PassSkill3[31] /2) + n_A_PassSkill3[21];
				if(ASPDch > ASPDplusMAX) ASPDplusMAX = ASPDch;
			}
		}
		w += ASPDplusMAX;
		w += Math.round(SkillSearch(425) /2);
		if(n_A_WeaponType == 12 && SkillSearch(224)) w += Math.round(SkillSearch(224) /2);
		n_A_ASPD += (200 - n_A_ASPD) * (w / 100);
		if(SkillSearch(454)){
			if(SkillSearch(449) >= 3){
				var wfsp = [0,0,0,1,1,2,2,2,3,3,4];
				n_A_ASPD += wfsp[SkillSearch(449)];
			}
		}
		if(SkillSearch(78) && (n_A_ActiveSkill == 0 || n_A_ActiveSkill == 284)) n_A_ASPD -= n_A_ASPD - n_A_ASPD * (40 + SkillSearch(78) * 10) / 100;
		if(SkillSearch(446)) n_A_ASPD -= n_A_ASPD - n_A_ASPD * (70 + SkillSearch(446) * 5) / 100;




//================================================================================================================================
//================================================================================================================================
//====
//==== ＡＳＰＤ　％増加　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_ASPD_UP; idx <= ITEM_SP_ASPD_UP; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		var w = 0;
		w += n_tok[12];
		if(EquipNumSearch(654)) w += Math.floor(SU_AGI / 14);
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==484 && SU_STR >= 50) w += 5;
		if(EquipNumSearch(624)) w += (n_A_Weapon_ATKplus);
		if(EquipNumSearch(641)) w += n_A_Weapon_ATKplus;
		if(EquipNumSearch(903) && GetHigherJobSeriesID(n_A_JOB) == 13) w += 20;
		if(SU_STR >= 77 && EquipNumSearch(944)) w += 4;
		if(n_A_Weapon_ATKplus >= 7 && n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1077) w += 10;
		if(n_A_Weapon2_ATKplus >= 7 && n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1077) w += 10;
		if(n_A_Weapon_ATKplus >= 5 && EquipNumSearch(1081)){
			w += 5;
			if(n_A_Weapon_ATKplus >= 9) w += 5;
		}
		if(n_A_Weapon_ATKplus >= 5 && EquipNumSearch(1086)){
			w += 5;
			if(n_A_Weapon_ATKplus >= 9) w += 5;
		}
		if(n_A_Weapon_ATKplus >= 5 && EquipNumSearch(1088)){
			w += 5;
			if(n_A_Weapon_ATKplus >= 9) w += 5;
		}
		if((n_A_JOB == 21 || n_A_JOB == 46) && EquipNumSearch(855)) w -= 5;
		if(EquipNumSearch(1121) && GetLowerJobSeriesID(n_A_JOB)==2) w += 3;
		if(SU_STR >= 95 && EquipNumSearch(1167)) w += 3;
		if(n_A_HEAD_DEF_PLUS >= 2 && EquipNumSearch(1462)) w += Math.floor(n_A_HEAD_DEF_PLUS / 2);
		if(n_A_BaseLV >= 80 && EquipNumSearch(1485)){
			w += 1;
			if(n_A_BaseLV >= 100) w += 1;
			if(n_A_BaseLV >= 150) w += 1;
		}
		if(SU_AGI >= 100 && EquipNumSearch(1525)){
			var wx = EquipNumSearch(1525);
			w += 2 * wx;
			if(SU_AGI >= 120) w += 2 * wx;
		}
		if(EquipNumSearch(1644)) w += n_A_Weapon_ATKplus;
		if(SU_AGI >= 108 && EquipNumSearch(1791)) w += 1;
		if(n_A_Weapon_ATKplus >= 2 && EquipNumSearch(1821)) w += Math.floor(n_A_Weapon_ATKplus / 2);
		if(n_A_BODY_DEF_PLUS >= 6 && EquipNumSearch(2059)) w += n_A_BODY_DEF_PLUS - 5;
		if(EquipNumSearch(2254)) w += n_A_Weapon_ATKplus;
		if(SU_VIT >= 108 && EquipNumSearch(2257)) w += -5;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(2258)) w += 5;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2345)) w += 2;
		if(n_A_PassSkill8[0] == 49){
			if(n_A_PassSkill8[17] == 6) w += 1;
			if(EquipNumSearch(1422)) w += 3;
		}
		if(EquipNumSearch(1888) && SkillSearch(89) == 10) w += 10;

		// 俊敏の時空ブーツ
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(1919)) {
			w += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS_S1)) {
			w += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}

		if(n_A_HEAD_DEF_PLUS >= 1 && EquipNumSearch(2164)) w += n_A_HEAD_DEF_PLUS;
		if(CardNumSearch(737)){
			w += 2 * ROUNDDOWN(SU_AGI / 10);
			if(EquipNumSearch(2415)) w -= 2 * ROUNDDOWN(SU_AGI / 10);
		}
		if(n_A_LEFT_DEF_PLUS >=8 && EquipNumSearch(2241)) w += -3;
		if(EquipNumSearch(2294)) w += 6 * ROUNDDOWN(n_A_LEFT_DEF_PLUS / 3);
		if(EquipNumSearch(2298)) w += ROUNDDOWN(n_A_BaseLV / 20);
		if(CardNumSearch(825)){
			if(n_A_HEAD_DEF_PLUS >= 7) w += 1 * CardNumSearch(825);
			if(n_A_HEAD_DEF_PLUS >= 9) w += 1 * CardNumSearch(825);
		}
		if(n_A_HEAD_DEF_PLUS >= 5 && TimeItemNumSearch(82)){
			w += 5;
			if(n_A_HEAD_DEF_PLUS >= 7) w += 10;
			if(n_A_HEAD_DEF_PLUS >= 9) w += 40;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 5 && EquipNumSearch(2414)){
			w += 1 * ROUNDDOWN(SU_AGI / 10);
			if(n_A_SHOULDER_DEF_PLUS >= 7) w += 1 * ROUNDDOWN(SU_AGI / 10);
		}
		if(EquipNumSearch(2456)) w += n_A_Weapon_ATKplus;
		if(EquipNumSearch(2521) && SkillSearch(454)) w += 10;

		//----------------------------------------------------------------
		// 「貴族の仮面」の、ベースレベル依存の効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_KIZOKUNO_KAMEN)){
			if (n_A_BaseLV >= 100) {
				w += 1;
			}
			if (n_A_BaseLV >= 150) {
				w += 1;
			}
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーハンマー」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w += 1 * n_A_Weapon_ATKplus;
				break;

			// ソードマン系
			case JOB_SERIES_ID_SWORDMAN:
				break;

			// マーチャント系
			case JOB_SERIES_ID_MERCHANT:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// プリースト系
				case JOB_SERIES_ID_PRIEST:
					w += 1 * n_A_Weapon_ATKplus;
					break;

				// モンク系
				case JOB_SERIES_ID_MONK:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「古びたルーンサークレット」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_FURUBITA_RUNECIRCRET)) {
			w += 1 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「S-Atk　ライオットチップセット」の、効果
		// 「S-Matk　ライオットチップセット」の、効果
		// 「S-Avoid　ライオットチップセット」の、効果
		// 「S-MaxHP　ライオットチップセット」の、効果
		// 「S-Quick　ライオットチップセット」の、効果
		// 「S-Cri　ライオットチップセット」の、効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_ATK)
			|| EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_MATK)
			|| EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_AVOID)
			|| EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_MAXHP)
			|| EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_QUICK)
			|| EquipNumSearch(ITEM_SET_ID_RIOTCHIP_S_CRI)
			){

			// ライオットチップとのセット効果
			w += 1 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		}

		//----------------------------------------------------------------
		// 「セリーヌ・キミカード　ノーブルセット」の、精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_SET_ID_CELINE_KIMI_NOBLE_CROSS)) {
			w += 2 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w += 10 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					w += 10 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「与一の肩掛け」の、＋７以上精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_YOICHINO_KATAKAE)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) {
				w += 3;
			}
			if (n_A_SHOULDER_DEF_PLUS >= 9) {
				w += 3;
			}
		}

		//----------------------------------------------------------------
		// 「ガーディアンブースター」の、＋８以上精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GUARDIAN_BOOSTER)) {
			if (n_A_SHOES_DEF_PLUS >= 8) {
				w += (n_A_SHOES_DEF_PLUS - 7);
			}
		}

		//----------------------------------------------------------------
		// 「勇者の怒りセット」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_YUSHANOIKARI_ORCISH_AXE_ORCISH_SWORD)) {
			w += 5 * ROUNDDOWN( (n_A_Weapon_ATKplus + n_A_Weapon2_ATKplus) / 2);
		}

		//----------------------------------------------------------------
		// 「魔羊の咆哮　クレセントサイダーセット」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_CRESCENT_CIZER)) {
			w += 5 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「魔羊の咆哮　テグリョンセット」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_TEGRYONG)
			|| EquipNumSearch(ITEM_SET_ID_MAHITSUZINO_HOKO_TEGRYONG_S2)) {
			w += 5 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「古王の双刃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KOONO_SOZIN)) {
			if (n_A_Weapon_ATKplus >= 7) {
				w += 5;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				w += 5;
			}
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーブラッディロア」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_BLOODYROAR)) {
			if (n_A_Weapon_ATKplus >= 5) w += 5;
			if (n_A_Weapon_ATKplus >= 7) w += 5;
		}

		//----------------------------------------------------------------
		// 「セイヴザキング」の、騎兵修練【未習得】時における、「スピアクイッケン」習得による効果
		//----------------------------------------------------------------
		if (SkillSearch(78) == 0) {
			if (EquipNumSearch(ITEM_ID_SAVE_THE_KING)) {
				w += 3 * SkillSearch(SKILL_ID_SPEAR_QUICKEN);
			}
		}

		//----------------------------------------------------------------
		// 「魔呪のブーツ」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MAZYUNO_BOOTS)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				w += 10;
			}
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 8) {
				if (SU_AGI >= 90) {
					w += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「反逆者のスカーフ」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HANGYAKUSHANO_SCARF)) > 0) {
			w += 2 * LearnedSkillSearch(SKILL_ID_MASS_SPIRAL) * itemCount;
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　パイルバンカーセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_PILEBUNKER)) {
			if (n_A_Weapon_ATKplus >= 7) {
				w += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				w += 10;
			}
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　ガーディアンブースターセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_BOOSTER)) > 0) {
			vartmp = 0;

			if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 5;
			if (n_A_SHOES_DEF_PLUS >= 9) vartmp += 5;

			w += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「エンチャント　名誉のニーヴ(迅速)」の、精錬による効果
		//----------------------------------------------------------------
		cardCountShield = CardNumSearch(CARD_ID_ENCHANT_MEIYONO_NIEVE_ZINSOKU, CARD_REGION_ID_SHIELD_ANY);
		if (cardCountShield > 0) {

			// 盾防具へのエンチャント
			vartmp = 0;
			if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 3;
			if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
			w += vartmp * cardCountShield

			// アクセサリへのエンチャント
			// 精錬できないので処理不要
		}

		//----------------------------------------------------------------
		// 「麒麟の角」の、素ＡＧＩによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_KIRINNO_TSUNO)) > 0) {
			if (SU_AGI >= 100) {
				w += 5 * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＡＧＩと素ＶＩＴによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			w += 5 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＡＧＩと素ＶＩＴによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			w += 5 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「勇者の靴　達人の槌　セット」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI)) > 0) {
			w += 1 * LearnedSkillSearch(SKILL_ID_DUPLELIGHT) * itemCount;
		}
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI_S2)) > 0) {
			w += 1 * LearnedSkillSearch(SKILL_ID_DUPLELIGHT) * itemCount;
		}

		//----------------------------------------------------------------
		// 「業風石　ペオースグリーブセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_GREEVE)) > 0) {
			vartmp = 0;

			if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 10;
			if (n_A_SHOES_DEF_PLUS >= 9) vartmp += 10;

			w += vartmp * itemCount;
		}

		if(n_A_PassSkill7[22]) w += 10;
		if(n_A_PassSkill6[21]) w -= 10 * n_A_PassSkill6[21];
		if(SkillSearch(627)) w += Math.floor(SU_AGI * SkillSearch(627) / 60);
		if(SkillSearch(433)){
			if(n_A_WeaponType==20 || n_A_WeaponType==0) w += SkillSearch(433);
		}
		if(SkillSearch(196)) w -= 25;
		if(n_A_PassSkill3[11]) w -= 3 * n_A_PassSkill3[11];
		if(SkillSearch(599)) w -= (50 - 10 * SkillSearch(599));
		if(n_A_IJYOU[5]) w -= 30;
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[14]) w += n_A_PassSkill9[14];
		n_A_ASPD += (200 - n_A_ASPD) * (w / 100);





//================================================================================================================================
//================================================================================================================================
//====
//==== ＡＳＰＤ固定増加　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_ASPD_PLUS; idx <= ITEM_SP_ASPD_PLUS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(EquipNumSearch(1339)) n_A_ASPD += ROUNDDOWN(n_A_Weapon_ATKplus / 2);
		if(SU_AGI >= 120 && EquipNumSearch(1311)) n_A_ASPD += 1;
		if(SU_STR >= 120 && EquipNumSearch(1320)) n_A_ASPD += 1;
		if(EquipNumSearch(1353)) n_A_ASPD += 1;
		if(n_A_WeaponType == 3 && n_A_Weapon_ATKplus >= 10) n_A_ASPD += CardNumSearch(530);
		if(n_A_WeaponType == 10 && n_A_Weapon_ATKplus >= 10) n_A_ASPD += CardNumSearch(531);
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1601)) n_A_ASPD += 1;
		if(n_A_PassSkill8[0] == 49){
			if(n_A_HEAD_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7) if(EquipNumSearch(1422)) n_A_ASPD += 1;
		}
		if(SU_AGI >= 120 && EquipNumSearch(1708)) n_A_ASPD += 1;
		if(SU_AGI >= 108 && EquipNumSearch(1791)) n_A_ASPD += 1;

		// 俊敏の時空ブーツ
		if(SU_AGI >= 120 && EquipNumSearch(1919)) n_A_ASPD += 1;
		if(SU_AGI >= 120 && EquipNumSearch(ITEM_ID_SHUNBINNO_ZIKU_BOOTS_S1)) n_A_ASPD += 1;

		if(SU_AGI >= 120 && EquipNumSearch(2295)) n_A_ASPD += 1;
		if(n_A_Weapon_ATKplus >= 10){
			if(n_A_Arrow == 2 && EquipNumSearch(2356)) n_A_ASPD += 1;
			if(n_A_Arrow == 5 && EquipNumSearch(2357)) n_A_ASPD += 1;
			if(n_A_Arrow == 4 && EquipNumSearch(2358)) n_A_ASPD += 1;
			if(n_A_Arrow == 6 && EquipNumSearch(2359)) n_A_ASPD += 1;
		}
		if(2504 <= n_A_Equip[EQUIP_REGION_ID_SHIELD] && n_A_Equip[EQUIP_REGION_ID_SHIELD] <= 2507){
			if(n_A_LEFT_DEF_PLUS >= 5) n_A_ASPD += 1;
			if(n_A_LEFT_DEF_PLUS >= 7) n_A_ASPD += 1;
		}
		if(n_A_WeaponType == 10 && n_A_Weapon_ATKplus >= 10 && EquipNumSearch(2515)) n_A_ASPD += 1;


		//----------------------------------------------------------------
		// 「戦死者のマント」の、純粋なＡＧＩが１３０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			if (SU_AGI >= 130) {
				if (EquipNumSearchFurubitaSet() > 0) {
					n_A_ASPD += 2;
				} else {
					n_A_ASPD += 1;
				}
			}
		}

		//----------------------------------------------------------------
		// 「元素のタオルセット」の、効果
		//----------------------------------------------------------------
		if(n_A_Weapon_ATKplus >= 10){

			if(n_A_Arrow == 2 && EquipNumSearch(ITEM_SET_ID_GENSONO_TOWEL_MOERU_YUMI)) {
				n_A_ASPD += 1;
			}

			if(n_A_Arrow == 5 && EquipNumSearch(ITEM_SET_ID_GENSONO_TOWEL_HYOTENNO_YUMI)) {
				n_A_ASPD += 1;
			}

			if(n_A_Arrow == 4 && EquipNumSearch(ITEM_SET_ID_GENSONO_TOWEL_DAICHINO_YUMI)) {
				n_A_ASPD += 1;
			}

			if(n_A_Arrow == 6 && EquipNumSearch(ITEM_SET_ID_GENSONO_TOWEL_HAYATENO_YUMI)) {
				n_A_ASPD += 1;
			}
		}

		//----------------------------------------------------------------
		// 「リス耳フード帽」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RISUMIMI_HOODBO)) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_A_ASPD += 1;
			if (n_A_HEAD_DEF_PLUS >= 7) n_A_ASPD += 1;
			if (n_A_HEAD_DEF_PLUS >= 9) n_A_ASPD += 1;
		}

		//----------------------------------------------------------------
		// 「沸騰する混沌の盾」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_FUTTOSURU_KONTONNO_TATE)) {
			if (n_A_LEFT_DEF_PLUS >= 5) n_A_ASPD += 1;
			if (n_A_LEFT_DEF_PLUS >= 7) n_A_ASPD += 1;
		}

		//----------------------------------------------------------------
		// 「ルーンナイトセイレン(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_RUNE_KNIGHT_SEIREN_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_RUNEKNIGHT) {
				n_A_ASPD += 2 * cardCount;
			}
		}


		n_A_ASPD += n_tok[101];
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[15]) n_A_ASPD += n_A_PassSkill9[15];
		if(SkillSearch(812) && SkillSearch(813) == 1){
			if(SkillSearch(812) == 7 || SkillSearch(812) == 8 || SkillSearch(812) == 9) n_A_ASPD += 5;
		}
		if(SkillSearch(165)) n_A_ASPD -= (25 -SkillSearch(165) *5);
		if(SkillSearch(750)) n_A_ASPD -= n_A_ASPD - n_A_ASPD / 2;
		if(SkillSearch(817)) n_A_ASPD = 179 + 2 * SkillSearch(817);

		//----------------------------------------------------------------
		// 「リベリオン－ヒートバレル」の、効果
		//----------------------------------------------------------------
		if (SkillSearch(SKILL_ID_HEAT_BARREL)) {
			n_A_ASPD += SkillSearch(SKILL_ID_HEAT_BARREL);
		}

		// 範囲外補正
		if(n_A_BaseLV >= 100){
			if(n_A_ASPD > 193) n_A_ASPD = 193;
		}else{
			if(n_A_ASPD > 190) n_A_ASPD = 190;
		}
		if(n_A_ASPD <0) n_A_ASPD = 0;
		var test=0;
		test = Math.floor(n_A_ASPD * 10) / 10;
		myInnerHtml("A_ASPD",test,0);
		n_A_ASPD = Math.floor(n_A_ASPD);
		n_A_ASPD = 200 - n_A_ASPD;
		n_A_ASPD = n_A_ASPD / 50;



//================================================================================================================================
//================================================================================================================================
//====
//==== モーションディレイ　ここから
//====
//================================================================================================================================
//================================================================================================================================

		n_Delay[1] = Math.floor(n_A_ASPD * 1000)/1000;
		if(n_A_ActiveSkill==17) n_Delay[1] = Math.floor(n_A_ASPD *75)/100;
		sandanDelay = 0;
		if(SkillSearch(187) && n_A_ActiveSkill == 0){
			sandanDelay = (1000 - n_A_AGI *4 - n_A_DEX *2) /1000;
			if(sandanDelay <0) sandanDelay = 0;
			if(sandanDelay <n_Delay[1]) sandanDelay = n_Delay[1];
			if(SkillSearch(301)) sandanDelay += 0.3;
		}




//================================================================================================================================
//================================================================================================================================
//====
//==== 詠唱時間－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_SKILL_CAST_DOWN; idx <= ITEM_SP_SKILL_CAST_DOWN; idx++) {
			n_tok[idx] -= GetRndEnchValue(idx);
		}

		var w_castDEX = n_A_DEX;
		if(w_castDEX <0) w_castDEX = 0;
		var w_castINT = n_A_INT;
		if(w_castINT <0) w_castINT = 0;
		n_A_CAST = 1 - Math.sqrt((w_castDEX + w_castINT / 2) / 265);
		if(n_A_CAST <0) n_A_CAST = 0;

		var w=100;
		w += n_tok[73];
		if(GetLowerJobSeriesID(n_A_JOB)==5 && CardNumSearch(454)) w -= 15;
		if(GetHigherJobSeriesID(n_A_JOB)==18 && CardNumSearch(460)) w -= 15;
		if(EquipNumSearch(750)) w -= n_A_Weapon_ATKplus;
		if(n_A_card[CARD_REGION_ID_HEAD_TOP]==177) w -= n_A_HEAD_DEF_PLUS;
		if(EquipNumSearch(849)) w -= n_A_HEAD_DEF_PLUS;
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1084)) w -= 5;
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1095)) w -= 5;
		if(SU_DEX >= 120 && EquipNumSearch(1312)) w -= 2;
		if(n_A_Weapon_ATKplus >= 10 && EquipNumSearch(1379)) w -= 10;
		if(EquipNumSearch(1411)) w -= Math.floor(n_A_SHOES_DEF_PLUS / 2);
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1483)) w -= 5;
		if(SU_DEX >= 80 && EquipNumSearch(1527)){
			var wx = EquipNumSearch(1527);
			w -= 1 * wx;
			if(SU_DEX >= 100) w -= 2 * wx;
		}
		if(EquipNumSearch(1628)){
			if(n_A_Weapon_ATKplus >= 10) w -= 10;
		}
		if(EquipNumSearch(1888) && (SkillSearch(241) == 10 || SkillSearch(540) == 10)) w -= 15;
		if(n_A_Weapon_ATKplus >= 10 && EquipNumSearch(2023)) w -= 20;
		if(n_A_HEAD_DEF_PLUS >= 1 && EquipNumSearch(2166)) w += -2 * n_A_HEAD_DEF_PLUS;
		if(n_A_BODY_DEF_PLUS >= 9 && EquipNumSearch(2250)) w += -5;
		if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(2323)){
			if(n_A_Weapon_ATKplus >= 10) w += -10;
		}
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2345)) w += -2;
		if(EquipNumSearch(2364)){
			if(n_A_BODY_DEF_PLUS % 2 == 0) w += (-1 * ROUNDDOWN(n_A_BODY_DEF_PLUS / 2));
			else w += 20;
		}
		if(EquipNumSearch(2366)){
			if(n_A_SHOES_DEF_PLUS >= 8) w += -5;
			if(n_A_SHOES_DEF_PLUS >= 9) w += (-1 * (n_A_SHOES_DEF_PLUS - 8));
		}
		if(CardNumSearch(832)){
			if(n_A_HEAD_DEF_PLUS >= 7) w += -1 * CardNumSearch(832);
			if(n_A_HEAD_DEF_PLUS >= 9) w += -1 * CardNumSearch(832);
		}
		if(EquipNumSearch(2441) || EquipNumSearch(2442)) w += -1 * ROUNDDOWN((n_A_SHOES_DEF_PLUS + n_A_HEAD_DEF_PLUS) / 2);
		if(EquipNumSearch(2491)){
			if(n_A_BaseLV >= 99 || n_B_TAISEI[38] == 1) w += 10;
			else w += ROUNDDOWN(n_A_BaseLV / 10);
		}
		if(EquipNumSearch(2499)){
			if(SU_DEX >= 108) w += -10;
			if(SU_DEX >= 120) w += -5;
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーハンマー」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				w -= 1 * ROUNDDOWN(n_A_Weapon_ATKplus / 2);
				break;

			// ソードマン系
			case JOB_SERIES_ID_SWORDMAN:
				break;

			// マーチャント系
			case JOB_SERIES_ID_MERCHANT:
				w -= 1 * ROUNDDOWN(n_A_Weapon_ATKplus / 2);
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// プリースト系
				case JOB_SERIES_ID_PRIEST:
					break;

				// モンク系
				case JOB_SERIES_ID_MONK:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「サラのローブセット」の、＋７精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_HEAL_PIERCED_TELEPORT_PIERCED_SARANO_ROBE)) {
			if (n_A_BODY_DEF_PLUS >= 7) {
				w -= 10;
			}
		}

		//----------------------------------------------------------------
		// 「おしゃべりオウム」の、効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_OSHABERI_OUMU)) {
			w -= ROUNDDOWN(SU_INT / 30);
		}

		//----------------------------------------------------------------
		// 「熾天使の花冠」の、強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SHITENSHINO_HANAKANMURI)) {
			w += 1 * ROUNDDOWN(SU_INT / 8);
			if (SU_INT >= 108) w += 4;
			if (SU_INT >= 120) w += 6;
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　ロッドセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_DEX)
			|| EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_ROD_INT)) {
			if (n_A_Weapon_ATKplus >= 10) {
				if (n_A_BaseLV <= 99) {
					w -= 3;
				}
				else {
					w -= 9;
				}
			}
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　サークレットセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_CIRCLET)) {
			if (n_A_HEAD_DEF_PLUS >= 7) w -= 6;
			if (n_A_HEAD_DEF_PLUS >= 9) w -= 6;
		}

		//----------------------------------------------------------------
		// 「堕天司祭の闇光外套」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_DATENSHISAINO_ANKOUGAITO)) {
			if (n_A_SHOULDER_DEF_PLUS >= 9) {
				w -= 5;
			}
		}

		//----------------------------------------------------------------
		// 「魔呪のブーツ」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MAZYUNO_BOOTS)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				w -= 10;
			}
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 8) {
				if (SU_DEX >= 90) {
					w -= 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			w -= 3 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			w -= 3 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「リンドブルムの皮」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_LINDWURMNO_KAWA)) > 0) {
			if (n_A_SHOULDER_DEF_PLUS >= 8) {
				w -= 2 * ROUNDDOWN((SU_AGI + SU_VIT) / 20) * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「火雷大神靴」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HONOIKADUCHINOOOKAMI_KUTSU)) > 0) {
			w -= 1 * n_A_SHOES_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「海竜の鎧」の、過剰精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_KAIRYUNO_YOROI)) > 0) {
			vartmp = 0;

			if (n_A_BODY_DEF_PLUS >= 7) vartmp += 5;
			if (n_A_BODY_DEF_PLUS >= 9) vartmp += 5;

			w -= vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「怨恨のカーリツバーグカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ENKONNO_KHALITZBURG)) > 0) {
			w -= n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「エンチャント　名誉のニーヴ(集中)」の、精錬による効果
		//----------------------------------------------------------------
		cardCountShield = CardNumSearch(CARD_ID_ENCHANT_MEIYONO_NIEVE_SHUCHU, CARD_REGION_ID_SHIELD_ANY);
		if (cardCountShield > 0) {

			// 盾防具へのエンチャント
			vartmp = 0;
			if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 5;
			if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 5;
			w -= vartmp * cardCountShield

			// アクセサリへのエンチャント
			// 精錬できないので処理不要
		}

		if(n_A_PassSkill3[2] != 0) w -= n_A_PassSkill3[2] * 3 + n_A_PassSkill3[32] + n_A_PassSkill3[22];
		if(TimeItemNumSearch(1)) w -= 50;
		if(SkillSearch(798)) w -= 10;
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[16]) w += -1 * n_A_PassSkill9[16];
		if(w <0) w=0;
		// 表示用変数に退避
		n_CastCutForDisp = w;

		n_A_CAST *= w /100;





//================================================================================================================================
//================================================================================================================================
//====
//==== 特定スキルの　詠唱時間－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		w = 100;
		if(GetEquippedTotalSPEquip(7000+n_A_ActiveSkill) != 0) w -= GetEquippedTotalSPEquip(7000+n_A_ActiveSkill);
		if(GetEquippedTotalSPCardAndElse(7000+n_A_ActiveSkill) != 0) w -= GetEquippedTotalSPCardAndElse(7000+n_A_ActiveSkill);
		if(n_A_ActiveSkill==321 || n_A_ActiveSkill==197) if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1097)) w -= 100;
		if(n_A_ActiveSkill==430) if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1100)) w -= 25;
		if(n_A_ActiveSkill==131) if(n_A_Weapon_ATKplus >= 10 && EquipNumSearch(1169)) w -= 8;
		if(n_A_ActiveSkill==272) if(n_A_Weapon_ATKplus >= 10 && EquipNumSearch(859)) w -= 50;
		if(n_A_ActiveSkill==131 || n_A_ActiveSkill==519 || n_A_ActiveSkill==520) if(EquipNumSearch(1687)) w -= 4 * n_A_LEFT_DEF_PLUS;
		if(n_A_ActiveSkill==51 || n_A_ActiveSkill==54 || n_A_ActiveSkill==56 || n_A_ActiveSkill==132) if(n_A_SHOES_DEF_PLUS >= 6 && EquipNumSearch(1894)) w -= n_A_SHOES_DEF_PLUS - 5;
		if(n_A_ActiveSkill==639 && EquipNumSearch(2430)){
			if(n_A_Weapon_ATKplus >= 5) w -= 10;
			if(n_A_Weapon_ATKplus >= 7) w -= 20;
			if(n_A_Weapon_ATKplus >= 9) w -= 40;
		}
		if(n_A_ActiveSkill == 443 && EquipNumSearch(2538)){
			w -= 50;
			if(n_A_SHOES_DEF_PLUS >= 7) w -= 50;
		}

		//----------------------------------------------------------------
		// 「ケラウノス」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if (n_A_ActiveSkill == SKILL_ID_RAIKODAN) {
			if ((itemCount = EquipNumSearch(ITEM_ID_KERAUNOS)) > 0) {
				w -= 5 * ROUNDDOWN(n_A_BaseLV / 15) * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「ケラウノス」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ( (n_A_ActiveSkill == SKILL_ID_RASETSU_HAOGEKI_MAX)
			|| (n_A_ActiveSkill == SKILL_ID_RASETSU_HAOGEKI)) {
			if ((itemCount = EquipNumSearch(ITEM_ID_KERAUNOS)) > 0) {
				w -= 3 * ROUNDDOWN(n_A_BaseLV / 20) * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「業風石　ゲラドリア　セット」の、精錬による強化
		//----------------------------------------------------------------
		if (n_A_ActiveSkill == SKILL_ID_WIND_CUTTER) {
			if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_GERADRIA)) > 0) {
				if (n_A_Weapon_ATKplus >= 10) {
					w -= 50;
				}
			}
		}



		if(w <0) w = 0;
		n_A_CAST *= w /100;
		if(n_A_PassSkill2[13]) n_A_CAST *= (100 - 15 * n_A_PassSkill2[13]) /100;
		if(SkillSearch(322)) n_A_CAST = n_A_CAST /2;
		if(SkillSearch(778)) n_A_CAST = n_A_CAST /2;




//================================================================================================================================
//================================================================================================================================
//====
//==== 固定詠唱－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		n_A_Kotei_Cast_Keigen = 0;

		// チェック用変数初期化
		// （固定詠唱短縮効果は、加算等はされず、最大の効果のみが適用される）
		var chkary = new Array();

		if(SkillSearch(524)) {
			chkary.push(5 + 5 * SkillSearch(524));
		}

		if(EquipNumSearch(1329)) {
			chkary.push(n_A_Weapon_ATKplus);
		}

		if(n_A_PassSkill6[14]) {
			chkary.push(10 * n_A_PassSkill6[14]);
		}

		if(CardNumSearch(514) || CardNumSearch(515) || CardNumSearch(588) || CardNumSearch(589)) {
			chkary.push(1);
		}

		if((n_A_JOB == 25 || n_A_JOB == 50) && CardNumSearch(541)) {
			chkary.push(50);
		}

		if(TimeItemNumSearch(42)) {
			chkary.push(50);
		}

		if(EquipNumSearch(1438)) {
			chkary.push(10);
		}

		if(EquipNumSearch(1451)) {
			chkary.push(3);
		}

		if(SkillSearch(778)) {
			chkary.push(100);
		}

		if(CardNumSearch(750)) {
			chkary.push(70);
		}

		if(n_A_PassSkill7[51]) {
			chkary.push(50);
		}

		if(n_A_PassSkill3[39] == 6 || n_A_PassSkill3[39] == 7){
			if(n_A_PassSkill3[41] >= 7) {
				chkary.push(70);
			}
			else {
				chkary.push(10 * n_A_PassSkill3[41]);
			}
		}

		if(EquipNumSearch(2462)) {
			chkary.push(50);
		}

		//----------------------------------------------------------------
		// 「古びた魔力石の帽子」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_FURUBITA_MARYOKUSEKI)) {
			chkary.push(7 * n_A_HEAD_DEF_PLUS);
		}

		//----------------------------------------------------------------
		// 「サラのローブセット」の、＋７精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_HEAL_PIERCED_TELEPORT_PIERCED_SARANO_ROBE)) {
			if (n_A_BODY_DEF_PLUS >= 7) {
				chkary.push(50);
			}
		}

		//----------------------------------------------------------------
		// 「覚醒ローブセット」の、効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_HEAL_PIERCED_TELEPORT_PIERCED_KAKUSEI_ROBE)) {
			chkary.push(50);
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　マントセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_MANT)) {
			chkary.push(50);
		}

		//----------------------------------------------------------------
		// 「T_W_O カード」の、装備効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_T_W_O)) {
			chkary.push(50);
		}


		var wMax = 0;
		for(i = 0; i < chkary.length; i++){
			if(chkary[i] > wMax) wMax = chkary[i];
		}

		n_A_Kotei_Cast_Keigen = wMax;
		if(n_A_IJYOU[5]) n_A_Kotei_Cast_Keigen -= 50;




//================================================================================================================================
//================================================================================================================================
//====
//==== スキルディレイ－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_SKILL_DELAY_DOWN; idx <= ITEM_SP_SKILL_DELAY_DOWN; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(n_A_Weapon_ATKplus >= 9
			&& (EquipNumSearch(934) || EquipNumSearch(ITEM_ID_TEGRYONG_S2)) ) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 20;
		}
		if(EquipNumSearch(1036) && n_A_HEAD_DEF_PLUS >= 6) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += n_A_HEAD_DEF_PLUS - 5;
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1084)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
		if(EquipNumSearch(1085)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
			if(n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
		}
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1095)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
		if(EquipNumSearch(936)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += Math.floor(n_A_Weapon_ATKplus * 1.5);
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1279)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += (n_A_HEAD_DEF_PLUS - 4);
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1459)){
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 4;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
		}
		if(SU_INT >= 100 && EquipNumSearch(1528)){
			var wx = EquipNumSearch(1528);
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 1 * wx;
			if(SU_INT >= 120) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 2 * wx;
		}
		if(EquipNumSearch(1629)){
			if(n_A_Weapon_ATKplus >= 10) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10;
		}
		if(EquipNumSearch(1888) && SkillSearch(69) == 10) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1897)){
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 5;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 3;
		}
		if(EquipNumSearch(1976)){
			if(n_A_PassSkill8[0] == 21){
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 2;
				if(n_A_PassSkill8[17] == 6) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 3;
			}
		}
		if(n_A_LEFT_DEF_PLUS >= 1 && EquipNumSearch(1990)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += n_A_LEFT_DEF_PLUS * 2;
		if(n_A_LEFT_DEF_PLUS >= 7 &&TimeItemNumSearch(66)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += (n_A_LEFT_DEF_PLUS - 6) * 5;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2345)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 2;
		if(EquipNumSearch(2346)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += n_A_Weapon_ATKplus;
		if(CardNumSearch(823)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 1 * CardNumSearch(823);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 1 * CardNumSearch(823);
		}
		if(EquipNumSearch(2440)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 2 * n_A_SHOES_DEF_PLUS;
		if(n_A_BaseLV >= 130 && EquipNumSearch(2465)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10;
		if(EquipNumSearch(2539) && SkillSearch(254)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 70;
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(2568)) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);

		//----------------------------------------------------------------
		// 「古びたボーンサークレット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_FURUBITA_BONECIRCRET)) {
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「執行者のマント」の、＋７以上精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SHIKKOSHANO_MANT)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 3;
			}
			if (n_A_SHOULDER_DEF_PLUS >= 9) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 3;
			}
		}

		//----------------------------------------------------------------
		// 「魔呪のブーツ」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MAZYUNO_BOOTS)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「[LOVA] バハムートカード」の、＋７以上精錬による強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOVA_BAHAMUT) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 1 * CardNumSearch(CARD_ID_LOVA_BAHAMUT);
			}
		}

		//----------------------------------------------------------------
		// 「[LOVA] 真化バハムートカード」の、＋７以上精錬による強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOVA_SHINKA_BAHAMUT) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 3 * CardNumSearch(CARD_ID_LOVA_SHINKA_BAHAMUT);
			}
		}

		//----------------------------------------------------------------
		// 「反逆者のスカーフ」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HANGYAKUSHANO_SCARF)) > 0) {
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 2 * LearnedSkillSearch(SKILL_ID_FIRE_RAIN) * itemCount;
		}

		//----------------------------------------------------------------
		// 「お座り教皇（私服）」の、精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_OSUWARI_KYOKO_SHIFUKU)) > 0) {
			if (n_A_HEAD_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10 * itemCount;
			}
			if (n_A_HEAD_DEF_PLUS >= 9) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 10 * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「グウィバーの皮」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_GWIBERNO_KAWA)) > 0) {
			if (n_A_SHOULDER_DEF_PLUS >= 8) {
				n_tok[ITEM_SP_SKILL_DELAY_DOWN] += 1 * ROUNDDOWN((SU_INT + SU_DEX) / 20) * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「エンチャント　名誉のニーヴ(熟練)」の、精錬による効果
		//----------------------------------------------------------------
		cardCountShield = CardNumSearch(CARD_ID_ENCHANT_MEIYONO_NIEVE_ZYUKUREN, CARD_REGION_ID_SHIELD_ANY);
		if (cardCountShield > 0) {

			// 盾防具へのエンチャント
			vartmp = 0;
			if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 5;
			if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 5;
			n_tok[ITEM_SP_SKILL_DELAY_DOWN] += vartmp * cardCountShield

			// アクセサリへのエンチャント
			// 精錬できないので処理不要
		}



		var w = n_A_PassSkill3[2];
		if(w){
			if(w==10) n_tok[ITEM_SP_SKILL_DELAY_DOWN] += w * 5 + n_A_PassSkill3[32] *2 + n_A_PassSkill3[29];
			else n_tok[ITEM_SP_SKILL_DELAY_DOWN] += w * 3 + n_A_PassSkill3[32] *2 + n_A_PassSkill3[29];
		}
		if(n_tok[ITEM_SP_SKILL_DELAY_DOWN] > 100) n_tok[ITEM_SP_SKILL_DELAY_DOWN] = 100;





//================================================================================================================================
//================================================================================================================================
//====
//==== ＨＰ回復力＋○○　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_HPR_UP; idx <= ITEM_SP_HPR_UP; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		n_A_HPR = Math.floor(n_A_VIT /5) + Math.floor(n_A_MaxHP /200);
		if(n_A_HPR <1) n_A_HPR = 1;
		var w = 0;
		w += n_tok[75];
		if(SU_LUK >= 77) w += 100 * CardNumSearch(221);
		if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(672)) w += 3;
		if(SU_LUK >= 55 && EquipNumSearch(1632)) w += 30;
		if(n_A_SHOES_DEF_PLUS <= 4 && CardNumSearch(407)) w += 5;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(2122)){
			w += 25;
			if(n_A_HEAD_DEF_PLUS >= 9) w += 25;
			if(n_A_HEAD_DEF_PLUS >= 10) w += 25;
		}
		if(n_A_HEAD_DEF_PLUS >= 1 && EquipNumSearch(2165)) w += 4 * n_A_HEAD_DEF_PLUS;
		if(EquipNumSearch(2407)) w += 10 * n_A_SHOES_DEF_PLUS;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2412)) w -= 100;
		if(CardNumSearch(866)){
			if(n_A_BODY_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 866)w += 30;
			}
			if(n_A_BODY_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 866)w += 100;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 866)w += 30;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 866)w += 100;
			}
			if(n_A_SHOES_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 866)w += 30;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 866)w += 30;
			}
			if(n_A_SHOES_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 866)w += 100;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 866)w += 100;
			}
		}
		if(n_A_PassSkill7[25]) w += 3;
		if(n_A_PassSkill7[23]) w += 20;
		if(SkillSearch(628)) w += 50 + 30 * SkillSearch(628);
		if(SkillSearch(621)) w -= 100;
		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[9] != 0) w += n_A_PassSkill10[9];
		var w2 = Math.floor(n_A_VIT /5);
		w2 = (w2 + n_A_MaxHP / 200) * w / 100;
		n_A_HPR += w2;
		n_A_HPR = ROUNDDOWN(n_A_HPR);
		if(n_A_IJYOU[2]) n_A_HPR = 0;
		myInnerHtml("A_HPR",n_A_HPR,0);






//================================================================================================================================
//================================================================================================================================
//====
//==== ＳＰ回復力＋○○　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_SPR_UP; idx <= ITEM_SP_SPR_UP; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		n_A_SPR = Math.floor(n_A_INT /6) + Math.floor(n_A_MaxSP /100) +1;
		var w = 0;
		w += SkillSearch(269) *3;
		if(SkillSearch(621)){
			w -= 100;
		}else if(SkillSearch(195)){
			w -= 50;
		}else if(TimeItemNumSearch(55) || TimeItemNumSearch(34)){
			w -= 50;
		}
		w += n_tok[76];
		if(SU_LUK >= 77) w += 100 * CardNumSearch(221);
		if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(673)) w += 3;
		if(SU_LUK >= 55 && EquipNumSearch(1632)) w += 30;
		if(n_A_HEAD_DEF_PLUS <= 4 && n_A_card[CARD_REGION_ID_HEAD_TOP]==179) w += 5;
		if(n_A_card[CARD_REGION_ID_HEAD_MID]==179) w += 5;
		if(n_A_SHOES_DEF_PLUS <= 4 && CardNumSearch(407)) w += 5;
		if(EquipNumSearch(1119) && GetLowerJobSeriesID(n_A_JOB)==5) w += 5;
		if(n_A_PassSkill7[25]) w += 3;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(1105)) w += 10;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(2122)){
			w += 25;
			if(n_A_HEAD_DEF_PLUS >= 9) w += 25;
			if(n_A_HEAD_DEF_PLUS >= 10) w += 25;
		}
		if(n_A_HEAD_DEF_PLUS >= 1 && EquipNumSearch(2165)) w += 4 * n_A_HEAD_DEF_PLUS;
		if(EquipNumSearch(2283)) w += n_A_HEAD_DEF_PLUS;

		//----------------------------------------------------------------
		// 「ヴァルゴ」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_VIRGO, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
			// アークビショップ限定の効果
			if (n_A_JOB == JOB_ID_ARCBISHOP) {
				w += 2 * n_A_HEAD_DEF_PLUS * cardCount;
			}
		}


		if(CardNumSearch(867)){
			if(n_A_BODY_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 867)w += 3;
			}
			if(n_A_BODY_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == 867)w += 10;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 867)w += 3;
			}
			if(n_A_SHOULDER_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == 867)w += 10;
			}
			if(n_A_SHOES_DEF_PLUS >= 6){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 867)w += 3;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 867)w += 3;
			}
			if(n_A_SHOES_DEF_PLUS >= 8){
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == 867)w += 10;
				if(n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == 867)w += 10;
			}
		}



		if(n_A_PassSkill7[24]) w += 20;
		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[10] != 0) w += n_A_PassSkill10[10];
		n_A_SPR += ROUNDDOWN(n_A_SPR * w / 100);
		if(n_A_INT>=120) n_A_SPR += Math.floor((n_A_INT-120)/2) +4;
		if(n_A_IJYOU[2]) n_A_SPR = 0;
		myInnerHtml("A_SPR",n_A_SPR,0);
		if(SkillSearch(155) || n_A_PassSkill7[40]){
			if(SkillSearch(739) == 0) myInnerHtml("A_SPR","<Font size=2>回復停止("+ n_A_SPR +")</Font>",0);
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃時、△△形モンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID; idx <= ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DRAGON; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(n_B[0] == 787) n_tok[37] += n_tok[241];
		if(ArrowOBJWork[n_A_Arrow][2]=="聖なる矢") n_tok[36] += 5;
		if(SkillSearch(234)) n_tok[39] += SkillSearch(234) *4;

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]) {
		case 1076:
		case 1077:
			if(n_A_Weapon2_ATKplus >= 5) n_tok[37] += 20;
			if(n_A_Weapon2_ATKplus >= 7) n_tok[37] += 20;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1076:
		case 1077:
		case 1086:
		case 1088:
		case 1100:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 20;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 20;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1081:
		case 1096:
		case 1097:
		case 1092:
		case 1093:
		case 1098:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 30;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 30;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1080:
		case 1082:
		case 1087:
		case 1090:
		case 1091:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 20;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 15;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1095:
		case 1094:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 25;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 20;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1089:
		case 1099:
		case 1101:
		case 1102:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 15;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 5;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1103:
			if(n_A_Weapon_ATKplus >= 5) n_tok[37] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[37] += 5;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1076:
		case 1077:
		case 1081:
		case 1082:
		case 1086:
		case 1088:
		case 1089:
		case 1090:
		case 1091:
		case 1092:
		case 1093:
		case 1094:
		case 1096:
		case 1097:
		case 1099:
		case 1100:
		case 1101:
		case 1102:
		case 1103:
			if(n_A_Weapon_ATKplus == 7) n_tok[37] += 9;
			if(n_A_Weapon_ATKplus == 8) n_tok[37] += 16;
			if(n_A_Weapon_ATKplus == 9) n_tok[37] += 25;
			if(n_A_Weapon_ATKplus >= 10) n_tok[37] += 36;
		}
		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1080:
		case 1087:
		case 1098:
			if(n_A_Weapon_ATKplus == 7) n_tok[37] += 16;
			if(n_A_Weapon_ATKplus == 8) n_tok[37] += 25;
			if(n_A_Weapon_ATKplus == 9) n_tok[37] += 36;
			if(n_A_Weapon_ATKplus >= 10) n_tok[37] += 49;
		}

		if(EquipNumSearch(1643) && CardNumSearch(20)){
			if(n_A_Arrow == 22) n_tok[37] += 2 * n_A_Weapon_ATKplus;
			if(n_A_Arrow == 23) n_tok[32] += 2 * n_A_Weapon_ATKplus;
			if(n_A_Arrow == 24) n_tok[34] += 2 * n_A_Weapon_ATKplus;
			if(n_A_Arrow == 25) n_tok[33] += 2 * n_A_Weapon_ATKplus;
		}
		if(n_A_PassSkill7[48]){
			n_tok[36] += 10;
			n_tok[176] += 10;
		}
		if(n_A_BODY_DEF_PLUS >= 6 && EquipNumSearch(1901)) n_tok[32] += n_A_BODY_DEF_PLUS - 5;
		if(n_A_BODY_DEF_PLUS >= 6 && 1930 <= n_A_Equip[EQUIP_REGION_ID_BODY] && n_A_Equip[EQUIP_REGION_ID_BODY] <= 1939){
			var w = 30 + (n_A_Equip[EQUIP_REGION_ID_BODY] - 1930);
			n_tok[w] += n_A_BODY_DEF_PLUS - 5;
		}
		if(EquipNumSearch(2117)) n_tok[37] += n_A_SHOES_DEF_PLUS;
		if(n_tok[261] != 0){
			for(var i=30;i<=39;i++) n_tok[i] += n_tok[261];
		}

		//----------------------------------------------------------------
		// 「迅雷剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_ZINRAI_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_ZINRAI_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「迅雷槍」の、過剰精錬による強化
		// 「迅雷鎚」の、過剰精錬による強化
		// 「迅雷弓」の、過剰精錬による強化
		// 「迅雷銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_ZINRAI_YARI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「迅雷弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_ZINRAI_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += 15;
		}


		//----------------------------------------------------------------
		// 「無双剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_MUSO_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_MUSO_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双槍」の、過剰精錬による強化
		// 「無双鎚」の、過剰精錬による強化
		// 「無双弓」の、過剰精錬による強化
		// 「無双銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MUSO_YARI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MUSO_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_ANIMAL] += 15;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 15;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャークレイモア」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_CLAYMORE)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 25;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーランス」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_LANCE)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーツーハンドアックス」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_TWOHAND_AXE)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 15;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーブラッディロア」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_BLOODYROAR)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 15;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャージャマダハル」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_JAMADHAR)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 15;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 10;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーハンターボウ」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_HUNTERBOW)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーハンドガン」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_HANDGUN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 20;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーライフル」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_RIFLE)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 35;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 35;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーガトリングガン」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_GATLINGGUN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 25;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 25;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーショットガン」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_SHOTGUN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 45;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 45;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーグレネードガン」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_GRENADEGUN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャー風魔手裏剣」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_FUMASHURIKEN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 30;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャークレイモア」の、「虐殺Ｌｖ２」による効果
		// 「アヴェンジャーツーハンドアックス」の、「虐殺Ｌｖ２」による効果
		// 「アヴェンジャー風魔手裏剣」の、「虐殺Ｌｖ２」による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_CLAYMORE)
			|| EquipNumSearch(ITEM_ID_AVENGER_TWOHAND_AXE)
			|| EquipNumSearch(ITEM_ID_AVENGER_FUMASHURIKEN)) {
			if(n_A_Weapon_ATKplus == 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 16;
			if(n_A_Weapon_ATKplus == 8) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 25;
			if(n_A_Weapon_ATKplus == 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 36;
			if(n_A_Weapon_ATKplus >= 10) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 49;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーランス」の、「虐殺Ｌｖ１」による効果
		// 「アヴェンジャーブラッディロア」の、「虐殺Ｌｖ１」による効果
		// 「アヴェンジャージャマダハル」の、「虐殺Ｌｖ１」による効果
		// 「アヴェンジャーハンターボウ」の、「虐殺Ｌｖ１」による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_LANCE)
			|| EquipNumSearch(ITEM_ID_AVENGER_BLOODYROAR)
			|| EquipNumSearch(ITEM_ID_AVENGER_JAMADHAR)
			|| EquipNumSearch(ITEM_ID_AVENGER_HUNTERBOW)) {
			if(n_A_Weapon_ATKplus == 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 9;
			if(n_A_Weapon_ATKplus == 8) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 16;
			if(n_A_Weapon_ATKplus == 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 25;
			if(n_A_Weapon_ATKplus >= 10) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_HUMAN] += 36;
		}

		//----------------------------------------------------------------
		// 「瑞々しいだいだい」の、「キューペット　モチリン」による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MIZUMIZUSHI_DAIDAI)) {
			if (n_A_PassSkill8[0] == 42) {
				if (n_A_PassSkill8[17] >= 5) {
					n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_PLANT] += 5;
				}
			}
		}



		//----------------------------------------------------------------
		// 「一碧剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_IPPEKI_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_IPPEKI_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「一碧槍」の、過剰精錬による強化
		// 「一碧鎚」の、過剰精錬による強化
		// 「一碧弓」の、過剰精錬による強化
		// 「一碧銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_IPPEKI_YARI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「一碧弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_IPPEKI_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID] += 15;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_DEMON] += 15;
		}



		//----------------------------------------------------------------
		// 「死霊魔術師のニット帽」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_SHIRYOMAZYUTSUSHINO_NITTOBO)) > 0) {
			vartmp = 0;

			if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 10;
			if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 10;

			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_UNDEAD] += vartmp * itemCount;
		}



		//----------------------------------------------------------------
		// 「業風石　ゲラドリア　セット」の、精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_GERADRIA)) > 0) {
			vartmp = 0;

			if (n_A_Weapon_ATKplus >= 7) {
				vartmp += 30;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				vartmp += 20;
			}

			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_INSECT] += vartmp * itemCount;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_FISH] += vartmp * itemCount;
		}




//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃時、△△サイズのモンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_PHYSICAL_DAMAGE_UP_SIZE_SMALL; idx <= ITEM_SP_PHYSICAL_DAMAGE_UP_SIZE_LARGE; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(EquipNumSearch(1325)){
			if(n_A_PassSkill8[0] == 13){
				n_tok[29] += 5;
				if(n_A_PassSkill8[17] == 6) n_tok[29] += 5;
			}
		}
		if(EquipNumSearch(1450)){
			if(n_A_PassSkill8[0] == 10){
				n_tok[27] += 5;
				if(n_A_PassSkill8[17] == 6) n_tok[27] += 5;
			}
		}
		if(EquipNumSearch(1644)) n_tok[28] += n_A_Weapon_ATKplus;
		if(n_tok[260] != 0){
			n_tok[27] += n_tok[260];
			n_tok[28] += n_tok[260];
			n_tok[29] += n_tok[260];
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 遠距離物理攻撃で与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(EquipNumSearch(628) && n_A_Arrow == 4) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 25;
		if(EquipNumSearch(626) && n_A_Arrow == 2) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 25;
		if(EquipNumSearch(627) && n_A_Arrow == 5) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 25;
		if(EquipNumSearch(629) && n_A_Arrow == 6) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 25;
		if(EquipNumSearch(630) && n_A_Arrow == 10) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 50;
		if(EquipNumSearch(1217)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += n_A_HEAD_DEF_PLUS;
		if(SU_AGI >= 120 && EquipNumSearch(1311)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 4;
		if(EquipNumSearch(101) && n_A_Arrow == 20) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 50;
		if(EquipNumSearch(1327) && n_A_Arrow == 21) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 50;
		if(EquipNumSearch(104) && n_A_Arrow == 11) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 50;
		if(SU_DEX >= 100 && EquipNumSearch(1527)){
			var wx = EquipNumSearch(1527);
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1 * wx;
			if(SU_DEX >= 120) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2 * wx;
		}
		if(EquipNumSearch(1600)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += n_A_BODY_DEF_PLUS * 2;
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1601)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 15;
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1606)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] -= 10;
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1634)){
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3;
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
		}
		if(EquipNumSearch(1695)) if(GetLowerJobSeriesID(n_A_JOB)==4) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 10;
		if(n_A_BaseLV >= 100 && EquipNumSearch(1764)){
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1;
			if(n_A_BaseLV >= 150) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1;
		}

		// 技巧の時空ブーツ
		if(SU_DEX >= 120 && EquipNumSearch(1921)) {
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
		}
		if(SU_DEX >= 120 && EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS_S1)) {
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
		}

		if(SU_DEX >= 110 && EquipNumSearch(1950)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1 * EquipNumSearch(1950);
		if(n_A_Weapon_ATKplus >= 7 && EquipNumSearch(2024)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
		if(n_A_HEAD_DEF_PLUS >= 6 && TimeItemNumSearch(64) && EquipNumSearch(2085)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += (n_A_HEAD_DEF_PLUS - 5);
		if(CardNumSearch(739)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1 * ROUNDDOWN(SU_DEX / 10);
		if(EquipNumSearch(2355)){
			if(n_A_BODY_DEF_PLUS >= 8) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2;
			if(n_A_BODY_DEF_PLUS >= 9) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3;
			if(n_A_Arrow == 2 && EquipNumSearch(2356)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 20;
			if(n_A_Arrow == 5 && EquipNumSearch(2357)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 20;
			if(n_A_Arrow == 4 && EquipNumSearch(2358)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 20;
			if(n_A_Arrow == 6 && EquipNumSearch(2359)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 20;
		}
		if(EquipNumSearch(2367)){
			if(n_A_SHOES_DEF_PLUS >= 8) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += (n_A_SHOES_DEF_PLUS - 7);
		}

		//----------------------------------------------------------------
		// 「戦死者のマント」の、純粋なＤＥＸが１３０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			if (SU_DEX >= 130) {
				if (EquipNumSearchFurubitaSet() > 0) {
					n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 10;
				} else {
					n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「天狗の巻物セット」の、強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_TENGUNO_MAKIMONO_KARASUTENGU)) {
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1;
			if (SU_STR >= 108) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1;
			if (SU_STR >= 120) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1;
		}

		//----------------------------------------------------------------
		// 「元素のタオル」の、＋８以上精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_GENSONO_TOWEL)) {
			if(n_A_SHOULDER_DEF_PLUS >= 8) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2;
			if(n_A_SHOULDER_DEF_PLUS >= 9) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3;
		}

		//----------------------------------------------------------------
		// 「パワードメイル」の、過剰精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_POWERED_MAIL)) {
			if(n_A_BODY_DEF_PLUS >= 5) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2 * (n_A_BODY_DEF_PLUS - 4);
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　ボウセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_BOW)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3 * ROUNDDOWN(SU_STR / 10);
			}
		}

		//----------------------------------------------------------------
		// 「フェアリーフのギリ粉」の、素ＤＥＸによる強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_FAIRLEAFNO_GIRIKO)) {
			if (SU_DEX >= 100) {
				n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 5;
			}
		}

		//----------------------------------------------------------------
		// 「カーリッツバーグ騎士団の鎧」の、過剰精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_KAHRITZBARGKISHIDANNO_YOROI)) {
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2 * n_A_BODY_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「パワフルAスケルトンカード」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_A_SKELETON)) > 0) {
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
		}

		//----------------------------------------------------------------
		// 「レンジャーセシル(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_RANGER_CECIL_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_RANGER) {
				n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「キックステップカード」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_KICK_STEP)) {
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3;
			if (n_A_SHOES_DEF_PLUS >= 9) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2;
		}


		if(CardNumSearch(829)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2 * CardNumSearch(829);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 1 * CardNumSearch(829);
		}
		if(SU_STR >= 108 && EquipNumSearch(2395)){
			n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 2;
			if(SU_STR >= 120) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 3;
		}
		if((n_B_TAISEI[38] == 0 || n_B_TAISEI[38] == 5) && SkillSearch(795)) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += 50 * SkillSearch(795);





//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃時、△△属性モンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_VANITY; idx <= ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_UNDEAD; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(n_A_LEFT_DEF_PLUS >= 1){
			if(EquipNumSearch(2205)) n_tok[40] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1509)) n_tok[41] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1511)) n_tok[48] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1513)) n_tok[43] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1515)) n_tok[42] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1517)) n_tok[47] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1519)) n_tok[45] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1521)) n_tok[49] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(1523)) n_tok[46] += n_A_LEFT_DEF_PLUS;
			if(EquipNumSearch(2132)) n_tok[44] += n_A_LEFT_DEF_PLUS;
		}
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1815)) n_tok[41] += 3;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1978)){
			n_tok[43] += 10;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[43] += 5;
		}
		if(n_A_BODY_DEF_PLUS >= 5){
			for(var i=0;i<=3;i++) if(EquipNumSearch(2328 + i)) n_tok[41 + i] += (n_A_BODY_DEF_PLUS - 4);
		}
		if(n_A_SHOES_DEF_PLUS >= 5 && EquipNumSearch(2503)){
			for(var i=40;i<=44;i++) n_tok[i] += 5;
			if(n_A_SHOES_DEF_PLUS >= 7){
				for(var i=40;i<=44;i++) n_tok[i] += 10;
			}
		}
		if(n_tok[262] != 0){
			for(var i=40;i<=49;i++) n_tok[i] += n_tok[262];
		}

		//----------------------------------------------------------------
		// 「迅雷剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_ZINRAI_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_ZINRAI_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「迅雷槍」の、過剰精錬による強化
		// 「迅雷鎚」の、過剰精錬による強化
		// 「迅雷弓」の、過剰精錬による強化
		// 「迅雷銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_ZINRAI_YARI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_ZINRAI_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「迅雷弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_ZINRAI_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += 15;
		}

		//----------------------------------------------------------------
		// 「無双剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_MUSO_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_MUSO_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双槍」の、過剰精錬による強化
		// 「無双鎚」の、過剰精錬による強化
		// 「無双弓」の、過剰精錬による強化
		// 「無双銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MUSO_YARI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_MUSO_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 10;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 15;
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MUSO_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += 15;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 15;
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 6) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「一碧剣」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == ITEM_ID_IPPEKI_KEN) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 15;
			}
		}
		if (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == ITEM_ID_IPPEKI_KEN) {
			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 10;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「一碧槍」の、過剰精錬による強化
		// 「一碧鎚」の、過剰精錬による強化
		// 「一碧弓」の、過剰精錬による強化
		// 「一碧銃」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_IPPEKI_YARI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_TSUCHI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_YUMI) > 0
			|| EquipNumSearch(ITEM_ID_IPPEKI_ZYU) > 0) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「一碧弓」の、矢装備による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_IPPEKI_YUMI) > 0 && n_A_Arrow == 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_FIRE] += 15;
		}

		//----------------------------------------------------------------
		// 「業風石　ゲラドリア　セット」の、精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_GERADRIA)) > 0) {
			vartmp = 0;

			if (n_A_Weapon_ATKplus >= 7) {
				vartmp += 30;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				vartmp += 20;
			}

			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WATER] += vartmp * itemCount;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_WIND] += vartmp * itemCount;
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃時、ボスモンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_PHYSICAL_DAMAGE_UP_BOSS; idx <= ITEM_SP_PHYSICAL_DAMAGE_UP_BOSS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(SU_STR >= 120 && EquipNumSearch(348)) n_tok[26] += 10 * EquipNumSearch(348);
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1402)) n_tok[26] += (n_A_HEAD_DEF_PLUS - 4);
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1409)) n_tok[26] += 5;
		if(n_A_BaseLV >= 100 && EquipNumSearch(1762)) n_tok[26] += 1;
		if(EquipNumSearch(2296)){
			if(n_A_PassSkill8[0] == 1){
				n_tok[26] += 10;
				if(n_A_PassSkill8[17] == 6) n_tok[26] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　アックスセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_AXE)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				if (n_A_Weapon_ATKplus >= 7) n_tok[26] += 20;
				if (n_A_Weapon_ATKplus >= 9) n_tok[26] += 30;
			}
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　ボウセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_BOW)) {
			if (n_A_SHOES_DEF_PLUS >= 7) {
				if (n_A_Weapon_ATKplus >= 7) n_tok[26] += 20;
				if (n_A_Weapon_ATKplus >= 9) n_tok[26] += 30;
			}
		}

		//----------------------------------------------------------------
		// 「炎竜の鎧」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_ENRYUNO_YOROI)) {
			if (n_A_BODY_DEF_PLUS >= 7) n_tok[26] += 10;
			if (n_A_BODY_DEF_PLUS >= 9) n_tok[26] += 10;
		}

		//----------------------------------------------------------------
		// 「業風石　ゲラドリア　セット」の、精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_GERADRIA)) > 0) {
			vartmp = 0;

			if (n_A_Weapon_ATKplus >= 7) {
				vartmp += 30;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				vartmp += 20;
			}

			n_tok[26] += vartmp * itemCount;
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 物理攻撃で与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(GetHigherJobSeriesID(n_A_JOB)==14) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10 * CardNumSearch(479);
		if(n_A_Weapon_ATKplus >= 9 && EquipNumSearch(1101)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_Weapon_ATKplus;
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7){
			if(EquipNumSearch(1585) || EquipNumSearch(1596)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5;
		}

		// ＳｐｅｃｉａｌＳＴＲ
		vartmp = CARD_ID_ENCHANT_SPECIAL_STR;
		cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
		cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
		cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
		cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
		cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
		cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
		cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
		cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
		cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
		if (cardCount > 0) {
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountHeadTop;
			if (n_A_LEFT_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShield;
			if (n_A_BODY_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountBody;
			if (n_A_SHOULDER_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShoulder;
			if (n_A_SHOES_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShoes;
		}

		// ＳｐｅｃｉａｌＡＧＩ
		vartmp = CARD_ID_ENCHANT_SPECIAL_AGI;
		cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
		cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
		cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
		cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
		cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
		cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
		cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
		cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
		cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
		if (cardCount > 0) {
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountHeadTop;
			if (n_A_LEFT_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShield;
			if (n_A_BODY_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountBody;
			if (n_A_SHOULDER_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShoulder;
			if (n_A_SHOES_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * cardCountShoes;
		}


		if(EquipNumSearch(1643) && ( 22 <= n_A_Arrow && n_A_Arrow <= 25)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 50;
		if(EquipNumSearch(1695)) if(GetLowerJobSeriesID(n_A_JOB)==1 || GetLowerJobSeriesID(n_A_JOB)==2 || GetLowerJobSeriesID(n_A_JOB)==6) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 8;
		if(EquipNumSearch(1741)) if(n_A_LEFT_DEF_PLUS >= 5) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_LEFT_DEF_PLUS - 4;
		if(EquipNumSearch(1802)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_Weapon_ATKplus;
		if(SU_STR >= 110 && EquipNumSearch(1946)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * EquipNumSearch(1946);
		if(SU_AGI >= 110 && CardNumSearch(710)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 7;
		if(CardNumSearch(828)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * CardNumSearch(828);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * CardNumSearch(828);
		}
		if(SU_STR >= 108 && EquipNumSearch(2395)){
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1;
			if(SU_STR >= 120) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2;
		}
		if(EquipNumSearch(2441)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += ROUNDDOWN((n_A_SHOES_DEF_PLUS + n_A_HEAD_DEF_PLUS) / 2);
		if(EquipNumSearch(2462)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_HEAD_DEF_PLUS;
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(2512)){
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2;
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 3;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 4;
		}
		if(n_A_card[CARD_REGION_ID_HEAD_TOP] == 894) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		if(EquipNumSearch(2541)) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2 * n_A_BODY_DEF_PLUS;
		if(n_A_PassSkill7[41]){
			if(n_A_PassSkill7[41] == 1) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5;
			if(n_A_PassSkill7[41] == 2) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10;
		}

		//----------------------------------------------------------------
		// 「戦死者のマント」の、純粋なＳＴＲが１３０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			if (SU_STR >= 130) {
				if (EquipNumSearchFurubitaSet() > 0) {
					n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10;
				} else {
					n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「天狗の巻物セット」の、強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_TENGUNO_MAKIMONO_KARASUTENGU)) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1;
			if (SU_STR >= 108) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2;
			if (SU_STR >= 120) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 3;
		}

		//----------------------------------------------------------------
		// 「拳闘士のグローブ」の、純粋なＳＴＲが１００以上の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_KENTOSHINO_GLOVE)){
			if (SU_STR >= 100) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5;
			}
		}

		//----------------------------------------------------------------
		// 「ダークハンド」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_DARK_HAND)) > 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * n_A_HEAD_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「リンディーホップ」の、過剰精錬による効果
		//----------------------------------------------------------------
		itemCountRight = EquipNumSearch(ITEM_ID_LINDY_HOP, EQUIP_REGION_ID_ARMS_RIGHT);
		itemCountLeft = EquipNumSearch(ITEM_ID_LINDY_HOP, EQUIP_REGION_ID_ARMS_LEFT);
		if ((itemCountRight > 0) || (itemCountLeft > 0)) {

			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 25;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 25;
			}

			if (n_A_Weapon2_ATKplus >= 7) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 25;
			}
			if (n_A_Weapon2_ATKplus >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 25;
			}
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 6 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 6 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「怨恨の白の騎士カード」の、武器種類による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ENKONNO_SHIRONO_KISHI)) > 0) {
			if ((n_A_WeaponType == ITEM_KIND_SWORD_2HAND)
				|| (n_A_WeaponType == ITEM_KIND_SPEAR_2HAND)
				|| (n_A_WeaponType == ITEM_KIND_AXE_2HAND)) {

				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5 * cardCount;

				if (n_A_Weapon_ATKplus >= 10) {
					n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10 * cardCount;
				}
			}
		}

		//----------------------------------------------------------------
		// 「魔眼のアムダライスカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_MAGANNO_AMDARAIS)) > 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_BODY_DEF_PLUS * cardCount;
		}

		//----------------------------------------------------------------
		// 「怨恨のカーリツバーグカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ENKONNO_KHALITZBURG)) > 0) {
			if (n_A_HEAD_DEF_PLUS >= 9) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 4 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「パワフルアムダライスカード」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_POWERFUL_AMDARAIS)) > 0) {
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 1 * ROUNDDOWN(n_A_BaseLV / 20) * cardCount;
		}

		//----------------------------------------------------------------
		// 「栄光の証」の、ベースレベルによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_EIKONO_AKASHI)) > 0) {
			if (n_A_BaseLV >= 150) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2 * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「エンチャント　死のニーヴ(腕力)」の、精錬による効果
		//----------------------------------------------------------------
		cardCountShield = CardNumSearch(CARD_ID_ENCHANT_SHINO_NIEVE_WANRYOKU, CARD_REGION_ID_SHIELD_ANY);
		if (cardCountShield > 0) {

			// 盾防具へのエンチャント
			vartmp = 0;
			if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 1;
			n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += vartmp * cardCountShield

			// アクセサリへのエンチャント
			// 精錬できないので処理不要
		}

		//----------------------------------------------------------------
		// 「ギロチンクロスエレメス(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_GUILLOTINE_CROSS_ELEMES_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_GILOTINCROSS) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「メカニックハワード(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_MECHANIC_HAWARD_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_MECHANIC) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「ルーンナイトセイレン(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_RUNE_KNIGHT_SEIREN_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_RUNEKNIGHT) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「ジェネティックエミュール(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_GENETIC_EMUR_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_GENETIC) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 15 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「シャドウチェイサーガーティ(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_SHADOW_CHASER_GARTY_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_SHADOWCHASER) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 5 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「修羅チェン(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_SHURA_CHENG_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_SHURA) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「ロイヤルガードランデル(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ROYAL_GUARD_RANDEL_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_ROYALGUARD) {
				n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 10 * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「クラップカード」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_CRAP)) {
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 3;
			if (n_A_SHOES_DEF_PLUS >= 9) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += 2;
		}



//================================================================================================================================
//================================================================================================================================
//====
//==== クリティカル攻撃で与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_CRITICAL_DAMAGE_UP; idx <= ITEM_SP_CRITICAL_DAMAGE_UP; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(EquipNumSearch(1089)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += (2 * n_A_Weapon_ATKplus);
		if(EquipNumSearch(1091)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10;
		}
		if(EquipNumSearch(1358)){
			if(ArrowOBJWork[n_A_Arrow][2]=="鋭い矢"){
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 5;
				if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 5;
			}
		}
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1591)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 15;
		if(EquipNumSearch(1592)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += n_A_SHOULDER_DEF_PLUS;
		if(n_A_SHOULDER_DEF_PLUS >= 5 && EquipNumSearch(1631)){
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 3;
			if(n_A_SHOULDER_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 4;
		}
		if(EquipNumSearch(1801)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2 * n_A_Weapon_ATKplus;
		if(n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1812)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 3;
		if(EquipNumSearch(1888) && SkillSearch(81) == 10) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 20;

		// 幸運の時空ブーツ
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(1922)) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}
		if(SU_LUK >= 120 && EquipNumSearch(1922)) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 30;
		}
		if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS_S1)) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
		}
		if(SU_LUK >= 120 && EquipNumSearch(ITEM_ID_KOUNNO_ZIKU_BOOTS_S1)) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 30;
		}

		if(SU_LUK >= 110 && EquipNumSearch(1951)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 1 * EquipNumSearch(1951);
		if(n_A_BODY_DEF_PLUS >= 5 && EquipNumSearch(2170)){
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 4;
			if(n_A_BODY_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 6;
		}
		if(EquipNumSearch(2242)){
			if(SU_LUK >= 108) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10;
			if(SU_LUK >= 120) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 17;
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] -= 2 * ROUNDDOWN(SU_DEX / 10);
		}
		if(n_A_SHOULDER_DEF_PLUS >= 5 && EquipNumSearch(2288)){
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 3;
			if(n_A_SHOULDER_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 4;
		}
		if(GetLowerJobSeriesID(n_A_JOB)==4 && EquipNumSearch(2517)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 15;

		//----------------------------------------------------------------
		// 「戦死者のマント」の、純粋なＬＵＫが１３０の時
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			if (SU_LUK >= 130) {
				if (EquipNumSearchFurubitaSet() > 0) {
					n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10;
				} else {
					n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「蒼き夜光石」の、ステによる強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AOKI_YAKOSEKI)) {
			if (SU_LUK >= 100) {
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10 * EquipNumSearch(ITEM_ID_AOKI_YAKOSEKI);
			}
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 1 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 1 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_RIGHT);
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 1 * n_A_Weapon2_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE, EQUIP_REGION_ID_ARMS_LEFT);
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「ローラカード」の、強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_LOLA)) {
			if (n_A_WeaponType == ITEM_KIND_CLUB) {
				n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += (10 + 1 * n_A_Weapon_ATKplus) * CardNumSearch(CARD_ID_LOLA);
			}
		}

		//----------------------------------------------------------------
		// 「アヴェンジャージャマダハル」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_JAMADHAR)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 20;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 20;
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーハンターボウ」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_HUNTERBOW)) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「リス耳フード帽」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RISUMIMI_HOODBO)) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2;
			if (n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 6;
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 12;
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 8) {
				if (SU_LUK >= 90) {
					n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 5;
				}
			}
		}

		//----------------------------------------------------------------
		// 「反逆者のスカーフ」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HANGYAKUSHANO_SCARF)) > 0) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 3 * LearnedSkillSearch(SKILL_ID_DRAGON_TAIL) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＳＴＲと素ＬＵＫによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 10 * ROUNDDOWN((SU_STR + SU_LUK) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「キックアンドキックカード」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_KICK_AND_KICK)) {
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 3;
			if (n_A_SHOES_DEF_PLUS >= 9) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2;
		}

		if(GetLowerJobSeriesID(n_A_JOB)==2 && n_A_card[CARD_REGION_ID_HEAD_TOP]==624) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += Math.floor(n_A_HEAD_DEF_PLUS / 2);
		if(CardNumSearch(738)) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += 2 * ROUNDDOWN(SU_LUK / 10);
		if(EquipNumSearch(1357)){
			if(EquipNumSearch(261)) n_tok[45] += 10;
			if(EquipNumSearch(1221)) n_tok[36] += 10;
			if(EquipNumSearch(364)) n_tok[30] += 10;
			if(EquipNumSearch(1023)) n_tok[37] += 10;
			if(EquipNumSearch(382)) n_tok[32] += 10;
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[18]) n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP] += n_A_PassSkill9[18];
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[19]){
			for(var i=30;i<=39;i++) n_tok[i] += n_A_PassSkill9[19];
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[20]){
			for(var i=40;i<=49;i++) n_tok[i] += n_A_PassSkill9[20];
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[21]){
			for(var i=27;i<=29;i++) n_tok[i] += n_A_PassSkill9[21];
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[22]) n_tok[ITEM_SP_LONGRANGE_DAMAGE_UP] += n_A_PassSkill9[22];
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[23]) n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += n_A_PassSkill9[23];
		if(n_A_WeaponType == 9 || n_A_WeaponType == 12){
			if(EquipNumSearch(2500)) n_tok[242] += 2 * n_A_Weapon_ATKplus;
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 魔法攻撃時、△△形モンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_MAGIC_DAMAGE_UP_RACE_SOLID; idx <= ITEM_SP_MAGIC_DAMAGE_UP_RACE_DRAGON; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(n_B[0] == 787) n_tok[177] += n_tok[242];
		if(EquipNumSearch(1083)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[177] += 5;
			if(n_A_Weapon_ATKplus >= 7) n_tok[177] += 5;
			if(n_A_Weapon_ATKplus >= 7){
				if(n_A_Weapon_ATKplus <= 10){
					n_tok[177] += 2 * (n_A_Weapon_ATKplus - 5);
				}else{
					n_tok[177] += 10;
				}
			}
		}
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1771)) n_tok[177] += 5;
		if(n_A_LEFT_DEF_PLUS >= 8 && EquipNumSearch(1446)) n_tok[174] += 4;
		if(n_A_BODY_DEF_PLUS >= 6 && EquipNumSearch(1901)) n_tok[172] += n_A_BODY_DEF_PLUS - 5;
		if(n_A_BODY_DEF_PLUS >= 6 && 1930 <= n_A_Equip[EQUIP_REGION_ID_BODY] && n_A_Equip[EQUIP_REGION_ID_BODY] <= 1939){
			var w = 170 + (n_A_Equip[EQUIP_REGION_ID_BODY] - 1930);
			n_tok[w] += n_A_BODY_DEF_PLUS - 5;
		}

		//----------------------------------------------------------------
		// 「迅雷杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_ZINRAI_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_FISH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_FISH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MUSO_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_ANIMAL] += 10;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_PLANT] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_ANIMAL] += 15;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_PLANT] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーウィザードスタッフ」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_WIZARDSTUFF)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_HUMAN] += 10;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_HUMAN] += 10;

			// 破滅Ｌｖ１
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_HUMAN] += 2 * (n_A_Weapon_ATKplus - 5);
			}
		}

		//----------------------------------------------------------------
		// 「裁きの靴　ホーリーステッキセット」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_SABAKINO_KUTSU_HOLY_STICK)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_UNDEAD] += 30;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_DEMON] += 30;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_UNDEAD] += 20;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_DEMON] += 20;
			}
		}

		//----------------------------------------------------------------
		// 「一碧杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_IPPEKI_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_SOLID] += 10;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_DEMON] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_SOLID] += 15;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_DEMON] += 15;
			}
		}



		//----------------------------------------------------------------
		// 「死霊魔術師のニット帽」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_SHIRYOMAZYUTSUSHINO_NITTOBO)) > 0) {
			vartmp = 0;

			if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 10;
			if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 10;

			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_UNDEAD] += vartmp * itemCount;
		}



		if(CardNumSearch(895)){
			n_tok[177] -= 50;
			n_tok[178] -= 50;
		}
		if(n_B[19]==9 && SkillSearch(234)) n_tok[179] += SkillSearch(234) *2;
		if(n_tok[266] != 0){
			for(var i=170;i<=179;i++) n_tok[i] += n_tok[266];
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[28]){
			for(var i=170;i<=179;i++) n_tok[i] += n_A_PassSkill9[28];
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== プレイヤー耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(n_A_BODY_DEF_PLUS >= 6 && (EquipNumSearch(2223) || EquipNumSearch(2224))){
			n_tok[243] += 2;
			if(n_A_BODY_DEF_PLUS >= 8) n_tok[243] += 3;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 6 && (EquipNumSearch(2227) || EquipNumSearch(2228))){
			n_tok[243] += 2;
			if(n_A_SHOULDER_DEF_PLUS >= 8) n_tok[243] += 3;
		}
		if(n_A_SHOES_DEF_PLUS >= 6 && (EquipNumSearch(2229) || EquipNumSearch(2230))){
			n_tok[243] += 2;
			if(n_A_SHOES_DEF_PLUS >= 8) n_tok[243] += 3;
		}
		if(SU_VIT >= 108 && EquipNumSearch(2257)) n_tok[243] += 3;

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＡＧＩと素ＶＩＴによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			n_tok[243] += 2 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＡＧＩと素ＶＩＴによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			n_tok[243] += 2 * ROUNDDOWN((SU_AGI + SU_VIT) / 80) * itemCount;
		}

		if(n_B[0] == 787) n_tok[57] += n_tok[243];





//================================================================================================================================
//================================================================================================================================
//====
//==== 種族耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_REGIST_RACE_SOLID; idx <= ITEM_SP_REGIST_RACE_DRAGON; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}



		if(CardNumSearch(452) && GetLowerJobSeriesID(n_A_JOB)==3){
			n_tok[51] += 30;
			n_tok[56] += 30;
		}
		if(n_A_PassSkill2[14] && GetHigherJobSeriesID(n_A_JOB) != 13) n_tok[56] += n_A_PassSkill2[14] * 5;
		if(SkillSearch(234)) n_tok[59] += SkillSearch(234) *4;
		for(var i=971;i<=977;i++){
			if(EquipNumSearch(i)){
				n_tok[50] -= 200;
				n_tok[51] -= 200;
				n_tok[52] -= 200;
				n_tok[53] -= 200;
				n_tok[54] -= 200;
				n_tok[55] -= 200;
				n_tok[56] -= 200;
				n_tok[58] -= 200;
				n_tok[59] -= 200;
			}
		}
		if(n_A_SHOULDER_DEF_PLUS >= 7 && EquipNumSearch(1110)) n_tok[57] += 3;
		if(n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1107)) n_tok[57] += 3;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(1104)) n_tok[57] += 2;
		if(n_A_LEFT_DEF_PLUS >= 8 && EquipNumSearch(1446)) n_tok[54] += 20;
		if(n_A_SHOULDER_DEF_PLUS >= 1){
			if(EquipNumSearch(2205)) n_tok[50] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1509)) n_tok[52] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1511)) n_tok[58] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1513)) n_tok[56] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1515)) n_tok[55] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1517)) n_tok[51] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1519)) n_tok[53] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1521)) n_tok[57] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(1523)) n_tok[59] += n_A_SHOULDER_DEF_PLUS;
			if(EquipNumSearch(2132)) n_tok[54] += n_A_SHOULDER_DEF_PLUS;
		}
		if(EquipNumSearch(1568)){
			for(var i=0;i<=9;i++) n_tok[50+i] -= 10;
			n_tok[57] += 10;
		}
		if(EquipNumSearch(1573)){
			for(var i=0;i<=9;i++) n_tok[50+i] -= 10;
			n_tok[51] += 10;
			n_tok[56] += 10;
		}
		if(n_A_HEAD_DEF_PLUS >= 9 && n_A_card[CARD_REGION_ID_HEAD_TOP]==626) n_tok[54] += 5;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1814)) n_tok[52] += 5;
		if(n_A_Weapon_ATKplus >= 6 && EquipNumSearch(1823)) n_tok[57] += (n_A_Weapon_ATKplus - 5);
		if(n_A_BODY_DEF_PLUS >= 3 && EquipNumSearch(1913)) n_tok[51] += Math.floor(n_A_BODY_DEF_PLUS / 3) * 5;
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(1942)) n_tok[55] += 5;
		if(n_A_HEAD_DEF_PLUS >= 6 && 1954 <= n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] && n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] <= 1963) n_tok[50 + n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] - 1954] += 5;
		if(n_A_HEAD_DEF_PLUS >= 7){
			if(EquipNumSearch(2073) || EquipNumSearch(2074) || EquipNumSearch(2075) || EquipNumSearch(2076)) n_tok[57] += 5;
		}
		if(2212 <= n_A_Equip[EQUIP_REGION_ID_BODY] && n_A_Equip[EQUIP_REGION_ID_BODY] <= 2221) n_tok[50 + (n_A_Equip[EQUIP_REGION_ID_BODY] - 2212)] += n_A_BODY_DEF_PLUS;
		if(EquipNumSearch(2289)) n_tok[54] += n_A_HEAD_DEF_PLUS;
		if(2300 <= n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] && n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] <= 2309 && n_B[0] != 787){
			if(n_A_HEAD_DEF_PLUS >= 5) n_tok[50 + (n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] - 2300)] += 5;
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[50 + (n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] - 2300)] += 5;
			if(n_A_Equip[EQUIP_REGION_ID_HEAD_TOP] == 2306){
				if(n_A_HEAD_DEF_PLUS >= 5) n_tok[56] -= 3;
				if(n_A_HEAD_DEF_PLUS >= 7) n_tok[56] -= 2;
			}
		}
		if(EquipNumSearch(1879)){
			for(var i=50;i<=59;i++) n_tok[i] += 30;
		}
		if(n_tok[263] != 0){
			for(var i=50;i<=59;i++) n_tok[i] += n_tok[263];
		}

		//----------------------------------------------------------------
		// 「戦死者のマント」の、精錬値２ごとの、人間種族耐性
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT)){
			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 2);
		}

		//----------------------------------------------------------------
		// 「古びた系頭装備」の、過剰精錬による、人間種族耐性
		//----------------------------------------------------------------
		if(EquipNumSearchFurubitaHead()) {
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 5;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
		}

		//----------------------------------------------------------------
		// 「A-Tolerance」の、精錬による効果
		//----------------------------------------------------------------
		if(CardNumSearch(CARD_ID_ENCHANT_A_TOLERANCE)){

			// 体装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_BODY_1] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_BODY_2] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_BODY_3] == CARD_ID_ENCHANT_A_TOLERANCE) {

				n_tok[ITEM_SP_REGIST_RACE_SOLID] += ROUNDDOWN(n_A_BODY_DEF_PLUS / 3);
				n_tok[ITEM_SP_REGIST_RACE_HUMAN] += ROUNDDOWN(n_A_BODY_DEF_PLUS / 3);
			}

			// 肩装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_1] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_2] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOULDER_3] == CARD_ID_ENCHANT_A_TOLERANCE) {

				n_tok[ITEM_SP_REGIST_RACE_SOLID] += ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3);
				n_tok[ITEM_SP_REGIST_RACE_HUMAN] += ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3);
			}

			// 靴装備に装着されている場合
			if (n_A_card[CARD_REGION_ID_ENCHANT_SHOES_1] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOES_2] == CARD_ID_ENCHANT_A_TOLERANCE
				|| n_A_card[CARD_REGION_ID_ENCHANT_SHOES_3] == CARD_ID_ENCHANT_A_TOLERANCE) {

				n_tok[ITEM_SP_REGIST_RACE_SOLID] += ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
				n_tok[ITEM_SP_REGIST_RACE_HUMAN] += ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
			}

			// ライオットチップとのセット効果
			if (EquipNumSearch(ITEM_SET_ID_RIOTCHIP_A_TOLERANCE)) {
				n_tok[ITEM_SP_REGIST_RACE_SOLID] += n_A_HEAD_DEF_PLUS;
				n_tok[ITEM_SP_REGIST_RACE_HUMAN] += n_A_HEAD_DEF_PLUS;
			}
		}

		//----------------------------------------------------------------
		// 「カルデュイの法衣」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_CARDYUINO_HOI)){
			if (n_A_BODY_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_BODY_DEF_PLUS >= 8) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_BODY_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
		}


		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				if (n_A_Weapon_ATKplus >= 7) {
					n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 10 * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				}
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				if (n_A_Weapon_ATKplus >= 7) {
					n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 10 * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				}
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「アヴェンジャー系装備」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_CLAYMORE)
			|| EquipNumSearch(ITEM_ID_AVENGER_LANCE)
			|| EquipNumSearch(ITEM_ID_AVENGER_TWOHAND_AXE)
			|| EquipNumSearch(ITEM_ID_AVENGER_BLOODYROAR)
			|| EquipNumSearch(ITEM_ID_AVENGER_JAMADHAR)
			|| EquipNumSearch(ITEM_ID_AVENGER_HUNTERBOW)
			|| EquipNumSearch(ITEM_ID_AVENGER_WIZARDSTUFF)
			|| EquipNumSearch(ITEM_ID_AVENGER_HANDGUN)
			|| EquipNumSearch(ITEM_ID_AVENGER_RIFLE)
			|| EquipNumSearch(ITEM_ID_AVENGER_GATLINGGUN)
			|| EquipNumSearch(ITEM_ID_AVENGER_SHOTGUN)
			|| EquipNumSearch(ITEM_ID_AVENGER_GRENADEGUN)
			|| EquipNumSearch(ITEM_ID_AVENGER_FUMASHURIKEN)) {
			if (n_A_Weapon_ATKplus >= 5) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 10;
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 10;
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　サークレットセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_CIRCLET)) {
			if (n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 4;
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 4;
		}

		//----------------------------------------------------------------
		// 「サバイバルオーブ　マントセット」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_MANT)) {
			if (n_A_SHOULDER_DEF_PLUS >= 5) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_SHOULDER_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GIGANT_BOOTS)) {
			if (n_A_SHOES_DEF_PLUS >= 5) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　アックスセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_AXE)) {
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 30;
		}

		//----------------------------------------------------------------
		// 「アインヘリヤルの鎧」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_EINHERJERNO_YOROI)) {
			if (n_A_BODY_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_BODY_DEF_PLUS >= 8) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
			if (n_A_BODY_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2;
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_GUARDIAN_PROCESSOR)) > 0) {
			if (n_A_HEAD_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 2 * itemCount;
			}
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　ガーディアンユニットセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_UNIT)) > 0) {
			vartmp = 0;

			if (n_A_BODY_DEF_PLUS >= 7) vartmp += 2;
			if (n_A_BODY_DEF_PLUS >= 9) vartmp += 2;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　ガーディアンエンジンセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_ENGINE)) > 0) {
			vartmp = 0;

			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 1;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　ガーディアンブースターセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_BOOSTER)) > 0) {
			vartmp = 0;

			if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_SHOES_DEF_PLUS >= 9) vartmp += 1;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「死霊魔術師のニット帽」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_SHIRYOMAZYUTSUSHINO_NITTOBO)) > 0) {
			vartmp = 0;

			if (n_A_HEAD_DEF_PLUS >= 7) vartmp += 3;
			if (n_A_HEAD_DEF_PLUS >= 9) vartmp += 5;

			n_tok[ITEM_SP_REGIST_RACE_UNDEAD] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「バレルヘルム」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_BARREL_HELM)){
			if (n_A_HEAD_DEF_PLUS >= 8) n_tok[ITEM_SP_REGIST_RACE_HUMAN] += 10;
		}

		//----------------------------------------------------------------
		// 「業風石　ペオースプレートセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_PLATE)) > 0) {
			vartmp = 0;

			if (n_A_BODY_DEF_PLUS >= 7) vartmp += 2;
			if (n_A_BODY_DEF_PLUS >= 9) vartmp += 2;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「業風石　ペオースマントセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_MANT)) > 0) {
			vartmp = 0;

			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 1;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「業風石　ペオースグリーブセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_GREEVE)) > 0) {
			vartmp = 0;

			if (n_A_SHOES_DEF_PLUS >= 7) vartmp += 1;
			if (n_A_SHOES_DEF_PLUS >= 9) vartmp += 1;

			n_tok[ITEM_SP_REGIST_RACE_HUMAN] += vartmp * itemCount;
		}



//================================================================================================================================
//================================================================================================================================
//====
//==== 属性耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_REGIST_ELM_VANITY; idx <= ITEM_SP_REGIST_ELM_UNDEAD; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}



		if(EquipNumSearch(737)) n_tok[60] += n_A_SHOULDER_DEF_PLUS * 3;
		if(EquipNumSearch(957)){
			for(i=0;i<=9;i++) n_tok[60+i] += 30;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 9 && CardNumSearch(403)) n_tok[60] += 5;
		if(n_A_BaseLV <= 79 && EquipNumSearch(1251)) n_tok[60] += 5;
		if(n_A_HEAD_DEF_PLUS >= 8 && EquipNumSearch(1244)) n_tok[61] += 5;
		if(n_A_HEAD_DEF_PLUS >= 2 && EquipNumSearch(1431)){
			var w = ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
			n_tok[61] += w;
			n_tok[62] += w;
			n_tok[63] += w;
			n_tok[64] += w;
		}
		if(n_A_LEFT_DEF_PLUS >= 6 && EquipNumSearch(1455)) n_tok[60] += n_A_LEFT_DEF_PLUS - 5;
		if(n_A_SHOULDER_DEF_PLUS >= 6 && EquipNumSearch(1531)){
			n_tok[60] += 2;
			if(n_A_SHOULDER_DEF_PLUS >= 8) n_tok[60] += 3;
		}
		if(n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7 && EquipNumSearch(1581)) n_tok[60] += 5;
		if(n_A_Weapon_ATKplus >= 7){
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1616) n_tok[61] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1617) n_tok[62] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1618) n_tok[63] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1619) n_tok[64] += 3;
		}
		if(n_A_Weapon2_ATKplus >= 7){
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1616) n_tok[61] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1617) n_tok[62] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1618) n_tok[63] += 3;
			if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1619) n_tok[64] += 3;
		}
		if(EquipNumSearch(1794)) n_tok[60] += n_A_HEAD_DEF_PLUS;
		if(EquipNumSearch(1797)){
			for(var i=61;i<=69;i++) n_tok[i] -= 3;
			if(n_A_SHOES_DEF_PLUS >= 6) n_tok[60] += (n_A_SHOES_DEF_PLUS - 5);
		}
		if(n_A_HEAD_DEF_PLUS >= 8 && EquipNumSearch(1798)) n_tok[64] += 5;
		if(n_A_HEAD_DEF_PLUS >= 9 && EquipNumSearch(1815)) n_tok[61] += 3;
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(1817)) n_tok[63] += 5;
		if(n_A_LEFT_DEF_PLUS >= 7 && EquipNumSearch(1886)){
			for(var i= 60;i<=69;i++) n_tok[i] += (n_A_LEFT_DEF_PLUS - 6) * 2;
		}
		if(GetLowerJobSeriesID(n_A_JOB) == 3 && EquipNumSearch(1913)) n_tok[69] += 10;
		if(n_A_LEFT_DEF_PLUS >= 3 && EquipNumSearch(1914)) n_tok[61] += Math.floor(n_A_LEFT_DEF_PLUS / 3) * 5;
		if(n_A_HEAD_DEF_PLUS >= 8 && EquipNumSearch(1915)) n_tok[62] += 5;
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(1943)) n_tok[60] += n_A_HEAD_DEF_PLUS - 5;
		if(EquipNumSearch(2104)){
			if(n_A_SHOULDER_DEF_PLUS >= 6) n_tok[60] += (n_A_SHOULDER_DEF_PLUS - 5);
		}
		if(n_A_LEFT_DEF_PLUS >= 1){
			for(var i=2144;i<=2152;i++){
				if(EquipNumSearch(i)) n_tok[60 +(i - 2143)] += n_A_LEFT_DEF_PLUS * 2;
			}
			if(EquipNumSearch(2143)) n_tok[60] += n_A_LEFT_DEF_PLUS;
		}
		if(EquipNumSearch(2209)) n_tok[60] += n_A_HEAD_DEF_PLUS;
		if(n_A_Arrow == 2 && EquipNumSearch(2356)) n_tok[63] += -10;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && EquipNumSearch(2452)) n_tok[60] += 20;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && EquipNumSearch(2453)) n_tok[60] += 5;
		if(EquipNumSearch(2548)) n_tok[63] += n_A_SHOES_DEF_PLUS;
		if(EquipNumSearch(2553)) n_tok[61] += n_A_SHOES_DEF_PLUS;
		if(EquipNumSearch(2558)) n_tok[64] += n_A_SHOES_DEF_PLUS;
		if(EquipNumSearch(2563)) n_tok[62] += n_A_SHOES_DEF_PLUS;

		//----------------------------------------------------------------
		// 「包装されなかった人形カード」の、＋９過剰による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_HOSOSARENAKATTA_NINGYO)) {
			if (n_A_SHOULDER_DEF_PLUS >= 9) {
				n_tok[CARD_SP_REGIST_ELM_VANITY] += 10;
				n_tok[CARD_SP_REGIST_ELM_PSYCO] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「マッドハッター」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MAD_HATTER)) {
			n_tok[CARD_SP_REGIST_ELM_DARK] += 5 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「ガーディアンセット」の、＋７過剰による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GUARDIAN_SET)) {
			if (n_A_BODY_DEF_PLUS >= 7
				&& n_A_SHOULDER_DEF_PLUS >= 7
				&& n_A_SHOES_DEF_PLUS >= 7) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「ルドのロールペーパー」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RUDONO_ROLLPAPER)) {
			n_tok[CARD_SP_REGIST_ELM_HOLY] += 2 * n_A_LEFT_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「ユニコーンの兜」の、スキル習得による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_UNICORNNO_KABUTO)) {
			if (SkillSearch(SKILL_ID_FAITH)) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] -= 2 * SkillSearch(SKILL_ID_FAITH);
			}
		}

		//----------------------------------------------------------------
		// 「ユニコーンの兜」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_UNICORNNO_KABUTO)) {
			if (n_A_HEAD_DEF_PLUS >= 8) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] += 5;
				n_tok[CARD_SP_REGIST_ELM_DARK] += 5;
			}
		}

		//----------------------------------------------------------------
		// 「堕天司祭の闇光外套」の、スキル習得による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_DATENSHISAINO_ANKOUGAITO)) {
			if (SkillSearch(SKILL_ID_FAITH)) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] -= 3 * SkillSearch(SKILL_ID_FAITH);
			}
		}

		//----------------------------------------------------------------
		// 「堕天司祭の闇光外套」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_DATENSHISAINO_ANKOUGAITO)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] += 20;
				n_tok[CARD_SP_REGIST_ELM_DARK] += 20;
			}
			if (n_A_SHOULDER_DEF_PLUS >= 9) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] += 10;
				n_tok[CARD_SP_REGIST_ELM_DARK] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「英雄マント」の、精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_EIYU_MANT)){
			n_tok[ITEM_SP_REGIST_ELM_VANITY] += 3 * ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3);
			if (n_A_SHOULDER_DEF_PLUS >= 10) {
				n_tok[ITEM_SP_REGIST_ELM_VANITY] += 20;
			}
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MAGICIAN) {
				n_tok[ITEM_SP_REGIST_ELM_ALL] += 5;
			}
		}

		//----------------------------------------------------------------
		// 「魔呪のマント」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MAZYUNO_MANT)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_REGIST_ELM_WATER] += 30;
				n_tok[ITEM_SP_REGIST_ELM_WIND] += 30;
			}
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 6) {
				n_tok[ITEM_SP_REGIST_ELM_EARTH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「ガーディアンプロセッサ　ガーディアンエンジンセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GUARDIAN_PROCESSOR_GUARDIAN_ENGINE)) > 0) {
			vartmp = 0;

			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 15;
			if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 15;

			n_tok[CARD_SP_REGIST_ELM_HOLY] += vartmp * itemCount;
			n_tok[CARD_SP_REGIST_ELM_DARK] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「マラン海賊団帽」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MARAN_KAIZOKUDANBO) > 0) {
			if (n_A_HEAD_DEF_PLUS >= 8) n_tok[CARD_SP_REGIST_ELM_WIND] += 15;
		}

		//----------------------------------------------------------------
		// 「エンチャント　セイクレッド」の、スキル習得による効果
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_ENCHANT_SACRED)) {
			if (SkillSearch(SKILL_ID_FAITH)) {
				n_tok[CARD_SP_REGIST_ELM_HOLY] -= 15 * CardNumSearch(CARD_ID_ENCHANT_SACRED);
			}
		}


		if(SkillSearch(150)){
			n_tok[60] += SkillSearch(150);
			n_tok[63] += 4 * SkillSearch(150);
		}
		if(SkillSearch(156)) n_tok[66] += 5 * SkillSearch(156);
		if(SkillSearch(487)){
			n_tok[67] += SkillSearch(487);
			n_tok[69] += SkillSearch(487);
		}
		if(SkillSearch(792)){
			if(SkillSearch(791) != 0) n_tok[60 + SkillSearch(791)] += 2 * SkillSearch(792);
		}
		if(n_A_PassSkill2[14] && GetHigherJobSeriesID(n_A_JOB) != 13) n_tok[66] += 5 * n_A_PassSkill2[14];
		if(SkillSearch(814) == 5){
			n_tok[63] += 100;
			n_tok[61] -= 100;
		}
		if(SkillSearch(814) == 14){
			n_tok[61] += 100;
			n_tok[64] -= 100;
		}
		if(SkillSearch(814) == 23){
			n_tok[64] += 100;
			n_tok[62] -= 100;
		}
		if(SkillSearch(814) == 32){
			n_tok[62] += 100;
			n_tok[63] -= 100;
		}
		if(n_A_PassSkill3[7]){
			for(i=61;i<=69;i++) n_tok[i] += 55 + 5 * n_A_PassSkill3[7];
			for(i=150;i<=159;i++) n_tok[i] += 10 * n_A_PassSkill3[7];
		}
		if(n_A_PassSkill7[11]){
			n_tok[61] += 20;
			n_tok[64] -= 15;
		}
		if(n_A_PassSkill7[12]){
			n_tok[62] += 20;
			n_tok[63] -= 15;
		}
		if(n_A_PassSkill7[13]){
			n_tok[63] += 20;
			n_tok[61] -= 15;
		}
		if(n_A_PassSkill7[14]){
			n_tok[64] += 20;
			n_tok[62] -= 15;
		}
		if(n_tok[264] != 0){
			for(var i=60;i<=69;i++) n_tok[i] += n_tok[264];
		}
		if(EquipNumSearch(1324)) for(var i=60;i<=69;i++) n_tok[i] += 5;






		if(n_tok[271] != 0){
			for(var i=330;i<=339;i++) n_tok[i] += n_tok[271];
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== サイズ耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_REGIST_SIZE_SMALL; idx <= ITEM_SP_REGIST_SIZE_LARGE; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}




		if(EquipNumSearch(624)) n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += n_A_Weapon_ATKplus;
		if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(1685)) n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 5;
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(2120)){
			n_tok[ITEM_SP_REGIST_SIZE_SMALL] += n_A_HEAD_DEF_PLUS - 5;
			n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += n_A_HEAD_DEF_PLUS - 5;
			n_tok[ITEM_SP_REGIST_SIZE_LARGE] += n_A_HEAD_DEF_PLUS - 5;
			if(n_A_HEAD_DEF_PLUS >= 10){
				n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 5;
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 5;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 5;
			}
		}
		if(EquipNumSearch(2336)) n_tok[192] += 2 * n_A_LEFT_DEF_PLUS;
		if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(2454)){
			n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 20;
			n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 20;
			n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 20;
		}
		if(EquipNumSearch(2456)) n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += n_A_Weapon_ATKplus;

		//----------------------------------------------------------------
		// 「スティングのシルクリボン」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_STINGNO_SILKRIBBON)){

			if(n_A_HEAD_DEF_PLUS >= 5){
				n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 2;
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 2;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 2;
			}

			if(n_A_HEAD_DEF_PLUS >= 7){
				n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 3;
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 3;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 3;
			}

			if(EquipNumSearch(ITEM_ID_SHINKUNO_BARA)){
				n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 5;
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 5;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 5;
			}

			if(CardNumSearch(CARD_ID_STING)){
				n_tok[ITEM_SP_REGIST_SIZE_SMALL] += 10;
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 10;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　シールドセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_SHIELD)) {
			if (n_A_LEFT_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 2;
			if (n_A_LEFT_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 3;
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_SWORDMAN) {
				n_tok[ITEM_SP_REGIST_SIZE_MEDIUM] += 3;
				n_tok[ITEM_SP_REGIST_SIZE_LARGE] += 5;
			}
		}




//================================================================================================================================
//================================================================================================================================
//====
//==== 遠距離攻撃耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(SkillSearch(421)) {
			n_tok[ITEM_SP_REGIST_LONGRANGE] += 20;
		}
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(1898)) {
			n_tok[ITEM_SP_REGIST_LONGRANGE] += n_A_HEAD_DEF_PLUS - 5;
		}
		if(n_A_LEFT_DEF_PLUS >= 6 && EquipNumSearch(1965)){
			n_tok[ITEM_SP_REGIST_LONGRANGE] += n_A_LEFT_DEF_PLUS - 5;
			n_tok[196] -= (n_A_LEFT_DEF_PLUS - 5);
		}
		if(EquipNumSearch(1999)) {
			n_tok[ITEM_SP_REGIST_LONGRANGE] += n_A_SHOULDER_DEF_PLUS;
		}
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(2184)){
			n_tok[ITEM_SP_REGIST_LONGRANGE] += 3;
			if(n_A_HEAD_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_REGIST_LONGRANGE] += 4;
			}
		}

		//----------------------------------------------------------------
		// 「執行者のマント」の、ギロチンクロス装備時の強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SHIKKOSHANO_MANT)) {
			if (n_A_JOB == 47) {

				// 効果本体
				n_tok[ITEM_SP_REGIST_LONGRANGE] += 20;
				if (n_A_SHOULDER_DEF_PLUS >= 7) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] += 15;
				}

				// 特定装備の効果打消し
				if (EquipNumSearch(ITEM_ID_IMUKENO_OSODE)) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] -= 35;
				}
				if (CardNumSearch(CARD_ID_HORN)) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] -= 35;
				}
			}
		}

		//----------------------------------------------------------------
		// 「与一の肩掛け」の、レンジャー装備時の強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_YOICHINO_KATAKAE)) {
			if (n_A_JOB == 49) {

				// 効果本体
				n_tok[ITEM_SP_REGIST_LONGRANGE] += 20;
				if (n_A_SHOULDER_DEF_PLUS >= 7) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] += 15;
				}

				// 特定装備の効果打消し
				if (EquipNumSearch(ITEM_ID_IMUKENO_OSODE)) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] -= 35;
				}
				if (CardNumSearch(CARD_ID_HORN)) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] -= 35;
				}
			}
		}

		//----------------------------------------------------------------
		// 「射向の大袖」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_IMUKENO_OSODE)) {
			if (n_A_LEFT_DEF_PLUS >= 5) n_tok[ITEM_SP_REGIST_LONGRANGE] += 5;
			if (n_A_LEFT_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_LONGRANGE] += 10;
			if (n_A_LEFT_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_LONGRANGE] += 15;
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ARCHER) {
				// 黄色いスカーフと同時に装備すると効果なし
				if (EquipNumSearch(ITEM_ID_KIROI_SCARF) == 0) {
					n_tok[ITEM_SP_REGIST_LONGRANGE] += 10;
				}
			}
		}

		//----------------------------------------------------------------
		// 「業風石　ペオースマントセット」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_GOFUSEKI_PEORTH_MANT)) > 0) {
			vartmp = 0;

			if (n_A_SHOULDER_DEF_PLUS >= 7) vartmp += 10;
			if (n_A_SHOULDER_DEF_PLUS >= 9) vartmp += 10;

			n_tok[ITEM_SP_REGIST_LONGRANGE] += vartmp * itemCount;
		}

		//----------------------------------------------------------------
		// 「[ECO] サラマンダー・アルマカード」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (CardNumSearch(CARD_ID_ECO_SALAMANDER_ARMA)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_LONGRANGE] += 10;
		}



//================================================================================================================================
//================================================================================================================================
//====
//==== ボスモンスターから受けるダメージ－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_REGIST_BOSS; idx <= ITEM_SP_REGIST_BOSS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}



		if(EquipNumSearch(1030)){
			n_tok[77] -= (5 * EquipNumSearch(1030));
			n_tok[79] -= (5 * EquipNumSearch(1030));
		}
		if(n_A_HEAD_DEF_PLUS >= 6 && EquipNumSearch(1650)) n_tok[79] += n_A_HEAD_DEF_PLUS - 5;
		if(EquipNumSearch(1627)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[79] -= 5;
			if(n_A_Weapon_ATKplus >= 7) n_tok[79] -= 5;
		}
		if(EquipNumSearch(1748) || EquipNumSearch(1749)) n_tok[77] += Math.floor(n_A_LEFT_DEF_PLUS / 3);
		if(EquipNumSearch(1754) || EquipNumSearch(1755)) n_tok[77] += Math.floor(n_A_BODY_DEF_PLUS / 2);

		//----------------------------------------------------------------
		// 「ギガントブーツ　ランスセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_LANCE)) {
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_REGIST_BOSS] += 20;
			if (n_A_Weapon_ATKplus >= 9) n_tok[ITEM_SP_REGIST_BOSS] += 30;
		}

		//----------------------------------------------------------------
		// 「ギガントブーツ　シールドセット」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_GIGANT_BOOTS_GIGANT_SHIELD)) {
			if (n_A_LEFT_DEF_PLUS >= 7) n_tok[ITEM_SP_REGIST_BOSS] += 2;
			if (n_A_LEFT_DEF_PLUS >= 9) n_tok[ITEM_SP_REGIST_BOSS] += 3;
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_MERCHANT) {
				n_tok[ITEM_SP_REGIST_NOTBOSS] += 3;
				n_tok[ITEM_SP_REGIST_BOSS] += 5;
			}
		}

		//----------------------------------------------------------------
		// 「シュタール・フォン・カイザー６１世」の、「キューペット　ジルタス」による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_STAHL_VON_KAISER_61)) {
			if (n_A_PassSkill8[0] == 14) {
				n_tok[ITEM_SP_REGIST_BOSS] += 5;

				if (n_A_PassSkill8[17] >= 6) {
					n_tok[ITEM_SP_REGIST_BOSS] += 5;
				}
			}
		}



//================================================================================================================================
//================================================================================================================================
//====
//==== ヒール回復量＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		n_tok[91] += n_tok[94] + n_tok[95];
		if(SkillSearch(269)) n_tok[91] += SkillSearch(269) * 2;
		if(SkillSearch(796)) n_tok[91] += 30 * SkillSearch(796);
		if(EquipNumSearch(644)) n_tok[91] += Math.floor(n_A_Weapon_ATKplus * 1.5);
		if(EquipNumSearch(1085)){
			if(n_A_Weapon_ATKplus >= 7) n_tok[91] += 5;
			if(n_A_Weapon_ATKplus >= 10) n_tok[91] += 10;
			if(n_A_Weapon_ATKplus >= 7){
				if(n_A_Weapon_ATKplus <= 10) n_tok[91] += 2 * (n_A_Weapon_ATKplus - 5);
				else n_tok[91] += 10;
			}
		}
		if(EquipNumSearch(1161) || EquipNumSearch(ITEM_ID_TATSUZINNO_TSUCHI_S2)) {
			n_tok[91] += SkillSearch(23);
		}
		if(EquipNumSearch(1359)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[91] += 3;
			if(EquipNumSearch(644)) n_tok[91] += n_A_Weapon_ATKplus;
			if(EquipNumSearch(863)) n_tok[91] += 3 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「魔法石の恩恵」の、装備効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MAHOSEKINO_ONKE)) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_tok[91] += 3;
			if (n_A_HEAD_DEF_PLUS >= 7) n_tok[91] += 5;
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[91] += 7;
			if (CardNumSearch(119) > 0) n_tok[91] += 10;
		}

		//----------------------------------------------------------------
		// 「ロザリオの首飾り　聖職者の看護帽セット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_ROSARIONO_KUBIKAZARI_SEISHOKUSHANO_KANGOBO)) {
			n_tok[91] += 2 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「ソヒョンの羽衣」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SOHIONNO_HAGOROMO)) {
			n_tok[91] += 1 * n_A_SHOULDER_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「熾天使の花冠」の、強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SHITENSHINO_HANAKANMURI)) {
			n_tok[91] += 1 * ROUNDDOWN(SU_INT / 8);
			if (SU_INT >= 108) n_tok[91] += 5;
			if (SU_INT >= 120) n_tok[91] += 10;
		}

		//----------------------------------------------------------------
		// 「皇竜の天翼」の、職業による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_KORYUNO_TENYOKU)) {
			if (GetLowerJobSeriesID(n_A_JOB) == JOB_SERIES_ID_ACOLYTE) {
				n_tok[91] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「セイヴザキング」の、騎兵修練【未習得】時における、過剰精錬による効果
		//----------------------------------------------------------------
		if (SkillSearch(78) == 0) {
			if (EquipNumSearch(ITEM_ID_SAVE_THE_KING)) {
				if (n_A_Weapon_ATKplus >= 6) {
					n_tok[91] += 40;
					n_tok[92] += 15;
				}
				if (n_A_Weapon_ATKplus >= 8) {
					n_tok[91] += 40;
					n_tok[92] += 15;
				}
			}
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 8) {
				if (SU_VIT >= 90) {
					n_tok[92] += 10;
				}
			}
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　グラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_GLASS)) > 0) {
			n_tok[91] += 10 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「暴徒のスカーフ　サングラスセット」の、素ＩＮＴと素ＤＥＸによる効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_BOTONO_SCARF_SUNGLASS)) > 0) {
			n_tok[91] += 10 * ROUNDDOWN((SU_INT + SU_DEX) / 80) * itemCount;
		}

		//----------------------------------------------------------------
		// 「[ECO] ミニー・ドゥ・アルマカード」の、精錬による効果
		//----------------------------------------------------------------
		cardCountRight = CardNumSearch(CARD_ID_ECO_MINIY_DO_ARMA, CARD_REGION_ID_ARMS_RIGHT_ANY);
		cardCountLeft = CardNumSearch(CARD_ID_ECO_MINIY_DO_ARMA, CARD_REGION_ID_ARMS_LEFT_ANY);
		if ((cardCountRight > 0) || (cardCountLeft > 0)) {
			n_tok[91] += 1 * n_A_Weapon_ATKplus * cardCountRight;
			n_tok[91] += 1 * n_A_Weapon2_ATKplus * cardCountLeft;
		}

		//----------------------------------------------------------------
		// 「ヴァルゴ」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_VIRGO, CARD_REGION_ID_HEAD_TOP_ANY)) > 0) {
			// アークビショップ限定の効果
			if (n_A_JOB == JOB_ID_ARCBISHOP) {
				n_tok[91] += 2 * n_A_HEAD_DEF_PLUS * cardCount;
			}
		}

		//----------------------------------------------------------------
		// 「アークビショップマーガレッタ(MVP)カード」の、職業による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_ARCH_BISHOP_MARGARETTE_MVP)) > 0) {
			if (n_A_JOB == JOB_ID_ARCBISHOP) {
				n_tok[91] += 15 * cardCount;
			}
		}



		if(EquipNumSearch(1469)){
			if(n_A_BODY_DEF_PLUS >= 5) n_tok[91] += Math.floor((n_A_BODY_DEF_PLUS - 5) / 2) * 2 + 2;
			n_tok[92] += Math.floor(n_A_BODY_DEF_PLUS / 2);
		}
		if(n_A_BaseLV <= 79 && EquipNumSearch(1533)) n_tok[92] += 5;
		if(n_A_Weapon_ATKplus >= 7 && n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7){
			if(EquipNumSearch(1563) || EquipNumSearch(1565)) n_tok[91] += 10;
		}
		if(EquipNumSearch(1695)) if(GetLowerJobSeriesID(n_A_JOB)==3 || GetLowerJobSeriesID(n_A_JOB)==5) n_tok[91] += 7;
		if(EquipNumSearch(1752) || EquipNumSearch(1753)) n_tok[92] += Math.floor(n_A_SHOULDER_DEF_PLUS / 3);
		if(EquipNumSearch(1698)) n_tok[91] += 6 * n_A_Weapon_ATKplus;
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1927)) n_tok[91] += 10;
		if(EquipNumSearch(2244)){
			n_tok[91] += 2 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 2);
			if(EquipNumSearch(2246)) n_tok[91] += 3 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		}
		if(EquipNumSearch(2282)) n_tok[91] += 2 * n_A_HEAD_DEF_PLUS;
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(2519)){
			n_tok[91] += 6;
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[91] += 9;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[91] += 12;
		}
		if(n_A_Weapon_ATKplus >= 1 && EquipNumSearch(2520)) n_tok[91] += 4 * n_A_Weapon_ATKplus;
		if(GetLowerJobSeriesID(n_A_JOB)==3 && n_A_card[CARD_REGION_ID_HEAD_TOP]==623) n_tok[91] += Math.floor(n_A_HEAD_DEF_PLUS / 2);
		if(CardNumSearch(826)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[91] += 2 * CardNumSearch(826);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[91] += 2 * CardNumSearch(826);
		}
		if(EquipNumSearch(2491)){
			if(n_A_BaseLV >= 99 || n_B_TAISEI[38] == 1) n_tok[91] -= 150;
			else{
				n_tok[91] -= 10 * ROUNDDOWN(n_A_BaseLV / 10);
				n_tok[92] += 10 * ROUNDDOWN(n_A_BaseLV / 10);
			}
		}
		if(CardNumSearch(827)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[92] += 1 * CardNumSearch(827);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[92] += 1 * CardNumSearch(827);
		}
		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[11] != 0) n_tok[91] += n_A_PassSkill10[11];
		n_tok[91] += n_tok[248];





//================================================================================================================================
//================================================================================================================================
//====
//==== 状態異常耐性　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(EquipNumSearch(534) || EquipNumSearch(1646) || EquipNumSearch(1717)){
			var wSPVS = GetLowerJobSeriesID(n_A_JOB);
			if(wSPVS==1 || wSPVS==2 || wSPVS==6) n_tok[ITEM_SP_REGIST_STATE_STUN] += 50;
			if(wSPVS==3 || wSPVS==4 || wSPVS==5) n_tok[ITEM_SP_REGIST_STATE_SILENCE] += 50;
		}
		if(EquipNumSearch(828)){
			n_tok[ITEM_SP_REGIST_STATE_STUN] += 2 * n_A_HEAD_DEF_PLUS;
			n_tok[ITEM_SP_REGIST_STATE_FROZEN] += 2 * n_A_HEAD_DEF_PLUS;
			n_tok[ITEM_SP_REGIST_STATE_STONE] += 2 * n_A_HEAD_DEF_PLUS;
		}

		//----------------------------------------------------------------
		// 「マッドハッター」の、職業ごとの効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_MAD_HATTER)) {
			var stateid = 0;
			switch (GetLowerJobSeriesID(n_A_JOB)) {
			case JOB_SERIES_ID_NOVICE:
				stateid = ITEM_SP_REGIST_STATE_FROZEN;
				break;
			case JOB_SERIES_ID_SWORDMAN:
				stateid = ITEM_SP_REGIST_STATE_CURSED;
				break;
			case JOB_SERIES_ID_THIEF:
				stateid = ITEM_SP_REGIST_STATE_BLIND;
				break;
			case JOB_SERIES_ID_ACOLYTE:
				stateid = ITEM_SP_REGIST_STATE_STONE;
				break;
			case JOB_SERIES_ID_ARCHER:
				stateid = ITEM_SP_REGIST_STATE_SLEEP;
				break;
			case JOB_SERIES_ID_MAGICIAN:
				stateid = ITEM_SP_REGIST_STATE_BLEEDING;
				break;
			case JOB_SERIES_ID_MERCHANT:
				stateid = ITEM_SP_REGIST_STATE_POISON;
				break;
			case JOB_SERIES_ID_TAEGKUON:
				stateid = ITEM_SP_REGIST_STATE_STUN;
				break;
			case JOB_SERIES_ID_NINJA:
				stateid = ITEM_SP_REGIST_STATE_SILENCE;
				break;
			case JOB_SERIES_ID_GUNSLINGER:
				stateid = ITEM_SP_REGIST_STATE_CONFUSE;
				break;
			}

			if (stateid != 0) {
				if (n_A_HEAD_DEF_PLUS < 5) {
					n_tok[stateid] += 20;
				}
				else if (n_A_HEAD_DEF_PLUS < 7) {
					n_tok[stateid] += 50;
				}
				else {
					n_tok[stateid] += 100;
				}
			}
		}

		//----------------------------------------------------------------
		// 「ジェミニ-S58の目」の、素ＡＧＩ９０以上の効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_GEMINIS58NO_ME)){
			if (SU_AGI >= 90) {
				n_tok[ITEM_SP_REGIST_STATE_STUN] += 30;
				n_tok[ITEM_SP_REGIST_STATE_SILENCE] += 30;
			}
		}

		//----------------------------------------------------------------
		// 「勇者の怒りセット」の、精錬による強化
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_YUSHANOIKARI_ORCISH_AXE_ORCISH_SWORD)) {
			if (n_A_Weapon_ATKplus + n_A_Weapon2_ATKplus >= 20) {
				n_tok[ITEM_SP_REGIST_STATE_STUN] += 100;
			}
		}

		//----------------------------------------------------------------
		// 「アインヘリヤルの鎧　イビルドルイドカードセット」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_EINHERJERNO_YOROI_EVIL_DRUID_CARD)){
			if (n_A_BODY_DEF_PLUS >= 9) {
				n_tok[ITEM_SP_REGIST_STATE_CURSED] += 100;
			}
		}

		//----------------------------------------------------------------
		// 「魔眼のアムダライスカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_MAGANNO_AMDARAIS)) > 0) {
			if (n_A_BODY_DEF_PLUS >= 9) {
				n_tok[ITEM_SP_REGIST_STATE_FROZEN] += 100;
			}
		}

		if(CardNumSearch(176)){
			if(SU_AGI >= 90){
				n_tok[ITEM_SP_REGIST_STATE_STUN] += 30 * CardNumSearch(176);
				n_tok[ITEM_SP_REGIST_STATE_SILENCE] += 30 * CardNumSearch(176);
			}
			if(SU_VIT >= 80){
				n_tok[ITEM_SP_REGIST_STATE_SLEEP] += 50 * CardNumSearch(176);
				n_tok[ITEM_SP_REGIST_STATE_STONE] += 50 * CardNumSearch(176);
			}
		}
		if(n_A_PassSkill8[0] == 42 && EquipNumSearch(1218)) n_tok[ITEM_SP_REGIST_STATE_STUN] += 10;
		if(n_A_PassSkill8[0] == 21 && EquipNumSearch(1464)){
			var wDH = GetLowerJobSeriesID(n_A_JOB);
			if(wDH==3 || wDH==4 || wDH==5){
				n_tok[ITEM_SP_REGIST_STATE_STUN] += 5;
				if(n_A_PassSkill8[17] == 6) n_tok[ITEM_SP_REGIST_STATE_STUN] += 15;
			}
		}
		if(n_A_BODY_DEF_PLUS >= 9 && EquipNumSearch(2455)) n_tok[ITEM_SP_REGIST_STATE_FROZEN] += 100;
		if(SkillSearch(814) == 35){
			n_tok[ITEM_SP_REGIST_STATE_BLEEDING] += 100;
			n_tok[ITEM_SP_REGIST_STATE_STONE] += 100;
		}
		n_tok[ITEM_SP_REGIST_STATE_FROZEN] += n_tok[249];





//================================================================================================================================
//================================================================================================================================
//====
//==== ＤＥＦ無視　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[12] != 0) n_tok[290] += n_A_PassSkill10[12];

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]) {
		case 1076:
		case 1077:
			if(n_A_Weapon2_ATKplus >= 5) n_tok[307] += 10;
			if(n_A_Weapon2_ATKplus >= 7) n_tok[307] += 15;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1076:
		case 1077:
		case 1080:
		case 1081:
		case 1086:
		case 1088:
		case 1089:
		case 1090:
		case 1092:
		case 1093:
		case 1097:
		case 1098:
		case 1099:
		case 1100:
		case 1101:
		case 1102:
		case 1103:
			if(n_A_Weapon_ATKplus >= 5) n_tok[307] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[307] += 15;
		}

		switch (n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]) {
		case 1082:
		case 1087:
		case 1094:
		case 1096:
			if(n_A_Weapon_ATKplus >= 5) n_tok[307] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[307] += 20;
		}

		//----------------------------------------------------------------
		// 「リス耳フード帽」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_RISUMIMI_HOODBO)) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_tok[ITEM_SP_IGNORE_DEF_RACE_ALL] += 20;
			if (n_A_HEAD_DEF_PLUS >= 7) n_tok[ITEM_SP_IGNORE_DEF_RACE_ALL] += 30;
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[ITEM_SP_IGNORE_DEF_RACE_ALL] += 40;
		}

		//----------------------------------------------------------------
		// 「勇者の靴　達人の槌　セット」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI)) > 0) {
			n_tok[ITEM_SP_IGNORE_DEF_RACE_UNDEAD] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_IGNORE_DEF_RACE_DEMON] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_IGNORE_DEF_RACE_HUMAN] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
		}
		if ((itemCount = EquipNumSearch(ITEM_SET_ID_YUSHANO_KUTSU_TATSUZINNO_TSUCHI_S2)) > 0) {
			n_tok[ITEM_SP_IGNORE_DEF_RACE_UNDEAD] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_IGNORE_DEF_RACE_DEMON] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
			n_tok[ITEM_SP_IGNORE_DEF_RACE_HUMAN] += 10 * LearnedSkillSearch(SKILL_ID_MACE_SHUREN) * itemCount;
		}




//================================================================================================================================
//================================================================================================================================
//====
//==== ＭＤＥＦ無視　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(EquipNumSearch(645)) n_tok[295] += 10 + n_A_Weapon_ATKplus;

		//----------------------------------------------------------------
		// 「レクイエムウィザードスタッフ」の、＋６以上の精錬によるＭＤＥＦ無視効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_REQUIEM_WIZARDSTUFF)) {
			if (n_A_Weapon_ATKplus >= 6) n_tok[295] += 10 * (n_A_Weapon_ATKplus - 5);
		}

		//----------------------------------------------------------------
		// 「ポロロッカシューズ　ラクリマセット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_POROROCA_SHOES_LACRYMA_STICK)) {

			// フロストノヴァ習得レベルによる強化
			n_tok[295] += 5 * LearnedSkillSearch(SKILL_ID_FROST_NOVA);
		}

		//----------------------------------------------------------------
		// 「アヴェンジャーウィザードスタッフ」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_AVENGER_WIZARDSTUFF)) {
			n_tok[ITEM_SP_IGNORE_MDEF_RACE_HUMAN] += 5 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「ひまわり少年」の、スキル習得による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HIMAWARI_SHONEN)) > 0) {
			if (LearnedSkillSearch(SKILL_ID_SIGHT_RASHER) >= 10) {
				n_tok[295] += 5 * n_A_Weapon_ATKplus;
			}
		}




		if(n_A_WeaponType==9) n_tok[295] += 2 * CardNumSearch(466);
		if(n_B[20]==1 && CardNumSearch(425)) n_tok[297] += 30 * CardNumSearch(425);
		if(EquipNumSearch(936)) n_tok[295] += (n_A_Weapon_ATKplus * 1);
		if(n_B[20]==1 && EquipNumSearch(1228)){
			if(n_A_HEAD_DEF_PLUS >= 6) n_tok[297] += (n_A_HEAD_DEF_PLUS - 5);
		}

		// 「シャドウスタッフ」の、スキル習得による効果
		if(EquipNumSearch(ITEM_ID_SHADOW_STUFF)){
			if (LearnedSkillSearch(SKILL_ID_HELL_INFERNO) >= 5) {
				n_tok[295] += (n_A_Weapon_ATKplus * 5);
			}
		}


		if(EquipNumSearch(2429)) n_tok[295] += 8 * Math.floor(n_A_Weapon_ATKplus / 3);
		if(n_A_PassSkill10[0] == 0 && n_A_PassSkill10[13] != 0) n_tok[295] += n_A_PassSkill10[13];
		if(n_B[20] == 1) n_tok[295] += n_tok[297];
		if(EquipNumSearch(1084) || EquipNumSearch(1095)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[317] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[317] += 20;
		}
		if(EquipNumSearch(1083)){
			if(n_A_Weapon_ATKplus >= 5) n_tok[317] += 10;
			if(n_A_Weapon_ATKplus >= 7) n_tok[317] += 15;
		}
		n_tok[ITEM_SP_CRITICAL_DAMAGE_UP] += n_tok[320+n_B[19]];



//================================================================================================================================
//================================================================================================================================
//====
//==== 属性モンスターから受けるダメージ－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

// TODO : ここでいいのか？


		//----------------------------------------------------------------
		// 「古びたミトラ」の、精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_FURUBITA_MITRA)) {
			n_tok[337] += 1 * n_A_HEAD_DEF_PLUS;
			n_tok[339] += 1 * n_A_HEAD_DEF_PLUS;
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 属性魔法で与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(n_A_Weapon_ATKplus >= 7 && n_A_BODY_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7){
			if(EquipNumSearch(1535)){
				n_tok[344] += 10;
				n_tok[342] += -15;
				n_tok[62] += -25;
			}
			if(EquipNumSearch(1537)){
				n_tok[344] += 10;
				n_tok[342] += -20;
				n_tok[62] += -20;
			}
			if(EquipNumSearch(1542)){
				n_tok[341] += 10;
				n_tok[344] += -15;
				n_tok[64] += -25;
			}
			if(EquipNumSearch(1544)){
				n_tok[341] += 10;
				n_tok[344] += -20;
				n_tok[64] += -20;
			}
			if(EquipNumSearch(1549)){
				n_tok[343] += 10;
				n_tok[341] += -15;
				n_tok[61] += -25;
			}
			if(EquipNumSearch(1551)){
				n_tok[343] += 10;
				n_tok[341] += -20;
				n_tok[61] += -20;
			}
			if(EquipNumSearch(1556)){
				n_tok[342] += 10;
				n_tok[343] += -15;
				n_tok[63] += -25;
			}
			if(EquipNumSearch(1558)){
				n_tok[342] += 10;
				n_tok[343] += -20;
				n_tok[63] += -20;
			}
		}
		if(n_A_SHOULDER_DEF_PLUS >= 7 && 1902 <= n_A_Equip[EQUIP_REGION_ID_SHOULDER] && n_A_Equip[EQUIP_REGION_ID_SHOULDER] <= 1905) n_tok[341 + n_A_Equip[EQUIP_REGION_ID_SHOULDER] - 1902] += 3;
		if(n_A_HEAD_DEF_PLUS >= 9 && 740 <= n_A_card[CARD_REGION_ID_HEAD_TOP] && n_A_card[CARD_REGION_ID_HEAD_TOP] <= 749) n_tok[340 + n_A_card[CARD_REGION_ID_HEAD_TOP] - 740] += 5;
		if(CardNumSearch(784)) n_tok[342] += 3 * n_A_SHOULDER_DEF_PLUS;
		if(CardNumSearch(883)) n_tok[343] += 3 * n_A_SHOULDER_DEF_PLUS;
		if(EquipNumSearch(2528)) n_tok[347] += 2 * n_A_BODY_DEF_PLUS;

		//----------------------------------------------------------------
		// 「ポロロッカシューズ」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_POROROCA_SHOES)) {
			if (n_A_SHOES_DEF_PLUS >= 5) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_WATER] += 3;
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_WATER] += 5;
		}

		//----------------------------------------------------------------
		// 「ポロロッカシューズ　ラクリマセット」の、精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_SET_ID_POROROCA_SHOES_LACRYMA_STICK)) {
			// ラクリマスティックの精錬による強化
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_WATER] += 4 * n_A_Weapon_ATKplus;
		}

		//----------------------------------------------------------------
		// 「堕天司祭の闇光外套」の、過剰精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_DATENSHISAINO_ANKOUGAITO)) {
			if (n_A_SHOULDER_DEF_PLUS >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_VANITY] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「裁きの靴」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_SABAKINO_KUTSU)) {
			if (n_A_SHOES_DEF_PLUS >= 5) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_HOLY] += 3;
			if (n_A_SHOES_DEF_PLUS >= 7) n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_HOLY] += 5;
		}

		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[30]){
			for(var i=340;i<=349;i++) n_tok[i] += n_A_PassSkill9[30];
		}

		//----------------------------------------------------------------
		// 「魔女の祭祀帽」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_MAZYONO_SAISHIBO)) > 0) {
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_DARK] += 3 * ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2) * itemCount;
		}

		//----------------------------------------------------------------
		// 「不滅のウィンドゴーストカード」の、精錬による効果
		//----------------------------------------------------------------
		if ((cardCount = CardNumSearch(CARD_ID_FUMETSUNO_WINDGHOST)) > 0) {
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_WIND] += 3 * n_A_SHOULDER_DEF_PLUS * cardCount;
		}

		//----------------------------------------------------------------
		// 「超越者のローブ」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_CHOETSUSHANO_ROBE)) > 0) {
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_PSYCO] += 2 * n_A_BODY_DEF_PLUS * itemCount;
		}

		//----------------------------------------------------------------
		// 「ひまわり少年」の、スキル習得による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HIMAWARI_SHONEN)) > 0) {
			if (LearnedSkillSearch(SKILL_ID_SIGHT_RASHER) >= 10) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_FIRE] += 20;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_FIRE] += 3 * n_A_Weapon_ATKplus;
			}
		}



//================================================================================================================================
//================================================================================================================================
//====
//==== 魔法攻撃時、△△属性モンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_VANITY; idx <= ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_UNDEAD; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		if(n_A_Weapon_ATKplus >= 7 && n_A_BODY_DEF_PLUS >= 7 && n_A_SHOULDER_DEF_PLUS >= 7 && n_A_SHOES_DEF_PLUS >= 7){
			if(EquipNumSearch(1570)){
				n_tok[49] += 5;
				n_tok[359] += 5;
			}
			if(EquipNumSearch(1572)){
				n_tok[49] += 15;
				n_tok[359] += 15;
			}
		}
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1789)){
			n_tok[351] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[352] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[353] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[354] += 5 * (n_A_HEAD_DEF_PLUS - 4);
		}
		if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1977)){
			n_tok[353] += 10;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[353] += 15;
		}
		if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(2394)){
			n_tok[355] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[356] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[357] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[358] += 5 * (n_A_HEAD_DEF_PLUS - 4);
			n_tok[359] += 5 * (n_A_HEAD_DEF_PLUS - 4);
		}
		if(n_A_SHOES_DEF_PLUS >= 5 && EquipNumSearch(2503)){
			for(var i=350;i<=354;i++) n_tok[i] += 5;
			if(n_A_SHOES_DEF_PLUS >= 7){
				for(var i=350;i<=354;i++) n_tok[i] += 10;
			}
		}
		if(SkillSearch(487)){
			n_tok[357] += 2 * SkillSearch(487);
			n_tok[359] += 2 * SkillSearch(487);
		}
		if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[29]){
			for(var i=350;i<=359;i++) n_tok[i] += n_A_PassSkill9[29];
		}

		//----------------------------------------------------------------
		// 「迅雷杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_ZINRAI_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_WATER] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_WATER] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「無双杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_MUSO_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_WIND] += 10;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_WIND] += 15;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_EARTH] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「裁きの靴　ホーリーステッキセット」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_SET_ID_SABAKINO_KUTSU_HOLY_STICK)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_DARK] += 30;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_UNDEAD] += 30;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_DARK] += 20;
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_UNDEAD] += 20;
			}
		}

		//----------------------------------------------------------------
		// 「ガイアシールド」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_GAIA_SHIELD) > 0) {
			if (n_A_LEFT_DEF_PLUS >= 6) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_EARTH] += 10;
			}
		}

		//----------------------------------------------------------------
		// 「上忍の腰帯」の、スキル習得による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_ZYONINNO_KOSHIOBI)) > 0) {
			var skllv = 0;
			skllv += LearnedSkillSearch(SKILL_ID_GENZYUTSU_KYOGAKU);
			skllv += LearnedSkillSearch(SKILL_ID_GENZYUTSU_ZYUSATSU);
			skllv += LearnedSkillSearch(SKILL_ID_GENZYUTSU_GENWAKU);
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_DARK] += 4 * skllv * itemCount;
		}

		//----------------------------------------------------------------
		// 「一碧杖」の、過剰精錬による効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_IPPEKI_TSUE)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_FIRE] += 10;
			}
			if (n_A_Weapon_ATKplus >= 9) {
				n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_FIRE] += 15;
			}
		}

		//----------------------------------------------------------------
		// 「火雷大神靴」の、精錬による効果
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_HONOIKADUCHINOOOKAMI_KUTSU)) > 0) {
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_EARTH] += 2 * n_A_SHOES_DEF_PLUS * itemCount;
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_PSYCO] += 2 * n_A_SHOES_DEF_PLUS * itemCount;
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_VANITY] += 2 * n_A_SHOES_DEF_PLUS * itemCount;
			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_UNDEAD] += 2 * n_A_SHOES_DEF_PLUS * itemCount;
		}






//================================================================================================================================
//================================================================================================================================
//====
//==== 魔法攻撃時、△△サイズのモンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_MAGIC_DAMAGE_UP_SIZE_SMALL; idx <= ITEM_SP_MAGIC_DAMAGE_UP_SIZE_LARGE; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== 魔法攻撃時、ボスモンスターに与えるダメージ＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		//----------------------------------------------------------------
		// ランダムエンチャント効果
		//----------------------------------------------------------------
		for (idx = ITEM_SP_MAGIC_DAMAGE_UP_BOSS; idx <= ITEM_SP_MAGIC_DAMAGE_UP_BOSS; idx++) {
			n_tok[idx] += GetRndEnchValue(idx);
		}

		//----------------------------------------------------------------
		// 「海竜の鎧」の、過剰精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_KAIRYUNO_YOROI)) > 0) {
			vartmp = 0;

			if (n_A_BODY_DEF_PLUS >= 7) vartmp += 10;
			if (n_A_BODY_DEF_PLUS >= 9) vartmp += 10;

			n_tok[ITEM_SP_MAGIC_DAMAGE_UP_BOSS] += vartmp * itemCount;
		}





//================================================================================================================================
//================================================================================================================================
//====
//==== スキル使用時の消費ＳＰ－○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

		if(EquipNumSearch(646)) n_tok[102] += (-2 * n_A_Weapon_ATKplus);
		if(EquipNumSearch(765)) if(SU_DEX >= 70) n_tok[102] += 10;
		if(EquipNumSearch(646)) if(n_A_Weapon_ATKplus >= 9) n_tok[102] += 20;
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1078 || n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT] == 1079){
			if(n_A_Weapon2_ATKplus >= 5) n_tok[102] += 5;
			if(n_A_Weapon2_ATKplus >= 7) n_tok[102] += 5;
		}
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1078 || n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT] == 1079){
			if(n_A_Weapon_ATKplus >= 5) n_tok[102] += 5;
			if(n_A_Weapon_ATKplus >= 7) n_tok[102] += 5;
		}
		if(EquipNumSearch(1171) && SkillSearch(234) == 5) n_tok[102] += 15;
		if(EquipNumSearch(1280)) if(n_A_HEAD_DEF_PLUS >= 3) n_tok[102] += n_A_HEAD_DEF_PLUS - 2;
		if(EquipNumSearch(1414)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[102] += 1;
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[102] += 1;
		}
		if(EquipNumSearch(1476)) if(n_A_Weapon_ATKplus >= 6) n_tok[102] += n_A_Weapon_ATKplus - 5;
		if(EquipNumSearch(1760)) if(n_A_HEAD_DEF_PLUS >= 6) n_tok[102] += (n_A_HEAD_DEF_PLUS - 5) * 10;
		if(SU_DEX >= 100 && EquipNumSearch(1787)){
			n_tok[102] += 5;
			if(SU_DEX >= 120) n_tok[102] += 5;
		}
		if(EquipNumSearch(1888) && SkillSearch(4) == 10) n_tok[102] += 5;
		if(EquipNumSearch(2191)) n_tok[102] += 2 * SkillSearch(116);
		if(EquipNumSearch(2208)) n_tok[102] += 2 * n_A_HEAD_DEF_PLUS;
		if(n_A_BODY_DEF_PLUS >= 7 && EquipNumSearch(2250)) n_tok[102] += 5;
		if(EquipNumSearch(2368)){
			if(n_A_SHOES_DEF_PLUS >= 8) n_tok[102] += (n_A_SHOES_DEF_PLUS - 7);
		}
		if(CardNumSearch(831)){
			if(n_A_HEAD_DEF_PLUS >= 7) n_tok[102] += 2 * CardNumSearch(831);
			if(n_A_HEAD_DEF_PLUS >= 9) n_tok[102] += 1 * CardNumSearch(831);
		}
		if(SU_STR >= 108 && EquipNumSearch(2427)){
			n_tok[102] += 20;
			if(SU_STR >= 120) n_tok[102] += 30;
		}
		if(n_A_SHOULDER_DEF_PLUS >= 3 && EquipNumSearch(2488)) n_tok[102] += 2 * ROUNDDOWN(n_A_SHOULDER_DEF_PLUS / 3);

		//----------------------------------------------------------------
		// 「ドゥクス・ティアのティアラ」の、過剰精錬による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_DOKUSTIANO_TIARA)) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_tok[102] += 3 * (n_A_HEAD_DEF_PLUS - 4);
		}

		//----------------------------------------------------------------
		// 「魔法石の恩恵」の、過剰精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_MAHOSEKINO_ONKE)) > 0) {
			if (n_A_HEAD_DEF_PLUS >= 5) n_tok[102] += 25;
			if (n_A_HEAD_DEF_PLUS >= 7) n_tok[102] += 25;
			if (n_A_HEAD_DEF_PLUS >= 9) n_tok[102] += 25;
		}

		//----------------------------------------------------------------
		// 「ヴァルキリーナイフ」の、職業による強化
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
			switch (GetLowerJobSeriesID(n_A_JOB)) {

			// ノービス系
			case JOB_SERIES_ID_NOVICE:
				break;

			// マジシャン系
			case JOB_SERIES_ID_MAGICIAN:
				break;

			// シーフ系
			case JOB_SERIES_ID_THIEF:
				break;

			default:
				switch (GetHigherJobSeriesID(n_A_JOB)) {

				// ハンター系
				case JOB_SERIES_ID_HUNTER:
					n_tok[102] += 5;
					break;

				// バード系、ダンサー系
				case JOB_SERIES_ID_BARD:
				case JOB_SERIES_ID_DANCER:
					break;
				}
			}
		}

		//----------------------------------------------------------------
		// 「テグリョン」の、過剰精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_TEGRYONG)) > 0) {
			if (n_A_Weapon_ATKplus >= 9) n_tok[102] += 20;
		}
		if ((itemCount = EquipNumSearch(ITEM_ID_TEGRYONG_S2)) > 0) {
			if (n_A_Weapon_ATKplus >= 9) n_tok[102] += 20;
		}

		//----------------------------------------------------------------
		// 「海竜の鎧」の、過剰精錬による強化
		//----------------------------------------------------------------
		if ((itemCount = EquipNumSearch(ITEM_ID_KAIRYUNO_YOROI)) > 0) {
			vartmp = 0;

			if (n_A_BODY_DEF_PLUS >= 7) vartmp += 5;
			if (n_A_BODY_DEF_PLUS >= 9) vartmp += 5;

			n_tok[102] += vartmp * itemCount;
		}



		if(CardNumSearch(457)) if(GetHigherJobSeriesID(n_A_JOB) == 14) n_tok[102] += 20;
		if(CardNumSearch(458)) if(GetHigherJobSeriesID(n_A_JOB) == 15) n_tok[102] += 10;
		if(n_A_PassSkill3[6]) n_tok[102] += 20 + n_A_PassSkill3[6] * 3 + Math.floor(n_A_PassSkill3[36] / 2) + n_A_PassSkill3[26];
		if(n_A_PassSkill3[39] == 2){
			if(n_A_PassSkill3[41] <= 6) n_tok[102] -= 15 - 3 * (n_A_PassSkill3[41] - 2);
		}
		if(SkillSearch(757)) n_tok[102] += SkillSearch(757) * 4;
		if(n_tok[102] > 100) n_tok[102] = 100;
		n_tok[102] = 100 - n_tok[102];
		if(SkillSearch(522)) n_tok[102] = n_tok[102] * -1;
		if(SkillSearch(796)){
			n_tok[102] = ROUNDDOWN(n_tok[102] * (200 + 20 * SkillSearch(796)) / 10) / 10;
		}








//================================================================================================================================
//================================================================================================================================
//====
//==== 必中攻撃＋○○％　ここから
//====
//================================================================================================================================
//================================================================================================================================

// TODO : ここでいいのか？


		//----------------------------------------------------------------
		// 「[ECO] ブリキングRX1・アルマカード」の、精錬による効果
		//----------------------------------------------------------------
		cardCountRight = CardNumSearch(CARD_ID_ECO_BURIKING_RX1_ARMA, CARD_REGION_ID_ARMS_RIGHT_ANY);
		cardCountLeft = CardNumSearch(CARD_ID_ECO_BURIKING_RX1_ARMA, CARD_REGION_ID_ARMS_LEFT_ANY);
		if ((cardCountRight > 0) || (cardCountLeft > 0)) {
			if (n_A_Weapon_ATKplus >= 7) n_tok[ITEM_SP_PERFECT_ATTACK_UP] += 5 * cardCountRight;
			if (n_A_Weapon2_ATKplus >= 7) n_tok[ITEM_SP_PERFECT_ATTACK_UP] += 5 * cardCountLeft;
		}

		//----------------------------------------------------------------
		// 「パイルバンカーT」の、精錬による効果
		//----------------------------------------------------------------
		if (EquipNumSearch(ITEM_ID_PILEBUNKER_T)) {
			if (n_A_Weapon_ATKplus >= 7) {
				n_tok[ITEM_SP_PERFECT_ATTACK_UP] += 30;
			}
		}






		if(EquipNumSearch(535)
			|| EquipNumSearch(1647)
			|| EquipNumSearch(1718)
			|| CardNumSearch(CARD_ID_ENCHANT_ENERGY_IKUSAOTOME)){
			var wVM = GetLowerJobSeriesID(n_A_JOB);
			if(wHPVS==1 || wHPVS==2 || wHPVS==6){
				n_tok[71] += 5;
				n_tok[71] += n_A_SHOULDER_DEF_PLUS * 2;
			}
		}
		if(TimeItemNumSearch(52)) n_tok[71] += n_A_LEFT_DEF_PLUS * 3;
		if(EquipNumSearch(1998)) n_tok[71] += 2 * n_A_SHOULDER_DEF_PLUS;
		if(EquipNumSearch(2293)) n_tok[71] += ROUNDDOWN(n_A_SHOES_DEF_PLUS / 2);
		if(EquipNumSearch(2521) && SkillSearch(453)) n_tok[71] += 10;
		n_A_zokusei = new Array();
		for(i=0;i<=9;i++){
			n_A_zokusei[i] = zokusei[n_A_BodyZokusei * 10 +1][i] + 100;
			n_A_zokusei[i] = n_A_zokusei[i] - Math.floor(n_A_zokusei[i] * n_tok[60+i]) / 100;
		}
		ClickB_Enemy();



		// 錐効果の計算
		n_A_QUAKE_KIRI = 0;

		//----------------------------------------------------------------
		// 「古びた迷彩ウサギフード」の、＋１０精錬による、錐効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_FURUBITA_MEISAIUSAGI)) {
			if (n_A_HEAD_DEF_PLUS >= 10) {
				n_tok[23] = 1;
			}
		}

		//----------------------------------------------------------------
		// 「古王の双刃」の、＋１０精錬による、錐効果
		//----------------------------------------------------------------
		if(EquipNumSearch(ITEM_ID_KOONO_SOZIN)) {
			if (n_A_Weapon_ATKplus >= 10) {
				n_tok[23] = 1;
			}
		}


		if((n_tok[23] >= 1 && NumSearch(n_A_ActiveSkill,n_SP_SKILL) == 0)
			|| n_A_ActiveSkill == 193) {
			var ch = 0;
			for(var i=0;i<=9;i++) if(n_tok[180+i] == 1) ch = 1;
			if(n_B[20] == 1){
				if(n_tok[22] >= 10) ch = 1;
			}else if(n_B[20] == 0){
				if(n_tok[22] >= 1) ch = 1;
			}
			if(ch == 0){
				n_tok[17] += Math.floor(n_B[13] / 2);
				n_A_QUAKE_KIRI = Math.floor(n_B[13] / 2);
			}
		}



		KakutyouKansuu();
	}
}





function StPlusCalc() {

	// ジョブ補正の適用
	InitJobInfo();
	n_A_JobLV = eval(document.calcForm.A_JobLV.value);
	var w2 = [0,0,0,0,0,0];
	w2 = GetJobBonus(n_A_JOB, n_A_JobLV);

	//----------------------------------------------------------------
	// スーパーノービスの無死亡ボーナス
	//----------------------------------------------------------------
	if(((n_A_JOB == 20 && n_A_JobLV >= 70) || n_A_JOB == 61) && SkillSearch(SKILL_ID_SUPER_NOVICE_NODEAD_BONUS)){
		for(var i = 0; i < 6; i++) w2[i] += 10;
	}

	// 求めた値を基礎値とする
	var wSPC_STR = w2[0];
	var wSPC_AGI = w2[1];
	var wSPC_VIT = w2[2];
	var wSPC_INT = w2[3];
	var wSPC_DEX = w2[4];
	var wSPC_LUK = w2[5];
	var wSPCall = 0;

	//----------------------------------------------------------------
	// ランダムエンチャント効果
	//----------------------------------------------------------------
	wSPC_STR += GetRndEnchValue(ITEM_SP_STR_PLUS);
	wSPC_AGI += GetRndEnchValue(ITEM_SP_AGI_PLUS);
	wSPC_VIT += GetRndEnchValue(ITEM_SP_VIT_PLUS);
	wSPC_INT += GetRndEnchValue(ITEM_SP_INT_PLUS);
	wSPC_DEX += GetRndEnchValue(ITEM_SP_DEX_PLUS);
	wSPC_LUK += GetRndEnchValue(ITEM_SP_LUK_PLUS);
	wSPCall += GetRndEnchValue(ITEM_SP_ALLSTATUS_PLUS);

	//----------------------------------------------------------------
	// 装備の加算値、全パラメタ上昇効果の加算値を適用
	//----------------------------------------------------------------
	wSPCall += GetEquippedTotalSPEquip(7);
	var wSPCall2 = GetEquippedTotalSPEquip(217);
	wSPC_STR += GetEquippedTotalSPEquip(1) + wSPCall + wSPCall2;
	wSPC_AGI += GetEquippedTotalSPEquip(2) + wSPCall;
	wSPC_VIT += GetEquippedTotalSPEquip(3) + wSPCall;
	wSPC_VIT += GetEquippedTotalSPEquip(213) + wSPCall2;
	wSPC_INT += GetEquippedTotalSPEquip(4) + wSPCall;
	wSPC_INT += GetEquippedTotalSPEquip(214) + wSPCall2;
	wSPC_DEX += GetEquippedTotalSPEquip(5) + wSPCall;
	wSPC_LUK += GetEquippedTotalSPEquip(6) + wSPCall + wSPCall2;

	//----------------------------------------------------------------
	// 「ふくろうの目」の、ＤＥＸ＋効果
	//----------------------------------------------------------------
	wSPC_DEX += SkillSearch(SKILL_ID_FUKURONO_ME);

	//----------------------------------------------------------------
	// 「ラウドボイス」の、ＳＴＲ＋効果
	//----------------------------------------------------------------
	if((SkillSearch(SKILL_ID_LOUD_VOICE) && SkillSearch(SKILL_ID_MADOGEAR) == 0)
		|| TimeItemNumSearch(17)
		|| TimeItemNumSearch(45)
		|| TimeItemNumSearch(58)) {
		wSPC_STR += 4;
	}

	//----------------------------------------------------------------
	// 「ヒルトバインディング」の、ＳＴＲ＋効果
	//----------------------------------------------------------------
	wSPC_STR += SkillSearch(SKILL_ID_HILT_BINDING);

	//----------------------------------------------------------------
	// 「念」の、ＳＴＲ＋、ＩＮＴ＋効果
	//----------------------------------------------------------------
	wSPC_STR += SkillSearch(SKILL_ID_NEN);
	wSPC_INT += SkillSearch(SKILL_ID_NEN);

	//----------------------------------------------------------------
	// 「ドラゴノロジー」の、ＩＮＴ＋効果
	//----------------------------------------------------------------
	if(SkillSearch(SKILL_ID_DRAGONOLOGY)) {
		wSPC_INT += Math.round(SkillSearch(SKILL_ID_DRAGONOLOGY) / 2);
	}

	if(SkillSearch(500)) wSPC_INT += SkillSearch(500);

	if(SkillSearch(286)){
		if(SkillSearch(286)==5)wSPC_STR +=16;
		if(SkillSearch(286)==4)wSPC_STR +=8;
		if(SkillSearch(286)==3)wSPC_STR +=4;
		if(SkillSearch(286)==2)wSPC_STR +=2;
		if(SkillSearch(286)==1)wSPC_STR +=1;
	}
	if(EquipNumSearch(1305)){
		var w = Math.floor(n_A_JobLV / 5);
		if(w > 6) w = 6;
		wSPC_STR -= w;
		wSPC_AGI -= w;
		wSPC_VIT -= w;
		wSPC_INT -= w;
		wSPC_DEX -= w;
		wSPC_LUK -= w;
	}
	var w = SkillSearch(42);
	if(w){
		w += 102;
		wSPC_DEX = Math.floor((n_A_DEX + wSPC_DEX) * w / 100) - n_A_DEX;
		wSPC_AGI = Math.floor((n_A_AGI + wSPC_AGI) * w / 100) - n_A_AGI;
	}else if(TimeItemNumSearch(54)){
		wSPC_DEX = Math.floor((n_A_DEX + wSPC_DEX) * 107 / 100) - n_A_DEX;
		wSPC_AGI = Math.floor((n_A_AGI + wSPC_AGI) * 107 / 100) - n_A_AGI;
	}else if(n_A_PassSkill6[3]){
		wSPC_DEX = Math.floor((n_A_DEX + wSPC_DEX) * (102 + n_A_PassSkill6[3]) / 100) - n_A_DEX;
		wSPC_AGI = Math.floor((n_A_AGI + wSPC_AGI) * (102 + n_A_PassSkill6[3]) / 100) - n_A_AGI;
	}else if(TimeItemNumSearch(31)){
		wSPC_DEX = Math.floor((n_A_DEX + wSPC_DEX) * 104 / 100) - n_A_DEX;
		wSPC_AGI = Math.floor((n_A_AGI + wSPC_AGI) * 104 / 100) - n_A_AGI;
	}else if(TimeItemNumSearch(4)){
		wSPC_DEX = Math.floor((n_A_DEX + wSPC_DEX) * 103 / 100) - n_A_DEX;
		wSPC_AGI = Math.floor((n_A_AGI + wSPC_AGI) * 103 / 100) - n_A_AGI;
	}
	if(SkillSearch(422)){
		wSPC_DEX += 4;
		wSPC_AGI += 4;
	}
	wSPC_AGI += GetEquippedTotalSPEquip(212) + wSPCall2;
	wSPC_DEX += GetEquippedTotalSPEquip(215) + wSPCall2;
	if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(672)) wSPC_AGI += 1;
	if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(673)) wSPC_INT += 1;
	if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(675)) wSPC_LUK += 2;
	if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(676)) wSPC_DEX += 2;
	if(GetLowerJobSeriesID(n_A_JOB)==41 && EquipNumSearch(678)) wSPC_LUK += 1;
	if(n_A_SHOES_DEF_PLUS >= 9 && EquipNumSearch(717)) wSPC_AGI += 2;
	if(n_A_HEAD_DEF_PLUS >= 5 && EquipNumSearch(1069)) wSPC_LUK += (n_A_HEAD_DEF_PLUS - 4);
	if(n_A_Weapon_ATKplus >= 6 && EquipNumSearch(1168)) wSPC_INT += (n_A_Weapon_ATKplus - 5);
	if(EquipNumSearch(1171) && SkillSearch(234) == 5) wSPC_INT += 3;
	if(EquipNumSearch(1172)) wSPC_INT += Math.floor(n_A_Weapon_ATKplus / 2);
	if(n_A_HEAD_DEF_PLUS >= 7 && EquipNumSearch(1273)) wSPC_AGI += 2;
	if(EquipNumSearch(348)) wSPC_STR += Math.floor(n_A_BaseLV / 5) * EquipNumSearch(348);
	if(n_A_BODY_DEF_PLUS >= 2 && EquipNumSearch(1493)) wSPC_AGI += Math.floor(n_A_BODY_DEF_PLUS / 2);
	if(SU_STR >= 60 && EquipNumSearch(1524)){
		wSPC_STR += 2 * EquipNumSearch(1524);
		if(SU_STR >= 80) wSPC_STR += 1 * EquipNumSearch(1524);
	}
	if(SU_AGI >= 60 && EquipNumSearch(1525)){
		wSPC_AGI += 2 * EquipNumSearch(1525);
		if(SU_AGI >= 80) wSPC_AGI += 1 * EquipNumSearch(1525);
	}
	if(SU_VIT >= 60 && EquipNumSearch(1526)){
		wSPC_VIT += 2 * EquipNumSearch(1526);
		if(SU_VIT >= 80) wSPC_VIT += 1 * EquipNumSearch(1526);
	}
	if(SU_DEX >= 60 && EquipNumSearch(1527)){
		wSPC_DEX += 2 * EquipNumSearch(1527);
		if(SU_DEX >= 80) wSPC_DEX += 1 * EquipNumSearch(1527);
	}
	if(SU_INT >= 60 && EquipNumSearch(1528)){
		wSPC_INT += 2 * EquipNumSearch(1528);
		if(SU_INT >= 80) wSPC_INT += 1 * EquipNumSearch(1528);
	}
	if(SU_LUK >= 60 && EquipNumSearch(1529)){
		var w = EquipNumSearch(1529);
		wSPC_LUK += 2 * w;
		if(SU_LUK >= 80){
			wSPC_LUK += w;
			wSPC_DEX += w;
		}
		if(SU_LUK >= 100){
			wSPC_INT += w;
			wSPC_DEX += w;
		}
		if(SU_LUK >= 120){
			wSPC_LUK += w;
			wSPC_DEX += w;
			wSPC_INT += 3 * w;
		}
	}
	if(SU_INT >= 120){
		if(EquipNumSearch(1538) || EquipNumSearch(1545) || EquipNumSearch(1552) || EquipNumSearch(1559)) wSPC_INT += 1;
	}
	if(n_A_SHOES_DEF_PLUS >= 8 && EquipNumSearch(1588)) wSPC_AGI += (n_A_SHOES_DEF_PLUS - 7);
	if(n_A_BaseLV >= 150){
		if(EquipNumSearch(1695)){
			wSPC_STR += 2;
			wSPC_AGI += 2;
			wSPC_VIT += 2;
			wSPC_INT += 2;
			wSPC_DEX += 2;
			wSPC_LUK += 2;
		}
	}
	if(EquipNumSearch(1695)) if(GetLowerJobSeriesID(n_A_JOB)==4) wSPC_DEX += 3;
	if(EquipNumSearch(1743)) wSPC_LUK += n_A_BODY_DEF_PLUS;
	if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==1078 || n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==1079){
		wSPC_INT += (n_A_Weapon_ATKplus -5);
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==1078){
			if(n_A_Weapon_ATKplus >= 7) wSPC_INT += 2;
			if(n_A_Weapon_ATKplus >= 9) wSPC_INT += 3;
		}
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==1079){
			if(n_A_Weapon_ATKplus >= 7) wSPC_INT += 2;
			if(n_A_Weapon_ATKplus >= 9) wSPC_INT += 5;
			if(n_A_Weapon_ATKplus >= 10) wSPC_INT += 3;
		}
	}
	if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]==1078 || n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]==1079){
		wSPC_INT += (n_A_Weapon2_ATKplus -5);
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]==1078){
			if(n_A_Weapon2_ATKplus >= 7) wSPC_INT += 2;
			if(n_A_Weapon2_ATKplus >= 9) wSPC_INT += 3;
		}
		if(n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]==1079){
			if(n_A_Weapon2_ATKplus >= 7) wSPC_INT += 2;
			if(n_A_Weapon2_ATKplus >= 9) wSPC_INT += 5;
			if(n_A_Weapon2_ATKplus >= 10) wSPC_INT += 3;
		}
	}
	if(EquipNumSearch(1766)){
		if(n_A_Weapon_ATKplus >= 1 && n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]==1766){
			wSPC_INT += n_A_Weapon_ATKplus;
			wSPC_LUK += n_A_Weapon_ATKplus;
		}
		if(n_A_Weapon2_ATKplus >= 1 && n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]==1766){
			wSPC_INT += n_A_Weapon2_ATKplus;
			wSPC_LUK += n_A_Weapon2_ATKplus;
		}
	}
	if(n_A_SHOULDER_DEF_PLUS >= 6 && EquipNumSearch(1767)) wSPC_AGI += 2 * (n_A_SHOULDER_DEF_PLUS - 5);
	if(n_A_SHOES_DEF_PLUS >= 6 && EquipNumSearch(1768)) wSPC_INT += n_A_SHOES_DEF_PLUS - 5;

	// 技巧の時空ブーツ
	if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(1921)) {
		wSPC_DEX += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
	}
	if(n_A_SHOES_DEF_PLUS >= 3 && EquipNumSearch(ITEM_ID_GIKONO_ZIKU_BOOTS_S1)) {
		wSPC_DEX += 3 * ROUNDDOWN(n_A_SHOES_DEF_PLUS / 3);
	}

	if(n_A_BODY_DEF_PLUS >= 3 && EquipNumSearch(1992)) wSPC_AGI += ROUNDDOWN(n_A_BODY_DEF_PLUS / 3);
	if(EquipNumSearch(2237)){
		wSPC_VIT += n_A_BODY_DEF_PLUS;
		if(EquipNumSearch(2239)) wSPC_VIT += 5 * n_A_BODY_DEF_PLUS;
	}
	if(EquipNumSearch(2332)){
		if(n_A_BaseLV <= 99) wSPC_DEX += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		else wSPC_DEX += n_A_HEAD_DEF_PLUS;
	}
	if(EquipNumSearch(2334)){
		if(n_A_BaseLV <= 99) wSPC_STR += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		else wSPC_STR += n_A_HEAD_DEF_PLUS;
	}
	if(EquipNumSearch(2338)){
		if(n_A_BaseLV <= 99) wSPC_INT += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		else wSPC_INT += n_A_HEAD_DEF_PLUS;
	}
	if(EquipNumSearch(2365)){
		var tx = ROUNDDOWN(n_A_BODY_DEF_PLUS / 2);
		if(SU_STR >= 90) wSPC_STR += tx;
		if(SU_AGI >= 90) wSPC_AGI += tx;
		if(SU_VIT >= 90) wSPC_VIT += tx;
		if(SU_INT >= 90) wSPC_INT += tx;
		if(SU_DEX >= 90) wSPC_DEX += tx;
		if(SU_LUK >= 90) wSPC_LUK += tx;
	}
	if(EquipNumSearch(2443)){
		var w2443 = 3 * n_A_SHOES_DEF_PLUS;
		wSPC_STR += w2443;
		wSPC_AGI += w2443;
		wSPC_VIT += w2443;
		wSPC_INT += w2443;
		wSPC_DEX += w2443;
		wSPC_LUK += w2443;
	}
	if(CardNumSearch(855)){
		if(n_A_SHOES_DEF_PLUS >= 9 && EquipNumSearch(2451)) wSPC_STR += 8;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && EquipNumSearch(2452)) wSPC_AGI += 8;
		if(n_A_SHOULDER_DEF_PLUS >= 9 && EquipNumSearch(2453)) wSPC_DEX += 10;
		if(n_A_LEFT_DEF_PLUS >= 9 && EquipNumSearch(2454)) wSPC_LUK += 10;
		if(n_A_BODY_DEF_PLUS >= 9 && EquipNumSearch(2455)) wSPC_VIT += 8;
	}
	if(n_A_BaseLV >= 130 && EquipNumSearch(2463)) wSPC_VIT += 4;
	if(EquipNumSearch(1808)){
		wSPC_STR += 10;
		wSPC_AGI += 10;
		wSPC_VIT += 10;
		wSPC_INT += 10;
		wSPC_DEX += 10;
		wSPC_LUK += 10;
	}
	if(EquipNumSearch(649)) wSPC_DEX -= SU_DEX;
	if(n_A_WeaponType==9) wSPC_INT += CardNumSearch(466);
	wSPCall = GetEquippedTotalSPCardAndElse(7) + GetEquippedTotalSPCardAndElse(217);
	wSPC_STR += GetEquippedTotalSPCardAndElse(1) + wSPCall;
	wSPC_AGI += GetEquippedTotalSPCardAndElse(2) + wSPCall;
	wSPC_VIT += GetEquippedTotalSPCardAndElse(3) + wSPCall;
	wSPC_INT += GetEquippedTotalSPCardAndElse(4) + wSPCall;
	wSPC_DEX += GetEquippedTotalSPCardAndElse(5) + wSPCall;
	wSPC_LUK += GetEquippedTotalSPCardAndElse(6) + wSPCall;
	if(GetLowerJobSeriesID(n_A_JOB)==3) wSPC_INT += CardNumSearch(383);
	if(CardNumSearch(173))wSPC_INT += n_A_LEFT_DEF_PLUS;
	if(CardNumSearch(402))wSPC_LUK += n_A_SHOULDER_DEF_PLUS;
	if(CardNumSearch(406))wSPC_AGI += n_A_SHOES_DEF_PLUS;
	if(CardNumSearch(198))wSPC_VIT += n_A_BODY_DEF_PLUS;
	if(n_A_card[CARD_REGION_ID_HEAD_TOP] == 180)wSPC_STR += n_A_HEAD_DEF_PLUS;
	if(CardNumSearch(185))wSPC_VIT += Math.floor(SU_DEX /18);
	if(CardNumSearch(187))wSPC_STR += Math.floor(SU_INT /18);
	if(CardNumSearch(189))wSPC_LUK += Math.floor(SU_AGI /18);
	if(CardNumSearch(191))wSPC_AGI += Math.floor(SU_LUK /18);
	if(CardNumSearch(196))wSPC_INT += Math.floor(SU_STR /18);
	if(CardNumSearch(197))wSPC_DEX += Math.floor(SU_VIT /18);
	if(CardNumSearch(405)){
		if(GetLowerJobSeriesID(n_A_JOB)==1 || GetLowerJobSeriesID(n_A_JOB)==2 || GetLowerJobSeriesID(n_A_JOB)==6){
			wSPC_STR += 2;
			if(EquipNumSearch(2058)) wSPC_STR += 2;
		}
		if(GetLowerJobSeriesID(n_A_JOB)==3 || GetLowerJobSeriesID(n_A_JOB)==4 || GetLowerJobSeriesID(n_A_JOB)==5){
			wSPC_INT += 2;
			if(EquipNumSearch(2058)) wSPC_INT += 2;
		}
	}
	if(GetLowerJobSeriesID(n_A_JOB)==5 && n_A_card[CARD_REGION_ID_HEAD_TOP]==621) wSPC_INT += Math.floor(n_A_HEAD_DEF_PLUS / 3);
	if(GetLowerJobSeriesID(n_A_JOB)==4 && n_A_card[CARD_REGION_ID_HEAD_TOP]==622) wSPC_DEX += Math.floor(n_A_HEAD_DEF_PLUS / 3);
	if(GetLowerJobSeriesID(n_A_JOB)==1 && n_A_card[CARD_REGION_ID_HEAD_TOP]==625) wSPC_STR += Math.floor(n_A_HEAD_DEF_PLUS / 3);
	if(GetLowerJobSeriesID(n_A_JOB)==6 && n_A_card[CARD_REGION_ID_HEAD_TOP]==637) wSPC_LUK += Math.floor(n_A_HEAD_DEF_PLUS / 3);


	// エンチャントＳｐｅｃｉａｌ系
	vartmp = CARD_ID_ENCHANT_SPECIAL_STR;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_STR += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_STR += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_STR += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_STR += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_STR += 3 * cardCountShoes;
	}

	vartmp = CARD_ID_ENCHANT_SPECIAL_AGI;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_AGI += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_AGI += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_AGI += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_AGI += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_AGI += 3 * cardCountShoes;
	}

	vartmp = CARD_ID_ENCHANT_SPECIAL_VIT;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_VIT += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_VIT += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_VIT += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_VIT += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_VIT += 3 * cardCountShoes;
	}

	vartmp = CARD_ID_ENCHANT_SPECIAL_INT;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_INT += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_INT += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_INT += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_INT += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_INT += 3 * cardCountShoes;
	}

	vartmp = CARD_ID_ENCHANT_SPECIAL_DEX;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_DEX += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_DEX += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_DEX += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_DEX += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_DEX += 3 * cardCountShoes;
	}

	vartmp = CARD_ID_ENCHANT_SPECIAL_LUK;
	cardCountHeadTop	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_TOP_ANY);
	cardCountHeadMid	 = CardNumSearch(vartmp, CARD_REGION_ID_HEAD_MID_ANY);
	cardCountShield		 = CardNumSearch(vartmp, CARD_REGION_ID_SHIELD_ANY);
	cardCountBody		 = CardNumSearch(vartmp, CARD_REGION_ID_BODY_ANY);
	cardCountShoulder	 = CardNumSearch(vartmp, CARD_REGION_ID_SHOULDER_ANY);
	cardCountShoes		 = CardNumSearch(vartmp, CARD_REGION_ID_SHOES_ANY);
	cardCountAccessary1	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_1_ANY);
	cardCountAccessary2	 = CardNumSearch(vartmp, CARD_REGION_ID_ACCESSARY_2_ANY);
	cardCount			 = CardNumSearch(vartmp, CARD_REGION_ID_ANY);
	if (cardCount > 0) {
		if (n_A_HEAD_DEF_PLUS >= 8) wSPC_LUK += 3 * cardCountHeadTop;
		if (n_A_LEFT_DEF_PLUS >= 8) wSPC_LUK += 3 * cardCountShield;
		if (n_A_BODY_DEF_PLUS >= 8) wSPC_LUK += 3 * cardCountBody;
		if (n_A_SHOULDER_DEF_PLUS >= 8) wSPC_LUK += 3 * cardCountShoulder;
		if (n_A_SHOES_DEF_PLUS >= 8) wSPC_LUK += 3 * cardCountShoes;
	}




	if(EquipNumSearch(2348)) wSPC_INT += Math.floor(n_A_BaseLV / 20);
	if(EquipNumSearch(2350)) wSPC_STR += Math.floor(n_A_BaseLV / 20);
	if(EquipNumSearch(2352)) wSPC_AGI += Math.floor(n_A_BaseLV / 20);
	if(EquipNumSearch(2354)) wSPC_DEX += Math.floor(n_A_BaseLV / 20);
	if(EquipNumSearch(2430)){
		wSPC_DEX += n_A_Weapon_ATKplus;
		wSPC_INT += n_A_Weapon_ATKplus;
	}
	if(EquipNumSearch(2521)){
		if(n_A_BaseLV <= 99) wSPC_VIT += ROUNDDOWN(n_A_HEAD_DEF_PLUS / 2);
		else wSPC_VIT += n_A_HEAD_DEF_PLUS;
		if(SkillSearch(450)){
			wSPC_STR += 30;
			wSPC_INT -= 30;
		}
	}
	if(EquipNumSearch(2543)) wSPC_VIT += n_A_SHOES_DEF_PLUS;





	/* TODO */
	// 独自実装箇所　ここから


	//----------------------------------------------------------------
	// 「ヴァルキリーハンマー」の、職業による強化
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_ID_VALKYRIE_HAMMER)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			wSPC_VIT += 1 * n_A_Weapon_ATKplus;
			break;

		// ソードマン系
		case JOB_SERIES_ID_SWORDMAN:
			wSPC_VIT += 1 * n_A_Weapon_ATKplus;
			break;

		// マーチャント系
		case JOB_SERIES_ID_MERCHANT:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// プリースト系
			case JOB_SERIES_ID_PRIEST:
				break;

			// モンク系
			case JOB_SERIES_ID_MONK:
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「古びたバレリーナの髪飾り」の、精錬による強化
	// 「古びたミンストレルソングの帽子」の、精錬による強化
	//----------------------------------------------------------------
	if(EquipNumSearch(ITEM_ID_FURUBITA_BALLERINA)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MINSTRELSONG)) {
		wSPC_STR += n_A_HEAD_DEF_PLUS;
		wSPC_AGI += n_A_HEAD_DEF_PLUS;
		wSPC_VIT += n_A_HEAD_DEF_PLUS;
		wSPC_DEX += n_A_HEAD_DEF_PLUS;
		wSPC_INT += n_A_HEAD_DEF_PLUS;
		wSPC_LUK += n_A_HEAD_DEF_PLUS;
	}

	//----------------------------------------------------------------
	// 「古びたシャドウクラウン」の、精錬による強化
	//----------------------------------------------------------------
	if(EquipNumSearch(ITEM_ID_FURUBITA_SHADOWCROWN)) {
		wSPC_DEX += 2 * n_A_HEAD_DEF_PLUS;
	}

	//----------------------------------------------------------------
	// 「エメラルドイヤリング」の、スキル習得による強化
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_ID_EMERALDEARRING)) {
		var wEMERALDEARRING = ROUNDDOWN(SkillSearch(631) / 2) * EquipNumSearch(ITEM_ID_EMERALDEARRING);
		wSPC_AGI += wEMERALDEARRING;
		wSPC_INT += wEMERALDEARRING;
		wSPC_DEX += wEMERALDEARRING;
	}

	//----------------------------------------------------------------
	// 「セリーヌ・キミカード　ノーブルセット」の、精錬による効果
	//----------------------------------------------------------------
	if (CardNumSearch(CARD_SET_ID_CELINE_KIMI_NOBLE_CROSS)) {
		wSPC_LUK += 3 * n_A_Weapon_ATKplus;
	}

	//----------------------------------------------------------------
	// 「ヴァルキリーナイフ」の、職業による強化
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE)) {
		switch (GetLowerJobSeriesID(n_A_JOB)) {

		// ノービス系
		case JOB_SERIES_ID_NOVICE:
			wSPC_INT += 2 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
			wSPC_DEX += 2 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
			wSPC_DEX -= ROUNDDOWN(SU_DEX / 10) * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
			break;

		// マジシャン系
		case JOB_SERIES_ID_MAGICIAN:
			break;

		// シーフ系
		case JOB_SERIES_ID_THIEF:
			break;

		default:
			switch (GetHigherJobSeriesID(n_A_JOB)) {

			// ハンター系
			case JOB_SERIES_ID_HUNTER:
				wSPC_INT += 2 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				wSPC_DEX += 2 * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;

			// バード系、ダンサー系
			case JOB_SERIES_ID_BARD:
			case JOB_SERIES_ID_DANCER:
				wSPC_DEX -= ROUNDDOWN(SU_DEX / 10) * n_A_Weapon_ATKplus * EquipNumSearch(ITEM_ID_VALKYRIE_KNIFE);
				break;
			}
		}
	}

	//----------------------------------------------------------------
	// 「ガーディアンユニット」の、精錬による効果
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_ID_GUARDIAN_UNIT)) {
		wSPC_VIT += 1 * n_A_BODY_DEF_PLUS;
	}

	//----------------------------------------------------------------
	// 「サバイバルオーブ　サークレットセット」の、装備効果
	//----------------------------------------------------------------
	if (EquipNumSearch(ITEM_SET_ID_SURVIVAL_ORB_SURVIVAL_CIRCLET)) {
		if (n_A_HEAD_DEF_PLUS >= 7) wSPC_VIT += 4;
		if (n_A_HEAD_DEF_PLUS >= 9) wSPC_VIT += 4;
	}

	//----------------------------------------------------------------
	// 「サファイアリスト」の、スキル習得による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_SAPPHIRE_LIST)) > 0) {
		var upCount = Math.floor(LearnedSkillSearch(SKILL_ID_SLIMPOTION_PITCHER) / 2);
		wSPC_INT += 1 * upCount * itemCount;
		wSPC_DEX += 1 * upCount * itemCount;
		wSPC_LUK += 1 * upCount * itemCount;
	}

	//----------------------------------------------------------------
	// 「[ECO] モーモー・アルマカード」の、精錬による効果
	//----------------------------------------------------------------
	if (CardNumSearch(CARD_ID_ECO_MOMO_ARMA)) {
		wSPC_VIT += 1 * n_A_SHOES_DEF_PLUS;
		wSPC_INT += 1 * n_A_SHOES_DEF_PLUS;

		if (n_A_SHOES_DEF_PLUS >= 9) {
			wSPC_VIT += 5;
			wSPC_INT += 5;
		}
	}

	//----------------------------------------------------------------
	// 「エナジー＜致命ノ一撃＞」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ENCHANT_ENERGY_CHIMEINO_ICHIGEKI)) > 0) {
		wSPC_LUK += 3 * n_A_SHOULDER_DEF_PLUS * cardCount;
	}

	//----------------------------------------------------------------
	// 「盗賊のすすめ第一巻」の、スキル習得による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_TOZOKUNO_SUSUME_DAIIKKAN)) > 0) {
		if (LearnedSkillSearch(SKILL_ID_GRAPHITY) >= 1) {
			wSPC_STR += 5 * itemCount;
			wSPC_AGI += 5 * itemCount;
			wSPC_INT += 5 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「時魔術師のローブ」の、追加発動による効果
	//----------------------------------------------------------------
	if ((bufLv = TimeItemNumSearch(114)) > 0) {
		wSPC_INT += 3 * n_A_BODY_DEF_PLUS * bufLv;
	}

	//----------------------------------------------------------------
	// 「超越者のローブ」の、精錬による効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_CHOETSUSHANO_ROBE)) > 0) {
		wSPC_INT += 3 * n_A_BODY_DEF_PLUS * itemCount;
	}

	//----------------------------------------------------------------
	// 「栄光の証」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((itemCount = EquipNumSearch(ITEM_ID_EIKONO_AKASHI)) > 0) {
		if (n_A_BaseLV >= 150) {
			wSPC_STR += 1 * itemCount;
			wSPC_AGI += 1 * itemCount;
			wSPC_VIT += 1 * itemCount;
			wSPC_INT += 1 * itemCount;
			wSPC_DEX += 1 * itemCount;
			wSPC_LUK += 1 * itemCount;
		}
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(腕力)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_WANRYOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_STR += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(迅速)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_ZINSOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_AGI += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(体力)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_TAIRYOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_VIT += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(知力)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_CHIRYOKU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_INT += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(集中)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_SHUCHU, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_DEX += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「エンチャント　血のニーヴ(幸運)」の、精錬による効果
	//----------------------------------------------------------------
	cardCountShield = CardNumSearch(CARD_ID_ENCHANT_CHINO_NIEVE_KOUN, CARD_REGION_ID_SHIELD_ANY);
	if (cardCountShield > 0) {

		// 盾防具へのエンチャント
		vartmp = 0;
		if (n_A_LEFT_DEF_PLUS >= 7) vartmp += 2;
		if (n_A_LEFT_DEF_PLUS >= 9) vartmp += 2;
		wSPC_LUK += vartmp * cardCountShield

		// アクセサリへのエンチャント
		// 精錬できないので処理不要
	}

	//----------------------------------------------------------------
	// 「ルーンナイトセイレン(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RUNE_KNIGHT_SEIREN_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ルーンナイトセイレン(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RUNE_KNIGHT_SEIREN_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ウォーロックカトリーヌ(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WARLOCK_CATHERINE_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ウォーロックカトリーヌ(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WARLOCK_CATHERINE_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「レンジャーセシル(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RANGER_CECIL_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「レンジャーセシル(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_RANGER_CECIL_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「アークビショップマーガレッタ(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ARCH_BISHOP_MARGARETTE_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「アークビショップマーガレッタ(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ARCH_BISHOP_MARGARETTE_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギロチンクロスエレメス(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GUILLOTINE_CROSS_ELEMES_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ギロチンクロスエレメス(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GUILLOTINE_CROSS_ELEMES_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「メカニックハワード(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MECHANIC_HAWARD_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「メカニックハワード(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MECHANIC_HAWARD_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ロイヤルガードランデル(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ROYAL_GUARD_RANDEL_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ロイヤルガードランデル(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_ROYAL_GUARD_RANDEL_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ソーサラーセリア(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SORCERER_CERIA_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ソーサラーセリア(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SORCERER_CERIA_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ミンストレルバジル(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MINSTREL_ARFOSIO_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ミンストレルバジル(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_MINSTREL_ARFOSIO_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ワンダラートレンティーニ(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WANDERER_TRENTINI_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ワンダラートレンティーニ(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_WANDERER_TRENTINI_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「修羅チェン(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHURA_CHENG_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「修羅チェン(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHURA_CHENG_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「シャドウチェイサーガーティ(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHADOW_CHASER_GARTY_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「シャドウチェイサーガーティ(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_SHADOW_CHASER_GARTY_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ジェネティックエミュール(MVP)カード」の、ベースレベルによる効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GENETIC_EMUR_MVP)) > 0) {
		if (n_A_BaseLV >= 165) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}

	//----------------------------------------------------------------
	// 「ジェネティックエミュール(MVP)カード」の、精錬による効果
	//----------------------------------------------------------------
	if ((cardCount = CardNumSearch(CARD_ID_GENETIC_EMUR_MVP)) > 0) {
		if (n_A_SHOULDER_DEF_PLUS >= 10) {
			wSPC_STR += 10 * cardCount;
			wSPC_AGI += 10 * cardCount;
			wSPC_VIT += 10 * cardCount;
			wSPC_INT += 10 * cardCount;
			wSPC_DEX += 10 * cardCount;
			wSPC_LUK += 10 * cardCount;
		}
	}







	if(n_A_PassSkill8[0] == 56){
		if(n_A_PassSkill8[17] == 6){
			wSPC_STR += 1;
			wSPC_AGI += 1;
			wSPC_VIT += 1;
			wSPC_DEX += 1;
			wSPC_INT += 1;
			wSPC_LUK += 1;
		}
	}
	wSPC_STR += n_A_PassSkill2[0];
	wSPC_INT += n_A_PassSkill2[0];
	wSPC_DEX += n_A_PassSkill2[0];
	if(n_A_PassSkill2[1] > 0 && n_A_IJYOU[0] == 0 && n_A_IJYOU[1] == 0) wSPC_AGI += n_A_PassSkill2[1] +2;
	wSPC_LUK += (n_A_PassSkill2[3] * 30);
	if(SkillSearch(270)) {
		wSPC_STR += 5;
		wSPC_AGI += 5;
		wSPC_VIT += 5;
		wSPC_DEX += 5;
		wSPC_INT += 5;
		wSPC_LUK += 5;
	}
	if(SkillSearch(379) && n_A_WeaponType==0) wSPC_STR += 10;
	if(SkillSearch(450) || n_A_PassSkill6[20]) wSPC_STR += 30;
	if(SkillSearch(587)){
		var w = ROUNDDOWN(n_A_BaseLV / 10 + n_A_JobLV / 5);
		wSPC_STR += w;
		wSPC_AGI += w;
		wSPC_VIT += w;
		wSPC_DEX += w;
		wSPC_INT += w;
		wSPC_LUK += w;
	}
	if(n_A_PassSkill4[0]){
		wSPC_STR += 5;
		wSPC_DEX += 5;
		wSPC_INT += 5;
	}
	wSPC_STR += n_A_PassSkill4[1];
	wSPC_VIT += n_A_PassSkill4[2];
	wSPC_AGI += n_A_PassSkill4[3];
	wSPC_DEX += n_A_PassSkill4[4];
	if(n_A_PassSkill4[5]){
		wSPC_STR += 20;
		wSPC_AGI += 20;
		wSPC_VIT += 20;
		wSPC_DEX += 20;
		wSPC_INT += 20;
		wSPC_LUK += 20;
	}
	if(n_A_PassSkill6[2] == 1){
		wSPC_STR += 3;
		wSPC_AGI += 3;
		wSPC_VIT += 3;
		wSPC_DEX += 3;
		wSPC_INT += 3;
		wSPC_LUK += 3;
	}
	if(n_A_PassSkill6[2] == 2){
		wSPC_STR += 5;
		wSPC_AGI += 5;
		wSPC_VIT += 5;
		wSPC_DEX += 5;
		wSPC_INT += 5;
		wSPC_LUK += 5;
	}
	if(n_A_PassSkill8[4]){
		wSPC_STR += 1;
		wSPC_AGI += 1;
		wSPC_VIT += 1;
		wSPC_DEX += 1;
		wSPC_INT += 1;
		wSPC_LUK += 1;
	}
	if(SkillSearch(310)){
		wSPC_STR -= 1;
		wSPC_AGI -= 1;
		wSPC_VIT -= 1;
		wSPC_DEX -= 1;
		wSPC_INT -= 1;
		wSPC_LUK -= 1;
	}
	if(n_A_PassSkill6[15]) wSPC_VIT += 4 + n_A_PassSkill6[15];
	if(n_A_PassSkill6[16]) wSPC_LUK += 4 + n_A_PassSkill6[16];
	if(SkillSearch(820)) wSPC_VIT += 5 * SkillSearch(820);
	if(n_A_PassSkill3[39] == 5) wSPC_INT -= n_A_PassSkill3[40] * n_A_PassSkill3[41];
	if(n_A_PassSkill3[39] == 4) wSPC_STR += n_A_PassSkill3[40] * n_A_PassSkill3[41];
	if(n_A_PassSkill7[49]){
		wSPC_STR += 10;
		wSPC_AGI += 10;
		wSPC_VIT += 10;
		wSPC_INT += 10;
		wSPC_DEX += 10;
		wSPC_LUK += 10;
	}else{
		if(n_A_PassSkill7[3]) wSPC_STR += n_A_PassSkill7[3];
		if(n_A_PassSkill7[4]) wSPC_AGI += n_A_PassSkill7[4];
		if(n_A_PassSkill7[5]) wSPC_VIT += n_A_PassSkill7[5];
		if(n_A_PassSkill7[6]) wSPC_INT += n_A_PassSkill7[6];
		if(n_A_PassSkill7[7]) wSPC_DEX += n_A_PassSkill7[7];
		if(n_A_PassSkill7[8]) wSPC_LUK += n_A_PassSkill7[8];
		if(TimeItemNumSearch(79)){
			if(n_A_PassSkill7[3] <6) wSPC_STR += 6 - n_A_PassSkill7[3];
			if(n_A_PassSkill7[4] <6) wSPC_AGI += 6 - n_A_PassSkill7[4];
			if(n_A_PassSkill7[5] <6) wSPC_VIT += 6 - n_A_PassSkill7[5];
			if(n_A_PassSkill7[6] <6) wSPC_INT += 6 - n_A_PassSkill7[6];
			if(n_A_PassSkill7[7] <6) wSPC_DEX += 6 - n_A_PassSkill7[7];
			if(n_A_PassSkill7[8] <6) wSPC_LUK += 6 - n_A_PassSkill7[8];
		}
	}
	if(n_A_PassSkill7[16]) wSPC_STR += 20;
	if(n_A_PassSkill7[17]) wSPC_AGI += 20;
	if(n_A_PassSkill7[18]) wSPC_VIT += 20;
	if(n_A_PassSkill7[19]) wSPC_INT += 20;
	if(n_A_PassSkill7[20]) wSPC_DEX += 20;
	if(n_A_PassSkill7[21]) wSPC_LUK += 20;
	if(SkillSearch(392)){
		if(35<= n_A_JOB && n_A_JOB <= 40 && n_A_BaseLV <70){
			var w=0;
			w = n_A_BaseLV - 10;
			if(w > 50) w = 50;
			if(w <0) w = 0;
			if(n_A_STR + wSPC_STR <= w) wSPC_STR = w - n_A_STR;
			if(n_A_AGI + wSPC_AGI <= w) wSPC_AGI = w - n_A_AGI;
			if(n_A_VIT + wSPC_VIT <= w) wSPC_VIT = w - n_A_VIT;
			if(n_A_INT + wSPC_INT <= w) wSPC_INT = w - n_A_INT;
			if(n_A_DEX + wSPC_DEX <= w) wSPC_DEX = w - n_A_DEX;
			if(n_A_LUK + wSPC_LUK <= w) wSPC_LUK = w - n_A_LUK;
		}
	}
	var w_marikon = 0;
	for(var i=12;i<=17;i++){
		if(n_A_PassSkill3[i] != 0) w_marikon = 1;
	}
	if(w_marikon == 1 && n_A_PassSkill3[18]==0){
		if(n_A_STR + wSPC_STR <99){
			if(n_A_STR + wSPC_STR + Math.floor(n_A_PassSkill3[12] /2) <99) wSPC_STR += Math.floor(n_A_PassSkill3[12] /2);
			else wSPC_STR = (99 - n_A_STR);
		}
		if(n_A_AGI + wSPC_AGI <99){
			if(n_A_AGI + wSPC_AGI + Math.floor(n_A_PassSkill3[13] /2) <99) wSPC_AGI += Math.floor(n_A_PassSkill3[13] /2);
			else wSPC_AGI = (99 - n_A_AGI);
		}
		if(n_A_VIT + wSPC_VIT <99){
			if(n_A_VIT + wSPC_VIT + Math.floor(n_A_PassSkill3[14] /2) <99) wSPC_VIT += Math.floor(n_A_PassSkill3[14] /2);
			else wSPC_VIT = (99 - n_A_VIT);
		}
		if(n_A_INT + wSPC_INT <99){
			if(n_A_INT + wSPC_INT + Math.floor(n_A_PassSkill3[15] /2) <99) wSPC_INT += Math.floor(n_A_PassSkill3[15] /2);
			else wSPC_INT = (99 - n_A_INT);
		}
		if(n_A_DEX + wSPC_DEX <99){
			if(n_A_DEX + wSPC_DEX + Math.floor(n_A_PassSkill3[16] /2) <99) wSPC_DEX += Math.floor(n_A_PassSkill3[16] /2);
			else wSPC_DEX = (99 - n_A_DEX);
		}
		if(n_A_LUK + wSPC_LUK <99){
			if(n_A_LUK + wSPC_LUK + Math.floor(n_A_PassSkill3[17] /2) <99) wSPC_LUK += Math.floor(n_A_PassSkill3[17] /2);
			else wSPC_LUK = (99 - n_A_LUK);
		}
	}else if(w_marikon == 1 && n_A_PassSkill3[18]){
		wSPC_STR += n_A_PassSkill3[12];
		wSPC_AGI += n_A_PassSkill3[13];
		wSPC_VIT += n_A_PassSkill3[14];
		wSPC_INT += n_A_PassSkill3[15];
		wSPC_DEX += n_A_PassSkill3[16];
		wSPC_LUK += n_A_PassSkill3[17];
	}
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[4]) wSPC_STR += n_A_PassSkill9[4];
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[5]) wSPC_AGI += n_A_PassSkill9[5];
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[6]) wSPC_VIT += n_A_PassSkill9[6];
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[7]) wSPC_INT += n_A_PassSkill9[7];
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[8]) wSPC_DEX += n_A_PassSkill9[8];
	if(n_A_PassSkill9[0] == 0 && n_A_PassSkill9[9]) wSPC_LUK += n_A_PassSkill9[9];
	if(n_A_IJYOU[0]){
		var w1;
		var w2;
		if(n_A_IJYOU[0] <= 5){
			w1 = Math.floor((n_A_AGI + wSPC_AGI) / 2);
			w2 = 9999;
		}else{
			w1 = Math.floor((n_A_AGI + wSPC_AGI) / 4);
			w2 = 5 * (n_A_IJYOU[0] - 5);
		}
		if(w1 > w2) wSPC_AGI -= w2;
		else wSPC_AGI -= w1;
		if(n_A_IJYOU[0] <= 5) w1 = Math.floor((n_A_DEX + wSPC_DEX) / 2);
		else w1 = Math.floor((n_A_DEX + wSPC_DEX) / 4);
		if(w1 > w2) wSPC_DEX -= w2;
		else wSPC_DEX -= w1;
	}
	if(n_A_IJYOU[1]) wSPC_AGI -= (n_A_IJYOU[1] + 2);
	if(n_A_IJYOU[3]) wSPC_LUK = -1 * n_A_LUK;
	n_A_STR += wSPC_STR;
	n_A_AGI += wSPC_AGI;
	n_A_VIT += wSPC_VIT;
	n_A_INT += wSPC_INT;
	n_A_DEX += wSPC_DEX;
	n_A_LUK += wSPC_LUK;
	if(wSPC_STR >= 0) myInnerHtml("A_STRp","+"+wSPC_STR,0);
	else myInnerHtml("A_STRp",wSPC_STR,0);
	if(wSPC_AGI >= 0) myInnerHtml("A_AGIp","+"+wSPC_AGI,0);
	else myInnerHtml("A_AGIp",wSPC_AGI,0);
	if(wSPC_VIT >= 0) myInnerHtml("A_VITp","+"+wSPC_VIT,0);
	else myInnerHtml("A_VITp",wSPC_VIT,0);
	if(wSPC_INT >= 0) myInnerHtml("A_INTp","+"+wSPC_INT,0);
	else myInnerHtml("A_INTp",wSPC_INT,0);
	if(wSPC_DEX >= 0) myInnerHtml("A_DEXp","+"+wSPC_DEX,0);
	else myInnerHtml("A_DEXp",wSPC_DEX,0);
	if(wSPC_LUK >= 0) myInnerHtml("A_LUKp","+"+wSPC_LUK,0);
	else myInnerHtml("A_LUKp",wSPC_LUK,0);
}




/**
 * 装備中のＳＰの合計値を取得する（装備のみ）.
 * @param spid ＳＰのＩＤ
 * @return 当該ＳＰのパラメタ合計値
 */
function GetEquippedTotalSPEquip(spid) {

	var w = 0;
	var itemData = 0;

	for(var i = 0; i <= 40; i++) {

		itemData = ItemObjNew[n_A_Equip[i]];

		for(var j = 0; itemData[ ITEM_DATA_INDEX_SPBEGIN + j ] != ITEM_SP_END; j += 2) {

			if(spid == itemData[ ITEM_DATA_INDEX_SPBEGIN + j ]) {
				w += itemData[ ITEM_DATA_INDEX_SPBEGIN + j + 1 ];
			}

		}

	}

	return w;
}




/**
 * 装備中のＳＰの合計値を取得する（装備以外）.
 * @param spid ＳＰのＩＤ
 * @return 当該ＳＰのパラメタ合計値
 */
function GetEquippedTotalSPCardAndElse(spid) {

	var w=0;
	var cardData = 0;

	// 装備中のカードのＳＰの合計値を取得
	for(var i = 0; i < n_A_card.length; i++) {

		cardData = CardObjNew[n_A_card[i]];

		for(var j = 0; cardData[CARD_DATA_INDEX_SPBEGIN + j] != 0; j += 2) {

			if(spid == cardData[CARD_DATA_INDEX_SPBEGIN + j]) {
				w += cardData[CARD_DATA_INDEX_SPBEGIN + j + 1];
			}
		}
	}

	// TODO : 謎処理　ペットステータスの反映？
	if(n_A_PassSkill8[17] == 0 || n_A_PassSkill8[17] >= 5){

		for(var j = 0; PET_OBJ[n_A_PassSkill8[0]][j + 3] != 0; j += 2) {

			if(spid == PET_OBJ[n_A_PassSkill8[0]][j +3]) {
				w += PET_OBJ[n_A_PassSkill8[0]][j +4];
			}
		}
	}



	// 追加発動効果の合計値を加算する
	var timeObj = 0;
	var w_num = [0,0,0,0];

	// 追加発動効果の指定状況を取得
	for(i = 0; i <= 3; i++) {
		w_num[i] = n_A_PassSkill8[8 + i];
	}

	// 追加発動効果の重複をチェック
	for(i = 0; i <= 2; i++) {
		for(j = i + 1; j <= 3; j++) {
			if(w_num[i] == w_num[j]) w_num[j] = 0;
		}
	}

	// データを検索して加算
	for(i = 0; i <= 3; i++) {

		timeObj = ITEM_SP_TIME_OBJ[w_num[i]];

		for(var j = 0; timeObj[5 + j] != 0; j += 2) {
			if(spid == timeObj[5 + j]) {
				w += timeObj[6 + j];
			}
		}
	}

	return w;
}








function ChangeEquip(num,sub){
	CardSlotPlus(num,sub);
	StAllCalc();
	ClickB_Item(num,sub);
	ActiveSkillSetPlus();
}




n_KurisuCheck = [0,0,0,0,0,0,0,0];
n_EquipCheck = [0,0,0,0,0,0,0,0,0];
n_CardTeisuu = [2,2,2,3,4,5,6,7,7];





function CardSlotPlus(wNUM,wSUB){

	var w_bui = "";
	var w_HyouziName = "";
	var ToshiBangou = 0;
	var nonName = "(エンチャントなし)";


	if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 50){
		w_bui = "A_head1_card";
		w_HyouziName = "C_HEAD1";
		ToshiBangou = 0;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 51){
		w_bui = "A_head2_card";
		w_HyouziName = "C_HEAD2";
		ToshiBangou = 1;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 52){
		w_bui = "A_head3_card";
		w_HyouziName = "C_HEAD3";
		ToshiBangou = 2;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 60){
		w_bui = "A_body_card";
		w_HyouziName = "C_BODY";
		ToshiBangou = 3;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 61){
		w_bui = "A_left_card";
		w_HyouziName = "C_LEFT";
		ToshiBangou = 4;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 62){
		w_bui = "A_shoulder_card";
		w_HyouziName = "C_SHO";
		ToshiBangou = 5;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 63){
		w_bui = "A_shoes_card";
		w_HyouziName = "C_SHOE";
		ToshiBangou = 6;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 64 && wSUB == 9){
		w_bui = "A_acces1_card";
		w_HyouziName = "C_ACC1";
		ToshiBangou = 7;
	}
	else if(ItemObjNew[wNUM][ITEM_DATA_INDEX_KIND] == 64 && wSUB == 10){
		w_bui = "A_acces2_card";
		w_HyouziName = "C_ACC2";
		ToshiBangou = 8;
	}else{
		w_HyouziName = 0;
	}

	if(10 <= ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] && ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] <10000 && wSUB != 0 && wSUB != 1){

		var wType = n_EnchantType[Math.floor(ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] / 10)];

		var wSTR = "<BR>";
		if(wType[1] != 0) wSTR += '<select id="'+ w_bui +'2"onChange="StAllCalc()|Click_Card(this[this.selectedIndex].value)"></select><BR>';
		if(wType[2] != 0) wSTR += '<select id="'+ w_bui +'3"onChange="StAllCalc()|Click_Card(this[this.selectedIndex].value)"></select><BR>';
		if(wType[3] != 0) wSTR += '<select id="'+ w_bui +'4"onChange="StAllCalc()|Click_Card(this[this.selectedIndex].value)"></select>';
		myInnerHtml(w_HyouziName,wSTR,0);
		if(wType[1] != 0){
			for(var i=0;i<n_EnchantList[wType[1]].length;i++){
				var w = n_EnchantList[wType[1]][i];
				if(i == 0 && w == 0) document.getElementById(w_bui +"2").options[0] = new Option(nonName,n_EnchantList[wType[1]][0]);
				else document.getElementById(w_bui +"2").options[i] = new Option(CardObjNew[w][2],w);
			}
		}
		if(wType[2] != 0){
			for(var i=0;i<n_EnchantList[wType[2]].length;i++){
				var w = n_EnchantList[wType[2]][i];
				if(i == 0 && w == 0) document.getElementById(w_bui +"3").options[0] = new Option(nonName,n_EnchantList[wType[2]][0]);
				else document.getElementById(w_bui +"3").options[i] = new Option(CardObjNew[w][2],w);
			}
		}
		if(wType[3] != 0){
			for(var i=0;i<n_EnchantList[wType[3]].length;i++){
				var w = n_EnchantList[wType[3]][i];
				if(i == 0 && w == 0) document.getElementById(w_bui +"4").options[0] = new Option(nonName,n_EnchantList[wType[3]][0]);
				else document.getElementById(w_bui +"4").options[i] = new Option(CardObjNew[w][2],w);
			}
		}
	}else{
		if(w_HyouziName != 0){
			var wSTR = "";
			myInnerHtml(w_HyouziName,wSTR,0);
		}
	}
	var jLeft = 0;
	if(wSUB == 0){
		w_bui = "A_weapon1_card";
	}
	if(wSUB == 1){
		w_bui = "A_weapon2_card";
		jLeft = 4;
	}
	if(wSUB == 0 || wSUB == 1){
		if(10 <= ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] && ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] <10000){
			var w = Math.floor((ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV]) / 10);
			var wType = n_EnchantType[w];
			for(var j=0;j<=3;j++){
				if(wType[j] != 0){
					var len = document.getElementById(w_bui +(j+1)).length;
					for(var i=0;i<len;i++) document.getElementById(w_bui +(j+1)).options[0] = null;
					if(n_EnchantList[wType[j]][0] == 0) document.getElementById(w_bui +(j+1)).options[0] = new Option(nonName,n_EnchantList[wType[j]][0]);
					else document.getElementById(w_bui +(j+1)).options[0] = new Option(CardObjNew[n_EnchantList[wType[j]][0]][2],n_EnchantList[wType[j]][0]);
					for(var i=1;i<n_EnchantList[wType[j]].length;i++){
						var w = n_EnchantList[wType[j]][i];
						document.getElementById(w_bui +(j+1)).options[i] = new Option(CardObjNew[w][2],w);
					}
					n_KurisuCheck[j+jLeft] = 1;
				}else if(n_KurisuCheck[j+jLeft] == 1){
					for(i=0;CardSortOBJ[1][i]!="NULL";i++){
						document.getElementById(w_bui +(j+1)).options[i] = new Option(CardObjNew[CardSortOBJ[1][i]][2],CardObjNew[CardSortOBJ[1][i]][0]);
					}
					n_KurisuCheck[j+jLeft] = 0;
				}
			}
		}else{
			for(var j=0;j<=3;j++){
				if(n_KurisuCheck[j+jLeft] == 1){
					for(i=0;CardSortOBJ[1][i]!="NULL";i++){
						document.getElementById(w_bui +(j+1)).options[i] = new Option(CardObjNew[CardSortOBJ[1][i]][2],CardObjNew[CardSortOBJ[1][i]][0]);
					}
					if(j==3) document.getElementById(w_bui +(j+1)).options[4] = new Option("製造ランクTOP10",106);
					n_KurisuCheck[j+jLeft] = 0;
				}
			}
		}
	}else{
		if(10 <= ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] && ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV] <10000){
			var w = Math.floor((ItemObjNew[wNUM][ITEM_DATA_INDEX_WPNLV]) / 10);
			var wType = n_EnchantType[w];
			if(wType[0] != 0){
				var wOBJ = document.getElementById(w_bui);
				var len = wOBJ.length;
				for(var i=0;i<len;i++) wOBJ.options[0] = null;
				wOBJ.options[0] = new Option(nonName,n_EnchantList[wType[0]][0]);
				for(var i=1;i<n_EnchantList[wType[0]].length;i++){
					var w = n_EnchantList[wType[0]][i];
					wOBJ.options[i] = new Option(CardObjNew[w][2],w);
				}
				n_EquipCheck[ToshiBangou] = 1;
				return;
			}
		}
		if(n_EquipCheck[ToshiBangou] == 1){
			var w = n_CardTeisuu[ToshiBangou];
			for(i=0;CardSortOBJ[w][i] != "NULL";i++){
				document.getElementById(w_bui).options[i] = new Option(CardObjNew[CardSortOBJ[w][i]][2],CardObjNew[CardSortOBJ[w][i]][0]);
			}
			n_EquipCheck[ToshiBangou] = 0;
		}
	}
}
function sort(work) {
	for(var i=1;work[i]!="EOF";i++){
		for(var k=i;k>0;k--){
			if(ItemObjNew[work[k-1]][ITEM_DATA_INDEX_KANA] > ItemObjNew[work[k]][ITEM_DATA_INDEX_KANA]){
				var work_backup = work[k-1];
				work[k-1] = work[k];
				work[k] = work_backup;
			}
		}
	}
	return work;
}
function WeaponSet() {
	InitJobInfo();
	n_A_WeaponType = eval(document.calcForm.A_WeaponType.value);
	var len = document.calcForm.A_weapon1.length;
	for(var i=0;i<len;i++) document.calcForm.A_weapon1.options[0] = null;
	work = new Array();
	j = 0;
	for (i=0;i<=ItemMax;
	i++){
		if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == n_A_WeaponType && JobEquipItemSearch(i) == 1){
			work[j] = i;
			j++;
		}else if((ItemObjNew[i][ITEM_DATA_INDEX_WPNLV] % 10) == 4 && ItemObjNew[i][ITEM_DATA_INDEX_KIND] == n_A_WeaponType && SuperNoviceFullWeaponCHECK){
			work[j] = i;
			j++;
		}
	}
	work[j] = "EOF";
	work = sort(work);
	for (i=0;i<j;
	i++) document.calcForm.A_weapon1.options[i] = new Option(ItemObjNew[work[i]][8],ItemObjNew[work[i]][0]);
}
function WeaponSetLeft() {
	InitJobInfo();
	n_A_Weapon2Type = eval(document.calcForm.A_Weapon2Type.value);
	var len = document.calcForm.A_weapon2.length;
	for(var i=0;i<len;i++) document.calcForm.A_weapon2.options[0] = null;
	work = new Array();
	j = 0;
	for (i=0;i<=ItemMax;
	i++){
		if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == n_A_Weapon2Type && JobEquipItemSearch(i) == 1) {
			work[j] = i;
			j++;
		}
	}
	work[j] = "EOF";
	work = sort(work);
	for (i=0;i<j;
	i++) document.calcForm.A_weapon2.options[i] = new Option(ItemObjNew[work[i]][8],ItemObjNew[work[i]][0]);
}
function WeaponSet2(){
	with(document.calcForm){
		InitJobInfo();
		var len = A_head1.length;
		for(var i=0;i<len;i++) A_head1.options[0] = null;
		var len = A_head2.length;
		for(i=0;i<len;i++) A_head2.options[0] = null;
		var len = A_head3.length;
		for(i=0;i<len;i++) A_head3.options[0] = null;
		var len = A_left.length;
		for(i=0;i<len;i++) A_left.options[0] = null;
		var len = A_body.length;
		for(i=0;i<len;i++) A_body.options[0] = null;
		var len = A_shoulder.length;
		for(i=0;i<len;i++) A_shoulder.options[0] = null;
		var len = A_shoes.length;
		for(i=0;i<len;i++) A_shoes.options[0] = null;
		var len = A_acces1.length;
		for(i=0;i<len;i++){
			A_acces1.options[0] = null;
			A_acces2.options[0] = null;
		}
		if(first_check == 0){
			first_check = 1;
			A_head1.options[0] = new Option(ItemObjNew[142][ITEM_DATA_INDEX_NAME],ItemObjNew[142][ITEM_DATA_INDEX_ID]);
			A_head2.options[0] = new Option(ItemObjNew[243][ITEM_DATA_INDEX_NAME],ItemObjNew[243][ITEM_DATA_INDEX_ID]);
			A_head3.options[0] = new Option(ItemObjNew[268][ITEM_DATA_INDEX_NAME],ItemObjNew[268][ITEM_DATA_INDEX_ID]);
			A_left.options[0] = new Option(ItemObjNew[305][ITEM_DATA_INDEX_NAME],ItemObjNew[305][ITEM_DATA_INDEX_ID]);
			A_body.options[0] = new Option(ItemObjNew[279][ITEM_DATA_INDEX_NAME],ItemObjNew[279][ITEM_DATA_INDEX_ID]);
			A_shoulder.options[0] = new Option(ItemObjNew[311][ITEM_DATA_INDEX_NAME],ItemObjNew[311][ITEM_DATA_INDEX_ID]);
			A_shoes.options[0] = new Option(ItemObjNew[317][ITEM_DATA_INDEX_NAME],ItemObjNew[317][ITEM_DATA_INDEX_ID]);
			A_acces1.options[0] = new Option(ItemObjNew[326][ITEM_DATA_INDEX_NAME],ItemObjNew[326][ITEM_DATA_INDEX_ID]);
			A_acces2.options[0] = new Option(ItemObjNew[326][ITEM_DATA_INDEX_NAME],ItemObjNew[326][ITEM_DATA_INDEX_ID]);
			return;
		}
		first_check = 2;
		var workB = new Array();
		for(i=0;i<=7;i++) workB[i] = new Array();
		var wsj = new Array();
		for(i=0;i<=7;i++) wsj[i]=0;
		for(i=0;i<=ItemMax;
		i++){
			if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 50 && (JobEquipItemSearch(i) == 1 || SuperNoviceFullWeaponCHECK)){
				workB[0][wsj[0]] = i;
				wsj[0]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 51 && (JobEquipItemSearch(i) == 1 || SuperNoviceFullWeaponCHECK)){
				workB[1][wsj[1]] = i;
				wsj[1]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 52 && (JobEquipItemSearch(i) == 1 || SuperNoviceFullWeaponCHECK)){
				workB[2][wsj[2]] = i;
				wsj[2]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 61 && JobEquipItemSearch(i) == 1){
				workB[3][wsj[3]] = i;
				wsj[3]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 60 && JobEquipItemSearch(i) == 1){
				workB[4][wsj[4]] = i;
				wsj[4]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 62 && JobEquipItemSearch(i) == 1){
				workB[5][wsj[5]] = i;
				wsj[5]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 63 && JobEquipItemSearch(i) == 1){
				workB[6][wsj[6]] = i;
				wsj[6]++;
			}
			else if(ItemObjNew[i][ITEM_DATA_INDEX_KIND] == 64 && JobEquipItemSearch(i) == 1){
				workB[7][wsj[7]] = i;
				wsj[7]++;
			}
		}
		for(i=0;i<=7;i++) workB[i][wsj[i]] = "EOF";
		for(var m=0;m<=7;m++) workB[m] = sort(workB[m]);
		var z = 0;
		for(i=0;i<wsj[0];i++){
			z = workB[0][i];
			A_head1.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[1];i++){
			z = workB[1][i];
			A_head2.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[2];i++){
			z = workB[2][i];
			A_head3.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[3];i++){
			z = workB[3][i];
			A_left.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[4];i++){
			z = workB[4][i];
			A_body.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[5];i++){
			z = workB[5][i];
			A_shoulder.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[6];i++){
			z = workB[6][i];
			A_shoes.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
		for(i=0;i<wsj[7];i++){
			z = workB[7][i];
			A_acces1.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
			A_acces2.options[i] = new Option(ItemObjNew[z][ITEM_DATA_INDEX_NAME],ItemObjNew[z][ITEM_DATA_INDEX_ID]);
		}
	}}
function FirstNovis(){
	if(first_check == 1){
		first_check = 2;
		WeaponSet2();
	}
}
function JobEquipItemSearch(nJEIS2) {
	var nJEIS = ItemObjNew[nJEIS2][ITEM_DATA_INDEX_EQPFLG];
	if(nJEIS >= 2000){
		if(n_Sanji == 1) nJEIS -= 2000;
		else return 0;
	}
	if(nJEIS >= 1000){
		if(n_Tensei == 1) nJEIS -= 1000;
		else return 0;
	}
	if(ItemObjNew[nJEIS2][ITEM_DATA_INDEX_EQPLV] >= 100) if(n_A_MaxLv <= 99) return 0;
	if(1824 <= ItemObjNew[nJEIS2][ITEM_DATA_INDEX_ID] && ItemObjNew[nJEIS2][ITEM_DATA_INDEX_ID] <= 1863) if(n_A_MaxLv >= 100) return 0;
	for(var j=0;JobEquipItemOBJ[n_A_JOB][j] != 999;j++) {
		if(JobEquipItemOBJ[n_A_JOB][j] == nJEIS) return 1;
	}
	return 0;
}




/**
 * 職業の基本条件を設定する
 */
function InitJobInfo() {

	// 職業ＩＤ
	n_A_JOB = eval(document.calcForm.A_JOB.value);

	// 最大レベルの設定
	switch (n_A_JOB) {
	case JOB_ID_RUNEKNIGHT:
	case JOB_ID_GILOTINCROSS:
	case JOB_ID_ARCBISHOP:
	case JOB_ID_RANGER:
	case JOB_ID_WARLOCK:
	case JOB_ID_MECHANIC:
	case JOB_ID_ROYALGUARD:
	case JOB_ID_SHADOWCHASER:
	case JOB_ID_SHURA:
	case JOB_ID_MINSTREL:
	case JOB_ID_WANDERER:
	case JOB_ID_SORCERER:
	case JOB_ID_GENETIC:
	case JOB_ID_KAGERO:
	case JOB_ID_OBORO:
	case JOB_ID_REBELLION:
		n_A_MaxLv = 165;
		break;

	case JOB_ID_SUPERNOVICE_PLUS:
		n_A_MaxLv = 160;
		break;

	default:
		n_A_MaxLv = 99;
		break;
	}

	// 転生フラグの設定
	switch (n_A_JOB) {
	case JOB_ID_LORDKNIGHT:
	case JOB_ID_ASSASINCROSS:
	case JOB_ID_HIGHPRIEST:
	case JOB_ID_SNIPER:
	case JOB_ID_HIGHWIZARD:
	case JOB_ID_WHITESMITH:
	case JOB_ID_PALADIN:
	case JOB_ID_CHASER:
	case JOB_ID_CHAMPION:
	case JOB_ID_CROWN:
	case JOB_ID_ZYPSY:
	case JOB_ID_PROFESSOR:
	case JOB_ID_CREATOR:
	case JOB_ID_HI_NOVICE:
	case JOB_ID_HI_SWORDMAN:
	case JOB_ID_HI_THIEF:
	case JOB_ID_HI_ACOLYTE:
	case JOB_ID_HI_ARCHER:
	case JOB_ID_HI_MAGICIAN:
	case JOB_ID_HI_MARCHANT:
		n_Tensei = 1;
		n_Sanji = 0;
		break;

	case JOB_ID_RUNEKNIGHT:
	case JOB_ID_GILOTINCROSS:
	case JOB_ID_ARCBISHOP:
	case JOB_ID_RANGER:
	case JOB_ID_WARLOCK:
	case JOB_ID_MECHANIC:
	case JOB_ID_ROYALGUARD:
	case JOB_ID_SHADOWCHASER:
	case JOB_ID_SHURA:
	case JOB_ID_MINSTREL:
	case JOB_ID_WANDERER:
	case JOB_ID_SORCERER:
	case JOB_ID_GENETIC:
		n_Tensei = 1;
		n_Sanji = 1;
		break;

	default:
		n_Tensei = 0;
		n_Sanji = 0;
		break;
	}
}



function NumSearch(NS1,NS2){
	var end = NS2.length-1;

	for(var i=0;i<=end;i++){
		if(NS1 == NS2[i]) return 1;
	}

	return 0;
}
function NumSearch2(NS1,NS2){
	var end = NS2.length-1;

	for(var i=0;i<=end;i++){
		if(NS1 == NS2[i]) return i;
	}

	return -1;
}





/**
 * 古びた頭装備の装備数を取得する.
 * @return 装備個数（０～）
 */
function EquipNumSearchFurubitaHead() {

	// いずれかの古びた頭装備があれば、１個
	if (EquipNumSearch(ITEM_ID_FURUBITA_BONECIRCRET)
		|| EquipNumSearch(ITEM_ID_FURUBITA_BALLERINA)
		|| EquipNumSearch(ITEM_ID_FURUBITA_KAZENOSASAYAKI)
		|| EquipNumSearch(ITEM_ID_FURUBITA_BLAZINGSOUL)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MARYOKUSEKI)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MIDASS)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MINSTRELSONG)
		|| EquipNumSearch(ITEM_ID_FURUBITA_SHADOWCROWN)
		|| EquipNumSearch(ITEM_ID_FURUBITA_DRIVERBAND)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MITRA)
		|| EquipNumSearch(ITEM_ID_FURUBITA_RUNECIRCRET)
		|| EquipNumSearch(ITEM_ID_FURUBITA_MEISAIUSAGI)
		|| EquipNumSearch(ITEM_ID_FURUBITA_SHUGONOKANNMURI)
		) {
		return 1;
	}

	// 該当なし
	return 0;

}

/**
 * 古びたシリーズセットの装備セット数を取得する.
 * @return 装備セット数（０～）
 */
function EquipNumSearchFurubitaSet() {

	// 戦死者のマントは必須
	if(EquipNumSearch(ITEM_ID_SENSHISHANO_MANT) == 0){
		return 0;
	}

	// いずれかの古びた頭装備があれば、１セット換算
	if (EquipNumSearchFurubitaHead()) {
		return 1;
	}

	// 該当なし
	return 0;
}





function KakutyouKansuu(){
	wKK = eval(document.calcForm.A_Kakutyou.value);
	if(wKK == 0){
		myInnerHtml("A_KakutyouData","",0);
		return;
	}

	// ヒール回復力
	if(wKK == 1){
		var Heal0 = new Array();
		var Heal2 = new Array();
		var wType = 0;

		// 表示するヒール種別（ヒール／ハイネス／サンク）を取得
		if (GetHigherJobSeriesID(n_A_JOB) == 9 || GetHigherJobSeriesID(n_A_JOB) == 14 || n_A_JOB == 61) {
			wType = eval(document.calcForm.A_KakutyouSelNum.value);
		}

		// 自分への使用か他人への使用か
		var wMy = eval(document.calcForm.A_KakutyouSelNum2.value);

		//--------------------------------
		// 回復量計算
		//--------------------------------

		// ヒールの場合
		if (wType == 0) {
			for (i = 0; i <= 10; i++) {
				Heal0[i] = HealCalc(i, 0, 0, wMy);
				Heal2[i] = HealCalc(i, 0, 2, wMy);
			}
		}

		// ハイネスヒールの場合
		else if (wType == 1) {
			for (i = 0; i <= 5; i++) {
				Heal0[i] = HealCalc(i, 1, 0, wMy);
				Heal2[i] = HealCalc(i, 1, 2, wMy);
			}
		}

		// サンクチュアリの場合
		else if (wType == 2) {

			for (i = 0; i<= 6; i++) {
				Heal0[i] = 100 * i;
			}
			Heal0[7] = Heal0[8] = Heal0[9] = Heal0[10] = 777;

			var w_BAI = 100 + n_tok[91];
			if (SkillSearch(SKILL_ID_MEDITATIO)) {
				w_BAI -= SkillSearch(SKILL_ID_MEDITATIO) * 2;
			}

			for (i = 0; i <= 10; i++) {
				Heal0[i] = Math.floor(Heal0[i] * w_BAI / 100);
				if(wMy == 0) {
					Heal0[i] = Math.floor(Heal0[i] * (100 + n_tok[92]) / 100);
				}
				Heal2[i] = Heal0[i];
			}
		}

		//--------------------------------
		// HTML組み立て
		//--------------------------------

		// ハイネスの場合はレベル５まで
		if (wType == 1) {
			w = "";
			for (i = 1; i <= 5; i++) {
				if (Heal0[i] == Heal2[i]) {
					w += "Lv"+i +"　"+ Heal0[i] +"<BR>";
				}
				else {
					w += "Lv"+i +"　"+ Heal0[i] +"　～　"+ Heal2[i] +"<BR>";
				}
			}
		}

		// ハイネス以外はレベル１０まで
		else {
			w = "";
			for (i = 1; i <= 10; i++) {
				if (Heal0[i] == Heal2[i]) {
					w += "Lv"+i +"　"+ Heal0[i] +"<BR>";
				}
				else {
					w += "Lv"+i +"　"+ Heal0[i] +"　～　"+ Heal2[i] +"<BR>";
				}
			}
		}

		// 補正表示
		if(n_tok[91] != 0) {
			w += "<Font size=2>ヒールの回復力+"+ n_tok[91] +"%(装備効果等合計)</Font><BR>";
		}

		if(n_tok[92] != 0) {
			w += "<Font size=2>受けるヒールの回復力+"+ n_tok[92] +"%</Font>";
		}

		myInnerHtml("A_KakutyouData",w,0);
	}



	else if(wKK == 2){
		if(GetLowerJobSeriesID(n_A_JOB) == 1 || n_A_JOB == 20 || n_A_JOB == 61){
			HPRLV = eval(document.calcForm.A_KakutyouSelNum.value);
			w = Math.floor((5 + n_A_MaxHP / 500) * HPRLV);
			myInnerHtml("A_KakutyouData","<br>回復量："+w,0);
		}else myInnerHtml("A_KakutyouData","",0);
	}
	else if(wKK == 3){
		if(GetLowerJobSeriesID(n_A_JOB)==5 || GetHigherJobSeriesID(n_A_JOB)==9 || n_A_JOB==20 || n_A_JOB==61 || GetLowerJobSeriesID(n_A_JOB)==44){
			SPRLV = eval(document.calcForm.A_KakutyouSelNum.value);
			w = Math.floor((3 + n_A_MaxSP / 500) * SPRLV);
			myInnerHtml("A_KakutyouData","<br>回復量："+w,0);
		}else myInnerHtml("A_KakutyouData","",0);
	}
	else if(wKK == 4){
		if(GetHigherJobSeriesID(n_A_JOB)==15){
			SPRLV = eval(document.calcForm.A_KakutyouSelNum.value);
			w1 = Math.floor((4 + n_A_MaxHP / 500) * SPRLV);
			w2 = Math.floor((2 + n_A_MaxSP / 500) * SPRLV);
			myInnerHtml("A_KakutyouData","<br>HP回復量："+w1+"<br>SP回復量："+w2,0);
		}else myInnerHtml("A_KakutyouData","",0);
	}
	else if(wKK == 5){
		syozijob =[0,800,400,400,600,200,800,800,400,600,700,400,1000,800,400,600,700,700,400,1000,0,800,400,600,700,400,1000,800,400,600,700,700,400,1000,0,800,400,400,600,200,800,800,800,400,600,800,1500,1200,1000,1200,1000,1800,1500,800,1000,1200,1200,1000,1200,600,600,0,800];
		syoziryou = 2000 + syozijob[n_A_JOB];
		if(n_A_PassSkill8[13]) syoziryou = 2000;
		syoziryou += eval(document.calcForm.A_STR.value) * 30;
		if(SkillSearch(78)) syoziryou += 1000;
		if(SkillSearch(446) >= 2) syoziryou += (500 + 200 * (SkillSearch(446) -1));
		if(GetLowerJobSeriesID(n_A_JOB)==6||n_A_JOB==20 || n_A_JOB==61) syoziryou += eval(document.calcForm.A_KakutyouSelNum.value) * 200;
		EquipKG = 0;
		for(i=0;i<=10;i++) EquipKG += ItemObjNew[n_A_Equip[i]][ITEM_DATA_INDEX_WEIGHT];
		myInnerHtml("A_KakutyouData","所持限界量："+syoziryou+"<BR>装備品重量合計："+EquipKG,0);
	}
	else if(wKK == 6){
		CBIstr = "<Font size=2><B>";
		for(i=0;i <= 9;i++){
			if(n_A_zokusei[i]==100){
				wkk6a = "";
				wkk6b = "";
			}
			if(n_A_zokusei[i]<100){
				wkk6a = "<Font color=blue>";
				wkk6b = "</Font>";
			}
			if(n_A_zokusei[i]>100){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a + ZokuseiOBJ[i] +"　"+n_A_zokusei[i] +" %" + wkk6b +"<BR>";
		}
		CBIstr += "</B></Font>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}
	else if(wKK == 7){
		CBIstr = "<Font size=2><B>";
		for(i=50;i <= 59;i++){
			if(n_tok[i]==0){
				wkk6a = "";
				wkk6b = "";
			}
			if(n_tok[i]>0){
				wkk6a = "<Font color=blue>";
				wkk6b = "</Font>";
			}
			if(n_tok[i]<0){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a + SyuzokuOBJ[i-50] +"　"+ n_tok[i] +" %" + wkk6b +"<BR>";
		}
		CBIstr += "</B></Font>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}

	// 状態異常耐性
	else if(wKK == 8){

		// 装備効果等による耐性
		var registByEffect = new Array();

		// 装備効果による上昇
		for (var idx = 0; idx <= 9; idx++) {
			registByEffect[idx] = n_tok[ITEM_SP_REGIST_STATE_POISON + idx];
		}

		// 不死属性付与による、凍結、石化耐性
		if (n_A_BodyZokusei == ELM_ID_UNDEAD) {
			registByEffect[STATE_ID_FROZEN] = 100;
			registByEffect[STATE_ID_STONE] = 100;
		}


		// ステータスによる基本耐性
		var registByStatus = new Array();
		registByStatus[STATE_ID_POISON]	 = n_A_VIT;
		registByStatus[STATE_ID_STUN]	 = n_A_VIT;
		registByStatus[STATE_ID_FROZEN]	 = n_A_MDEF;
		registByStatus[STATE_ID_CURSED]	 = n_A_LUK;
		registByStatus[STATE_ID_BLIND]	 = n_A_INT;
		registByStatus[STATE_ID_SLEEP]	 = n_A_AGI;
		registByStatus[STATE_ID_SILENCE] = n_A_INT;
		registByStatus[STATE_ID_CONFUSE] = n_A_LUK;
		registByStatus[STATE_ID_BLEEDING]= n_A_AGI;
		registByStatus[STATE_ID_STONE]	 = n_A_MDEF;

		// LUK0 による呪い完全耐性
		if(n_A_LUK == 0) {
			registByStatus[STATE_ID_CURSED] = 100;
		}


		//--------------------------------
		// HTML組立
		//--------------------------------
		CBIstr = "<TABLE border=\"1\"><TBODY><TR><TD>異常</TD><TD>装備耐性</TD><TD>ステ耐性</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			CBIstr += "<TR><TD>" + GetStateText(idx) + "</TD>";
			CBIstr += "<TD align=\"center\">" + registByEffect[idx] + " %</TD>";
			CBIstr += "<TD align=\"center\">" + registByStatus[idx] + " %</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}


	else if(wKK == 9){
		CBIstr = "<Font size=2><B>";
		wkk9w = ["ボスモンスター","遠距離攻撃","一般モンスター"];
		for(i=77;i <= 79;i++){
			if(n_tok[i]==0){
				wkk6a = "";
				wkk6b = "";
			}
			if(n_tok[i]>0){
				wkk6a = "<Font color=blue>";
				wkk6b = "</Font>";
			}
			if(n_tok[i]<0){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a + wkk9w[i-77] +"耐性　"+ n_tok[i] +" %" + wkk6b +"<BR>";
		}
		for(i=190;i <= 192;i++){
			if(n_tok[i]==0){
				wkk6a = "";
				wkk6b = "";
			}
			if(n_tok[i]>0){
				wkk6a = "<Font color=blue>";
				wkk6b = "</Font>";
			}
			if(n_tok[i]<0){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a + SizeOBJ[i-190] +"耐性　"+ n_tok[i] +" %" + wkk6b +"<BR>";
		}
		if(n_B[0] != 787){
			if((n_tok[57] + n_tok[243]) == 0){
				wkk6a = "";
				wkk6b = "";
			}
			if((n_tok[57] + n_tok[243]) <0){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			if((n_tok[57] + n_tok[243]) > 0){
				wkk6a = "<Font color=blue>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a +"プレイヤー耐性+人間形耐性　"+ (n_tok[57] + n_tok[243]) +" %" + wkk6b +"<BR>";
		}else{
			if(n_tok[57] == 0){
				wkk6a = "";
				wkk6b = "";
			}
			if(n_tok[57] <0){
				wkk6a = "<Font color=red>";
				wkk6b = "</Font>";
			}
			if(n_tok[57] > 0){
				wkk6a = "<Font color=bule>";
				wkk6b = "</Font>";
			}
			CBIstr += wkk6a +"プレイヤー耐性+人間形耐性　"+ n_tok[57] +" %" + wkk6b +"<BR>";
		}
		CBIstr += "</B></Font>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}else if(wKK == 10){
		var wkk10 = "詠唱時間：";
		if(n_A_CAST == 1) wkk10 += "100%<BR>";
		else if(n_A_CAST > 1) wkk10 += "<Font color='red'>"+ Math.round(n_A_CAST *10000)/100+"%</Font><BR>";
		else wkk10 += "<Font color='blue'>"+ Math.round(n_A_CAST *10000)/100+"%</Font><BR>";

		// 装備効果の表示
		if (n_CastCutForDisp > 100) {
			wkk10 += "<Font color='red'>（装備効果：" + (n_CastCutForDisp - 100) + "%増加）</Font><BR>";
		}
		else if (n_CastCutForDisp < 100) {
			wkk10 += "<Font color='blue'>（装備効果：" + ((n_CastCutForDisp - 100) * -1) + "%短縮）</Font><BR>";
		}
		else {
			wkk10 += "（装備効果：0%）<BR>";
		}

		wkk10 += "<BR>";

		wkk10 += "ディレイ時間：";
		if(n_tok[ITEM_SP_SKILL_DELAY_DOWN] == 0) wkk10 += "100%<BR>";
		else if(n_tok[ITEM_SP_SKILL_DELAY_DOWN] <0) wkk10 += "<Font color='red'>"+ Math.round((100 - n_tok[ITEM_SP_SKILL_DELAY_DOWN]) *100)/100 +"%</Font><BR>";
		else wkk10 += "<Font color='blue'>"+ Math.round((100 - n_tok[ITEM_SP_SKILL_DELAY_DOWN]) *100)/100 +"%</Font><BR>";

		wkk10 += "<BR>";

		wkk10 += "SP消費量：";
		if(n_tok[102] >= 0 || (n_tok[102] <0 && n_tok[102] == -100)){
			var w = n_tok[102];
			if(w <0) w = w * -1 * 1.25;
			if(w == 100) wkk10 += "100%";
			else if(w > 100) wkk10 += "<Font color='red'>"+ w +"%</Font>";
			else wkk10 += "<Font color='blue'>"+ w +"%</Font>";
		}else{
			var w = n_tok[102] * -1;
			if(w * 1.25 == 100) wkk10 += "100%";
			else if(w * 1.25 > 100) wkk10 += "約<Font color='red'>"+ (w * 1.25) +"%</Font>("+ w +"% x 125%)";
			else wkk10 += "約<Font color='blue'>"+ (w * 1.25) +"%</Font>("+ w +"% x 125%)";
		}
		myInnerHtml("A_KakutyouData",wkk10,0);
	}

	// 経験値表示
	else if(wKK == 11){
		var NowBaseExp = eval(document.calcForm.A_KakutyouSelNum.value);
		var NowJobExp = eval(document.calcForm.A_KakutyouSelNum2.value);
		if(!(0 <= NowBaseExp && NowBaseExp <= 100)){
			NowBaseExp = 0;
			document.calcForm.A_KakutyouSelNum.value = 0;
		}
		if(!(0 <= NowJobExp && NowJobExp <= 100)){
			NowJobExp = 0;
			document.calcForm.A_KakutyouSelNum2.value = 0;
		}

		var BaseType = 0;
		var JobType = 0;
		if(21 <= n_A_JOB && n_A_JOB <= 40) BaseType = 1;
		if(n_A_JOB == 34) JobType = 1;
		if((1 <= n_A_JOB && n_A_JOB <= 6) || n_A_JOB == 41) JobType = 2;
		if(35 <= n_A_JOB && n_A_JOB <= 40) JobType = 3;
		if((7 <= n_A_JOB && n_A_JOB <= 19) || n_A_JOB == 43) JobType = 4;
		if(21 <= n_A_JOB && n_A_JOB <= 33) JobType = 5;
		if(n_A_JOB == 42) JobType = 7;
		if(n_A_JOB == 44 || n_A_JOB == 45) JobType = 6;
		if(46 <= n_A_JOB && n_A_JOB <= 62){
			BaseType = 1;
			JobType = 8;
		}
		if(n_A_JOB == 20) JobType = 9;

		// ベース経験値計算
		var wkk11;
		var MonsterNum = 0;
		var OneCheck = 0;
		var MaxLV = GetBaseLevelMax(n_A_JOB);

		NowBaseExp = Math.floor(PC_BaseExp[BaseType][n_A_BaseLV] * NowBaseExp / 100);
		if(n_A_BaseLV == MaxLV) {
			wkk11 = "<Font size=2>BaseLvアップに必要なBaseExp：<B>"+ 0 +"</B>exp<BR>";
		}
		else {
			wkk11 = "<Font size=2>BaseLvアップに必要なBaseExp：<B>"+ Kanma(PC_BaseExp[BaseType][n_A_BaseLV] - NowBaseExp) +"</B>exp<BR>";
		}

		if (n_B[15] != 0) {

			for(i = n_A_BaseLV; i < MaxLV; i++){

				var LvUpExp = PC_BaseExp[BaseType][i];
				var w1 = Math.floor((LvUpExp - NowBaseExp) / n_B[15]);

				MonsterNum += w1;
				NowBaseExp += w1 * n_B[15];

				while (NowBaseExp < LvUpExp) {
					NowBaseExp += n_B[15];
					MonsterNum += 1;
				}

				if (OneCheck == 0) {
					OneCheck = 1;
					wkk11 += "(<B>"+ n_B[1] +" "+ Kanma(MonsterNum) +"</B>匹)<BR>";
				}

				NowBaseExp -= LvUpExp;
				if(NowBaseExp > LvUpExp - 1) {
					NowBaseExp = LvUpExp -1;
				}
			}

			wkk11 += "BaseLv"+ MaxLV +"になるまで"+ n_B[1] +"<B>"+ Kanma(MonsterNum) +"</B>匹<BR><BR>";
		}


		// ジョブ経験値計算
		MonsterNum = 0;
		OneCheck = 0;
		var MaxJobLV = GetJobLevelMax(n_A_JOB);

		NowJobExp = Math.floor(PC_JobExp[JobType][n_A_JobLV] * NowJobExp / 100);
		if(n_A_JobLV == MaxJobLV) {
			wkk11 += "<Font size=2>JobLvアップに必要なJobExp：<B>"+ 0 +"</B>exp<BR>";
		}
		else {
			wkk11 += "JobLvアップに必要なJobExp：<B>"+ Kanma(PC_JobExp[JobType][n_A_JobLV] - NowJobExp) +"</B>exp<BR>";
		}

		if (n_B[16] != 0) {

			for (i = n_A_JobLV; i < MaxJobLV; i++) {

				var LvUpExp = PC_JobExp[JobType][i];
				var w1 = Math.floor((LvUpExp - NowJobExp) / n_B[16]);

				MonsterNum += w1;
				NowJobExp += w1 * n_B[16];

				while (NowJobExp < LvUpExp) {
					NowJobExp += n_B[16];
					MonsterNum += 1
				}

				if(OneCheck == 0){
					OneCheck = 1;
					wkk11 += "(<B>"+ n_B[1] +" "+ Kanma(MonsterNum) +"</B>匹)<BR>";
				}

				NowJobExp -= LvUpExp;
				if(NowJobExp > LvUpExp -1) {
					NowJobExp = LvUpExp -1;
				}
			}

			wkk11 += "JobLv"+ MaxJobLV +"になるまで"+ n_B[1] +"<B>"+ Kanma(MonsterNum) +"</B>匹<BR>";
		}

		wkk11 += "</Font>";
		myInnerHtml("A_KakutyouData",wkk11,0);
	}


	//------------------------------------------------------------------------------------------------
	// 物理特化
	//------------------------------------------------------------------------------------------------
	else if (wKK == 12) {

		CBIstr = "<TABLE><TBODY><TR>";

		//--------------------------------
		// 種族特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-種族-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetRaceText(idx);
			spcVal = n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_RACE_SOLID + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// 属性特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-敵属性-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetElementText(idx);
			spcVal = n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_MONSTER_ELM_VANITY + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// その他特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-サイズ-</TD></TR>";
		for (idx = 0; idx <= 2; idx++) {
			spcTtl = GetSizeText(idx);
			spcVal = n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_SIZE_SMALL + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "<TR><TD colspan=2>　</TD></TR>";
		CBIstr += "<TR><TD colspan=2>-ボス-</TD></TR>";
		for (idx = 0; idx <= 0; idx++) {
			spcTtl = "ボス";
			spcVal = n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP_BOSS + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "<TR><TD colspan=2>　</TD></TR>";
		CBIstr += "<TR><TD colspan=2>-物理UP-</TD></TR>";
		for (idx = 0; idx <= 0; idx++) {
			spcTtl = "物理";
			spcVal = n_tok[ITEM_SP_PHYSICAL_DAMAGE_UP + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// 防御無視
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-防御無視-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetRaceText(idx);
			spcVal = n_tok[ITEM_SP_IGNORE_DEF_RACE_SOLID + idx];
			spcVal += n_tok[ITEM_SP_IGNORE_DEF_RACE_ALL];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "</TR></TBODY></TABLE>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}


	//------------------------------------------------------------------------------------------------
	// 魔法特化
	//------------------------------------------------------------------------------------------------
	else if (wKK == 13) {

		CBIstr = "<TABLE><TBODY><TR>";

		//--------------------------------
		// 種族特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-種族-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetRaceText(idx);
			spcVal = n_tok[ITEM_SP_MAGIC_DAMAGE_UP_RACE_SOLID + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// 属性特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-敵属性-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetElementText(idx);
			spcVal = n_tok[ITEM_SP_MAGIC_DAMAGE_UP_MONSTER_ELM_VANITY + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// 属性魔法
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-属性魔法-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetElementText(idx);
			spcVal = n_tok[ITEM_SP_MAGIC_DAMAGE_UP_ELM_VANITY + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// その他特化
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-サイズ-</TD></TR>";
		for (idx = 0; idx <= 2; idx++) {
			spcTtl = GetSizeText(idx);
			spcVal = n_tok[ITEM_SP_MAGIC_DAMAGE_UP_SIZE_SMALL + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "<TR><TD colspan=2>　</TD></TR>";
		CBIstr += "<TR><TD colspan=2>-ボス-</TD></TR>";
		for (idx = 0; idx <= 0; idx++) {
			spcTtl = "ボス";
			spcVal = n_tok[ITEM_SP_MAGIC_DAMAGE_UP_BOSS + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "<TR><TD colspan=2>　</TD></TR>";
		CBIstr += "<TR><TD colspan=2>-魔法UP-</TD></TR>";
		for (idx = 0; idx <= 0; idx++) {
			spcTtl = "魔法";
			spcVal = n_tok[ITEM_SP_MAGICAL_DAMAGE_UP + idx];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "<TD>　</TD>";

		//--------------------------------
		// 防御無視
		//--------------------------------
		CBIstr += "<TD valign=\"top\"><TABLE><TBODY>";
		CBIstr += "<TR><TD colspan=2>-防御無視-</TD></TR>";
		for (idx = 0; idx <= 9; idx++) {
			spcTtl = GetRaceText(idx);
			spcVal = n_tok[ITEM_SP_IGNORE_MDEF_RACE_SOLID + idx];
			spcVal += n_tok[ITEM_SP_IGNORE_MDEF_RACE_ALL];

			spcFontColor = "black";
			if (spcVal > 0) spcFontColor = "blue";
			else if (spcVal < 0) spcFontColor = "red";

			CBIstr += "<TR><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcTtl +"</B></Font>";
			CBIstr += "</TD><TD>";
			CBIstr += "<Font size=2 color=" + spcFontColor + "><B>" + spcVal +" %" + "</B></Font>";
			CBIstr += "</TD></TR>";
		}
		CBIstr += "</TBODY></TABLE></TD>";

		CBIstr += "</TR></TBODY></TABLE>";
		myInnerHtml("A_KakutyouData",CBIstr,0);
	}

}
function Kanma(num){
	var str = "";
	var x = new Array();
	if(num <0){
		num = num * -1;
		str += "-";
	}
	for(var i=0;Math.floor(num / 1000) != 0;i++){
		var w = (num % 1000);
		if(w == 0){
			x[i] = ",000";
		}else if(w <10){
			x[i] = ",00" + w;
		}else if(w <100){
			x[i] = ",0" + w;
		}else{
			x[i] = "," + w;
		}
		num = Math.floor(num / 1000);
	}
	x[i] = num;
	while(i>=0){
		str += x[i];
		i--;
	}
	return str;
}
function ROUNDDOWN(num){
	if(num >= 0){
		num = Math.floor(num) }else{
			num = Math.floor(-1 * num);
			num = (-1 * num);
		}
	return num;
}
function KakutyouKansuu2(){
	wKK = eval(document.calcForm.A_Kakutyou.value);
	if(wKK == 1){
		var wStr = "";
		if(GetHigherJobSeriesID(n_A_JOB)==9 || GetHigherJobSeriesID(n_A_JOB)==14 || n_A_JOB==61) wStr += '<select name="A_KakutyouSelNum"onChange="StAllCalc()"></select><BR>';
		wStr += '<select name="A_KakutyouSelNum2"onChange="StAllCalc()"></select><BR>';
		myInnerHtml("A_KakutyouSel",wStr,0);
		if(GetHigherJobSeriesID(n_A_JOB)==9 || GetHigherJobSeriesID(n_A_JOB)==14 || n_A_JOB==61) document.calcForm.A_KakutyouSelNum.options[0] = new Option(SkillObjNew[25][SKILL_DATA_INDEX_NAME],0);
		if(n_A_JOB==48 || n_A_JOB==53){
			document.calcForm.A_KakutyouSelNum.options[1] = new Option(SkillObjNew[489][SKILL_DATA_INDEX_NAME],1);
			document.calcForm.A_KakutyouSelNum.options[2] = new Option(SkillObjNew[94][SKILL_DATA_INDEX_NAME],2);
		}else if(GetHigherJobSeriesID(n_A_JOB)==9 || GetHigherJobSeriesID(n_A_JOB)==14 || n_A_JOB==61) document.calcForm.A_KakutyouSelNum.options[1] = new Option(SkillObjNew[94][SKILL_DATA_INDEX_NAME],2);
		document.calcForm.A_KakutyouSelNum2.options[0] = new Option("自分へ使った時の回復量",0);
		document.calcForm.A_KakutyouSelNum2.options[1] = new Option("他人へ使った時の回復量",1);
		return;
	}
	if(wKK == 2){
		if(GetLowerJobSeriesID(n_A_JOB)==1||n_A_JOB==20 || n_A_JOB==61){
			myInnerHtml("A_KakutyouSel","HP回復力向上LV：" + '<select name="A_KakutyouSelNum"onChange="StAllCalc()"></select>',0);
			for(i=0;i<=10;i++) document.calcForm.A_KakutyouSelNum.options[i] = new Option(i,i);
			document.calcForm.A_KakutyouSelNum.value=10;
			return;
		}else{
			myInnerHtml("A_KakutyouSel","使用不可職業",0);
			return;
		}
	}
	if(wKK == 3){
		if(GetLowerJobSeriesID(n_A_JOB)==5||GetHigherJobSeriesID(n_A_JOB)==9||n_A_JOB==20 || n_A_JOB==61||GetLowerJobSeriesID(n_A_JOB)==44){
			SPRname = "SP回復力向上LV：";
			if(GetLowerJobSeriesID(n_A_JOB)==44) SPRname = "忍法修練LV：";
			myInnerHtml("A_KakutyouSel",SPRname + '<select name="A_KakutyouSelNum"onChange="StAllCalc()"></select>',0);
			for(i=0;i<=10;i++) document.calcForm.A_KakutyouSelNum.options[i] = new Option(i,i);
			document.calcForm.A_KakutyouSelNum.value=10;
			return;
		}else{
			myInnerHtml("A_KakutyouSel","使用不可職業",0);
			return;
		}
	}
	if(wKK == 4){
		if(GetHigherJobSeriesID(n_A_JOB)==15){
			myInnerHtml("A_KakutyouSel","息吹LV：" + '<select name="A_KakutyouSelNum"onChange="StAllCalc()"></select>',0);
			for(i=0;i<=5;i++) document.calcForm.A_KakutyouSelNum.options[i] = new Option(i,i);
			document.calcForm.A_KakutyouSelNum.value=5;
			return;
		}else{
			myInnerHtml("A_KakutyouSel","使用不可職業",0);
			return;
		}
	}
	if(wKK == 5){
		if(GetLowerJobSeriesID(n_A_JOB)==6 || n_A_JOB==20 || n_A_JOB==61){
			myInnerHtml("A_KakutyouSel","所持限界量増加スキル：" + '<select name="A_KakutyouSelNum"onChange="StAllCalc()"></select><BR>',0);
			for(i=0;i<=10;i++) document.calcForm.A_KakutyouSelNum.options[i] = new Option(i,i);
			if(n_A_JOB==20 || n_A_JOB==61) document.calcForm.A_KakutyouSelNum.value=0;
			else document.calcForm.A_KakutyouSelNum.value=5;
		}else{
			myInnerHtml("A_KakutyouSel","",0);
		}
		return;
	}
	if(wKK == 11){
		var w;
		w = '<Font size="2">現在のBaseExpゲージ<input type="text" name="A_KakutyouSelNum" value="0" size=4 onChange="StAllCalc()" style="text-align : right;">%<BR>';
		w += '現在のJobExp ゲージ<input type="text" name="A_KakutyouSelNum2" value="0" size=4 onChange="StAllCalc()" style="text-align : right;">%<BR></Font>';
		myInnerHtml("A_KakutyouSel",w,0);
		return;
	}
	myInnerHtml("A_KakutyouSel","",0);
}
function SetCardShort(){
	with(document.calcForm){
		w = eval(A_cardshort.value);
		if(CardShort[w][1] <10000){
			var wX1 = Math.floor(ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_RIGHT]][ITEM_DATA_INDEX_WPNLV] / 10);
			if(n_EnchantType[wX1][0] == 0) A_weapon1_card1.value = CardShort[w][1];
			if(n_EnchantType[wX1][1] == 0) A_weapon1_card2.value = CardShort[w][2];
			if(n_EnchantType[wX1][2] == 0) A_weapon1_card3.value = CardShort[w][3];
			if(n_EnchantType[wX1][3] == 0) A_weapon1_card4.value = CardShort[w][4];
			if(w == 9 || w == 10){
				w = MonsterObjNew[eval(B_Enemy.value)][18];
				if(10 <= w && w <= 14) A_weapon1_card1.value = 204;
				if((20 <= w && w <= 24) || (80 <= w && w <= 94)) A_weapon1_card1.value = 203;
				if(30 <= w && w <= 34) A_weapon1_card1.value = 201;
				if(40 <= w && w <= 44) A_weapon1_card1.value = 202;
			}
		}else{
			if(CardShort[w][2] != 0) A_weapon1_card1.value = CardShort[w][2];
			if(CardShort[w][3] != 0) A_head1_card.value = CardShort[w][3];
			if(CardShort[w][4] != 0) A_left_card.value = CardShort[w][4];
			if(CardShort[w][5] != 0) A_body_card.value = CardShort[w][5];
			if(CardShort[w][6] != 0) A_shoulder_card.value = CardShort[w][6];
			if(CardShort[w][7] != 0) A_shoes_card.value = CardShort[w][7];
			if(CardShort[w][8] != 0) A_acces1_card.value = CardShort[w][8];
			if(CardShort[w][9] != 0) A_acces2_card.value = CardShort[w][9];
		}
		ActiveSkillSetPlus();
	}}
function SetCardShortLeft(){
	with(document.calcForm){
		w = eval(A_cardshortLeft.value);
		var wX1 = Math.floor(ItemObjNew[n_A_Equip[EQUIP_REGION_ID_ARMS_LEFT]][ITEM_DATA_INDEX_WPNLV] / 10);
		if(n_EnchantType[wX1][0] == 0) A_weapon2_card1.value = CardShort[w][1];
		if(n_EnchantType[wX1][1] == 0) A_weapon2_card2.value = CardShort[w][2];
		if(n_EnchantType[wX1][2] == 0) A_weapon2_card3.value = CardShort[w][3];
		if(n_EnchantType[wX1][3] == 0) A_weapon2_card4.value = CardShort[w][4];
		if(w == 9 || w == 10){
			w = MonsterObjNew[eval(B_Enemy.value)][18];
			if(10 <= w && w <= 14) A_weapon2_card1.value = 204;
			if((20 <= w && w <= 24) || (80 <= w && w <= 94)) A_weapon2_card1.value = 203;
			if(30 <= w && w <= 34) A_weapon2_card1.value = 201;
			if(40 <= w && w <= 44) A_weapon2_card1.value = 202;
		}
	}}
wESx = new Array();
for(i=0;i<=EnemyNum;i++) wESx[i]=new Array();
function EnemySort(){
	var len = document.calcForm.B_Enemy.length;
	for(var i=0;i<len;i++) document.calcForm.B_Enemy.options[0] = null;
	ESNum= [1,18,19,32,33,15,16,31,3,100];
	var wES2 = eval(document.calcForm.ENEMY_SORT.value);
	if(wES2==0){
		var x = new Array();
		for(var i=0;i<=EnemyNum;i++) x[i] = MonsterABC[i];
		x = SZ(x);
		var j=0;
		for(var i=0;i<=EnemyNum;i++){
			if(x[i] != -1){
				document.calcForm.B_Enemy.options[j] = new Option(MonsterObjNew[x[i]][1],x[i]);
				j++;
			}
		}
		return;
	}
	wES = ESNum[eval(document.calcForm.ENEMY_SORT.value)];
	wESx[0][0] = "S";
	wESx[0][1] = "E";
	STERTw = 0;
	ENDw = 0;
	for(i=1;i<=EnemyNum;i++){
		j=ENDw;
		if(MonsterObjNew[i][wES] >= MonsterObjNew[j][wES]){
			wESx[j][1] = i;
			wESx[i][0] = j;
			wESx[i][1] = "E";
			ENDw=i;
		}else{
			j=STERTw;
			if(MonsterObjNew[i][wES] <= MonsterObjNew[j][wES]){
				wESx[j][0] = i;
				wESx[i][0] = "S";
				wESx[i][1] = j;
				STERTw=i;
			}else{
				j=STERTw;
				jbk=STERTw;
				while(MonsterObjNew[i][wES] > MonsterObjNew[j][wES]){
					jbk=j;
					j = wESx[j][1];
				}
				wESx[jbk][1] = i;
				wESx[i][0] = jbk;
				wESx[i][1] = j;
				wESx[j][0] = i;
			}
		}
	}
	var x = new Array();
	var i;
	x[0] = i = STERTw;
	for(var j=1;wESx[i][1]!="E";j++){
		x[j] = wESx[i][1];
		i = wESx[i][1];
	}
	x = SZ(x);
	ESwork2 = new Array();
	if(wES==32 || wES==33){
		for(i=0;i<=EnemyNum;i++) ESwork2[i] = MonsterObjNew[i][wES] +")";
	}
	else if(wES==19){
		for(i=0;i<=EnemyNum;i++) ESwork2[i] = SyuzokuOBJ[MonsterObjNew[i][19]] +")";
	}
	else if(wES==18){
		for(i=0;i<=EnemyNum;i++) ESwork2[i] = ZokuseiOBJ[Math.floor(MonsterObjNew[i][18] /10)] + MonsterObjNew[i][18] % 10 +")";
	}
	else{
		for(i=0;i<=EnemyNum;i++) ESwork2[i] = "";
	}
	var j=0;
	for(i=0;i<=EnemyNum;i++){
		if(x[i] != -1){
			document.calcForm.B_Enemy.options[j] = new Option(ESwork2[x[i]] + MonsterObjNew[x[i]][1],x[i]);
			j++;
		}
	}
}




function SZ(wSTR){
	var w = document.calcForm.ENEMY_SORT2.value;
	if(w != 0){
		for(var i=0;i<=EnemyNum;i++){
			if(wSTR[i] != -1){
				for(var j=0;MonMap[w][j] != "N";j++){
					if(wSTR[i] == MonMap[w][j]) break;
				}
				if(MonMap[w][j] == "N") wSTR[i] = -1;
			}
		}
	}
	return wSTR;
}









JobName = [
	"ノービス"
	,"ソードマン"
	,"シーフ"
	,"アコライト"
	,"アーチャー"
	,"マジシャン"
	,"マーチャント"

	,"ナイト"
	,"アサシン"
	,"プリースト"
	,"ハンター"
	,"ウィザード"
	,"ブラックスミス"
	,"クルセイダー"
	,"ローグ"
	,"モンク"
	,"バード"
	,"ダンサー"
	,"セージ"
	,"アルケミスト"
	, "スーパーノービス"

	,"ロードナイト"
	,"アサシンクロス"
	,"ハイプリースト"
	,"スナイパー"
	,"ハイウィザード"
	,"ホワイトスミス"
	,"パラディン"
	,"チェイサー"
	,"チャンピオン"
	,"クラウン"
	,"ジプシー"
	,"プロフェッサー"
	,"クリエイター"

	, "ハイ ノービス"
	,"ハイ ソードマン"
	,"ハイ シーフ"
	,"ハイ アコライト"
	,"ハイ アーチャー"
	,"ハイ マジシャン"
	,"ハイ マーチャント"

	,"テコン"
	,"拳聖"
	,"ソウルリンカー"
	,"忍者"
	,"ガンスリンガー"

	, "ルーンナイト"
	,"ギロチンクロス"
	,"アークビショップ"
	,"レンジャー"
	,"ウォーロック"
	,"メカニック"
	,"ロイヤルガード"
	,"シャドウチェイサー"
	,"修羅"
	,"ミンストレル"
	,"ワンダラー"
	,"ソーサラー"
	,"ジェネティック"

	,"影狼"
	,"朧"
	,"スーパーノービス+"
	,"リベリオン"
];


// 職業選択セレクトボックスの構築
for (i = 0; i < 21; i++) {
	document.calcForm.A_JOB.options[i] = new Option(JobName[i], i);
}
document.calcForm.A_JOB.options[i++] = new Option(JobName[61], 61);
for (i; i <= 61; i++) {
	document.calcForm.A_JOB.options[i] = new Option(JobName[i - 1], i - 1);
}
for (i; i < JobName.length; i++) {
	document.calcForm.A_JOB.options[i] = new Option(JobName[i], i);
}



SpeedPotName = ["なし","スピードアップポーション","ハイスピードポーション","バーサークポーション"];
document.calcForm.A_SpeedPOT.options[0] = new Option(SpeedPotName[0],0);
document.calcForm.A_SpeedPOT.options[1] = new Option(SpeedPotName[1],1);



for (i=0;i<ArrowOBJWork.length;i++) document.calcForm.A_Arrow.options[i] = new Option(ArrowOBJWork[i][2],i);



EnName =["なし","水","地","火","風","毒","聖","闇","念","死"];
for (i=0;i<=9;i++) document.calcForm.A_Weapon_zokusei.options[i] = new Option(EnName[i],i);



CardShort =[ ["カードショートカット",0,0,0,0], ["武器カード全解除",0,0,0,0], ["+20%",1,0,0,0], ["+40%",1,1,0,0], ["+60%",1,1,1,0], ["+80%",1,1,1,1], ["サイズ特化2枚",3,3,0,0], ["サイズ特化3枚",3,3,3,0], ["サイズ特化4枚",3,3,3,3], ["特化属性+星",0,106,0,0], ["特化属性+星2",0,106,106,0], ["星のかけら3",106,106,106,0], ["ヒルスリオン2枚",497,497,0,0], ["ヒルスリオン3枚",497,497,497,0], ["ヒルスリオン4枚",497,497,497,497], ["アンドレ2枚",11,11,0,0], ["アンドレ3枚",11,11,11,0], ["アンドレ4枚",11,11,11,11], ["チャッキー2枚",326,326,0,0], ["チャッキー3枚",326,326,326,0], ["チャッキー4枚",326,326,326,326], ["ソルスケ2枚",41,41,0,0], ["ソルスケ3枚",41,41,41,0], ["ソルスケ4枚",41,41,41,41], ["マミー2枚",40,40,0,0], ["マミー3枚",40,40,40,0], ["マミー4枚",40,40,40,40], ["+44%",1,2,0,0], ["+68%",1,1,2,0], ["+96%",1,1,2,2], ["オーク特化2枚",252,252,0,0], ["オーク特化3枚",252,252,13,0], ["オーク特化4枚",252,252,252,13], ["アチャスケ2枚",107,107,0,0], ["アチャスケ3枚",107,107,107,0], ["アチャスケ4枚",107,107,107,107], ["深淵2枚",31,31,0,0], ["深淵3枚",31,31,31,0], ["深淵4枚",31,31,31,31], ["ファブル2枚",4,4,0,0], ["ファブル3枚",4,4,4,0], ["ファブル4枚",4,4,4,4], ["ドロップス2枚",5,5,0,0], ["ドロップス3枚",5,5,5,0], ["ドロップス4枚",5,5,5,5], ["十七系2枚",156,156,0,0], ["十七系3枚",156,156,156,0], ["十七系4枚",156,156,156,156], ["剣士セット",10000,223,347,0,317,0,362,354,0], ["盗賊セット",10000,233,0,0,0,295,391,395,260], ["聖職セット",10000,253,383,307,301,0,0,270,0], ["弓手セット",10000,279,0,0,224,340,351,230,0], ["魔系セット",10000,0,337,358,220,346,379,350,0], ["商人セット",10000,326,376,0,281,0,388,216,0], ["クルセセット",10000,0,347,0,190,0,362,354,0], ["ローグセット",10000,0,113,0,0,295,391,260,413], ["モンクセット",10000,253,383,0,181,0,0,270,0], ["雷鳥セット",10000,279,0,0,224,340,408,230,0], ["セージセット",10000,0,337,0,193,346,379,350,0], ["アルケミセット",10000,326,175,0,281,0,388,104,0], ["test用(未)",0,0,0,0], ];
for(i=0;i<=59;i++) document.calcForm.A_cardshort.options[i] = new Option(CardShort[i][0],i);



var HSEname = ["STR","AGI","VIT","INT","DEX","LUK"];



tPlusTaiseiSyokia();



for(i=0;i<ITEM_SP_TIME_OBJ.length;i++){
	if(ITEM_SP_TIME_OBJ[i][3] == 1){
		var str = "<Font size='2'><B>(特殊効果の" + ITEM_SP_TIME_OBJ[i][2] +"状態で計算する機能はページ下の暫定追加機能にあります)</B></Font>";
		if(ItemObjNew[ITEM_SP_TIME_OBJ[i][4]][ITEM_DATA_INDEX_DETAIL] == 0) ItemObjNew[ITEM_SP_TIME_OBJ[i][4]][ITEM_DATA_INDEX_DETAIL] = str;
		else ItemObjNew[ITEM_SP_TIME_OBJ[i][4]][ITEM_DATA_INDEX_DETAIL] += "<BR>"+ str;
	}
}
for(i=0;i<ITEM_SP_TIME_OBJ.length;i++){
	if(ITEM_SP_TIME_OBJ[i][3] == 2){
		var str = "<Font size='2'><B>(特殊効果の" + ITEM_SP_TIME_OBJ[i][2] +"状態で計算する機能はページ下の暫定追加機能にあります)</B></Font>";
		if(CardObjNew[ITEM_SP_TIME_OBJ[i][4]][3] == 0) CardObjNew[ITEM_SP_TIME_OBJ[i][4]][3] = str;
		else CardObjNew[ITEM_SP_TIME_OBJ[i][4]][3] += "<BR>"+ str;
	}
}





n_A_JOB = 0;
Init();
document.calcForm.A_JOB.value = 0;
ClickJob(0);
if(Taijin==0) EnemySort();
CalcStatusPoint(true);
calc();
LoadCookieConf();
LoadCookie3();
function DEBUG(){
	for(var i=1;i<=19;i++){
		var w = SaveDataAll[i].search("undefined");
		if(w != -1){
			var wstr = SaveDataAll[i].substr(0,w);
			SaveDataAll[i] = wstr + "a999";
		}
	}
}







DEBUG();
URLIN();
function Init(){
	document.calcForm.A_Weapon_zokusei.value = 0;
	n_A_Weapon_zokusei = 0;
	document.calcForm.A_Weapon_ATKplus.value = 0;
	n_A_Weapon_ATKplus = 0;
	document.calcForm.A_HEAD_DEF_PLUS.value = 0;
	document.calcForm.A_BODY_DEF_PLUS.value = 0;
	document.calcForm.A_LEFT_DEF_PLUS.value = 0;
	document.calcForm.A_SHOULDER_DEF_PLUS.value = 0;
	document.calcForm.A_SHOES_DEF_PLUS.value = 0;
	n_A_HEAD_DEF_PLUS = 0;
	n_A_BODY_DEF_PLUS = 0;
	n_A_LEFT_DEF_PLUS = 0;
	n_A_SHOULDER_DEF_PLUS = 0;
	n_A_SHOES_DEF_PLUS = 0;
	n_A_card = new Array();
	for(i=0;i<=53;i++) n_A_card[i] = 0;
	document.calcForm.A_weapon1_card1.value = 0;
	document.calcForm.A_weapon1_card2.value = 0;
	document.calcForm.A_weapon1_card3.value = 0;
	document.calcForm.A_weapon1_card4.value = 0;
	document.calcForm.A_head1_card.value = 0;
	document.calcForm.A_head2_card.value = 0;
	document.calcForm.A_left_card.value = 0;
	document.calcForm.A_body_card.value = 0;
	document.calcForm.A_shoulder_card.value = 0;
	document.calcForm.A_shoes_card.value = 0;
	document.calcForm.A_acces1_card.value = 0;
	document.calcForm.A_acces2_card.value = 0;
	document.calcForm.A_isyou3.value = 0;
	n_A_PassSkill = new Array();
	for(i=0;i<=21;i++) n_A_PassSkill[i] = 0;
	n_A_PassSkill2 = new Array();
	for(i=0;i<=15;i++) n_A_PassSkill2[i] = 0;
	n_A_PassSkill3 = new Array();
	for(i=0;i<=46;i++) n_A_PassSkill3[i] = 0;
	n_A_PassSkill4 = new Array();
	for(i=0;i<=35;i++) n_A_PassSkill4[i] = 0;

	// オートスペル設定
	n_A_PassSkill5 = new Array();
	for (var idx = 0 ; idx < AUTO_SPELL_SETTING_COUNT; idx++) {
		n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_ID + idx] = 0;
		n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_LV + idx] = 0;
		n_A_PassSkill5[OBJID_OFFSET_AS_SKILL_PROB + idx] = 0;
	}

	n_A_PassSkill6 = new Array();
	for(i=0;i<=35;i++) n_A_PassSkill6[i] = 0;
	n_A_PassSkill7 = new Array();
	for(i=0;i<=51;i++) n_A_PassSkill7[i] = 0;
	n_A_PassSkill8 = new Array();
	for(i=0;i<=27;i++) n_A_PassSkill8[i] = 0;
	n_A_PassSkill9 = new Array();
	for(i=0;i<=30;i++) n_A_PassSkill9[i] = 0;
	n_A_PassSkill10 = new Array();
	for(i=0;i<=15;i++) n_A_PassSkill10[i] = 0;
	n_A_IJYOU = new Array();
	for(i=0;i<=5;i++) n_A_IJYOU[i] = 0;
	n_B_IJYOU = new Array();
	for(i=0;i<=41;i++) n_B_IJYOU[i] = 0;
	n_B_KYOUKA = new Array();
	for(i=0;i<=11;i++) n_B_KYOUKA[i] = 0;
	n_B_TAISEI = new Array();
	for(i=0;i<=38;i++) n_B_TAISEI[i] = 0;
	n_B_MAKE = new Array();
	for(i=0;i<=16;i++) n_B_MAKE[i] = 1;
	for(i=17;i<=24;i++) n_B_MAKE[i] = 0;
	n_A_Equip = new Array();
	for(i=0;i<=40;i++) n_A_Equip[i] = 0;
	n_Skill1SW=0;
	n_Skill2SW=0;
	n_Skill3SW=0;
	n_Skill4SW=0;
	n_Skill5SW=0;
	n_Skill6SW=0;
	n_Skill7SW=0;
	n_Skill8SW=0;
	n_Skill9SW=0;
	n_Skill10SW=0;
	n_IjyouSW = 0;
	n_KyoukaSW = 0;
	n_TaiseiSW = 0;
	n_B_MakeSW=0;
	document.calcForm.A1_SKILLSW.checked = 0;
	document.calcForm.A2_SKILLSW.checked = 0;
	document.calcForm.A3_SKILLSW.checked = 0;
	document.calcForm.A4_SKILLSW.checked = 0;

	// オートスペル設定欄
	objInput = document.getElementById("OBJID_EXTRACT_SETTING_AUTO_SPELL");
	if (objInput) {
		objInput.checked = 0;
	}

	document.calcForm.A6_SKILLSW.checked = 0;
	document.calcForm.A7_SKILLSW.checked = 0;
	document.calcForm.A8_SKILLSW.checked = 0;
	document.calcForm.A9_SKILLSW.checked = 0;
	document.calcForm.A10_SKILLSW.checked = 0;
	document.calcForm.B_IJYOUSW.checked = 0;
	document.calcForm.B_KYOUKASW.checked = 0;
	document.calcForm.B_TAISEISW.checked = 0;
	document.calcForm.B_MAKESW.checked = 0;
	Click_PassSkillSW();
	OnClickSkillSWLearned();
	Click_SkillSW();
	Click_Skill3SW();
	Click_Skill4SW();
	OnClickExtractSettingAutoSpell();
	Click_Skill6SW();
	Click_Skill7SW();
	Click_Skill8SW();
	Click_Skill9SW();
	Click_Skill10SW();
	Click_IjyouSW();
	Click_EnemyKyoukaSW();
	Click_EnemyTaiseiSW();
	Click_Monster_MakeSW();
	Click_CONFIG();
	myInnerHtml("C_HEAD1","",0);
	myInnerHtml("C_HEAD2","",0);
	myInnerHtml("C_HEAD3","",0);
	myInnerHtml("C_BODY","",0);
	myInnerHtml("C_LEFT","",0);
	myInnerHtml("C_SHO","",0);
	myInnerHtml("C_SHOE","",0);
	myInnerHtml("C_ACC1","",0);
	myInnerHtml("C_ACC2","",0);
}
